---------------------------------------------------------------------------------
--
-- Prat - A framework for World of Warcraft chat mods
--
-- Copyright (C) 2006-2011  Prat Development Team
--
-- This program is free software; you can redistribute it and/or
-- modify it under the terms of the GNU General Public License
-- as published by the Free Software Foundation; either version 2
-- of the License, or (at your option) any later version.
--
-- This program is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-- GNU General Public License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with this program; if not, write to:
--
-- Free Software Foundation, Inc.,
-- 51 Franklin Street, Fifth Floor,
-- Boston, MA  02110-1301, USA.
--
--
-------------------------------------------------------------------------------



--[[ BEGIN STANDARD HEADER ]] --

-- Imports
local _G = _G
local LibStub = LibStub
local tonumber = tonumber
local tostring = tostring
local pairs = pairs
local type = type
local Prat = select(2, ...)
local setmetatable = setmetatable
local tinsert = tinsert

-- Isolate the environment
setfenv(1, select(2, ...))

--[[ END STANDARD HEADER ]] --

local PL = Prat.Localizations


--[===[@debug@
PL:AddLocale(nil, "enUS", {
  prat = "Prat",
  ["display_name"] = "Display Settings",
  ["display_desc"] = "Chat Frame Control and Look",
  ["formatting_name"] = "Chat Formatting",
  ["formatting_desc"] = "Change the way the lines look and feel",
  ["extras_name"] = "Extra Stuff",
  ["extras_desc"] = "Msc. Modules",
  ["modulecontrol_name"] = "Module Control",
  ["modulecontrol_desc"] = "Control the loading and enabling of Prat's modules.",
  ["reload_required"] = "This option change may not take full effect until you %s your UI.",
  load_no = "Don't Load",
  load_disabled = "Disabled",
  load_enabled = "Enabled",
  load_desc = "Control the load behavior for this module.",
  load_disabledonrestart = "Disabled (reload)",
  load_enabledonrestart = "Enabled (reload)",
})
--@end-debug@]===]

-- These Localizations are auto-generated. To help with localization
-- please go to http://www.wowace.com/projects/prat-3-0/localization/


  --@non-debug@
do
    local L

L=
{
	["display_desc"] = "Chat Frame Control and Look",
	["display_name"] = "Display Settings",
	["extras_desc"] = "Msc. Modules",
	["extras_name"] = "Extra Stuff",
	["formatting_desc"] = "Change the way the lines look and feel",
	["formatting_name"] = "Chat Formatting",
	["load_desc"] = "Control the load behavior for this module.",
	["load_disabled"] = "Disabled",
	["load_disabledonrestart"] = "Disabled (reload)",
	["load_enabled"] = "Enabled",
	["load_enabledonrestart"] = "Enabled (reload)",
	["load_no"] = "Don't Load",
	["modulecontrol_desc"] = "Control the loading and enabling of Prat's modules.",
	["modulecontrol_name"] = "Module Control",
	["prat"] = "Prat",
	["reload_required"] = "This option change may not take full effect until you %s your UI.",
	["AddonMsgs"] = {
		["Addon message options."] = true,
		["AddonMsgs"] = true,
		["show_desc"] = "Toggle showing hidden addon messages in each chat window.",
		["show_name"] = "Show Addon Messages",
		["show_perframedesc"] = "Toggle showing hidden addon messages on and off.",
		["show_perframename"] = "ChatFrame%d AddonMsgsShow",
	},
	["Alias"] = {
		[" - list all aliases; supply <keyword> to search for matching aliases (cmd aliases: /listallaliases)"] = true,
		["%s() called with blank string!"] = true,
		["%s() called with nil argument!"] = true,
		["/%s aliased to \"/%s\""] = true,
		["/%s aliased to: /%s"] = true,
		["<alias> - remove the alias <alias> (cmd aliases: /delalias, /remalias)"] = true,
		["<command>[ <value>] - alias <command> to be executed as <value>, or return the value of the currently defined alias for <command> if <command> has not been assigned a value. eg: \"/alias /examplehello /say hello there\" - typing \"/examplehello\" will now cause your character to say \"hello there\"; \"/alias examplehello\" - s \"/examplehello is aliased to /say hello there\" (cmd aliases: /addalias)"] = true,
		["<keyword> - finds all aliases matching <keyword> (cmd aliases: /findalias)"] = true,
		["add"] = true,
		["add an alias"] = true,
		["alias \"/%s\" does not exist"] = true,
		["dealiasing command /%s to /%s"] = true,
		["deleting alias \"/%s\" (previously aliased as \"/%s\")"] = true,
		["Display extra information in the chat frame when commands are dealiased"] = true,
		["Don't overwrite existing aliases when using /addalias"] = true,
		["Expand aliases as you are typing"] = true,
		["find aliases matching a given search term"] = true,
		["findaliases"] = true,
		["infinite loop detected for alias /%s - ignoring"] = true,
		["inline"] = true,
		["list all aliases"] = true,
		["listaliases"] = true,
		["matching aliases found: %d"] = true,
		["module_desc"] = "Adds the command /alias, which can be used to alias slash commands in a similar way to the Unix alias command.",
		["module_name"] = "Alias",
		["No aliases have been defined"] = true,
		["noclobber"] = true,
		["noclobber set - skipping new alias: /%s already expands to /%s"] = true,
		["Options"] = true,
		["Options for altering the behaviour of Alias"] = true,
		["overwriting existing alias \"/%s\" (was aliased to \"/%s\")"] = true,
		["refusing to alias \"/%s\" to anything in the interests of Not Buggering Everything Up"] = true,
		["remove an alias"] = true,
		["There is no alias current defined for \"%s\""] = true,
		["total aliases: %d"] = true,
		["tried to show value for alias \"%s\" but undefined in module.Aliases!"] = true,
		["unalias"] = true,
		["verbose"] = true,
		["warnUser() called with nil argument!"] = true,
		["warnUser() called with zero length string!"] = true,
	},
	["AltNames"] = {
		["%d alts found for %s: %s"] = true,
		["%s alts imported from LOKWhoIsWho"] = true,
		["%s total alts linked to mains"] = true,
		["(.-)'s? [Aa]lt"] = "%f[%a\\192-\\255]([%a\\192-\\255]+)%f[^%a\\128-\\255]'s [Aa]lt",
		["([^%s%p%d%c%z]+)'s alt"] = "%f[%a\\192-\\255]([%a\\192-\\255]+)%f[^%a\\128-\\255]'s [Aa]lt",
		[".*[Aa]lts?$"] = true,
		["<alt name> (eg, /altnames del Personyouthoughtwassomeonesaltbutreallyisnt)"] = true,
		["<main> (eg /altnames listalts Fin)"] = true,
		["<search term> (eg, /altnames find fin)"] = true,
		["Alt"] = true,
		["alt"] = true,
		["alt name exists: %s -> %s; not overwriting as set in preferences"] = true,
		["AltNames"] = true,
		["Alts:"] = true,
		["autoguildalts_desc"] = "Automatically run the import from guild roster command silently",
		["autoguildalts_name"] = "Auto Import Guild Alts",
		["Be quiet"] = true,
		["character removed: %s"] = true,
		["Class colour"] = true,
		["Clear all"] = true,
		["Clear all links between alts and main names."] = true,
		["Colour"] = true,
		["Delete a character's link to another character as their main."] = true,
		["Delete alt"] = true,
		["Disabled"] = true,
		["Display a player's alts in the tooltip"] = true,
		["Display a player's main name in the tooltip"] = true,
		["Display main names in the same colour as that of the alt's class (taking the data from the PlayerNames module if it is enabled)"] = true,
		["Display main names in the same colour as that of the main's class (taking the data from the PlayerNames module if it is enabled)"] = true,
		["Don't overwrite existing alt <-> main links when importing or adding new alts."] = true,
		["Don't overwrite existing links"] = true,
		["don't use"] = true,
		["Don't use data from the PlayerNames module at all"] = true,
		["ERROR: some function sent a blank message!"] = true,
		["Find characters"] = true,
		["Fix alts"] = true,
		["Fix corrupted entries in your list of alt names."] = true,
		["Found alt: %s => main: %s"] = true,
		["guild member alts found and imported: %s"] = true,
		["Import from Guild Greet database"] = true,
		["Import from guild roster"] = true,
		["Import options"] = true,
		["Imports alt names from a Guild Greet database, if present"] = true,
		["Imports alt names from the guild roster by checking for members with the rank \"alt\" or \"alts\", or guild / officer notes like \"<name>'s alt\""] = true,
		["Imports data from LOKWhoIsWho, if present (drop your SavedVariablesLOKWhoIsWho.lua in the Prat directory to be able to use this)."] = true,
		["Left"] = true,
		["link <alt name> <main name> (eg, /altnames link Fin Finjathealtoffin)"] = true,
		["Link alt"] = true,
		["Link someone's alt character with the name of their main."] = true,
		["linked alt %s => %s"] = true,
		["List all"] = true,
		["List all links between alts and their main names."] = true,
		["List alts"] = true,
		["List alts for a given character"] = true,
		["LOKWhoIsWho data not found"] = true,
		["LOKWhoIsWho import"] = true,
		["LOKWhoIsWho lua file not found, sorry."] = true,
		["Main"] = true,
		["main"] = true,
		["Main name position"] = true,
		["Main:"] = true,
		["mainpos_desc"] = "Where to display a character's main name when on their alt.",
		["mainpos_name"] = "Main name position",
		["module_desc"] = "Allows people's alt characters to be linked to their mains, which can then be displayed next to their names when found in chat messages (default=off).",
		["no alts found for character "] = true,
		["no alts or mains found matching \"%s\""] = true,
		["No arg string given to :addAlt()"] = true,
		["no characters called \"%s\" found; nothing deleted"] = true,
		["No Guild Greet database found"] = true,
		["No main name supplied to link %s to"] = true,
		["no matches found"] = true,
		["quiet"] = "Be quiet",
		["quiet_desc"] = "Whether to report to the chat frame or not.",
		["quiet_name"] = true,
		["Right"] = true,
		["Search the list of linked characters for matching main or alt names."] = true,
		["searched for: %s - total matches: %s"] = true,
		["Show alts in tooltip"] = true,
		["Show main in tooltip"] = true,
		["Start"] = true,
		["The colour of an alt's main name that will be displayed"] = true,
		["Use class colour (from the PlayerNames module)"] = true,
		["use class colour of alt"] = true,
		["use class colour of main"] = true,
		["Use LibAlts Data"] = true,
		["Use the data available via the shared alt information library."] = true,
		["Various ways to import a main's alts from other addons"] = true,
		["warning: alt %s already linked to %s"] = true,
		["Where to display a character's main name when on their alt."] = true,
		["Whether to report to the chat frame or not."] = true,
		["You are not in a guild"] = true,
		["You have not yet linked any alts with their mains."] = true,
	},
	["Bubbles"] = {
		["color_desc"] = "Color the chat bubble border the same as the chat type.",
		["color_name"] = "Color Bubbles",
		["font_desc"] = "Use the same font you are using on the chatframe",
		["font_name"] = "Use Chat Font",
		["fontsize_desc"] = "Set the chat bubble font size",
		["fontsize_name"] = "Font Size",
		["format_desc"] = "Apply Prat's formatting to the chat bubble text.",
		["format_name"] = "Format Text",
		["icons_desc"] = "Show raid icons in the chat bubbles.",
		["icons_name"] = "Show Raid Icons",
		["module_desc"] = "Chat bubble related customizations",
		["module_name"] = "Bubbles",
		["shorten_desc"] = "Shorten the chat bubbles down to a single line each. Mouse over the bubble to expand the text.",
		["shorten_name"] = "Shorten Bubbles",
		["transparent_desc"] = "Hide background and border textures from chat bubbles. (/reload required to undo this option)",
		["transparent_name"] = "Transparent Bubbles",
	},
	["Buttons"] = {
		["alpha_desc"] = "Sets alpha of chat menu and arrows for all chat windows.",
		["alpha_name"] = "Set Alpha",
		["Buttons"] = true,
		["Chat window button options."] = true,
		["chatmenu_desc"] = "Toggles chat menu on and off.",
		["chatmenu_name"] = "Show Chat Menu",
		["Default"] = true,
		["Right, Inside Frame"] = true,
		["Right, Outside Frame"] = true,
		["scrollReminder_desc"] = "Show reminder button when not at the bottom of a chat window.",
		["scrollReminder_name"] = "Show ScrollDown Reminder",
		["Set Position"] = true,
		["Sets position of chat menu and arrows for all chat windows."] = true,
		["Show Arrows"] = true,
		["Show Chat%d Arrows"] = true,
		["showbnet_desc"] = "Show Social Menu",
		["showbnet_name"] = "Show Social Menu",
		["showmenu_desc"] = "Show Chat Menu",
		["showmenu_name"] = "Show Menu",
		["showminimize_desc"] = "Show Minimize Button",
		["showminimize_name"] = "Show Minimize Button",
		["Toggle showing chat arrows for each chat window."] = true,
		["Toggles navigation arrows on and off."] = true,
	},
	["ChannelColorMemory"] = {
		["(%w+)%s?(.*)"] = "(%S+)%s?(.*)",
		["ChannelColorMemory"] = true,
		["Remembers the colors of each channel name."] = true,
	},
	["ChannelNames"] = {
		["%s settings."] = true,
		["<string>"] = true,
		["Add Channel Abbreviation"] = true,
		["addnick_desc"] = "Adds an abbreviated channel name. Prefix the name with '#' to include the channel number. (e.g. '#Trade').",
		["Blank"] = true,
		["chanlink_desc"] = "Make the channel a clickable link which opens chat to that channel.",
		["chanlink_name"] = "Create Channel Link",
		["Channel %d"] = true,
		["Channel name abbreviation options."] = true,
		["ChannelNames"] = true,
		["channelnick_desc"] = "Channel Abbreviations",
		["channelnick_name"] = "Channel Abbreviations",
		["Clear Channel Abbreviation"] = true,
		["Clears an abbreviated channel name."] = true,
		["colon_desc"] = "Toggle adding colon after channel replacement.",
		["colon_name"] = "Show Colon",
		["Dont display the channel/chat type name"] = true,
		["otheropts_desc"] = "Additional channel formating options, and channel link controls.",
		["otheropts_name"] = "Other Options",
		["Remove Channel Abbreviation"] = true,
		["Removes an an abbreviated channel name."] = true,
		["Replace"] = true,
		["Set"] = true,
		["space_desc"] = "Toggle adding space after channel replacement.",
		["space_name"] = "Show Space",
		["Toggle replacing this channel."] = true,
		["Use a custom replacement for the chat %s text."] = true,
	},
	["ChannelSticky"] = {
		["Channel"] = true,
		["ChannelSticky"] = true,
		["Chat channel sticky options."] = true,
		["ChatType"] = true,
		["Per chat type options."] = true,
		["smartgroup_desc"] = "Adds a /smart or /smrt command which automatically picks the correct type of chat, RAID, PARTY, or INSTANCE_CHAT",
		["smartgroup_name"] = "Smart Groups",
		["Sticky %s"] = true,
		["Sticky Per Chat Frame"] = true,
		["Toggle remembering the chat type last used per chat frame."] = true,
		["Toggles sticky on and off for %s."] = true,
	},
	["ChatFrames"] = {
		["Chat window frame parameter options"] = true,
		["framealpha_desc"] = "Conrols the transparency of the chatframe when you hover over it with your mouse.",
		["framealpha_name"] = "Set Chatframe Alpha",
		["Frames"] = true,
		["mainchatonload_desc"] = "Automatically select the first chat frame and make it active on load.",
		["mainchatonload_name"] = "Force Main Chat Frame On Load",
		["maxchatheight_desc"] = "Sets the maximum height for all chat windows.",
		["maxchatheight_name"] = "Set Maximum Height",
		["maxchatwidth_desc"] = "Sets the maximum width for all chat windows.",
		["maxchatwidth_name"] = "Set Maximum Width",
		["minchatheight_desc"] = "Sets the minimum height for all chat windows.",
		["minchatheight_name"] = "Set Minimum Height",
		["minchatwidth_desc"] = "Sets the minimum width for all chat windows.",
		["minchatwidth_name"] = "Set Minimum Width",
		["rememberframepositions_desc"] = "Remember the chatframe positions, and restore them on load",
		["rememberframepositions_name"] = "Remember Positions",
		["removeclamp_desc"] = "Allow the chatframe to be moved flush with the edge of the screen",
		["removeclamp_name"] = "Zero Clamp Size",
	},
	["ChatLink"] = {
		["gem_desc"] = "Enable GEM Compatiblity Mode",
		["gem_name"] = "GEM Compatibility",
		["module_desc"] = "Chat channel item link options.",
		["module_info"] = "This module allows you to link items into non-trade chat channels ie. General, or private channels such as your class channel. To users without an addon capable of decoding it, it will look like spam, so be courteous",
		["module_name"] = "ChannelLinks",
		["Trade"] = true,
	},
	["ChatLog"] = {
		["A module to automaticaly enable chat and combat logging."] = true,
		["Chat log recorded to <WoW Installation>\\Logs\\WoWChatLog.txt only upon logout."] = true,
		["Chat Log: Disabled"] = true,
		["Chat Log: Enabled"] = true,
		["ChatLog"] = true,
		["Combat log recorded to <WoW Installation>\\Logs\\WoWCombatLog.txt only upon logout."] = true,
		["Combat Log: Disabled"] = true,
		["Combat Log: Enabled"] = true,
		["quiet_desc"] = "Dont display any messages when this mod is enabled, or when it changes the log settings.",
		["quiet_name"] = "Suppress Feedback Messages",
		["Toggle Chat Log"] = true,
		["Toggle chat log on and off."] = true,
		["Toggle Combat Log"] = true,
		["Toggle combat log on and off."] = true,
	},
	["ChatTabs"] = {
		["Active Alpha"] = true,
		["All"] = true,
		["Always"] = true,
		["Chat window tab options."] = true,
		["Default"] = true,
		["disableflash_desc"] = "Disable flashing of the chat tabs.",
		["disableflash_name"] = "Disable Flashing",
		["Hidden"] = true,
		["Individual"] = true,
		["Not Active Alpha"] = true,
		["preventdrag_desc"] = "Prevent dragging chat tabs with mouse",
		["preventdrag_name"] = "Prevent Dragging",
		["Set ChatFrame%d Display Mode"] = true,
		["Set Display Mode"] = true,
		["Set tab display mode for each chat window."] = "Set tab display mode for each chat window. Checked (on), Unchecked (off), Greyed Check (default)",
		["Set tab display to always, hidden or the Blizzard default."] = true,
		["Sets alpha of chat tab for active chat frame."] = true,
		["Sets alpha of chat tab for not active chat frame."] = true,
		["Tabs"] = true,
	},
	["Clear"] = {
		["Adds clear text slash commands (/clear)(/cls)(/clearall)(/clsall)."] = true,
		["Clear"] = true,
		["Clearall"] = true,
		["Clears all chat frames."] = true,
		["Clears the current chat frame."] = true,
	},
	["CopyChat"] = {
		[" Text"] = true,
		["BBCode"] = true,
		["BOTTOMLEFT"] = "Bottom, Left",
		["BOTTOMRIGHT"] = "Bottom, Right",
		["buttonpos_desc"] = "Where on the chatframe to show the copy button",
		["buttonpos_name"] = "Button Location",
		["ChatFrame"] = true,
		["Copy all of the text in the selected chat frame into an edit box"] = true,
		["Copy Text"] = true,
		["Copy Text Format"] = true,
		["Copy text from the active chat window."] = true,
		["Copy To Editbox"] = true,
		["CopyChat"] = true,
		["HTML"] = true,
		["Message From : %s"] = true,
		["Plain"] = true,
		["Should the copied text be plain, or formatted so you can see the colors."] = true,
		["showbutton_desc"] = "Show a button on the chatframe",
		["showbutton_name"] = "Copy Button",
		["TOPLEFT"] = "Top, Left",
		["TOPRIGHT"] = "Top, Right",
		["Wowace.com Forums"] = true,
	},
	["CustomFilters"] = {
		["<string>"] = true,
		["Add a pattern to search for."] = true,
		["Add Pattern"] = true,
		["Block Message"] = true,
		["Channel Data"] = true,
		["Channel to send output text to."] = true,
		["Enabled"] = true,
		["Extra data for WHISPER (target) and CHANNEL (channel name or num)"] = true,
		["Filter Name"] = true,
		["Forward"] = true,
		["Forward the message to a chat channel."] = true,
		["Forward the message to a custom chat channel."] = "Output to a private chat channel",
		["ForwardCustom"] = true,
		["ForwardMessage"] = true,
		["ForwardMessageCustom"] = "Private Channel",
		["Hilight Color"] = true,
		["Hilight Match Text"] = true,
		["Inbound"] = true,
		["inchannels_desc"] = "Search in certain channels",
		["inchannels_name"] = "Search Channels",
		["Is this pattern enabled for use?"] = true,
		["Match Options"] = true,
		["module_desc"] = "Module to support custom filters.",
		["module_name"] = "CustomFilters",
		["Only output the message portion of the chat text, leave out the channel, and playername etc."] = true,
		["Outbound"] = true,
		["Output Channel"] = true,
		["Output Message Only"] = true,
		["Pattern Info"] = true,
		["Pattern Options"] = true,
		["Play a sound when this message is output to the chatframe"] = true,
		["Play Sound"] = true,
		["Prevent the message from being displayed"] = true,
		["Remove an existing pattern."] = true,
		["Remove Pattern"] = true,
		["Replacement Text"] = true,
		["Search Format String"] = true,
		["Search Pattern"] = true,
		["Secondary Output"] = true,
		["Send to a secondary output"] = true,
		["Supplied pattern is a format string instead of a pattern"] = true,
		["Your name for this filter"] = true,
	},
	["Editbox"] = {
		["Attach edit box to..."] = true,
		["Attach to..."] = true,
		["Background color"] = true,
		["Background Inset"] = true,
		["Background texture"] = true,
		["Border color"] = true,
		["Border texture"] = true,
		["Bottom"] = true,
		["Color border by channel"] = true,
		["currently_broken_alt_behavior"] = [=[Arrow key behaviour broken in current WoW client,

Use ALT-UP and ALT-DOWN instead of just UP DOWN to access history]=],
		["Edge Size"] = true,
		["Editbox"] = true,
		["Editbox options."] = true,
		["Font"] = true,
		["Free-floating"] = true,
		["Free-floating, Locked"] = true,
		["Requires the Alt key to be held down to move the cursor in chat"] = true,
		["Select the font to use for the edit box"] = true,
		["Sets the frame's border color to the color of your currently active channel"] = true,
		["Tile Size"] = true,
		["Top"] = true,
		["Use Alt key for cursor movement"] = true,
	},
	["EventNames"] = {
		["allevents_desc"] = "Enable Prat processing for all chat events.",
		["allevents_name"] = "Process all events",
		["Chat window event name options."] = true,
		["EventNames"] = true,
		["Show"] = true,
		["Show events on chatframes"] = true,
		["show_desc"] = "Toggle showing event names in each window.",
		["show_name"] = "Show Event Names",
	},
	["Fading"] = {
		["duration_desc"] = "Set the number of seconds to wait before before fading text of chat windows.",
		["duration_name"] = "Set Fading Delay (Seconds)",
		["module_desc"] = "Chat window text fading options.",
		["module_name"] = "Fading",
		["textfade_desc"] = "Toggle enabling text fading for each chat window.",
		["textfade_name"] = "Enable Fading",
	},
	["Filtering"] = {
		["A module to provide basic chat filtering."] = true,
		["afkdnd_desc"] = "Throttle AFK and DND messages.",
		["afkdnd_name"] = "Throttle AFK and DND messages.",
		["bgjoin_desc"] = "Filter out channel Battleground leave/join spam",
		["bgjoin_name"] = "Filter BG Leave/Join",
		["Filtering"] = true,
		["leavejoin_desc"] = "Filter out channel leave/join spam",
		["leavejoin_name"] = "Filter Channel Leave/Join",
		["notices_desc"] = "Filter out other custom channel notification messages, e.g. moderator changes.",
		["notices_name"] = "Filter Channel Notices",
		["tradespam_desc"] = "Throttle messages to prevent the same message from being repeated multiple times",
		["tradespam_name"] = "Throttle Spam",
	},
	["Font"] = {
		["Auto Restore Font Size"] = true,
		["Chat window font options."] = true,
		["Font"] = true,
		["monochrome_desc"] = "Toggles monochrome coloring of the font.",
		["monochrome_name"] = "Toggle Monochrome",
		["None"] = true,
		["Outline"] = true,
		["outlinemode_desc"] = "Sets mode for the outline around the font.",
		["outlinemode_name"] = "Set Outline Mode",
		["rememberfont_desc"] = "Remember your font choice and restore it at startup.",
		["rememberfont_name"] = "Remember Font",
		["Set ChatFrame%d Font Size"] = true,
		["Set Font Face"] = true,
		["Set Font Size"] = true,
		["Set Separately"] = true,
		["Set text font size for each chat window."] = true,
		["Set text font size."] = true,
		["Set the text font face for all chat windows."] = true,
		["shadowcolor_desc"] = "Set the color of the shadow effect.",
		["shadowcolor_name"] = "Set Shadow Color",
		["Thick Outline"] = true,
		["Toggle setting options separately for each chat window."] = true,
		["Workaround a Blizzard bug which changes the font size when you open a system menu."] = true,
	},
	["History"] = {
		["Chat history options."] = true,
		["Color GMOTD"] = true,
		["Colors the GMOTD label"] = true,
		["delaygmotd_desc"] = "Delay GMOTD until after all the startup spam",
		["delaygmotd_name"] = "Delay GMOTD",
		["divider"] = "========== End of Scrollback ==========",
		["History"] = true,
		["Maximum number of lines of command history to save."] = true,
		["Save Command History"] = true,
		["Saves command history between sessions (for use with alt+up arrow or just the up arrow)"] = true,
		["Scrollback"] = true,
		["Scrollback Options"] = true,
		["scrollbacklen_desc"] = "Number of chatlines to save in the scrollback buffer.",
		["scrollbacklen_name"] = "Scrollback Length",
		["Set Chat Lines"] = true,
		["Set Command History"] = true,
		["Set the number of lines of chat history for each window."] = true,
		["Store the chat lines between sessions"] = true,
	},
	["KeyBindings"] = {
		["Channel %d"] = true,
		["Copy Selected Chat Frame"] = true,
		["Guild Channel"] = true,
		["Instance Channel"] = true,
		["Next Chat Tab"] = true,
		["Officer Channel"] = true,
		["Party Channel"] = true,
		["Prat CopyChat"] = true,
		["Prat Keybindings"] = true,
		["Prat TellTarget"] = true,
		["Raid Channel"] = true,
		["Raid Warning Channel"] = true,
		["Say"] = true,
		["Smart Group Channel"] = true,
		["TellTarget"] = true,
		["Whisper"] = true,
		["Yell"] = true,
	},
	["OriginalButtons"] = {
		["alpha_desc"] = "Sets alpha of chat menu and arrows for all chat windows.",
		["alpha_name"] = "Set Alpha",
		["buttonframe_desc"] = "Toggles the button frame menu on and off.",
		["buttonframe_name"] = "Show Button Frame",
		["ChannelNames"] = true,
		["Chat window button options."] = true,
		["chatmenu_desc"] = "Toggles chat menu on and off.",
		["chatmenu_name"] = "Show Chat Menu",
		["Default"] = true,
		["Original Buttons"] = true,
		["reflow_desc"] = "Chatframe text should flow around the buttons not under them.",
		["reflow_name"] = "Text Flows Around",
		["reminder_desc"] = "Show reminder button when not at the bottom of a chat window.",
		["reminder_name"] = "Show ScrollDown Reminder",
		["Right, Inside Frame"] = true,
		["Right, Outside Frame"] = true,
		["Set Position"] = true,
		["Sets position of chat menu and arrows for all chat windows."] = true,
		["Show Arrows"] = true,
		["Show Chat%d Arrows"] = true,
		["Toggle showing chat arrows for each chat window."] = true,
		["Toggles navigation arrows on and off."] = true,
	},
	["OriginalEditbox"] = {
		["Autohide"] = true,
		["BACKGROUND"] = true,
		["Bar colour"] = true,
		["Border colour"] = true,
		["Border width"] = true,
		["Bottom"] = true,
		["Click the edit box to open it up for editing. Only available if Autohide is disabled."] = true,
		["Clickable"] = true,
		["DIALOG"] = true,
		["Editbox options."] = true,
		["Enable Arrowkeys"] = true,
		["Enable using arrowkeys in editbox without the alt key."] = true,
		["Hide Border"] = true,
		["Hide the border around the edit box."] = true,
		["Hide the edit box after you have pressed enter."] = true,
		["HIGH"] = true,
		["Lock editbox position if undocked."] = true,
		["Lock Position"] = true,
		["LOW"] = true,
		["MEDIUM"] = true,
		["OriginalEditbox"] = true,
		["Padding"] = true,
		["Set Alpha"] = true,
		["Set Position"] = true,
		["Set Strata"] = true,
		["Set the alpha of the editbox."] = true,
		["Set the amount of padding inside the edit box"] = true,
		["Set the edit box background colour"] = true,
		["Set the edit box border colour"] = true,
		["Set the frame strata of the editbox."] = true,
		["Set the position of the editbox."] = true,
		["Set the texture of the chat edit box"] = true,
		["Set the width of the edit box's border"] = true,
		["Set the width of the editbox."] = true,
		["Set Width (NB: only enabled if the editbox is undocked)"] = true,
		["Texture"] = true,
		["Top"] = true,
		["Undocked"] = true,
	},
	["Paragraph"] = {
		["adjustlinks_desc"] = "Adjust links to restore clickability on centered or right-aligned text.",
		["adjustlinks_name"] = "Fix placement of player/item links",
		["Center"] = true,
		["Chat window paragraph options."] = true,
		["justification_desc"] = "Set horizontal alignment for each chat window",
		["justification_name"] = "Set Alignment",
		["Left"] = true,
		["Line Spacing"] = true,
		["Paragraph"] = true,
		["Right"] = true,
		["Set the line spacing for all chat windows."] = true,
	},
	["PlayerNames"] = {
		["Actively Query Player Info"] = true,
		["Angled"] = true,
		["Brackets"] = true,
		["Brackets Common Color"] = true,
		["Brackets Use Common Color"] = true,
		["Class"] = true,
		["Color by Level Difference"] = true,
		["coloreverywhere_desc"] = "Color player names if they appear in the text of the chat message",
		["coloreverywhere_name"] = "Color Names Everywhere",
		["Enable Alt-Invite"] = true,
		["Enable Invite Links"] = true,
		["Enable TabComplete"] = true,
		["hoverhilight_desc"] = "Hilight chat lines from a specific player when hovering over thier playerlink",
		["hoverhilight_name"] = "Hover Hilighting",
		["How to color other player's level."] = true,
		["How to color player's name."] = true,
		["Keep Info"] = true,
		["Keep Lots Of Info"] = true,
		["Keep player information between session for all players except cross-server players"] = true,
		["Keep player information between session, but limit it to friends and guild members."] = true,
		["Let TasteTheNaimbow set the common color for unknown player names."] = true,
		["Level Color Mode"] = true,
		["linkifycommon_desc"] = "Linkify Common Messages",
		["linkifycommon_name"] = "Linkify Common Messages",
		["No additional coloring"] = true,
		["None"] = true,
		["Player Color Mode"] = true,
		["Player name formating options."] = true,
		["PlayerNames"] = true,
		["Prat_Playernames: Stored Player Data Cleared"] = true,
		["Query the server for all player names we do not know. Note: This happpens pretty slowly, and this data is not saved."] = true,
		["Random"] = true,
		["realidcolor_desc"] = "RealID Name Coloring",
		["realidcolor_name"] = "RealID Coloring",
		["Reset Settings"] = true,
		["Restore default settings, and delete stored character data."] = true,
		["Set common color of unknown player names."] = true,
		["Sets common color of brackets to use around player names."] = true,
		["Sets style of brackets to use around player names."] = true,
		["Show Group"] = true,
		["Show Level"] = true,
		["Show Raid Target Icon"] = true,
		["Square"] = true,
		["Tab completion : "] = true,
		["tabcomplete_name"] = "Possible Names",
		["Toggle group invites by alt-clicking hyperlinked keywords like 'invite'."] = true,
		["Toggle group invites by alt-clicking on player name."] = true,
		["Toggle level showing."] = true,
		["Toggle raid group showing."] = true,
		["Toggle showing the raid target icon which is currently on the player."] = true,
		["Toggle tab completion of player names."] = true,
		["Toggle using a common color for brackets around player names."] = true,
		["Toggle using a common color for unknown player names."] = true,
		["Too many matches (%d possible)"] = true,
		["Unknown Common Color"] = true,
		["Unknown Common Color From TasteTheNaimbow"] = true,
		["Unknown Use Common Color"] = true,
		["Use Channel Color"] = true,
		["Use Player Color"] = true,
		["Use toon name for RealID"] = true,
	},
	["PopupMessage"] = {
		["Add Nickname"] = true,
		["Adds an alternate name to show in popups."] = true,
		["Clear Nickname"] = true,
		["Clears alternate name to show in popups."] = true,
		["framealpha_desc"] = "Set the alpha value of the popup frame when fully faded in.",
		["framealpha_name"] = "Popup Frame Alpha",
		["Popup"] = true,
		["PopupMessage"] = true,
		["Remove Nickname"] = true,
		["Removes an alternate name to show in popups."] = true,
		["Set Separately"] = true,
		["Show All Popups"] = true,
		["Show Popups"] = true,
		["Show Popups for all chat windows."] = true,
		["Show Popups for each window."] = true,
		["show_desc"] = "Show Popups for each window.",
		["show_name"] = "Show Popups",
		["show_perframedesc"] = "Toggles showing popups on and off.",
		["show_perframename"] = "Show ChatFrame%d Popups",
		["showall_desc"] = "Show Popups for all chat windows.",
		["showall_name"] = "Show All Popups",
		["Shows messages in a popup window."] = true,
		["Shows messages with your name in a popup."] = true,
		["Toggle setting options separately for each chat window."] = true,
	},
	["Scroll"] = {
		["Bottom"] = "Bottom to top",
		["Chat window scrolling options."] = true,
		["Control whether text is added to the frame at the top or the bottom."] = true,
		["lowdown_desc"] = "Toggle auto jumping to the bottom for each chat window.",
		["lowdown_name"] = "Enable TheLowDown",
		["modified_speed"] = "Set Shift+MouseWheel Speed",
		["modified_speed_desc"] = "Set number of lines mousewheel will scroll when shift is pressed.",
		["mousewheel_desc"] = "Toggle mousewheel support for each chat window.",
		["mousewheel_name"] = "Enable MouseWheel",
		["Scroll"] = true,
		["Set Ctrl+MouseWheel Speed"] = true,
		["Set MouseWheel Speed"] = true,
		["Set number of lines mousewheel will scroll when ctrl is pressed."] = true,
		["Set number of lines mousewheel will scroll."] = true,
		["Set TheLowDown Delay"] = true,
		["Set time to wait before jumping to the bottom of chat windows."] = true,
		["Text scroll direction"] = true,
		["Top"] = "Top to bottom",
	},
	["Search"] = {
		["err_notfound"] = "Not Found",
		["err_tooshort"] = "Search term is too short",
		["find_results"] = "Find Results:",
		["module_desc"] = "Adds the ability to search the chatframes.",
		["module_info"] = [=[This module adds the /find and /findall commands to search the chat history

Usage:

 /find <text> 

 /findall <text>]=],
		["module_name"] = "Search",
	},
	["ServerNames"] = {
		["autoabbreviate_desc"] = "Shorten the server name to 3 letters",
		["autoabbreviate_name"] = "Auto-abbreviate",
		["colon_desc"] = "Toggle adding colon after server replacement.",
		["colon_name"] = "Show Colon",
		["randomclr_desc"] = "Use a random color for each server.",
		["randomclr_name"] = "Random Colors",
		["Server name abbreviation options."] = true,
		["ServerNames"] = true,
	},
	["Sounds"] = {
		["A module to play sounds on certain chat messages."] = true,
		["Add a custom channel"] = true,
		["bn_whisper_desc"] = "Sound for %s Battle.Net whisper messages",
		["bn_whisper_name"] = "Battle.Net Whisper",
		["Custom Channels"] = true,
		["group_lead_desc"] = "Sound for %s raid leader, party leader or dungeon guide messages",
		["group_lead_name"] = "Group Leader",
		["guild_desc"] = "Sound for %s guild messages",
		["guild_name"] = "Guild",
		["incoming"] = true,
		["Incoming Sounds"] = true,
		["officer_desc"] = "Sound for %s officer channel messages",
		["officer_name"] = "Officer",
		["outgoing"] = true,
		["Outgoing Sounds"] = true,
		["party_desc"] = "Sound for %s party messages",
		["party_name"] = "Party",
		["Play a sound for a certain channel name (can be a substring)"] = true,
		["raid_desc"] = "Sound for %s raid or battleground group/leader messages",
		["raid_name"] = "Raid",
		["Remove a custom channel"] = true,
		["Reset settings"] = true,
		["Restore default settings and resets custom channel list"] = true,
		["Sound selection for incoming chat messages"] = true,
		["Sound selection for outgoing (from you) chat messages"] = true,
		["Sounds"] = true,
		["whisper_desc"] = "Sound for %s whisper messages",
		["whisper_name"] = "Whisper",
	},
	["Substitutions"] = {
		["%d total user defined substitutions"] = true,
		["|cffff0000warning:|r subtitution \"%s\" already defined as \"%s\", overwriting"] = true,
		["<noguild>"] = true,
		["<notarget>"] = true,
		["A module to provide basic chat substitutions."] = true,
		["Are you sure - this will delete all user defined substitutions and reset defaults?"] = true,
		["Are you sure?"] = true,
		["can't find substitution index for a substitution named '%s'"] = true,
		["current-prompt"] = [=[Current value: '%s' 
Click to paste into the chat.]=],
		["defined %s: expands to => %s"] = true,
		["Delete all"] = true,
		["Delete substitution"] = true,
		["Deletes a user defined substitution"] = true,
		["Deletes all user defined substitutions"] = true,
		["female"] = true,
		["her"] = true,
		["hers"] = true,
		["him"] = true,
		["his"] = true,
		["it"] = true,
		["its"] = true,
		["List of available substitutions"] = true,
		["List of available substitutions defined by this module. (NB: users may define custom values for existing substitutions, but they will revert to the default value if the user definition is deleted.)"] = true,
		["List substitutions"] = true,
		["Lists all current subtitutions in the default chat frame"] = true,
		["male"] = true,
		["MapLoc"] = true,
		["MapPos"] = true,
		["MapXPos"] = true,
		["MapYPos"] = true,
		["MapZone"] = true,
		["module:buildUserSubsIndex(): warning: module patterns not defined!"] = true,
		["MouseoverTargetName"] = true,
		["NO MATCHFUNC FOUND"] = true,
		["no substitution name given"] = true,
		["no substitution name supplied for deletion"] = true,
		["no user defined subs found"] = true,
		["no value given for subtitution \"%s\""] = true,
		["Options for setting and removing user defined substitutions. (NB: users may define custom values for existing substitutions, but they will revert to the default value if the user definition is deleted.)"] = true,
		["PlayerAverageItemLevel"] = true,
		["PlayerCurrentMana"] = true,
		["PlayerHealthDeficit"] = true,
		["PlayerHP"] = true,
		["PlayerManaDeficit"] = true,
		["PlayerMaxHP"] = true,
		["PlayerMaxMana"] = true,
		["PlayerName"] = true,
		["PlayerPercentHP"] = true,
		["PlayerPercentMana"] = true,
		["RandNum"] = true,
		["removing user defined substitution \"%s\"; previously expanded to => \"%s\""] = true,
		["Set substitution"] = true,
		["Set the value of a user defined substitution (NB: this may be the same as an existing default substitution; to reset it to the default, just remove the user created definition)."] = true,
		["subname -- NOTE: sub name without the prefix '%'"] = true,
		["subname = text after expansion -- NOTE: sub name without the prefix \"%\""] = true,
		["substitution: %s defined as => %s"] = true,
		["Substitutions"] = true,
		["TargetClass"] = true,
		["TargetGender"] = true,
		["TargetGuild"] = true,
		["TargetHealth"] = true,
		["TargetHealthDeficit"] = true,
		["TargetIcon"] = true,
		["TargetLevel"] = true,
		["TargetManaDeficit"] = true,
		["TargetName"] = true,
		["TargetPercentHP"] = true,
		["TargetPossesive"] = true,
		["TargetPronoun"] = true,
		["TargetRace"] = true,
		["TargetTargetName"] = true,
		["unknown sex"] = true,
		["user defined substition \"%s\" not found"] = true,
		["User defined substitutions"] = true,
		["user substitutions index (usersubs_idx) doesn't exist! oh dear."] = true,
		["usersub_"] = true,
	},
	["TellTarget"] = {
		["/tt"] = true,
		["Adds telltarget slash command (/tt)."] = true,
		["No target selected."] = true,
		["NoTarget"] = true,
		["Target does not exist."] = true,
		["Target is not a player."] = true,
		["TellTarget"] = true,
	},
	["Timestamps"] = {
		["Chat window timestamp options."] = true,
		["colortimestamp_desc"] = "Toggle coloring the timestamp on and off.",
		["colortimestamp_name"] = "Color Timestamp",
		["Format All Timestamps"] = true,
		["HH:MM (12-hour)"] = true,
		["HH:MM (24-hour)"] = true,
		["HH:MM:SS (12-hour)"] = true,
		["HH:MM:SS (24-hour)"] = true,
		["HH:MM:SS AM (12-hour)"] = true,
		["localtime_desc"] = "Toggle using local time on and off.",
		["localtime_name"] = "Use Local Time",
		["MM:SS"] = true,
		["Post-Timestamp"] = true,
		["Pre-Timestamp"] = true,
		["Set the timestamp format"] = true,
		["Set Timestamp Color"] = true,
		["Sets the color of the timestamp."] = true,
		["Show Timestamp"] = true,
		["show_desc"] = "Toggle showing timestamp on and off for each window.",
		["show_name"] = "Show Timestamp",
		["space_desc"] = "Toggle adding space after timestamp on and off.",
		["space_name"] = "Show Space",
		["Timestamps"] = true,
		["Toggle showing timestamp for each window."] = true,
		["twocolumn_desc"] = "Place the timestamps in a separate column so the text does not wrap underneath them",
		["twocolumn_name"] = "2 Column Chat",
	},
	["UrlCopy"] = {
		["Change the color of the URL."] = true,
		["Color URL"] = true,
		["Set Color"] = true,
		["Show Brackets"] = true,
		["Toggle"] = true,
		["Toggle showing brackets on and off."] = true,
		["Toggle the module on and off."] = true,
		["Toggle the URL color on and off."] = true,
		["URL formating options."] = true,
		["UrlCopy"] = true,
		["Use Popup"] = true,
		["Use popup window to show URL."] = true,
	}
}

PL:AddLocale(PRAT_MODULE.name, "enUS",L)


L=
{
	["display_desc"] = "Comportement et apparence de la fenêtre de discussion.",
	["display_name"] = "Options d'affichage",
	["extras_desc"] = "Modules divers",
	["extras_name"] = "Suppléments",
	["formatting_desc"] = "Apparence des lignes et du texte",
	["formatting_name"] = "Formatage du texte",
	["load_desc"] = "Contrôle le comportement de chargement de ce module.",
	["load_disabled"] = "Désactivé",
	["load_disabledonrestart"] = "Désactivé (recharger)",
	["load_enabled"] = "Activé",
	["load_enabledonrestart"] = "Activé (recharger)",
	["load_no"] = "Ne pas charger",
	["modulecontrol_desc"] = "Contrôler le chargement et l'activation des modules de Prat",
	["modulecontrol_name"] = "Contrôle des modules",
	["prat"] = "Prat",
	["reload_required"] = "Le nouveau paramètre de cette option ne prendra pas effet intégralement tant que vous n'aurez pas %s votre interface.",
	["AddonMsgs"] = {
		--Translation missing 
		-- ["Addon message options."] = "",
		--Translation missing 
		-- ["AddonMsgs"] = "",
		--Translation missing 
		-- ["show_desc"] = "",
		--Translation missing 
		-- ["show_name"] = "",
		--Translation missing 
		-- ["show_perframedesc"] = "",
		--Translation missing 
		-- ["show_perframename"] = "",
	},
	["Alias"] = {
		[" - list all aliases; supply <keyword> to search for matching aliases (cmd aliases: /listallaliases)"] = "- liste tous les alias ; fournissez un <mot clé> pour trouver une correspondance d'alias (cmd alias: /listallaliases)",
		["%s() called with blank string!"] = "%s() appelé avec un argument vide !",
		["%s() called with nil argument!"] = "%s() appelé sans argument !",
		["/%s aliased to \"/%s\""] = "/%s défini comme alias de \"/%s\"",
		["/%s aliased to: /%s"] = "/%s défini comme alias de : /%s",
		["<alias> - remove the alias <alias> (cmd aliases: /delalias, /remalias)"] = "<alias> - Enlever l'alias <alias> (cmd des alias: /delalias, /remalias)",
		["<command>[ <value>] - alias <command> to be executed as <value>, or return the value of the currently defined alias for <command> if <command> has not been assigned a value. eg: \"/alias /examplehello /say hello there\" - typing \"/examplehello\" will now cause your character to say \"hello there\"; \"/alias examplehello\" - s \"/examplehello is aliased to /say hello there\" (cmd aliases: /addalias)"] = "<commande>[ <valeur> ] - Créé un alias <commande> exécuté comme <valeur>. si <commande> n'a pas de valeur assigné, retourne la valeur de l'alias actuellement définit pour <commande>. Ex: \"/alias /examplebonjour /dire Bonjour à tous\" - Taper \"/exemplebonjour\" fera alors dire \"Bonjour à tous\" à votre personnage; \"/alias examplehello\" fera dire \"/examplebonjour est un alias pour /dire Bonjour à tous\" (cmd des alias : /addalias)",
		["<keyword> - finds all aliases matching <keyword> (cmd aliases: /findalias)"] = "<motclé> - Trouve tout les alias avec <motclé> (cmd des alias /findalias)",
		["add"] = "ajouter",
		["add an alias"] = "ajouter un alias",
		["alias \"/%s\" does not exist"] = "l'alias \"/%s\" n'existe pas",
		["dealiasing command /%s to /%s"] = "Enlever l'alias de la commande /%s vers /%s",
		["deleting alias \"/%s\" (previously aliased as \"/%s\")"] = "Supprimer l'alias \"/%s\" (Précédemment l'alias de \"/%s\")",
		["Display extra information in the chat frame when commands are dealiased"] = "Afficher des informations supplémentaires dans le chat quand des alias de commandes sont supprimés",
		["Don't overwrite existing aliases when using /addalias"] = "Ne pas écraser les alias existant avec /addalias",
		["Expand aliases as you are typing"] = "Agrandir les alias au fur et à mesure que vous tapez ",
		["find aliases matching a given search term"] = "Trouver des alias correspondant à un terme recherché",
		["findaliases"] = "TrouverAlias",
		["infinite loop detected for alias /%s - ignoring"] = "Boucle infinie détectée pour l'alias /%s - ignorée",
		["inline"] = "en ligne",
		["list all aliases"] = "Lister tout les alias",
		["listaliases"] = "ListerAlias",
		["matching aliases found: %d"] = "Alias correspondant trouvés: %d",
		["module_desc"] = "Ajoute la commande /alias qui peut être utilisé pour créer des alias de commandes slash de façon similaire aux commandes d'alias d'UNIX",
		["module_name"] = "Alias",
		["No aliases have been defined"] = "Aucun alias n'a été défini",
		["noclobber"] = "NePasÉcraser",
		["noclobber set - skipping new alias: /%s already expands to /%s"] = "NePasÉcraser défini - Passer le nouvel alias: /%s déjà étendu à /%s",
		["Options"] = true,
		["Options for altering the behaviour of Alias"] = "Options pour modifier le comportement des alias",
		["overwriting existing alias \"/%s\" (was aliased to \"/%s\")"] = "Écraser l'alias existant \"/%s\" (Était l'alias de \"/%s\")  ",
		["refusing to alias \"/%s\" to anything in the interests of Not Buggering Everything Up"] = "Refuser à l'alias \"/%s\" de faire quoi que ce soit dans l'intérêt de ne pas tout bugger par dessus",
		["remove an alias"] = "Supprimer un alias",
		["There is no alias current defined for \"%s\""] = "Il n'y a pas d'alias actuellement défini pour \"%s\"",
		["total aliases: %d"] = "Alias totaux : %d",
		["tried to show value for alias \"%s\" but undefined in module.Aliases!"] = "A tenté de montrer la valeur de l'alias \"%s\" mais il était indéfini dans le module Alias!",
		["unalias"] = "Enlever l'alias",
		["verbose"] = "détaillé",
		["warnUser() called with nil argument!"] = "warnUser() appelé avec un argument nul !",
		["warnUser() called with zero length string!"] = "warnUser() appelé avec un chaine de longueur zéro !",
	},
	["AltNames"] = {
		--Translation missing 
		-- ["%d alts found for %s: %s"] = "",
		--Translation missing 
		-- ["%s alts imported from LOKWhoIsWho"] = "",
		--Translation missing 
		-- ["%s total alts linked to mains"] = "",
		--Translation missing 
		-- ["(.-)'s? [Aa]lt"] = "",
		--Translation missing 
		-- ["([^%s%p%d%c%z]+)'s alt"] = "",
		--Translation missing 
		-- [".*[Aa]lts?$"] = "",
		--Translation missing 
		-- ["<alt name> (eg, /altnames del Personyouthoughtwassomeonesaltbutreallyisnt)"] = "",
		--Translation missing 
		-- ["<main> (eg /altnames listalts Fin)"] = "",
		--Translation missing 
		-- ["<search term> (eg, /altnames find fin)"] = "",
		--Translation missing 
		-- ["Alt"] = "",
		--Translation missing 
		-- ["alt"] = "",
		--Translation missing 
		-- ["alt name exists: %s -> %s; not overwriting as set in preferences"] = "",
		--Translation missing 
		-- ["AltNames"] = "",
		--Translation missing 
		-- ["Alts:"] = "",
		--Translation missing 
		-- ["autoguildalts_desc"] = "",
		--Translation missing 
		-- ["autoguildalts_name"] = "",
		--Translation missing 
		-- ["Be quiet"] = "",
		--Translation missing 
		-- ["character removed: %s"] = "",
		--Translation missing 
		-- ["Class colour"] = "",
		--Translation missing 
		-- ["Clear all"] = "",
		--Translation missing 
		-- ["Clear all links between alts and main names."] = "",
		--Translation missing 
		-- ["Colour"] = "",
		--Translation missing 
		-- ["Delete a character's link to another character as their main."] = "",
		--Translation missing 
		-- ["Delete alt"] = "",
		--Translation missing 
		-- ["Disabled"] = "",
		--Translation missing 
		-- ["Display a player's alts in the tooltip"] = "",
		["Display a player's main name in the tooltip"] = "Affiche le nom principale d'un joueur dans la tooltip",
		--Translation missing 
		-- ["Display main names in the same colour as that of the alt's class (taking the data from the PlayerNames module if it is enabled)"] = "",
		--Translation missing 
		-- ["Display main names in the same colour as that of the main's class (taking the data from the PlayerNames module if it is enabled)"] = "",
		["Don't overwrite existing alt <-> main links when importing or adding new alts."] = "Ne pas écraser les liens principal <-> Alternatif lors d'un import ou d'un ajout de nouveaux personnages Alternatifs",
		["Don't overwrite existing links"] = "Ne pas écraser les liens existant",
		--Translation missing 
		-- ["don't use"] = "",
		["Don't use data from the PlayerNames module at all"] = "Ne pas utiliser les donnée du module \"PlayerNames\" du tout",
		["ERROR: some function sent a blank message!"] = "ERREUR: une fonction a envoyé un message blanc !",
		["Find characters"] = "Trouver des personnages",
		["Fix alts"] = "Réparer les personnages secondaires",
		["Fix corrupted entries in your list of alt names."] = "Réparer les entrées corrompues dans votre liste de noms alternatifs.",
		--Translation missing 
		-- ["Found alt: %s => main: %s"] = "",
		--Translation missing 
		-- ["guild member alts found and imported: %s"] = "",
		--Translation missing 
		-- ["Import from Guild Greet database"] = "",
		--Translation missing 
		-- ["Import from guild roster"] = "",
		--Translation missing 
		-- ["Import options"] = "",
		--Translation missing 
		-- ["Imports alt names from a Guild Greet database, if present"] = "",
		--Translation missing 
		-- ["Imports alt names from the guild roster by checking for members with the rank \"alt\" or \"alts\", or guild / officer notes like \"<name>'s alt\""] = "",
		--Translation missing 
		-- ["Imports data from LOKWhoIsWho, if present (drop your SavedVariablesLOKWhoIsWho.lua in the Prat directory to be able to use this)."] = "",
		--Translation missing 
		-- ["Left"] = "",
		--Translation missing 
		-- ["link <alt name> <main name> (eg, /altnames link Fin Finjathealtoffin)"] = "",
		--Translation missing 
		-- ["Link alt"] = "",
		--Translation missing 
		-- ["Link someone's alt character with the name of their main."] = "",
		--Translation missing 
		-- ["linked alt %s => %s"] = "",
		--Translation missing 
		-- ["List all"] = "",
		--Translation missing 
		-- ["List all links between alts and their main names."] = "",
		--Translation missing 
		-- ["List alts"] = "",
		--Translation missing 
		-- ["List alts for a given character"] = "",
		--Translation missing 
		-- ["LOKWhoIsWho data not found"] = "",
		--Translation missing 
		-- ["LOKWhoIsWho import"] = "",
		--Translation missing 
		-- ["LOKWhoIsWho lua file not found, sorry."] = "",
		--Translation missing 
		-- ["Main"] = "",
		--Translation missing 
		-- ["main"] = "",
		--Translation missing 
		-- ["Main name position"] = "",
		--Translation missing 
		-- ["Main:"] = "",
		--Translation missing 
		-- ["mainpos_desc"] = "",
		--Translation missing 
		-- ["mainpos_name"] = "",
		--Translation missing 
		-- ["module_desc"] = "",
		--Translation missing 
		-- ["no alts found for character "] = "",
		--Translation missing 
		-- ["no alts or mains found matching \"%s\""] = "",
		--Translation missing 
		-- ["No arg string given to :addAlt()"] = "",
		--Translation missing 
		-- ["no characters called \"%s\" found; nothing deleted"] = "",
		--Translation missing 
		-- ["No Guild Greet database found"] = "",
		--Translation missing 
		-- ["No main name supplied to link %s to"] = "",
		--Translation missing 
		-- ["no matches found"] = "",
		--Translation missing 
		-- ["quiet"] = "",
		--Translation missing 
		-- ["quiet_desc"] = "",
		--Translation missing 
		-- ["quiet_name"] = "",
		["Right"] = "Droite",
		--Translation missing 
		-- ["Search the list of linked characters for matching main or alt names."] = "",
		--Translation missing 
		-- ["searched for: %s - total matches: %s"] = "",
		--Translation missing 
		-- ["Show alts in tooltip"] = "",
		--Translation missing 
		-- ["Show main in tooltip"] = "",
		--Translation missing 
		-- ["Start"] = "",
		--Translation missing 
		-- ["The colour of an alt's main name that will be displayed"] = "",
		--Translation missing 
		-- ["Use class colour (from the PlayerNames module)"] = "",
		--Translation missing 
		-- ["use class colour of alt"] = "",
		--Translation missing 
		-- ["use class colour of main"] = "",
		--Translation missing 
		-- ["Use LibAlts Data"] = "",
		--Translation missing 
		-- ["Use the data available via the shared alt information library."] = "",
		--Translation missing 
		-- ["Various ways to import a main's alts from other addons"] = "",
		--Translation missing 
		-- ["warning: alt %s already linked to %s"] = "",
		--Translation missing 
		-- ["Where to display a character's main name when on their alt."] = "",
		--Translation missing 
		-- ["Whether to report to the chat frame or not."] = "",
		--Translation missing 
		-- ["You are not in a guild"] = "",
		--Translation missing 
		-- ["You have not yet linked any alts with their mains."] = "",
	},
	["Bubbles"] = {
		["color_desc"] = "Colorie la bordure de la bulle en fonction du type de discussion.",
		["color_name"] = "Colorier les bulles",
		["font_desc"] = "Utiliser la même police que celle de la fenêtre de discussion.",
		["font_name"] = "Police du chat",
		["fontsize_desc"] = "Définit la taille du texte dans les bulles.",
		["fontsize_name"] = "Taille du texte",
		["format_desc"] = "Appliquer le formatage de Prat aux textes dans les bulles.",
		["format_name"] = "Formater le texte",
		["icons_desc"] = "Montrer les icônes de raid dans les bulles.",
		["icons_name"] = "Montrer les icônes de raid",
		["module_desc"] = "Options des bulles de chat .",
		["module_name"] = "Bulles",
		["shorten_desc"] = "Raccourci le texte des bulles à une seule ligne. Mettre la souris sur la bulle pour étendre la bulle et voir le texte en entier.",
		["shorten_name"] = "Raccourcir les bulles",
		--Translation missing 
		-- ["transparent_desc"] = "",
		--Translation missing 
		-- ["transparent_name"] = "",
	},
	["Buttons"] = {
		["alpha_desc"] = "Définit la transparence du menu du chat et des flèches pour toutes les fenêtres de discussion.",
		["alpha_name"] = "Définir la transparence",
		["Buttons"] = "Boutons",
		["Chat window button options."] = "Options des boutons de la fenêtre de discussion.",
		["chatmenu_desc"] = "Activer et désactiver le menu du tchat",
		["chatmenu_name"] = "Montrer le menu du chat",
		["Default"] = "Défaut",
		["Right, Inside Frame"] = "Droite, dans le cadre",
		["Right, Outside Frame"] = "Droite, en dehors du cadre",
		["scrollReminder_desc"] = "Montrer le bouton de rappel lorsque vous n'êtes pas à la fin de la fenêtre de discussion.",
		["scrollReminder_name"] = "Montrer le rappel",
		["Set Position"] = "Définir la position",
		["Sets position of chat menu and arrows for all chat windows."] = "Définir la position du menu et des flèches de toutes les fenêtres de discussion.",
		["Show Arrows"] = "Montrer les flèches",
		["Show Chat%d Arrows"] = "Afficher les boutons fléchés du chat",
		["showbnet_desc"] = "Montrer le menu Social.",
		["showbnet_name"] = "Montrer le menu Social",
		["showmenu_desc"] = "Montrer le menu de la fenêtre de discussion.",
		["showmenu_name"] = "Montrer le menu",
		["showminimize_desc"] = "Montrer le bouton pour minimiser la discussion.",
		["showminimize_name"] = "Montrer Minimiser",
		["Toggle showing chat arrows for each chat window."] = "Activer l'affichage des flèches pour chaque fenêtre de discussion.",
		["Toggles navigation arrows on and off."] = "Activer et désactiver les flèches de navigations",
	},
	["ChannelColorMemory"] = {
		--Translation missing 
		-- ["(%w+)%s?(.*)"] = "",
		["ChannelColorMemory"] = "Couleur Canal",
		["Remembers the colors of each channel name."] = "Mémorise la couleur de chaque nom de canal.",
	},
	["ChannelNames"] = {
		["%s settings."] = "Options pour %s .",
		["<string>"] = "<chaîne>",
		["Add Channel Abbreviation"] = "Ajouter une abréviation",
		["addnick_desc"] = "Ajoute une abréviation pour le nom de ce canal. Préfixer le nom avec '#' permet d'inclure le numéro du canal. (Exemple : '#Commerce')",
		--Translation missing 
		-- ["Blank"] = "",
		--Translation missing 
		-- ["chanlink_desc"] = "",
		--Translation missing 
		-- ["chanlink_name"] = "",
		["Channel %d"] = "Canal %d",
		["Channel name abbreviation options."] = "Options d'abréviations des noms de canaux.",
		["ChannelNames"] = "Noms des canaux",
		["channelnick_desc"] = "Abréviations des noms des canaux.",
		["channelnick_name"] = "Abréviations",
		--Translation missing 
		-- ["Clear Channel Abbreviation"] = "",
		--Translation missing 
		-- ["Clears an abbreviated channel name."] = "",
		--Translation missing 
		-- ["colon_desc"] = "",
		--Translation missing 
		-- ["colon_name"] = "",
		--Translation missing 
		-- ["Dont display the channel/chat type name"] = "",
		["otheropts_desc"] = "Options supplémentaires du formatage des noms de canaux.",
		["otheropts_name"] = "Autres options",
		--Translation missing 
		-- ["Remove Channel Abbreviation"] = "",
		--Translation missing 
		-- ["Removes an an abbreviated channel name."] = "",
		["Replace"] = "Remplacer",
		--Translation missing 
		-- ["Set"] = "",
		--Translation missing 
		-- ["space_desc"] = "",
		--Translation missing 
		-- ["space_name"] = "",
		["Toggle replacing this channel."] = "Active/Désactive le texte de remplacement pour ce canal.",
		["Use a custom replacement for the chat %s text."] = "Utiliser un texte de remplacement pour le canal %s.",
	},
	["ChannelSticky"] = {
		--Translation missing 
		-- ["Channel"] = "",
		--Translation missing 
		-- ["ChannelSticky"] = "",
		--Translation missing 
		-- ["Chat channel sticky options."] = "",
		--Translation missing 
		-- ["ChatType"] = "",
		--Translation missing 
		-- ["Per chat type options."] = "",
		["smartgroup_desc"] = "Ajouter une commande /gr qui sélectionne automatiquement le bon type de chat : raid, groupe, champ de bataille",
		["smartgroup_name"] = "Groupes intelligents",
		--Translation missing 
		-- ["Sticky %s"] = "",
		--Translation missing 
		-- ["Sticky Per Chat Frame"] = "",
		--Translation missing 
		-- ["Toggle remembering the chat type last used per chat frame."] = "",
		--Translation missing 
		-- ["Toggles sticky on and off for %s."] = "",
	},
	["ChatFrames"] = {
		["Chat window frame parameter options"] = "Options de la fenêtre de discussion",
		["framealpha_desc"] = "Définit la transparence de la fenêtre de discussion quand la souris passe par dessus.",
		["framealpha_name"] = "Transparence",
		["Frames"] = "Fenêtre",
		["mainchatonload_desc"] = "Sélectionne automatiquement la première fenêtre de discussion et la rend active lors du chargement.",
		--Translation missing 
		-- ["mainchatonload_name"] = "",
		["maxchatheight_desc"] = "Définit la hauteur maximale pour toutes les fenêtres de discussion.",
		["maxchatheight_name"] = "Hauteur maximale",
		["maxchatwidth_desc"] = "Définit la largeur maximale pour toutes les fenêtres de discussion.",
		["maxchatwidth_name"] = "Largeur maximale",
		["minchatheight_desc"] = "Définit la hauteur minimum pour toutes les fenêtres de discussion.",
		["minchatheight_name"] = "Hauteur minimum",
		["minchatwidth_desc"] = "Définit la largeur minimum pour toutes les fenêtres de discussion.",
		["minchatwidth_name"] = "Largeur minimum",
		--Translation missing 
		-- ["rememberframepositions_desc"] = "",
		--Translation missing 
		-- ["rememberframepositions_name"] = "",
		--Translation missing 
		-- ["removeclamp_desc"] = "",
		--Translation missing 
		-- ["removeclamp_name"] = "",
	},
	["ChatLink"] = {
		--Translation missing 
		-- ["gem_desc"] = "",
		--Translation missing 
		-- ["gem_name"] = "",
		--Translation missing 
		-- ["module_desc"] = "",
		--Translation missing 
		-- ["module_info"] = "",
		--Translation missing 
		-- ["module_name"] = "",
		--Translation missing 
		-- ["Trade"] = "",
	},
	["ChatLog"] = {
		["A module to automaticaly enable chat and combat logging."] = "Un module pour activer automatiquement la journalisation du chat et des combats",
		["Chat log recorded to <WoW Installation>\\Logs\\WoWChatLog.txt only upon logout."] = "Journalisation du chat enregistré dans <WoW Installation>\\Logs\\WoWChatLog.txt jusqu'à la prochaine déconnexion",
		["Chat Log: Disabled"] = "Journalisation Chat : Désactivé",
		["Chat Log: Enabled"] = "Journalisation Chat : Activé",
		["ChatLog"] = true,
		["Combat log recorded to <WoW Installation>\\Logs\\WoWCombatLog.txt only upon logout."] = "Journalisation des combats enregistré dans <WoW Installation>\\Logs\\WoWChatLog.txt jusqu'à la prochaine déconnexion",
		["Combat Log: Disabled"] = "Journalisation des combats : Désactivé",
		["Combat Log: Enabled"] = "Journalisation des combats : Activé",
		["quiet_desc"] = "N'afficher aucun messages quand ce mod est activé ou quand il change les paramètres de journalisation",
		["quiet_name"] = "Supprimer les messages de feedback",
		["Toggle Chat Log"] = "Activer la journalisation du chat",
		["Toggle chat log on and off."] = "Activer/Désactiver la journalisation du chat",
		["Toggle Combat Log"] = "Activer la journalisation des combat",
		["Toggle combat log on and off."] = "Activer/Désactiver la journalisation des combats",
	},
	["ChatTabs"] = {
		["Active Alpha"] = "Transparence",
		["All"] = "Tout",
		["Always"] = "Toujours",
		["Chat window tab options."] = "Options des onglets des fenêtres de discussion.",
		["Default"] = "Défaut",
		["disableflash_desc"] = "Désactiver le clignotement des onglets.",
		["disableflash_name"] = "Pas de clignotement",
		["Hidden"] = "Caché",
		["Individual"] = "Individuel",
		["Not Active Alpha"] = "Transparence inactive",
		["preventdrag_desc"] = "Empêcher le déplacement des onglets avec la souris",
		["preventdrag_name"] = "Verrouiller",
		["Set ChatFrame%d Display Mode"] = "Définir le mode d'affichage de la fenêtre de discussion %d",
		["Set Display Mode"] = "Mode d'affichage",
		["Set tab display mode for each chat window."] = "Définir le mode d'affichage des onglets pour chaque fenêtre de chat. Coché (On), Décoché (Off) Coché en gris (Défaut)",
		["Set tab display to always, hidden or the Blizzard default."] = "Définir l'affichage des onglets sur toujours, caché ou par défaut Blizzard",
		["Sets alpha of chat tab for active chat frame."] = "Définit la transparence de l'onglet pour les fenêtres de discussion actives.",
		["Sets alpha of chat tab for not active chat frame."] = "Définit la transparence de l'onglet pour les fenêtres de discussion inactives.",
		["Tabs"] = "Onglets",
	},
	["Clear"] = {
		["Adds clear text slash commands (/clear)(/cls)(/clearall)(/clsall)."] = "Ajoute les commandes slash de nettoyage du texte (/clear)(/cls)(/clearall)(/clsall).",
		["Clear"] = "Effacer",
		["Clearall"] = "EffacerTout",
		["Clears all chat frames."] = "Efface toutes les fenêtres de discussion.",
		["Clears the current chat frame."] = "Efface la fenêtre de discussion actuelle.",
	},
	["CopyChat"] = {
		[" Text"] = "Texte",
		["BBCode"] = true,
		--Translation missing 
		-- ["BOTTOMLEFT"] = "",
		--Translation missing 
		-- ["BOTTOMRIGHT"] = "",
		--Translation missing 
		-- ["buttonpos_desc"] = "",
		--Translation missing 
		-- ["buttonpos_name"] = "",
		--Translation missing 
		-- ["ChatFrame"] = "",
		["Copy all of the text in the selected chat frame into an edit box"] = "Copier tout le texte de la fenêtre de discussion sélectionnée dans une boîte d'édition.",
		["Copy Text"] = "Copier le texte",
		["Copy Text Format"] = "Format du texte copié",
		["Copy text from the active chat window."] = "Copier le texte à partir de la fenêtre de discussion active.",
		--Translation missing 
		-- ["Copy To Editbox"] = "",
		["CopyChat"] = "Copier",
		["HTML"] = true,
		["Message From : %s"] = "Message de : %s",
		["Plain"] = "Texte seul",
		["Should the copied text be plain, or formatted so you can see the colors."] = "Le texte copié doit-il être seul, ou formaté de tel manière à voir les couleurs.",
		["showbutton_desc"] = "Montrer un bouton sur la fenêtre de discussion.",
		["showbutton_name"] = "Bouton de copie",
		--Translation missing 
		-- ["TOPLEFT"] = "",
		--Translation missing 
		-- ["TOPRIGHT"] = "",
		["Wowace.com Forums"] = "Forums wowace.com",
	},
	["CustomFilters"] = {
		--Translation missing 
		-- ["<string>"] = "",
		--Translation missing 
		-- ["Add a pattern to search for."] = "",
		--Translation missing 
		-- ["Add Pattern"] = "",
		--Translation missing 
		-- ["Block Message"] = "",
		--Translation missing 
		-- ["Channel Data"] = "",
		--Translation missing 
		-- ["Channel to send output text to."] = "",
		["Enabled"] = "Activé",
		--Translation missing 
		-- ["Extra data for WHISPER (target) and CHANNEL (channel name or num)"] = "",
		--Translation missing 
		-- ["Filter Name"] = "",
		--Translation missing 
		-- ["Forward"] = "",
		--Translation missing 
		-- ["Forward the message to a chat channel."] = "",
		--Translation missing 
		-- ["Forward the message to a custom chat channel."] = "",
		--Translation missing 
		-- ["ForwardCustom"] = "",
		--Translation missing 
		-- ["ForwardMessage"] = "",
		--Translation missing 
		-- ["ForwardMessageCustom"] = "",
		--Translation missing 
		-- ["Hilight Color"] = "",
		--Translation missing 
		-- ["Hilight Match Text"] = "",
		--Translation missing 
		-- ["Inbound"] = "",
		--Translation missing 
		-- ["inchannels_desc"] = "",
		--Translation missing 
		-- ["inchannels_name"] = "",
		--Translation missing 
		-- ["Is this pattern enabled for use?"] = "",
		--Translation missing 
		-- ["Match Options"] = "",
		--Translation missing 
		-- ["module_desc"] = "",
		--Translation missing 
		-- ["module_name"] = "",
		--Translation missing 
		-- ["Only output the message portion of the chat text, leave out the channel, and playername etc."] = "",
		--Translation missing 
		-- ["Outbound"] = "",
		--Translation missing 
		-- ["Output Channel"] = "",
		--Translation missing 
		-- ["Output Message Only"] = "",
		--Translation missing 
		-- ["Pattern Info"] = "",
		--Translation missing 
		-- ["Pattern Options"] = "",
		--Translation missing 
		-- ["Play a sound when this message is output to the chatframe"] = "",
		--Translation missing 
		-- ["Play Sound"] = "",
		--Translation missing 
		-- ["Prevent the message from being displayed"] = "",
		--Translation missing 
		-- ["Remove an existing pattern."] = "",
		--Translation missing 
		-- ["Remove Pattern"] = "",
		--Translation missing 
		-- ["Replacement Text"] = "",
		--Translation missing 
		-- ["Search Format String"] = "",
		--Translation missing 
		-- ["Search Pattern"] = "",
		--Translation missing 
		-- ["Secondary Output"] = "",
		--Translation missing 
		-- ["Send to a secondary output"] = "",
		--Translation missing 
		-- ["Supplied pattern is a format string instead of a pattern"] = "",
		--Translation missing 
		-- ["Your name for this filter"] = "",
	},
	["Editbox"] = {
		["Attach edit box to..."] = "Définit la position de la boîte d'édition.",
		["Attach to..."] = "Position",
		["Background color"] = "Couleur du fond",
		["Background Inset"] = "Marge du fond",
		["Background texture"] = "Texture du fond",
		["Border color"] = "Couleur de la bordure",
		["Border texture"] = "Texture de la bordure",
		["Bottom"] = "Bas",
		["Color border by channel"] = "Colorier avec le canal",
		--Translation missing 
		-- ["currently_broken_alt_behavior"] = "",
		["Edge Size"] = "Taille de la bordure",
		["Editbox"] = "Boite d'édition",
		["Editbox options."] = "Options de la boite d'édition.",
		["Font"] = "Police d'écriture",
		["Free-floating"] = "Flottante",
		["Free-floating, Locked"] = "Flottante, verrouillée",
		["Requires the Alt key to be held down to move the cursor in chat"] = "Requiert de maintenir la touche Alt enfoncée pour déplacer le curseur lorsque vous écrivez un message.",
		["Select the font to use for the edit box"] = "Définit la police du texte dans la boîte d'édition.",
		["Sets the frame's border color to the color of your currently active channel"] = "Définit la couleur de la bordure avec la couleur du canal actif.",
		["Tile Size"] = "Taille du fond",
		["Top"] = "Haut",
		["Use Alt key for cursor movement"] = "Curseur avec Alt",
	},
	["EventNames"] = {
		--Translation missing 
		-- ["allevents_desc"] = "",
		--Translation missing 
		-- ["allevents_name"] = "",
		["Chat window event name options."] = "Options des évènements de la fenêtre de chat",
		["EventNames"] = "Nom des évènements",
		["Show"] = "Montrer",
		["Show events on chatframes"] = "Montrer les évènements dans le cadre du chat",
		["show_desc"] = "Activer l'affichage des noms d'évènements dans chaque fenêtre",
		["show_name"] = "Montrer les noms d'évènements",
	},
	["Fading"] = {
		["duration_desc"] = "Définir le nombre de secondes à attendre avant la disparition du texte de la fenêtre de chat",
		["duration_name"] = "Délai avant fondu (secondes)",
		["module_desc"] = "Option des délais de disparition.",
		["module_name"] = "Fondu",
		["textfade_desc"] = "Activé le fondu pour chaque fenêtre de discussions.",
		["textfade_name"] = "Activé le fondu",
	},
	["Filtering"] = {
		["A module to provide basic chat filtering."] = "Un module pour fournir un filtrage basique",
		--Translation missing 
		-- ["afkdnd_desc"] = "",
		--Translation missing 
		-- ["afkdnd_name"] = "",
		["bgjoin_desc"] = "Filtrer les messages du canal Champ de bataille: \"quitte/rejoint\"",
		["bgjoin_name"] = "Filtrer BG quitte/rejoint",
		["Filtering"] = "Filtrage",
		["leavejoin_desc"] = "Filtrer les messages: \"quitte/rejoint le canal\"",
		["leavejoin_name"] = "Filtre Rejoindre/Quitte",
		--Translation missing 
		-- ["notices_desc"] = "",
		["notices_name"] = "Notifications de filtrage",
		--Translation missing 
		-- ["tradespam_desc"] = "",
		--Translation missing 
		-- ["tradespam_name"] = "",
	},
	["Font"] = {
		["Auto Restore Font Size"] = "Restauration automatique de la taille du texte",
		["Chat window font options."] = "Options de formatage du texte.",
		["Font"] = "Police",
		["monochrome_desc"] = "Activer/Désactiver la monochromie de la police.",
		["monochrome_name"] = "Monochromie",
		["None"] = "Aucun",
		["Outline"] = "Contour",
		["outlinemode_desc"] = "Définit le contour autour de la police.",
		["outlinemode_name"] = "Contour de la police",
		["rememberfont_desc"] = "Se souvenir de la police du texte et la restaurer au chargement.",
		["rememberfont_name"] = "Mémoriser la police",
		["Set ChatFrame%d Font Size"] = "Définit la taille de la police de la fenêtre de discussion %d",
		["Set Font Face"] = "Police d'écriture",
		["Set Font Size"] = "Taille de la police",
		["Set Separately"] = "Configurer séparément",
		["Set text font size for each chat window."] = "Définir la taille du texte de chaque fenêtre.",
		["Set text font size."] = "Définit la taille du texte.",
		["Set the text font face for all chat windows."] = "Définit la police du texte pour toutes les fenêtres de discussions.",
		["shadowcolor_desc"] = "Définit la couleur de l'ombre.",
		["shadowcolor_name"] = "Couleur de l'ombre",
		["Thick Outline"] = "Contour épais",
		["Toggle setting options separately for each chat window."] = "Activer/Désactiver les options séparées pour chaque fenêtre.",
		["Workaround a Blizzard bug which changes the font size when you open a system menu."] = "Contourner un bug de Blizzard qui change la taille de la police quand on ouvre un menu système.",
	},
	["History"] = {
		["Chat history options."] = "Option de l'historique.",
		--Translation missing 
		-- ["Color GMOTD"] = "",
		--Translation missing 
		-- ["Colors the GMOTD label"] = "",
		["delaygmotd_desc"] = "Afficher le message du jour de la guilde après tous les autres messages lors de la connexion.",
		--Translation missing 
		-- ["delaygmotd_name"] = "",
		["divider"] = "========== Fin de l'historique ==========",
		["History"] = "Historique",
		["Maximum number of lines of command history to save."] = "Nombre maximum de lignes de commande à sauvegarder dans l'historique.",
		["Save Command History"] = "Historique de commandes",
		["Saves command history between sessions (for use with alt+up arrow or just the up arrow)"] = "Sauvegarde l'historique des commandes entre les sessions (à utiliser avec alt+haut ou juste haut)",
		--Translation missing 
		-- ["Scrollback"] = "",
		--Translation missing 
		-- ["Scrollback Options"] = "",
		["scrollbacklen_desc"] = "Nombre de lignes de discussions à sauvegarder dans l'historique.",
		["scrollbacklen_name"] = "Taille de l'historique",
		["Set Chat Lines"] = "Historique de discussions",
		["Set Command History"] = "Historique de commandes",
		["Set the number of lines of chat history for each window."] = "Définit le nombre de lignes dans l'historique pour chaque fenêtre.",
		["Store the chat lines between sessions"] = "Sauvegarder l'historique des discussions entre les sessions.",
	},
	["KeyBindings"] = {
		["Channel %d"] = "Canal %d",
		["Copy Selected Chat Frame"] = "Copier la fenêtre de chat sélectionné",
		["Guild Channel"] = "Canal de Guilde",
		["Instance Channel"] = "Canal d'Instance",
		--Translation missing 
		-- ["Next Chat Tab"] = "",
		["Officer Channel"] = "Canal Officier",
		["Party Channel"] = "Canal de Groupe",
		["Prat CopyChat"] = "Prat Copier-le-Chat",
		["Prat Keybindings"] = "Prat Association-de-touche",
		["Prat TellTarget"] = "Prat Dire-à-la-cible",
		["Raid Channel"] = "Canal Raid",
		["Raid Warning Channel"] = "Canal Avertissement",
		["Say"] = "Dire",
		--Translation missing 
		-- ["Smart Group Channel"] = "",
		["TellTarget"] = "Chuchoter à la cible",
		["Whisper"] = "Chuchoter",
		["Yell"] = "Crier",
	},
	["OriginalButtons"] = {
		["alpha_desc"] = "Définir l'alpha du menu du chat et des flèches pour toutes les fenêtres.",
		["alpha_name"] = "Définir l'alpha",
		--Translation missing 
		-- ["buttonframe_desc"] = "",
		--Translation missing 
		-- ["buttonframe_name"] = "",
		["ChannelNames"] = "Noms-des-Canaux",
		["Chat window button options."] = "Bouton d'options de la fenêtre de chat.",
		["chatmenu_desc"] = "Activer et désactiver le menu du chat",
		["chatmenu_name"] = "Afficher le menu de chat",
		["Default"] = "Défaut",
		["Original Buttons"] = "Boutons d'origine",
		--Translation missing 
		-- ["reflow_desc"] = "",
		--Translation missing 
		-- ["reflow_name"] = "",
		["reminder_desc"] = "Montrer une icône de rappel lorsque vous n'êtes pas en bas de la fenêtre de chat",
		["reminder_name"] = "Montrer un rappel pour le défilement vers le bas",
		["Right, Inside Frame"] = "Droite, Dans le cadre",
		["Right, Outside Frame"] = "Droite, En dehors du cadre",
		["Set Position"] = "Définir la position",
		["Sets position of chat menu and arrows for all chat windows."] = "Définir la position du menu de chat et des flèches pour toute les fenêtres.",
		["Show Arrows"] = "Afficher les flèches",
		["Show Chat%d Arrows"] = "Montrer les flèches du Chat%d",
		["Toggle showing chat arrows for each chat window."] = "Activer les flèches de chat pour chaque fenêtre de chat",
		["Toggles navigation arrows on and off."] = "Activer et désactiver les flèches de navigation",
	},
	["OriginalEditbox"] = {
		--Translation missing 
		-- ["Autohide"] = "",
		--Translation missing 
		-- ["BACKGROUND"] = "",
		--Translation missing 
		-- ["Bar colour"] = "",
		--Translation missing 
		-- ["Border colour"] = "",
		--Translation missing 
		-- ["Border width"] = "",
		--Translation missing 
		-- ["Bottom"] = "",
		--Translation missing 
		-- ["Click the edit box to open it up for editing. Only available if Autohide is disabled."] = "",
		--Translation missing 
		-- ["Clickable"] = "",
		--Translation missing 
		-- ["DIALOG"] = "",
		--Translation missing 
		-- ["Editbox options."] = "",
		--Translation missing 
		-- ["Enable Arrowkeys"] = "",
		--Translation missing 
		-- ["Enable using arrowkeys in editbox without the alt key."] = "",
		["Hide Border"] = "Cacher la bordure",
		["Hide the border around the edit box."] = "Cacher la bordure autour de l'invite de discussion.",
		["Hide the edit box after you have pressed enter."] = "Cacher l'invite de discussion après avoir fait Entrée.",
		["HIGH"] = "HAUT",
		--Translation missing 
		-- ["Lock editbox position if undocked."] = "",
		["Lock Position"] = "Verrouiller la position",
		["LOW"] = "BAS",
		["MEDIUM"] = "MILIEU",
		--Translation missing 
		-- ["OriginalEditbox"] = "",
		--Translation missing 
		-- ["Padding"] = "",
		["Set Alpha"] = "Définir la transparance",
		["Set Position"] = "Définir la position",
		["Set Strata"] = "Définir la couche",
		["Set the alpha of the editbox."] = "Définit la transparence de la boite d'édition",
		["Set the amount of padding inside the edit box"] = "Définir la quantité d'espacement à l'intérieur de la boite d'édition",
		["Set the edit box background colour"] = "Définir la couleur de fond de la boite d'édition",
		["Set the edit box border colour"] = "Définir la couleur de la bordure de la boite d'édition",
		--Translation missing 
		-- ["Set the frame strata of the editbox."] = "",
		["Set the position of the editbox."] = "Définir la position de l'invite de discussion.",
		["Set the texture of the chat edit box"] = "Définir la texture de l'invite de discussion",
		["Set the width of the edit box's border"] = "Définir la largeur de la bordure de l'invite de discussion",
		["Set the width of the editbox."] = "Définir la largeur de l'invite de discussion.",
		--Translation missing 
		-- ["Set Width (NB: only enabled if the editbox is undocked)"] = "",
		["Texture"] = true,
		["Top"] = "Haut",
		--Translation missing 
		-- ["Undocked"] = "",
	},
	["Paragraph"] = {
		["adjustlinks_desc"] = "Ajuster les liens pour pouvoir cliquer dessus si ils sont centrés ou alignés à droite.",
		["adjustlinks_name"] = "Répare la position des liens des joueurs/objets",
		["Center"] = "Centrer",
		["Chat window paragraph options."] = "Options de paragraphe.",
		["justification_desc"] = "Défiinr l'alignement horizontale pour chaque fenêtre de chat",
		["justification_name"] = "Définir l'alignement",
		["Left"] = "Gauche",
		["Line Spacing"] = "Espacement des lignes",
		["Paragraph"] = "Paragraphe",
		["Right"] = "Droite",
		["Set the line spacing for all chat windows."] = "Définit l'espacement des lignes pour toutes les fenêtres de discussions.",
	},
	["PlayerNames"] = {
		["Actively Query Player Info"] = "Interroger activement les joueurs",
		["Angled"] = "Chevrons",
		["Brackets"] = "Crochets",
		["Brackets Common Color"] = "Couleur des crochets",
		["Brackets Use Common Color"] = "Couleur des crochets",
		["Class"] = "Classe du joueur",
		["Color by Level Difference"] = "Différence de niveau",
		["coloreverywhere_desc"] = "Colorier le nom des joueurs si ils apparaissent dans le texte des messages.",
		["coloreverywhere_name"] = "Couleur partout",
		["Enable Alt-Invite"] = "Invitation avec Alt",
		["Enable Invite Links"] = "Liens d'invitation",
		["Enable TabComplete"] = "Complétion avec Tab",
		["hoverhilight_desc"] = "Mettre en surbrillance les lignes de chat d'un joueur spécifique quand la souris survole un lien vers ce joueur",
		["hoverhilight_name"] = "Surbrillance de noms survolés",
		["How to color other player's level."] = "Définit la couleur du niveau des autres joueurs.",
		["How to color player's name."] = "Définit la couleur du nom des joueurs.",
		["Keep Info"] = "Garder les info.",
		["Keep Lots Of Info"] = "Garder beaucoup d'info.",
		["Keep player information between session for all players except cross-server players"] = "Garder les informations sur tous les joueurs entre les sessions sauf pour les joueurs inter-serveurs.",
		["Keep player information between session, but limit it to friends and guild members."] = "Garder les informations sur les joueurs entre les sessions, mais seulement pour les amis et membres de la guilde.",
		["Let TasteTheNaimbow set the common color for unknown player names."] = "Laisser TasteTheNaimbow définir la couleur des joueurs inconnus.",
		["Level Color Mode"] = "Couleur des niveaux",
		--Translation missing 
		-- ["linkifycommon_desc"] = "",
		--Translation missing 
		-- ["linkifycommon_name"] = "",
		["No additional coloring"] = "Pas de couleur",
		["None"] = "Aucun",
		["Player Color Mode"] = "Couleur des joueurs",
		["Player name formating options."] = "Options de formatage pour les noms des joueurs.",
		["PlayerNames"] = "Nom des joueurs",
		["Prat_Playernames: Stored Player Data Cleared"] = "Prat_Playernames: Informations des joueurs réinitialisées.",
		["Query the server for all player names we do not know. Note: This happpens pretty slowly, and this data is not saved."] = "Interroge le serveur pour tous les noms de joueurs que nous ne connaissons pas. Note : Cela peut être très lent, et les informations ne sont pas sauvegardées.",
		["Random"] = "Aléatoire",
		["realidcolor_desc"] = "Couleur des noms RealID.",
		["realidcolor_name"] = "Couleur RealID",
		["Reset Settings"] = "Réinitialiser",
		["Restore default settings, and delete stored character data."] = "Remets les options par défaut, et supprime toutes les informations enregistrées sur les joueurs.",
		["Set common color of unknown player names."] = "Définit la couleur pour les noms de joueurs inconnus.",
		["Sets common color of brackets to use around player names."] = "Définit la couleur des crochets autour du noms des joueurs.",
		["Sets style of brackets to use around player names."] = "Définit le style des crochets autour du nom des joueurs.",
		["Show Group"] = "Montrer le groupe",
		["Show Level"] = "Montrer le niveau",
		["Show Raid Target Icon"] = "Montrer l'icône de raid",
		["Square"] = "Crochets",
		["Tab completion : "] = "Auto-complétion :",
		["tabcomplete_name"] = "Noms possibles",
		["Toggle group invites by alt-clicking hyperlinked keywords like 'invite'."] = "Active/Désactive l'invitation de groupe en faisant Alt+clic sur des mots-clé hyperliens comme 'inviter'.",
		["Toggle group invites by alt-clicking on player name."] = "Active/Désactive l'invitation de groupe en faisant Alt+clic sur le nom d'un joueur.",
		["Toggle level showing."] = "Active/Désactive l'affichage du niveau.",
		["Toggle raid group showing."] = "Active/Désactive l'affichage du groupe de raid.",
		["Toggle showing the raid target icon which is currently on the player."] = "Active/Désactive l'affichage de l'icône de raid qui est sur le joueur.",
		["Toggle tab completion of player names."] = "Active/Désactive l'auto-complétion du nom des joueurs.",
		["Toggle using a common color for brackets around player names."] = "Active/Désactive l'utilisation d'une couleur commune pour les crochets autour du nom des joueurs.",
		["Toggle using a common color for unknown player names."] = "Active/Désactive l'utilisation d'une couleur commune pour les joueurs inconnus.",
		["Too many matches (%d possible)"] = "Trop de résultats (%d possibles)",
		["Unknown Common Color"] = "Couleur pour inconnu",
		--Translation missing 
		-- ["Unknown Common Color From TasteTheNaimbow"] = "",
		["Unknown Use Common Color"] = "Couleur pour inconnu",
		["Use Channel Color"] = "Couleur du canal",
		["Use Player Color"] = "Couleur du joueur",
		--Translation missing 
		-- ["Use toon name for RealID"] = "",
	},
	["PopupMessage"] = {
		["Add Nickname"] = "Ajouter un surnom",
		--Translation missing 
		-- ["Adds an alternate name to show in popups."] = "",
		["Clear Nickname"] = "Efface le surnom",
		--Translation missing 
		-- ["Clears alternate name to show in popups."] = "",
		["framealpha_desc"] = "Régler la transparence de la popup lorsqu'elle disparait.",
		["framealpha_name"] = "Transparence des popups",
		["Popup"] = true,
		["PopupMessage"] = "Message popup",
		["Remove Nickname"] = "Retirer un surnom",
		--Translation missing 
		-- ["Removes an alternate name to show in popups."] = "",
		["Set Separately"] = "Afficher séparément",
		["Show All Popups"] = "Afficher toutes les popups",
		["Show Popups"] = "Afficher les popups",
		["Show Popups for all chat windows."] = "Afficher les popups pour toutes les fenêtres de discussion.",
		["Show Popups for each window."] = "Afficher les popups pour chaque fenêtre.",
		["show_desc"] = "Afficher les popups pour chaque fenêtre.",
		["show_name"] = "Afficher les popups",
		["show_perframedesc"] = "Active ou désactive l'affichage des popups.",
		["show_perframename"] = "Afficher les popups de la fenêtre de discussion %d",
		["showall_desc"] = "Afficher les popups pour toutes les fenêtres de discussion.",
		["showall_name"] = "Afficher toutes les popups",
		["Shows messages in a popup window."] = "Afficher les messages dans une fenêtre popup.",
		["Shows messages with your name in a popup."] = "Afficher les messages avec votre nom dans une popup.",
		["Toggle setting options separately for each chat window."] = "Activer des préférences différentes pour chaque fenêtre de discussion.",
	},
	["Scroll"] = {
		["Bottom"] = "Bas vers le haut",
		["Chat window scrolling options."] = "Options de défilement.",
		["Control whether text is added to the frame at the top or the bottom."] = "Définit si le texte est ajouté en bas ou en haut de la fenêtre.",
		--Translation missing 
		-- ["lowdown_desc"] = "",
		--Translation missing 
		-- ["lowdown_name"] = "",
		--Translation missing 
		-- ["modified_speed"] = "",
		--Translation missing 
		-- ["modified_speed_desc"] = "",
		["mousewheel_desc"] = "Active/Désactive le support de la molette pour chaque fenêtre.",
		["mousewheel_name"] = "Activer la molette",
		["Scroll"] = "Défilement",
		["Set Ctrl+MouseWheel Speed"] = "Vitesse Ctrl+Molette",
		["Set MouseWheel Speed"] = "Vitesse Molette",
		["Set number of lines mousewheel will scroll when ctrl is pressed."] = "Définit le nombre de lignes qui défilent lorsque Ctrl est enfoncé.",
		["Set number of lines mousewheel will scroll."] = "Définit le nombre de lignes qui défilent lors d'un coup de molette avec la souris.",
		--Translation missing 
		-- ["Set TheLowDown Delay"] = "",
		["Set time to wait before jumping to the bottom of chat windows."] = "Régler le temps d'attente avant de sauter au bas de la fenêtre de chat.",
		["Text scroll direction"] = "Direction du texte",
		["Top"] = "Haut en bas",
	},
	["Search"] = {
		--Translation missing 
		-- ["err_notfound"] = "",
		--Translation missing 
		-- ["err_tooshort"] = "",
		--Translation missing 
		-- ["find_results"] = "",
		--Translation missing 
		-- ["module_desc"] = "",
		--Translation missing 
		-- ["module_info"] = "",
		--Translation missing 
		-- ["module_name"] = "",
	},
	["ServerNames"] = {
		["autoabbreviate_desc"] = "Raccourcir le nom des serveurs à 3 lettres.",
		["autoabbreviate_name"] = "Abréviation",
		--Translation missing 
		-- ["colon_desc"] = "",
		--Translation missing 
		-- ["colon_name"] = "",
		["randomclr_desc"] = "Utiliser une couleur aléatoire pour chaque serveur.",
		["randomclr_name"] = "Couleurs aléatoires",
		["Server name abbreviation options."] = "Options d'abréviation des noms de serveur.",
		["ServerNames"] = "Noms de serveur",
	},
	["Sounds"] = {
		["A module to play sounds on certain chat messages."] = "Un module pour jouer un son sur certains évènements de messages.",
		["Add a custom channel"] = "Ajouter un canal",
		["bn_whisper_desc"] = "Son pour les messages Battle.Net %s",
		["bn_whisper_name"] = "Chuchotement Battle.Net",
		["Custom Channels"] = "Canaux personnalisés",
		["group_lead_desc"] = "Son pour les messages des leaders de raid, de groupe, ou des maîtres de donjon %s",
		["group_lead_name"] = "Chef de groupe",
		["guild_desc"] = "Son pour les messages de guilde %s",
		["guild_name"] = "Guilde",
		["incoming"] = "entrants",
		["Incoming Sounds"] = "Sons entrants",
		["officer_desc"] = "Son pour les messages d'officier %s",
		["officer_name"] = "Officier",
		["outgoing"] = "sortants",
		["Outgoing Sounds"] = "Sons sortants",
		["party_desc"] = "Son pour les messages de groupe %s",
		["party_name"] = "Groupe",
		["Play a sound for a certain channel name (can be a substring)"] = "Jouer un son pour un certain nom de canal (peut être une sous chaîne)",
		["raid_desc"] = "Son pour les messages de raid/CdB %s",
		["raid_name"] = "Raid",
		["Remove a custom channel"] = "Supprimer un canal personnalisé",
		["Reset settings"] = "Réinitialiser les options",
		["Restore default settings and resets custom channel list"] = "Restaurer les options par défaut et réinitialise la liste des canaux personnalisés",
		["Sound selection for incoming chat messages"] = "Sélection du son pour les messages entrants",
		["Sound selection for outgoing (from you) chat messages"] = "Sélection du son pour les messages sortants (de vous)",
		["Sounds"] = "Sons",
		["whisper_desc"] = "Son pour les messages privés %s",
		["whisper_name"] = "Chuchoter",
	},
	["Substitutions"] = {
		["%d total user defined substitutions"] = "%s substitutions personnalisées totales",
		--Translation missing 
		-- ["|cffff0000warning:|r subtitution \"%s\" already defined as \"%s\", overwriting"] = "",
		["<noguild>"] = "<pas de guilde>",
		["<notarget>"] = "<pas de cible>",
		["A module to provide basic chat substitutions."] = "Un module qui propose quelques substitutions basiques.",
		["Are you sure - this will delete all user defined substitutions and reset defaults?"] = "Etes-vous sûr ? Cela supprimera toutes les substitutions personnalisées et réinitialisera les valeurs par défaut.",
		["Are you sure?"] = "Êtes-vous sûr ?",
		--Translation missing 
		-- ["can't find substitution index for a substitution named '%s'"] = "",
		["current-prompt"] = [=[Valeur actuelle : '%s'
Cliquez pour coller dans le chat.]=],
		--Translation missing 
		-- ["defined %s: expands to => %s"] = "",
		["Delete all"] = "Tout supprimer",
		["Delete substitution"] = "Supprimer la substitution",
		["Deletes a user defined substitution"] = "Supprime une substitution personnalisée",
		["Deletes all user defined substitutions"] = "Supprime toutes les substitutions personnalisées",
		--Translation missing 
		-- ["female"] = "",
		--Translation missing 
		-- ["her"] = "",
		--Translation missing 
		-- ["hers"] = "",
		--Translation missing 
		-- ["him"] = "",
		--Translation missing 
		-- ["his"] = "",
		--Translation missing 
		-- ["it"] = "",
		--Translation missing 
		-- ["its"] = "",
		["List of available substitutions"] = "Liste des substitution disponibles",
		["List of available substitutions defined by this module. (NB: users may define custom values for existing substitutions, but they will revert to the default value if the user definition is deleted.)"] = "Liste toutes les substitutions disponibles définies par ce module. (NB: l'utilisateur peut définir des valeurs personnalisées pour les substitutions existantes, mais celles-ci seront remisent à leurs valeurs par défaut si les options sont réinitialisées.)",
		["List substitutions"] = "Liste des substitutions",
		["Lists all current subtitutions in the default chat frame"] = "Liste toutes les substitutions dans la fenêtre de discussion",
		--Translation missing 
		-- ["male"] = "",
		["MapLoc"] = "Localisation",
		["MapPos"] = "Position",
		["MapXPos"] = "Position X",
		["MapYPos"] = "Position Y",
		["MapZone"] = "Zone",
		--Translation missing 
		-- ["module:buildUserSubsIndex(): warning: module patterns not defined!"] = "",
		--Translation missing 
		-- ["MouseoverTargetName"] = "",
		["NO MATCHFUNC FOUND"] = "PAS DE FONCTION ASSOCIÉE TROUVÉE",
		--Translation missing 
		-- ["no substitution name given"] = "",
		--Translation missing 
		-- ["no substitution name supplied for deletion"] = "",
		--Translation missing 
		-- ["no user defined subs found"] = "",
		--Translation missing 
		-- ["no value given for subtitution \"%s\""] = "",
		["Options for setting and removing user defined substitutions. (NB: users may define custom values for existing substitutions, but they will revert to the default value if the user definition is deleted.)"] = "Options pour ajouter ou enlever les substitutions définies par l'utilisateur. (NB: les utilisateurs peuvent changer la valeur des substitutions existantes, mais elles seront remisent à leur valeur par défaut si les préférences de l'utilisateur sont supprimés.)",
		--Translation missing 
		-- ["PlayerAverageItemLevel"] = "",
		["PlayerCurrentMana"] = "Mana actuelle",
		["PlayerHealthDeficit"] = "Déficit de vie",
		["PlayerHP"] = "HP actuel",
		["PlayerManaDeficit"] = "Déficit de mana",
		["PlayerMaxHP"] = "HP Max",
		["PlayerMaxMana"] = "Mana Max",
		["PlayerName"] = "Nom joueur",
		["PlayerPercentHP"] = "Pourcentage HP",
		["PlayerPercentMana"] = "Pourcentage Mana",
		["RandNum"] = "Nombre aléatoire",
		--Translation missing 
		-- ["removing user defined substitution \"%s\"; previously expanded to => \"%s\""] = "",
		["Set substitution"] = "Paramétrer une substitution",
		--Translation missing 
		-- ["Set the value of a user defined substitution (NB: this may be the same as an existing default substitution; to reset it to the default, just remove the user created definition)."] = "",
		--Translation missing 
		-- ["subname -- NOTE: sub name without the prefix '%'"] = "",
		--Translation missing 
		-- ["subname = text after expansion -- NOTE: sub name without the prefix \"%\""] = "",
		--Translation missing 
		-- ["substitution: %s defined as => %s"] = "",
		["Substitutions"] = true,
		["TargetClass"] = "Cible Classe",
		["TargetGender"] = "Cible Sexe",
		["TargetGuild"] = "Cible Guilde",
		["TargetHealth"] = "Santé Cible",
		["TargetHealthDeficit"] = "Déficit Vie Cible",
		["TargetIcon"] = "CibleIcone",
		["TargetLevel"] = "CibleNiveau",
		["TargetManaDeficit"] = "CibleManqueDeMana",
		--Translation missing 
		-- ["TargetName"] = "",
		--Translation missing 
		-- ["TargetPercentHP"] = "",
		--Translation missing 
		-- ["TargetPossesive"] = "",
		--Translation missing 
		-- ["TargetPronoun"] = "",
		--Translation missing 
		-- ["TargetRace"] = "",
		--Translation missing 
		-- ["TargetTargetName"] = "",
		["unknown sex"] = "sexe inconnue",
		--Translation missing 
		-- ["user defined substition \"%s\" not found"] = "",
		--Translation missing 
		-- ["User defined substitutions"] = "",
		--Translation missing 
		-- ["user substitutions index (usersubs_idx) doesn't exist! oh dear."] = "",
		--Translation missing 
		-- ["usersub_"] = "",
	},
	["TellTarget"] = {
		["/tt"] = true,
		["Adds telltarget slash command (/tt)."] = "Ajoute la commande telltarget (/tt) pour envoyer un message privé au joueur ciblé.",
		["No target selected."] = "Pas de cible sélectionnée.",
		["NoTarget"] = "PasDeCible",
		["Target does not exist."] = "La cible n'existe pas.",
		["Target is not a player."] = "La cible n'est pas un joueur.",
		["TellTarget"] = true,
	},
	["Timestamps"] = {
		["Chat window timestamp options."] = "Options de l'heure des messages.",
		["colortimestamp_desc"] = "Active/Désactive la couleur de l'heure des messages.",
		["colortimestamp_name"] = "Couleur de l'heure",
		["Format All Timestamps"] = "Formatage de l'heure",
		["HH:MM (12-hour)"] = "HH:MM (12 heures)",
		["HH:MM (24-hour)"] = "HH:MM (24 heures)",
		["HH:MM:SS (12-hour)"] = "HH:MM:SS (12 heures)",
		["HH:MM:SS (24-hour)"] = "HH:MM:SS (24 heures)",
		["HH:MM:SS AM (12-hour)"] = "HH:MM:SS AM (12 heures)",
		["localtime_desc"] = "Active/Désactive l'utilisation de l'heure locale.",
		["localtime_name"] = "Utiliser l'heure locale",
		["MM:SS"] = true,
		["Post-Timestamp"] = "Après l'heure",
		["Pre-Timestamp"] = "Avant l'heure",
		["Set the timestamp format"] = "Définit le format de l'heure.",
		["Set Timestamp Color"] = "Configurer la couleur",
		["Sets the color of the timestamp."] = "Définit la couleur de l'heure des messages.",
		["Show Timestamp"] = "Montrer l'heure des messages",
		["show_desc"] = "Active/Désactive l'affiche de l'heure pour chaque fenêtre.",
		["show_name"] = "Montrer l'heure des messages",
		["space_desc"] = "Active/Désactive l'ajout d'un espace après l'heure.",
		["space_name"] = "Montrer l'espace",
		["Timestamps"] = "Heure des messages",
		["Toggle showing timestamp for each window."] = "Active/Désactive l'affiche de l'heure des messages pour chaque fenêtre.",
		["twocolumn_desc"] = "Place l'heure dans une colonne séparée de manière à ce qu'aucun texte ne s'écrive en dessous de l'heure.",
		["twocolumn_name"] = "Discussion à 2 colonnes",
	},
	["UrlCopy"] = {
		["Change the color of the URL."] = "Définit la couleur des liens URL.",
		["Color URL"] = "Colorier les URL",
		["Set Color"] = "Couleur des URL",
		["Show Brackets"] = "Afficher les crochets",
		["Toggle"] = "Activé/Désactivé",
		["Toggle showing brackets on and off."] = "Active/Désactive l'affichage de crochets.",
		["Toggle the module on and off."] = "Active/Désactive le module.",
		["Toggle the URL color on and off."] = "Active/Désactive la couleur des liens URL.",
		["URL formating options."] = "Options de formatage des liens URL.",
		["UrlCopy"] = "Copie de liens",
		["Use Popup"] = "Utiliser une popup",
		["Use popup window to show URL."] = "Utiliser une popup pour afficher le lien URL sélectionné.",
	}
}

PL:AddLocale(PRAT_MODULE.name, "frFR",L)


L=
{
	["display_desc"] = "Steuerung und Darstellung des Chatfensters",
	["display_name"] = "Anzeigeeinstellungen",
	["extras_desc"] = "Verschiedene Module",
	["extras_name"] = "Sonstiges",
	["formatting_desc"] = "Darstellung der Zeilen im Chat ändern (Look&Feel)",
	["formatting_name"] = "Chat formatieren",
	["load_desc"] = "Steuert das Ladeverhalten dieses Moduls.",
	["load_disabled"] = "Ausgeschaltet",
	["load_disabledonrestart"] = "Deaktiviert (neu laden)",
	["load_enabled"] = "Eingeschaltet",
	["load_enabledonrestart"] = "Aktiviert (neu laden)",
	["load_no"] = "Nicht laden",
	["modulecontrol_desc"] = "Steuert das Laden und Aktivieren von Prat-Modulen.",
	["modulecontrol_name"] = "Modulsteuerung",
	["prat"] = "Prat",
	["reload_required"] = "Diese Änderung wird erst nach dem Neustart vollständig wirksam.",
	["AddonMsgs"] = {
		["Addon message options."] = "Optionen für AddOn-Meldungen",
		["AddonMsgs"] = "AddOn-Meldungen",
		["show_desc"] = "Anzeige versteckter AddOn-Meldungen in jedem Chatfenster ein-/ausschalten.",
		["show_name"] = "AddOn-Meldungen anzeigen",
		["show_perframedesc"] = "Anzeige versteckter AddOn-Meldungen ein-/ausschalten.",
		["show_perframename"] = "Addon-Meldungen in Chatfenster %d anzeigen",
	},
	["Alias"] = {
		[" - list all aliases; supply <keyword> to search for matching aliases (cmd aliases: /listallaliases)"] = "- Auflisten aller Aliase; <Suchbegriff> eingeben, um nach passenden Aliasen zu suchen (cmd aliases: /listallaliases)",
		["%s() called with blank string!"] = "%s() mit leerem String aufgerufen!",
		["%s() called with nil argument!"] = "%s() mit nil Parameter aufgerufen!",
		["/%s aliased to \"/%s\""] = "/%s hat nun den Alias \"/%s\"",
		["/%s aliased to: /%s"] = "/%s hat nun den Alias: /%s",
		["<alias> - remove the alias <alias> (cmd aliases: /delalias, /remalias)"] = "<alias> - entfernt den Alias <alias> (cmd aliases: /delalias, /remalias)",
		["<command>[ <value>] - alias <command> to be executed as <value>, or return the value of the currently defined alias for <command> if <command> has not been assigned a value. eg: \"/alias /examplehello /say hello there\" - typing \"/examplehello\" will now cause your character to say \"hello there\"; \"/alias examplehello\" - s \"/examplehello is aliased to /say hello there\" (cmd aliases: /addalias)"] = "<befehl>[ <wert>] - alias <befehl> auszuführen als <wert>, oder den Wert des gegenwärtig definierten Alias erwidern für <befehl> falls <befehl> noch kein Wert zugewiesen worden ist; z.B: \"/alias /beispielhallo /say hallo du\" - die Eingabe von \"/beispielhallo\" wird nun deinen Charakter veranlassen, zu sagen \"hallo du\"; \"/alias beispielhallo\" - s \"/beispielhallo is aliased to /say hallo du\" (befehl alias: /addalias)",
		["<keyword> - finds all aliases matching <keyword> (cmd aliases: /findalias)"] = "<keyword> - Findet alle Alias, die <keyword> (Stichwort) entsprechen (cmd aliases: /findalias)",
		["add"] = "hinzufügen",
		["add an alias"] = "Ein Alias hinzufügen",
		["alias \"/%s\" does not exist"] = "Alias \"/%s\" existiert nicht.",
		["dealiasing command /%s to /%s"] = "Alias des Befehls ausschalten /%s wird /%s ",
		["deleting alias \"/%s\" (previously aliased as \"/%s\")"] = "Alias \"/%s\" wird gelöscht (bisheriger Alias \"/%s\")",
		["Display extra information in the chat frame when commands are dealiased"] = "Zusätzliche Informationen im Chatfenster anzeigen, wenn Alias von Befehlen ausgeschaltet wird.",
		["Don't overwrite existing aliases when using /addalias"] = "Bestehende Alias nicht überschreiben, wenn /addalias benutzt wird.",
		["Expand aliases as you are typing"] = "Autovervollständigung von Alias während des Tippens",
		["find aliases matching a given search term"] = "Mit einem Suchbegriff nach Alias suchen",
		["findaliases"] = true,
		["infinite loop detected for alias /%s - ignoring"] = "Endlosschleife entdeckt für Alias /%s - wird ignoriert",
		["inline"] = "innerhalb",
		["list all aliases"] = "Alle Alias auflisten",
		["listaliases"] = true,
		["matching aliases found: %d"] = "Passende Alias gefunden: %d",
		["module_desc"] = "Fügt das Kommando /alias hinzu, das verwendet werden kann, um \"Slash\"-Befehle durch Alias zu ersetzen, ähnlich wie der Alias-Befehl unter Unix.",
		["module_name"] = "Alias",
		["No aliases have been defined"] = "Es wurden keine Alias definiert.",
		["noclobber"] = true,
		["noclobber set - skipping new alias: /%s already expands to /%s"] = "\"Noclobber\" (kein unsinniger Kleinkram) eingeschaltet - neues Alias übergehen: /%s wird bereits erweitert zu /%s",
		["Options"] = "Optionen",
		["Options for altering the behaviour of Alias"] = "Optionen für Verhaltensänderung von Alias",
		["overwriting existing alias \"/%s\" (was aliased to \"/%s\")"] = "Überschreibe vorhandenes Alias \"/%s\" (Vorheriges Alias war: \"/%s\")",
		["refusing to alias \"/%s\" to anything in the interests of Not Buggering Everything Up"] = "Verweigert Alias von \"/%s\" zu etwas anderem, um Störungen zu vermeiden.",
		["remove an alias"] = "Ein Alias entfernen",
		["There is no alias current defined for \"%s\""] = "Es ist derzeit kein Alias definiert für \"%s\"",
		["total aliases: %d"] = "Gesamtanzahl an Alias: %d",
		["tried to show value for alias \"%s\" but undefined in module.Aliases!"] = "Versuche einen Wert für Alias von \"%s\" anzuzeigen, ist aber nicht definiert im Modul \"Alias\"!",
		["unalias"] = "Alias aufheben",
		["verbose"] = "verlängern",
		["warnUser() called with nil argument!"] = "warnUser() mit nil-Paramter aufgerufen!",
		["warnUser() called with zero length string!"] = "warnUser() mit leerem String aufgerufen!",
	},
	["AltNames"] = {
		["%d alts found for %s: %s"] = "%d Alts gefunden für %s: %s",
		["%s alts imported from LOKWhoIsWho"] = "%s Alts importiert von LOKWhoIsWho",
		["%s total alts linked to mains"] = "Insgesamt %s Alts mit Haupt-Charakteren verknüpft",
		["(.-)'s? [Aa]lt"] = " %f[%a\\192-\\255]([%a\\192-\\255]+)%f[^%a\\128-\\255]s [Aa]lt",
		["([^%s%p%d%c%z]+)'s alt"] = "%f[%a\\192-\\255]([%a\\192-\\255]+)%f[^%a\\128-\\255]s [Aa]lt",
		[".*[Aa]lts?$"] = true,
		["<alt name> (eg, /altnames del Personyouthoughtwassomeonesaltbutreallyisnt)"] = "<Altname> (z.B. /altnames del FalscherAltname)",
		["<main> (eg /altnames listalts Fin)"] = "<main> (z.b. /altnames listalts Shylera)",
		["<search term> (eg, /altnames find fin)"] = "<Suchbegriff> (z.b. /altnames find Shy)",
		["Alt"] = true,
		["alt"] = "Alt",
		["alt name exists: %s -> %s; not overwriting as set in preferences"] = "Alt-Name vorhanden: %s -> %s; wir nicht überschrieben, wie in der Auswahl eingestellt.",
		["AltNames"] = "AltName",
		["Alts:"] = true,
		["autoguildalts_desc"] = "Automatisch den Import von der Gildenliste im Hintergrund ausführen.",
		["autoguildalts_name"] = "Auto-Import der Gilden-Alts",
		["Be quiet"] = "Stumm schalten",
		["character removed: %s"] = "Charakter entfernt: %s",
		["Class colour"] = "Klassenfarbe",
		["Clear all"] = "Alle löschen",
		["Clear all links between alts and main names."] = "Alle Verknüpfungen zwischen Alt- und Haupt-Charakternamen löschen",
		["Colour"] = "Farbe",
		["Delete a character's link to another character as their main."] = "Die Verknüpfung eines Charakters zu einem anderen (Haupt-)Charakter löschen.",
		["Delete alt"] = "Alts löschen",
		["Disabled"] = "Inaktiv",
		["Display a player's alts in the tooltip"] = "Die Altnamen eines Spielers im Tooltip anzeigen.",
		["Display a player's main name in the tooltip"] = "Den Namen des Hauptcharakters eines Spielers im Tooltip anzeigen.",
		["Display main names in the same colour as that of the alt's class (taking the data from the PlayerNames module if it is enabled)"] = "Namen der Hauptcharaktere in Klassenfarbe des Alts anzeigen (Daten werden vom Modul PlayerNames geliefert, falls aktiviert).",
		["Display main names in the same colour as that of the main's class (taking the data from the PlayerNames module if it is enabled)"] = "Namen der Hauptcharaktere in Klassenfarbe des Hauptcharakters anzeigen (Daten werden vom Modul PlayerNames geliefert, falls aktiviert).",
		["Don't overwrite existing alt <-> main links when importing or adding new alts."] = "Vorhandenen Alt nicht überschreiben <-> Verknüpfungen zu Hauptcharakteren während des Imports oder des Hinzufügens von neuen Alts.",
		["Don't overwrite existing links"] = "Bestehende Verknüpfungen nicht überschreiben",
		["don't use"] = "Nicht verwenden",
		["Don't use data from the PlayerNames module at all"] = "Daten vom Modul SpielerNamen nicht verwenden.",
		["ERROR: some function sent a blank message!"] = "ERROR: eine Funktion hat eine leere Nachricht hinterlassen.",
		["Find characters"] = "Charaktersuche",
		["Fix alts"] = "Alts reparieren",
		["Fix corrupted entries in your list of alt names."] = "Korrupte Einträge in deiner Liste der Alt-Namen reparieren.",
		["Found alt: %s => main: %s"] = "Alt gefunden: %s => Haupt: %s",
		["guild member alts found and imported: %s"] = "Alt-Chars eines Gildenmitglieds gefunden und importiert: %s",
		["Import from Guild Greet database"] = "Importiere von der Gilden-Begrüßungs-Datenbank",
		["Import from guild roster"] = "Importiere von Gildenliste",
		["Import options"] = "Import-Optionen",
		["Imports alt names from a Guild Greet database, if present"] = "Importiert Alt-Namen von einer Gilden-Begrüßungs-Datenbank, wenn vorhanden.",
		["Imports alt names from the guild roster by checking for members with the rank \"alt\" or \"alts\", or guild / officer notes like \"<name>'s alt\""] = "Importiert Alt-Namen von der Gildenliste, indem Mitglieder mit dem Rang \"alt\" oder \"alts\", oder Gilden- und Gildenoffiziersnotizen wie \"<name>s alt\" geprüft werden.",
		["Imports data from LOKWhoIsWho, if present (drop your SavedVariablesLOKWhoIsWho.lua in the Prat directory to be able to use this)."] = "Importiert Daten von LOKWhoIsWho, wenn vorhanden (um diese Funktion verwenden zu können, kopiere deine Datei SavedVariablesLOKWhoIsWho.lua in den Prat-Ordner!).",
		["Left"] = "Links",
		["link <alt name> <main name> (eg, /altnames link Fin Finjathealtoffin)"] = "Verknüpfe <alt-name> <hauptcharname> (z.B. /altnames link Fin Finjaderaltvonfin)",
		["Link alt"] = "Alt verknüpfen",
		["Link someone's alt character with the name of their main."] = "Jemandes Alt-Charakter mit dem Namen seines Hauptcharakters verknüpfen.",
		["linked alt %s => %s"] = "Altchar verknüpft %s => %s",
		["List all"] = "Alle auflisten",
		["List all links between alts and their main names."] = "Alle Verknüpfungen zwischen Alts und deren Hauptchar-Namen auflisten.",
		["List alts"] = "Alts auflisten",
		["List alts for a given character"] = "Alts eines bestimmten Charakters auflisten.",
		["LOKWhoIsWho data not found"] = "LOKWhoIsWho-Daten nicht gefunden",
		["LOKWhoIsWho import"] = "LOKWhoIsWho-Import",
		["LOKWhoIsWho lua file not found, sorry."] = "LOKWhoIsWho.lua-Datei nicht gefunden, entschuldige.",
		["Main"] = "Hauptchar",
		["main"] = "Hauptchar",
		["Main name position"] = "Position des Namens eines Hauptcharakters",
		["Main:"] = "Hauptchar:",
		["mainpos_desc"] = "Wo der Name eines Hauptchars dargestellt werden soll, wenn diese mit ihrem Alt-Char zocken.",
		["mainpos_name"] = "Hauptchar-Name Position",
		["module_desc"] = "Erlaubt das Verknüpfen von Alt-Chars mit deren Hauptchars, was dann neben deren Namen angezeigt werden kann, wenn sie in Chat-Mitteilungen erscheinen (standard = aus).",
		["no alts found for character "] = "Keine Alt-Chars für diesen Charakter gefunden.",
		["no alts or mains found matching \"%s\""] = "Keine Alt-Chars oder Hauptchars gefunden, die mit \"%s\" übereinstimmen.",
		["No arg string given to :addAlt()"] = "Kein Parameter angegeben für: :addAlt()",
		["no characters called \"%s\" found; nothing deleted"] = "Keine Charaktere mit dem Namen \"%s\" gefunden; es wurde nichts gelöscht.",
		["No Guild Greet database found"] = "Keine Gilden-Begrüßungs-Datenbank gefunden.",
		["No main name supplied to link %s to"] = "Kein Hauptcharname geliefert, mit dem %s verknüpft werden kann.",
		["no matches found"] = "Keine Übereinstimmungen gefunden.",
		["quiet"] = "Sei ruhig",
		["quiet_desc"] = "Ob Meldungen an den Chat-Rahmen gesendet werden oder nicht.",
		["quiet_name"] = true,
		["Right"] = "Rechts",
		["Search the list of linked characters for matching main or alt names."] = "Durchsuche die Liste der verknüpften Charaktere nach passenden Hauptchar- oder Altchar-Namen.",
		["searched for: %s - total matches: %s"] = "Gesucht nach: %s - gesamte Übereinstimmungen: %s",
		["Show alts in tooltip"] = "Alts im Tooltip anzeigen",
		["Show main in tooltip"] = "Hauptchar im Tooltip anzeigen",
		["Start"] = "Starte",
		["The colour of an alt's main name that will be displayed"] = "Die Farbe des Hauptcharnamens eines Alts, der dargestellt wird.",
		["Use class colour (from the PlayerNames module)"] = "Klassenfarbe verwenden (vom Modul \"PlayerNames\") ",
		["use class colour of alt"] = "Klassenfarbe für Alt-Char verwenden.",
		["use class colour of main"] = "Klassenfarbe des Hauptchars verwenden",
		["Use LibAlts Data"] = "Daten von LibAlts benutzen",
		["Use the data available via the shared alt information library."] = "Verwende die vorhandenen Daten über die gemeinsam genutzte Alt-Informations-Sammlung.",
		["Various ways to import a main's alts from other addons"] = "Verschiedene Möglichkeiten, wie man die Alts eines Hauptchars von anderen AddOns importieren kann.",
		["warning: alt %s already linked to %s"] = "Warnung: Alt %s ist bereits mit %s verknüpft!",
		["Where to display a character's main name when on their alt."] = "Wo der Name eines Hauptcharakters angezeigt werden soll, wenn diese mit ihrem Alt-Char zocken.",
		["Whether to report to the chat frame or not."] = "Ob Meldungen im Chatfenster erscheinen oder nicht.",
		["You are not in a guild"] = "Du bist in keiner Gilde",
		["You have not yet linked any alts with their mains."] = "Bisher hast du keine Alt-Chars mit ihren Hauptchars verknüpft.",
	},
	["Bubbles"] = {
		["color_desc"] = "Färbe den Sprechblasenrahmen, im selben Stil, wie den Chattyp ein.",
		["color_name"] = "Sprechblasen färben",
		["font_desc"] = "Die selbe Schriftart wie auch für das Chatfenster verwenden",
		["font_name"] = "Chatschriftart verwenden",
		["fontsize_desc"] = "Stellt die Schriftgröße der Sprechblasen ein",
		["fontsize_name"] = "Schriftgröße",
		["format_desc"] = "Benutze die Pratformatierung zum Einfärben des Sprechblasentextes",
		["format_name"] = "Text formatieren",
		["icons_desc"] = "Zielmarkierungssymbole in den Sprechblasen anzeigen.",
		["icons_name"] = "Zielmarkierungssymbole anzeigen",
		["module_desc"] = "Einstellung des Sprechblasenverhaltens",
		["module_name"] = "Blasen",
		["shorten_desc"] = "Verkürze die Sprechblasen zu einem Einzeiler. Fahre mit der Maus über die Sprachblase , um den Text zu erweitern",
		["shorten_name"] = "Sprechblasen verkürzen",
		["transparent_desc"] = "Ausblenden des Hintergrunds und den Randstrukturen von Sprechblasen. (/reload ist erforderlich, um diese Option rückgängig zu machen)",
		["transparent_name"] = "Transparente Blasen",
	},
	["Buttons"] = {
		["alpha_desc"] = "Stellt die Transparenz der Chatmenüs und Navigationspfeile aller Chatfenster ein.",
		["alpha_name"] = "Transparenz einstellen",
		["Buttons"] = "Schaltflächen",
		["Chat window button options."] = "Optionen für die die Schaltflächen der Chatfenster",
		["chatmenu_desc"] = "Schaltet das Chatmenü ein/aus.",
		["chatmenu_name"] = "Chatmenü anzeigen",
		["Default"] = "Standard",
		["Right, Inside Frame"] = "Rechts, innerhalb des Rahmens",
		["Right, Outside Frame"] = "Rechts, außerhalb des Rahmens",
		["scrollReminder_desc"] = "Zeigt eine Erinnerungsschaltfläche an, wenn du dich nicht am unteren Ende des Chatfensters befindest.",
		["scrollReminder_name"] = "ScrollDown-Erinnerung anzeigen",
		["Set Position"] = "Position einstellen",
		["Sets position of chat menu and arrows for all chat windows."] = "Stellt die Position des Chatmenüs und der Navigationspfeile für alle Chatfenster ein.",
		["Show Arrows"] = "Zeige die Navigationspfeile",
		["Show Chat%d Arrows"] = "Navigationspfeile im Chat%d anzeigen",
		["showbnet_desc"] = "Geselligkeitsmenü anzeigen",
		["showbnet_name"] = "Geselligkeitsmenü anzeigen",
		["showmenu_desc"] = "Chatmenü anzeigen",
		["showmenu_name"] = "Menü anzeigen",
		["showminimize_desc"] = "Zeigt den Schalter zum Minimieren an",
		["showminimize_name"] = "Zeige Minimieren-Knopf",
		["Toggle showing chat arrows for each chat window."] = "Anzeige der Navigationspfeile für jedes Chatfenster ein- und ausschalten.",
		["Toggles navigation arrows on and off."] = "Schaltet die Anzeige der Navigationspfeile an und aus",
	},
	["ChannelColorMemory"] = {
		["(%w+)%s?(.*)"] = true,
		["ChannelColorMemory"] = true,
		["Remembers the colors of each channel name."] = "Speichert die Farbe jedes Kanalnamens.",
	},
	["ChannelNames"] = {
		["%s settings."] = "%s -Einstellungen.",
		["<string>"] = true,
		["Add Channel Abbreviation"] = "Hinzufügen einer Kanal-Abkürzung",
		["addnick_desc"] = "Fügt einen abgekürzten Kanalnamen hinzu. Füge den Vorsatz '#' dem Namen hinzu, um die Nummer des Kanals mit anzuzeigen (z.B. '#Handel')",
		["Blank"] = "Leer",
		["chanlink_desc"] = "Den Kanal zu einem anklickbaren Link machen, der den Chat zu diesem Kanal öffnet.",
		["chanlink_name"] = "Kanal-Link erstellen",
		["Channel %d"] = "Kanal %d",
		["Channel name abbreviation options."] = "Optionen zu Kanalnamen-Abkürzungen.",
		["ChannelNames"] = "Channel-Namen",
		["channelnick_desc"] = "Kanalabkürzungen",
		["channelnick_name"] = "Kanalabkürzungen",
		["Clear Channel Abbreviation"] = "Channel-Abkürzung löschen",
		["Clears an abbreviated channel name."] = "Löscht die Abkürzung eines Kanals",
		["colon_desc"] = "Hinzufügen eines Doppelpunkts nach dem Ersetzen des Kanals ein-/ausschalten.",
		["colon_name"] = "Doppelpunkt anzeigen",
		["Dont display the channel/chat type name"] = "Name des Kanal-/Chat-Typs nicht anzeigen",
		["otheropts_desc"] = "Weitere Formatierungsoptionen für die Kanäle, sowie Steuerung der Kanal-Links.",
		["otheropts_name"] = "Weitere Optionen",
		["Remove Channel Abbreviation"] = "Kanal-Abkürzung entfernen",
		["Removes an an abbreviated channel name."] = "Entfernt einen abgekürzten Kanalnamen.",
		["Replace"] = "Ersetzen",
		["Set"] = "Setzen",
		["space_desc"] = [=[Hinzufügen eines Leerzeichens nach dem Ersetzen des Kanals ein-/ausschalten.
]=],
		["space_name"] = "Leerzeichen anzeigen",
		["Toggle replacing this channel."] = "Ersetzen für diesen Kanal ein-/ausschalten.",
		["Use a custom replacement for the chat %s text."] = "Benutze einen allgemein üblichen Ersatz für den Text des Chats %s.",
	},
	["ChannelSticky"] = {
		["Channel"] = "Kanal",
		["ChannelSticky"] = true,
		["Chat channel sticky options."] = "\"Sticky\"-Optionen für Chat-Kanal.",
		["ChatType"] = true,
		["Per chat type options."] = "Optionen nach Chat-Type.",
		["smartgroup_desc"] = "Fügt einen Befehl /gr hinzu, der automatisch den richtigen Chat-Typ aufnimmt - RAID, PARTY, oder BATTLEGROUND",
		["smartgroup_name"] = "Intelligente Gruppen",
		["Sticky %s"] = "\"Sticky\" %s",
		["Sticky Per Chat Frame"] = "\"Sticky\" nach Chat-Rahmen",
		["Toggle remembering the chat type last used per chat frame."] = "Das Merken des Chat-Typs, der zuletzt im Chatfenster aktiviert war, umschalten.",
		["Toggles sticky on and off for %s."] = "\"Sticky\" ein- und ausschalten für %s.",
	},
	["ChatFrames"] = {
		["Chat window frame parameter options"] = "Optionen für Parameter des Chatfenster-Rahmens",
		["framealpha_desc"] = "Steuert die Transparenz des Chatfensters, wenn du die Maus darüberlegst.",
		["framealpha_name"] = "Transparenz für Chatfenster einstellen",
		["Frames"] = "Fenster",
		["mainchatonload_desc"] = "Automatisch das erste Chatfenster auswählen und beim Laden aktivieren.",
		["mainchatonload_name"] = "Haupt-Chatfenster beim Laden erzwingen",
		["maxchatheight_desc"] = "Die maximale Höhe für alle alle Chatfenster einstellen.",
		["maxchatheight_name"] = "Maximale Höhe einstellen",
		["maxchatwidth_desc"] = "Die maximale Breite für alle Chatfenster einstellen.",
		["maxchatwidth_name"] = "Maximale Breite einstellen.",
		["minchatheight_desc"] = "Die minimale Höhe für alle Chatfenster einstellen.",
		["minchatheight_name"] = "Minimale Höhe einstellen",
		["minchatwidth_desc"] = "Die minimale Breite für alle Chatfenster einstellen.",
		["minchatwidth_name"] = "Minimale Breite einstellen.",
		["rememberframepositions_desc"] = "Die Positionen des Chatfensters merken und diese beim Laden wiederherstellen",
		["rememberframepositions_name"] = "Positionen merken",
		["removeclamp_desc"] = "Das Verschieben des Chatfensters bündig zur Bildschirmkante zulassen",
		["removeclamp_name"] = "Klammergröße Null",
	},
	["ChatLink"] = {
		["gem_desc"] = "GEM-Kompatibilitätsmodus aktivieren",
		["gem_name"] = "GEM-Kompatibilität",
		["module_desc"] = "Optionen für Gegenstandslinks in Chat-Kanal.",
		["module_info"] = "Dieses Modul ermöglicht dir, Gegenstände in jedwede Chat-Kanäle (Nicht-Handels-Kanäle) zu verlinken; z.B. allgemeine oder private Kanäle,  wie deinen Klassen-Kanal. Für Benutzer ohne AddOn mit der Fähigkeit diese zu Dekodieren, wird dies wie Spam aussehen - also sei höflich.",
		["module_name"] = "ChannelLinks",
		["Trade"] = "Handel",
	},
	["ChatLog"] = {
		["A module to automaticaly enable chat and combat logging."] = "Ein Modul, das automatisch das Speichern des Chat- und Kampflogs aktiviert.",
		["Chat log recorded to <WoW Installation>\\Logs\\WoWChatLog.txt only upon logout."] = "Speicherung des Chat-Logs in <WoW Installation>\\Logs\\WoWChatLog.txt nur während des Ausloggens.",
		["Chat Log: Disabled"] = "Chat-Log: Inaktiv",
		["Chat Log: Enabled"] = "Chat-Log: Aktiv",
		["ChatLog"] = true,
		["Combat log recorded to <WoW Installation>\\Logs\\WoWCombatLog.txt only upon logout."] = "Speicherung des Kampflogs in <WoW Installation>\\Logs\\WoWCombatLog.txt nur während des Ausloggens.",
		["Combat Log: Disabled"] = "Kampflog: Inaktiv",
		["Combat Log: Enabled"] = "Kampflog: Aktiv",
		["quiet_desc"] = "Zeigt keinerlei Mitteilungen an, wenn dieser Modus aktiv ist, oder wenn es die Log-Einstellungen verändert.",
		["quiet_name"] = "Feedback-Mitteilungen unterdrücken",
		["Toggle Chat Log"] = "Chat-Log umschalten",
		["Toggle chat log on and off."] = "Chat-Log ein- und ausschalten.",
		["Toggle Combat Log"] = "Kampflog umschalten",
		["Toggle combat log on and off."] = "Kampflog ein- und ausschalten.",
	},
	["ChatTabs"] = {
		["Active Alpha"] = "Aktive Transparenz",
		["All"] = "Alle",
		["Always"] = "Immer",
		["Chat window tab options."] = "Optionen für Chatfensterreiter",
		["Default"] = "Standard",
		["disableflash_desc"] = "Deaktiviert das Blinken der Chat-Tabs.",
		["disableflash_name"] = "Blinken ausschalten",
		["Hidden"] = "Verborgen",
		["Individual"] = "Individuell",
		["Not Active Alpha"] = "Inaktive Transparenz",
		["preventdrag_desc"] = "Verhindert das Verschieben der Chattabs mit der Maus.",
		["preventdrag_name"] = "Ziehen verhindern",
		["Set ChatFrame%d Display Mode"] = "Darstellungsmodus von Chatfenster%d einstellen",
		["Set Display Mode"] = "Darstellungsmodus einstellen",
		["Set tab display mode for each chat window."] = "Reiterdarstellungsmodus für jedes Chatfenster einstellen: markiert (an), nicht markiert (aus), grau markiert (standard)",
		["Set tab display to always, hidden or the Blizzard default."] = "Reiterdarstellung einstellen: immer, verbergen oder Blizzards Standard",
		["Sets alpha of chat tab for active chat frame."] = "Transparenz der Chatreiter von aktiven Chatfenstern einstellen.",
		["Sets alpha of chat tab for not active chat frame."] = "Transparenz der Chatreiter von inaktiven Chatfenstern einstellen.",
		["Tabs"] = "Reiter (Reiter der Chatfenster)",
	},
	["Clear"] = {
		["Adds clear text slash commands (/clear)(/cls)(/clearall)(/clsall)."] = "Fügt \"Slash\"-Befehle zum Löschen von Text hinzu (/clear)(/cls)(/clsall).",
		["Clear"] = "Löschen",
		["Clearall"] = "Alles löschen",
		["Clears all chat frames."] = "Alle Chatfenster leeren",
		["Clears the current chat frame."] = "Das aktuelle Chatfenster leeren.",
	},
	["CopyChat"] = {
		[" Text"] = "Text",
		["BBCode"] = true,
		["BOTTOMLEFT"] = "Unten, links",
		["BOTTOMRIGHT"] = "Unten, rechts",
		["buttonpos_desc"] = "Wo im Chatfenster die Kopier-Schaltfläche angezeigt werden soll.",
		["buttonpos_name"] = "Schaltflächenposition",
		["ChatFrame"] = "Chatfenster",
		["Copy all of the text in the selected chat frame into an edit box"] = "Den gesamten Text des ausgewählten Chatfensters in ein Eingabefeld kopieren",
		["Copy Text"] = "Text kopieren",
		["Copy Text Format"] = "Textformat kopieren",
		["Copy text from the active chat window."] = "Text im aktiven Chatfenster kopieren.",
		["Copy To Editbox"] = "In das Eingabefenster kopieren",
		["CopyChat"] = true,
		["HTML"] = true,
		["Message From : %s"] = "Mitteilung von: %s",
		["Plain"] = "Einfach",
		["Should the copied text be plain, or formatted so you can see the colors."] = "Soll der kopierte Text einfach oder formattiert mit farbiger Darstellung kopiert werden?",
		["showbutton_desc"] = "Schaltfläche im Chat-Rahmen anzeigen",
		["showbutton_name"] = "Schaltfläche Kopieren",
		["TOPLEFT"] = "Oben, links",
		["TOPRIGHT"] = "Oben, rechts",
		["Wowace.com Forums"] = "Wowace.com Foren",
	},
	["CustomFilters"] = {
		["<string>"] = true,
		["Add a pattern to search for."] = "Muster hinzufügen, nach dem gesucht wird.",
		["Add Pattern"] = "Muster hinzufügen",
		["Block Message"] = "Blockiere Mitteilung",
		["Channel Data"] = "Kanal-Daten",
		["Channel to send output text to."] = "Kanal, an den Ausgabetext gesendet werden soll.",
		["Enabled"] = "Aktiviert",
		["Extra data for WHISPER (target) and CHANNEL (channel name or num)"] = "Zusätzliche Daten für WHISPER (Ziel) und CHANNEL (Kanalname oder -nummer)",
		["Filter Name"] = "Name filtern",
		["Forward"] = "Weiterleiten",
		["Forward the message to a chat channel."] = "Mitteilung weiterleiten an Chat-Kanal.",
		["Forward the message to a custom chat channel."] = "Ausgabe an einen privaten Chat-Kanal",
		["ForwardCustom"] = true,
		["ForwardMessage"] = true,
		["ForwardMessageCustom"] = "Privater Kanal",
		["Hilight Color"] = "Farbe für Hervorhebungen",
		["Hilight Match Text"] = "Text hervorheben, der Suchbegriff entspricht",
		["Inbound"] = "Eingehend",
		["inchannels_desc"] = "Suche in bestimmten Kanälen",
		["inchannels_name"] = "Suche Kanäle",
		["Is this pattern enabled for use?"] = "Ist das Muster zur Anwendung aktiviert?",
		["Match Options"] = "Übereinstimmungsoptionen",
		["module_desc"] = "Modul zur Unterstützung eigener Filter.",
		["module_name"] = "CustomFilters",
		["Only output the message portion of the chat text, leave out the channel, and playername etc."] = "Nur den Mitteilungsabschnitt des Chat-Textes ausgeben - Kanal, Spielernamen etc. auslassen.",
		["Outbound"] = "Ausgehend",
		["Output Channel"] = "Ausgabekanal",
		["Output Message Only"] = "Nur Mitteilung ausgeben",
		["Pattern Info"] = "Muster-Informationen",
		["Pattern Options"] = "Optionen für Muster",
		["Play a sound when this message is output to the chatframe"] = "Einen Klang abspielen, wenn diese Mitteilung an das Chatfenster ausgegeben wurde.",
		["Play Sound"] = "Ton abspielen",
		["Prevent the message from being displayed"] = "Die Anzeige der Mitteilung verhindern.",
		["Remove an existing pattern."] = "Ein vorhandenes Muster entfernen.",
		["Remove Pattern"] = "Muster entfernen",
		["Replacement Text"] = "Ersatztext",
		["Search Format String"] = "Suche Formatierungs-String",
		["Search Pattern"] = "Suchmuster",
		["Secondary Output"] = "Sekundäre Ausgabe",
		["Send to a secondary output"] = "Versende eine sekundäre Ausgabe",
		["Supplied pattern is a format string instead of a pattern"] = "Geliefertes Muster ist eine Formatierungsvariable anstatt eines Musters.",
		["Your name for this filter"] = "Dein Name für diesen Filter",
	},
	["Editbox"] = {
		["Attach edit box to..."] = "Befestige Eingabefeld an ...",
		["Attach to..."] = "Befestige an ...",
		["Background color"] = "Hintergrundfarbe",
		["Background Inset"] = "Hintergrundbild",
		["Background texture"] = "Hintergrundtextur",
		["Border color"] = "Randfarbe",
		["Border texture"] = "Randtextur",
		["Bottom"] = "Unten",
		["Color border by channel"] = "Rand einfärben nach Kanal",
		["currently_broken_alt_behavior"] = [=[Das Verhalten der Pfeiltasten im Chat ist im aktuellen WoW-Client defekt,

verwende stattdessen Alt+Hoch und Alt+Runter, um durch den Chatverlauf zu scrollen.]=],
		["Edge Size"] = "Kantengröße",
		["Editbox"] = "Eingabefeld",
		["Editbox options."] = "Optionen für das Eingabefeld.",
		["Font"] = "Schriftart",
		["Free-floating"] = "Freischwebend",
		["Free-floating, Locked"] = "Freischwebend, fixiert",
		["Requires the Alt key to be held down to move the cursor in chat"] = "Das Drücken der Alt-Taste wird benötigt, um den Cursor (Zeiger) im Chat zu bewegen.",
		["Select the font to use for the edit box"] = "Schriftart auswählen, die im Eingabefeld verwendet wird.",
		["Sets the frame's border color to the color of your currently active channel"] = "Wendet die Randfarbe des Rahmens auf die Farbe deines gegenwärtig aktiven Kanals an.",
		["Tile Size"] = "Kachelgröße",
		["Top"] = "Oben",
		["Use Alt key for cursor movement"] = "Benutze Alt-Taste für Cursor-Bewegung",
	},
	["EventNames"] = {
		["allevents_desc"] = "Prat-Verarbeitung für alle Chat-Ereignisse aktivieren.",
		["allevents_name"] = "Alle Ereignisse verarbeiten",
		["Chat window event name options."] = "Optionen zu Ereignisnamen in Chatfenstern.",
		["EventNames"] = "Ereignisnamen",
		["Show"] = "Anzeigen",
		["Show events on chatframes"] = "Ereignisse in Chatfenstern anzeigen",
		["show_desc"] = "Anzeige der Ereignisnamen in jedem Fenster ein- und ausschalten",
		["show_name"] = "Ereignisnamen anzeigen",
	},
	["Fading"] = {
		["duration_desc"] = "Stellt die Anzahl der Sekunden ein ehe der Text in Chatfenstern verblasst.",
		["duration_name"] = "Verzögerung des Verblassens einstellen (Sekunden)",
		["module_desc"] = "Optionen zum Verblassen des Textes in Chatfenstern.",
		["module_name"] = "Verblassen",
		["textfade_desc"] = "Schaltet das Verblassen des Textes jedes Chatfenster ein/aus.",
		["textfade_name"] = "Verblassen einschalten",
	},
	["Filtering"] = {
		["A module to provide basic chat filtering."] = "Ein Modul, welches das elementare Filtern von Chat ermöglicht.",
		["afkdnd_desc"] = "AFK- und DND-Mitteilungen unterdrücken",
		["afkdnd_name"] = "AFK- und DND-Mitteilungen unterdrücken",
		["bgjoin_desc"] = "Filtert bzw. entfernt Schlachtzugsverlassens- und -beitrittsnachrichten.",
		["bgjoin_name"] = "Filter BG Verlassen/Betreten",
		["Filtering"] = "Filtert",
		["leavejoin_desc"] = "Filtert bzw. entfernt Kanalbeitritts- und -verlassensnachrichten.",
		["leavejoin_name"] = "Filter Kanal Verlassen/Beitreten",
		["notices_desc"] = "Die allgemein üblichen Benachrichtigungen in Kanälen verhindern, z.B. Moderatorenwechsel.",
		["notices_name"] = "Kanal-Meldungen filtern",
		["tradespam_desc"] = "Begrenze die Nachrichten um zu verhindern das gleiche Nachrichten ständig wiederholt werden",
		["tradespam_name"] = "Spam begrenzen",
	},
	["Font"] = {
		["Auto Restore Font Size"] = "Schriftgröße automatisch wiederherstellen",
		["Chat window font options."] = "Optionen für Schrifttyp in Chatfenstern.",
		["Font"] = "Schrifttyp",
		["monochrome_desc"] = "Einfarbige Einfärbung der Schrift umschalten.",
		["monochrome_name"] = "Einfarbigkeit ein- und ausschalten",
		["None"] = "Keiner",
		["Outline"] = "Umrandung",
		["outlinemode_desc"] = "Stellt Modus für die Umrandung des Schrifttyps ein.",
		["outlinemode_name"] = "Umrandungsmodus einstellen",
		["rememberfont_desc"] = "Deine Wahl des Schrifttyps merken und beim Starten wiederherstellen.",
		["rememberfont_name"] = "Schrifttyp merken",
		["Set ChatFrame%d Font Size"] = "Schriftgröße im Chatfenster %d einstellen",
		["Set Font Face"] = "Schrifttyp einstellen",
		["Set Font Size"] = "Schriftgröße einstellen",
		["Set Separately"] = "Einzeln einstellen",
		["Set text font size for each chat window."] = "Schriftgröße von Text für jedes Chatfenster einstellen.",
		["Set text font size."] = "Schriftgröße von Text einstellen.",
		["Set the text font face for all chat windows."] = "Schriftart von Text für alle Chatfenster einstellen.",
		["shadowcolor_desc"] = "Farbe des Schatteneffekts einstellen.",
		["shadowcolor_name"] = "Schattenfarbe einstellen",
		["Thick Outline"] = "Dicke Umrandung",
		["Toggle setting options separately for each chat window."] = "Optionen einzeln für jedes Chatfenster einstellen umschalten.",
		["Workaround a Blizzard bug which changes the font size when you open a system menu."] = "Einen Bug von Blizzard umgehen, welcher die Schriftgröße ändert sobald du ein Systemmenü öffnest.",
	},
	["History"] = {
		["Chat history options."] = "Optionen zum Chatverlauf.",
		["Color GMOTD"] = "Farbe Gildennachricht des Tages",
		["Colors the GMOTD label"] = "Färbt die GMOTD-Beschriftung",
		["delaygmotd_desc"] = "GMOTD verzögern, bis die Ausgabe aller Mitteilungen nach dem Einloggen vollendet ist.",
		["delaygmotd_name"] = "GMOTD verzögern",
		["divider"] = "======= Ende der Aufzeichnungen =======",
		["History"] = "Verlauf",
		["Maximum number of lines of command history to save."] = "Maximal zu speichernde Zeilenanzahl des Befehlsverlaufs.",
		["Save Command History"] = "Befehlsverlauf speichern",
		["Saves command history between sessions (for use with alt+up arrow or just the up arrow)"] = "Speichert Befehlsverlauf zwischen Sitzungen (um mit Alt + \"Pfeil nach oben\" oder nur \"Pfeil nach oben\" verwendet zu werden).",
		["Scrollback"] = "Aufzeichnung",
		["Scrollback Options"] = "Optionen zum Aufwärtsscrollen",
		["scrollbacklen_desc"] = "Anzahl der Chatzeilen, die im Puffer gespeichert werden sollen",
		["scrollbacklen_name"] = "Scroll-Weite",
		["Set Chat Lines"] = "Chatzeilen einstellen",
		["Set Command History"] = "Befehlsverlauf einstellen",
		["Set the number of lines of chat history for each window."] = "Die Zeilenanzahl des Chatverlaufs für jedes Fenster einstellen.",
		["Store the chat lines between sessions"] = "Speichert den Chat zwischen den Sitzungen",
	},
	["KeyBindings"] = {
		["Channel %d"] = "Kanal %d",
		["Copy Selected Chat Frame"] = "Ausgewähltes Chatfenster kopieren",
		["Guild Channel"] = "Gildenkanal",
		["Instance Channel"] = "Schlachtfeld-Kanal",
		["Next Chat Tab"] = "Nächster Chatreiter",
		["Officer Channel"] = "Offizierskanal",
		["Party Channel"] = "Gruppenkanal",
		["Prat CopyChat"] = true,
		["Prat Keybindings"] = true,
		["Prat TellTarget"] = true,
		["Raid Channel"] = "Schlachtzugskanal",
		["Raid Warning Channel"] = "Schlachtzugswarnkanal",
		["Say"] = true,
		["Smart Group Channel"] = "Intelligenter Gruppenkanal",
		["TellTarget"] = true,
		["Whisper"] = true,
		["Yell"] = true,
	},
	["OriginalButtons"] = {
		["alpha_desc"] = "Transparenz des Chatmenüs sowie der Navigationspfeile für alle Chatfenster einstellen.",
		["alpha_name"] = "Transparenz einstellen",
		["buttonframe_desc"] = "Schaltfächenrahmen-Menü anzeigen/verbergen",
		["buttonframe_name"] = "Schaltfächenrahmen anzeigen",
		["ChannelNames"] = "Kanalnamen",
		["Chat window button options."] = "Optionen für Chatfenster-Schaltfläche",
		["chatmenu_desc"] = "Ein-/Ausschalten des Chatmenüs",
		["chatmenu_name"] = "Chatmenü anzeigen",
		["Default"] = "Standard",
		["Original Buttons"] = "Standardschaltflächen",
		["reflow_desc"] = "Chatfenster-Text soll um die Schaltflächen herum fließen, nicht unter sie.",
		["reflow_name"] = "Umfließungstext",
		["reminder_desc"] = "Zeige Erinnerungs-Schaltfläche, wenn nicht am unteren Ende des Chat-Fensters.",
		["reminder_name"] = "Runterscroll-Erinnerung anzeigen",
		["Right, Inside Frame"] = "Rechts, innerhalb des Rahmens",
		["Right, Outside Frame"] = "Rechts, außerhalb des Rahmens",
		["Set Position"] = "Position festlegen",
		["Sets position of chat menu and arrows for all chat windows."] = "Position von Chatmenü und -pfeilen für alle Fenster festlegen.",
		["Show Arrows"] = "Scrollsymbole anzeigen",
		["Show Chat%d Arrows"] = "%d -Chat-Pfeile anzeigen",
		["Toggle showing chat arrows for each chat window."] = "Ein-/Ausschalten der Chatpfeile für jedes Chatfenster.",
		["Toggles navigation arrows on and off."] = "Ein-/Ausschalten der Navigationspfeile",
	},
	["OriginalEditbox"] = {
		["Autohide"] = "Automatisch verbergen",
		["BACKGROUND"] = "HINTERGRUND",
		["Bar colour"] = "Leistenfarbe",
		["Border colour"] = "Randfarbe",
		["Border width"] = "Randbreite",
		["Bottom"] = "Unten",
		["Click the edit box to open it up for editing. Only available if Autohide is disabled."] = "Das Eingabefeld anklicken, um es für die Eingabe zu Öffnen. Nur verfügbar, wenn \"Autohide\" (automatisch verbergen) deaktiviert ist.",
		["Clickable"] = "Anklickbar",
		["DIALOG"] = true,
		["Editbox options."] = "Eingabefeld-Optionen",
		["Enable Arrowkeys"] = "Pfeiltasten aktivieren",
		["Enable using arrowkeys in editbox without the alt key."] = "Die Benutzung der Pfeiltasten im Eingabefeld ohne die Alt-Taste aktivieren.",
		["Hide Border"] = "Rand verbergen",
		["Hide the border around the edit box."] = "Rand um das Eingabefeld verbergen.",
		["Hide the edit box after you have pressed enter."] = "Das Eingabefeld nach dem Drücken von \"Eingabe\" verbergen.",
		["HIGH"] = "HOCH",
		["Lock editbox position if undocked."] = "Position des Eingabefelds fixieren, falls es freigesetzt sein sollte.",
		["Lock Position"] = "Position fixieren",
		["LOW"] = "NIEDRIG",
		["MEDIUM"] = true,
		["OriginalEditbox"] = true,
		["Padding"] = "Einlage",
		["Set Alpha"] = "Transparenz einstellen",
		["Set Position"] = "Position einstellen",
		["Set Strata"] = "Ebenen einstellen",
		["Set the alpha of the editbox."] = "Die Transparenz des Eingabefelds einstellen.",
		["Set the amount of padding inside the edit box"] = "Die Füllmenge innerhalb des Eingabefelds einstellen.",
		["Set the edit box background colour"] = "Die Hintergrundfarbe des Eingabefelds einstellen.",
		["Set the edit box border colour"] = "Die Randfarbe des Eingabefelds einstellen.",
		["Set the frame strata of the editbox."] = "Die Rahmenebene des Eingabefelds einstellen.",
		["Set the position of the editbox."] = "Die Position des Eingabefelds einstellen.",
		["Set the texture of the chat edit box"] = "Die Textur des Chat-Eingabefelds einstellen.",
		["Set the width of the edit box's border"] = "Die Randbreite des Eingabefelds einstellen.",
		["Set the width of the editbox."] = "Die Breite des Eingabefelds einstellen.",
		["Set Width (NB: only enabled if the editbox is undocked)"] = "Breite einstellen (NB: Nur aktiv, wenn das Eingabefeld freigesetzt ist)",
		["Texture"] = "Textur",
		["Top"] = "Oben",
		["Undocked"] = "Abgekoppelt",
	},
	["Paragraph"] = {
		["adjustlinks_desc"] = "Links anpassen, um die Fähigkeit des Anklickens wiederherzustellen, wenn Text zentriert oder rechtsbündig ist.",
		["adjustlinks_name"] = "Platzierung von Spieler-/Gegenstands-Links reparieren.",
		["Center"] = "Mitte",
		["Chat window paragraph options."] = "Paragraphoptionen in Chatfenstern.",
		["justification_desc"] = "Horizontale Ausrichtung für jedes Chat-Fenster einstellen.",
		["justification_name"] = "Ausrichtung einstellen",
		["Left"] = "Links",
		["Line Spacing"] = "Zeilenabstand",
		["Paragraph"] = true,
		["Right"] = "Rechts",
		["Set the line spacing for all chat windows."] = "Den Zeilenabstand für alle Chatfenster einstellen.",
	},
	["PlayerNames"] = {
		["Actively Query Player Info"] = "Spielerinformationen aktiv abfragen",
		["Angled"] = "Abgewinkelt",
		["Brackets"] = "Klammern",
		["Brackets Common Color"] = "Standardfarbe der Klammern",
		["Brackets Use Common Color"] = "Klammern verwende die Standardfarbe",
		["Class"] = "Klasse",
		["Color by Level Difference"] = "Entsprechend des Stufenunterschieds einfärben",
		["coloreverywhere_desc"] = "Spielernamen einfärben, wenn diese im Text einer Chat-Mitteilung auftreten.",
		["coloreverywhere_name"] = "Namen überall einfärben",
		["Enable Alt-Invite"] = "Alt-Einladungen aktivieren",
		["Enable Invite Links"] = "Einladungs-Links aktivieren",
		["Enable TabComplete"] = "TabComplete aktivieren",
		["hoverhilight_desc"] = "Chat-Zeilen eines bestimmten Spielers hervorheben, wenn die Maus über den Spielerlink gelegt wird.",
		["hoverhilight_name"] = "Schwebendes Hervorheben",
		["How to color other player's level."] = "Wie die Stufen anderer Spieler eingefärbt werden sollen.",
		["How to color player's name."] = "Wie die Namen der Spieler eingefärbt werden sollen.",
		["Keep Info"] = "Informationen merken",
		["Keep Lots Of Info"] = "Viele Informationen speichern",
		["Keep player information between session for all players except cross-server players"] = "Spielerinformationen aller Spieler außer Spielern anderer Server zwischen Sitzungen merken.",
		["Keep player information between session, but limit it to friends and guild members."] = "Spielerinformationen zwischen Sitzungen speichern, aber schränke dies ein auf Freunde und Gildenmitglieder.",
		["Let TasteTheNaimbow set the common color for unknown player names."] = "Lasse TasteTheNaimbow die übliche Farbe für unbekannte Spielernamen einstellen.",
		["Level Color Mode"] = "Stufenfarbe-Modus",
		["linkifycommon_desc"] = "Allgemeine Mitteilungen in Links umwandeln",
		["linkifycommon_name"] = "Allgemeine Mitteilungen in Links umwandeln",
		["No additional coloring"] = "Keine zusätzliche Einfärbung",
		["None"] = "Keine",
		["Player Color Mode"] = "Spielerfarbe-Modus",
		["Player name formating options."] = "Formatierungsoptionen für Spielernamen",
		["PlayerNames"] = true,
		["Prat_Playernames: Stored Player Data Cleared"] = "Prat_Playernames: Gespeicherte Spielerdaten gelöscht",
		["Query the server for all player names we do not know. Note: This happpens pretty slowly, and this data is not saved."] = "Alle uns unbekannten Spielernamen beim Server abfragen. Merke: dies passiert ziemlich langsam und diese Daten sind nicht gespeichert.",
		["Random"] = "Zufällig",
		["realidcolor_desc"] = "RealID-Namenseinfärbung",
		["realidcolor_name"] = "RealID-Einfärbung",
		["Reset Settings"] = "Einstellungen zurücksetzen",
		["Restore default settings, and delete stored character data."] = "Standardeinstellungen wiederherstellen und gespeicherte Charakterdaten löschen.",
		["Set common color of unknown player names."] = "Allgemein übliche Farbe bei unbekannten Spielernamen einstellen.",
		["Sets common color of brackets to use around player names."] = "Allgemein übliche Farbe der Klammern bei Spielernamen einstellen.",
		["Sets style of brackets to use around player names."] = "Stil der Klammern bei Spielernamen einstellen.",
		["Show Group"] = "Gruppe anzeigen",
		["Show Level"] = "Stufe anzeigen",
		["Show Raid Target Icon"] = "Zielmarkierungssymbol anzeigen",
		["Square"] = "Quadrat",
		["Tab completion : "] = "Tab-Ergänzung:",
		["tabcomplete_name"] = "Mögliche Namen",
		["Toggle group invites by alt-clicking hyperlinked keywords like 'invite'."] = "Gruppeneinladungen umschalten, indem Hyperlinks von Stichworten wie \"invite\" bei gleichzeitigem Drücken der Alt-Taste angeklickt werden.",
		["Toggle group invites by alt-clicking on player name."] = "Gruppeneinladungen umschalten, indem Spielernamen bei gleichzeitigem Drücken der Alt-Taste angeklickt werden.",
		["Toggle level showing."] = "Stufenanzeige umschalten.",
		["Toggle raid group showing."] = "Schlachtzugsgruppenanzeige umschalten.",
		["Toggle showing the raid target icon which is currently on the player."] = "Anzeige von Schlachtzugsziel-Symbol, welches gegenwärtig dem Spieler zugewiesen ist, umschalten.",
		["Toggle tab completion of player names."] = "Tag-Ergänzung von Spielernamen umschalten.",
		["Toggle using a common color for brackets around player names."] = "Die Verwendung der allgemein üblichen Farbe für Klammern bei Spielernamen umschalten.",
		["Toggle using a common color for unknown player names."] = "Die Verwendung der allgemein üblichen Farbe für unbekannte Spielernamen umschalten.",
		["Too many matches (%d possible)"] = "Zu viele Entsprechungen (%d möglich)",
		["Unknown Common Color"] = "Unbekannte übliche Farbe",
		["Unknown Common Color From TasteTheNaimbow"] = "Unbekannte übliche Farbe von TasteTheNaimbow",
		["Unknown Use Common Color"] = "Unbekannt - übliche Farbe verwenden",
		["Use Channel Color"] = "Kanalfarbe verwenden",
		["Use Player Color"] = "Spielerfarbe verwenden",
		["Use toon name for RealID"] = "Charakternamen statt RealID verwenden",
	},
	["PopupMessage"] = {
		["Add Nickname"] = "Spitzname hinzufügen",
		["Adds an alternate name to show in popups."] = "Einen anderen (alternierenden) Namen hinzufügen, der in Popups angezeigt werden soll.",
		["Clear Nickname"] = "Spitznamen löschen",
		["Clears alternate name to show in popups."] = "Einen anderen (alternierenden) Namen löschen, der in Popups angezeigt werden soll.",
		["framealpha_desc"] = "Den Transparenzwert des Popup-Rahmens bei voller Darstellung einstellen.",
		["framealpha_name"] = "Transparenz der Popup-Rahmens",
		["Popup"] = true,
		["PopupMessage"] = true,
		["Remove Nickname"] = "Spitznamen entfernen",
		["Removes an alternate name to show in popups."] = "Einen anderen (alternierenden) Namen entfernen, der in Popups angezeigt werden soll.",
		["Set Separately"] = "Einzeln einstellen",
		["Show All Popups"] = "Alle Popups anzeigen",
		["Show Popups"] = "Popups anzeigen",
		["Show Popups for all chat windows."] = "Popups für alle Chatfenster anzeigen.",
		["Show Popups for each window."] = "Popups für jedes Fenster anzeigen.",
		["show_desc"] = "Popups für jedes Fenster anzeigen.",
		["show_name"] = "Popups anzeigen",
		["show_perframedesc"] = "Anzeige der Popups ein- und ausschalten.",
		["show_perframename"] = "Popups vom Chatfenster%d anzeigen",
		["showall_desc"] = "Popups für alle Chatfenster anzeigen.",
		["showall_name"] = "Alle Popups anzeigen",
		["Shows messages in a popup window."] = "Mitteilungen in einem Popup-Fenster anzeigen.",
		["Shows messages with your name in a popup."] = "Mitteilungen in einem Popup-Fenster mit deinem Namen anzeigen.",
		["Toggle setting options separately for each chat window."] = "Optionseinstellungen einzeln für jedes Chatfenster umschalten.",
	},
	["Scroll"] = {
		["Bottom"] = "Von unten nach oben",
		["Chat window scrolling options."] = "Optionen zum Scrollen in Chatfenstern.",
		["Control whether text is added to the frame at the top or the bottom."] = "Steuerung, ob der Text oben oder unten im Chatfenster hinzugefügt wird.",
		["lowdown_desc"] = "Automatisches Springen zum unteren Ende eines Chatfensters ein-/ausschalten.",
		["lowdown_name"] = "TheLowDown aktivieren",
		["modified_speed"] = "SHIFT + Mausrad-Geschwindigkeit einstellen",
		["modified_speed_desc"] = "Anzahl der Zeilen, die bei Betätigung des Mausrads gescrollt werden, während die SHIFT-Taste gedrückt wird.",
		["mousewheel_desc"] = "Mausradunterstützung für jedes Chatfenster ein-/ausschalten.",
		["mousewheel_name"] = "Mausrad aktivieren",
		["Scroll"] = "Scrollen",
		["Set Ctrl+MouseWheel Speed"] = "Geschwindigkeit für <Strg>-Mausrad einstellen",
		["Set MouseWheel Speed"] = "Geschwindigkeit des Mausrads einstellen",
		["Set number of lines mousewheel will scroll when ctrl is pressed."] = "Anzahl der Zeilen, die per Mausrad weitergescrollt werden, während <Strg> gedrückt wird, einstellen.",
		["Set number of lines mousewheel will scroll."] = "Zeilenanzahl einstellen, die das Mausrad weiterscrollt.",
		["Set TheLowDown Delay"] = "TheLowDown-Verzögerung einstellen",
		["Set time to wait before jumping to the bottom of chat windows."] = "Wartezeit einstellen, ehe zum Ende von Chatfenstern gesprungen wird.",
		["Text scroll direction"] = "Scroll-Richtung im Text",
		["Top"] = "Von oben nach unten",
	},
	["Search"] = {
		["err_notfound"] = "Nicht gefunden",
		["err_tooshort"] = "Suchbegriff zu kurz",
		["find_results"] = "Gefundene Ergebnisse:",
		["module_desc"] = [=[Aktiviert die Suchfunktion in Chatfenstern.

Suche]=],
		["module_info"] = [=[Aktiviert die Textbefehle /find und /findall, um die Chathistorie zu durchsuchen

Benutzung:

/find <text>

/findall <text>

Suche]=],
		["module_name"] = "Suchen",
	},
	["ServerNames"] = {
		["autoabbreviate_desc"] = "Kürze den Server-Namen auf 3 Buchstaben",
		["autoabbreviate_name"] = "Auto-Abkürzen",
		["colon_desc"] = "Hinzufügen eines Doppelpunkts nach dem Ersetzen des Servers ein-/ausschalten.",
		["colon_name"] = "Doppelpunkt anzeigen",
		["randomclr_desc"] = "Eine zufällige Farbe für jeden Server verwenden.",
		["randomclr_name"] = "Zufällige Farben",
		["Server name abbreviation options."] = "Optionen für Abkürzungen von Server-Namen",
		["ServerNames"] = "ServerNamen",
	},
	["Sounds"] = {
		["A module to play sounds on certain chat messages."] = "Ein Modul, um bei bestimmten Mitteilungen, Töne abzuspielen.",
		["Add a custom channel"] = "Einen benutzerdefinierten Kanal hinzufügen.",
		["bn_whisper_desc"] = "Sound für %s Battle.Net-Flüsternachrichten",
		["bn_whisper_name"] = "Battle.Net-Flüsternachricht",
		["Custom Channels"] = "Benutzerdefinierte Kanäle",
		["group_lead_desc"] = "Klang für %s Schlachtzugsleiter, Gruppenführer oder Anleitungsmitteilungen für Instanzen.",
		["group_lead_name"] = "Gruppenanführer",
		["guild_desc"] = "Klang für %s Gildenmitteilungen",
		["guild_name"] = "Gilde",
		["incoming"] = "eingehend",
		["Incoming Sounds"] = "Eingehende Klänge",
		["officer_desc"] = "Klang für %s Mitteilungen im Offizierskanal",
		["officer_name"] = "Offizier",
		["outgoing"] = "ausgehend",
		["Outgoing Sounds"] = "Ausgehende Töne",
		["party_desc"] = "Klang für %s Gruppenmitteilungen",
		["party_name"] = "Gruppe",
		["Play a sound for a certain channel name (can be a substring)"] = "Einen Klang für einen bestimmten Kanalnamen abspielen (kann ein Substring sein).",
		["raid_desc"] = "Klang für %s Gruppen- und Führermitteilungen in Schlachtzügen oder Schlachtfeldern",
		["raid_name"] = "Schlachtzug",
		["Remove a custom channel"] = "Einen allgemeinen Kanal entfernen",
		["Reset settings"] = "Einstellungen zurücksetzen",
		["Restore default settings and resets custom channel list"] = "Standardeinstellungen wiederherstellen und allgemein übliche Kanalliste zurücksetzen.",
		["Sound selection for incoming chat messages"] = "Klangauswahl für eingehende Chat-Mitteilungen",
		["Sound selection for outgoing (from you) chat messages"] = "Klangauswahl für ausgehende (von dir) Chat-Mitteilungen",
		["Sounds"] = "Klänge",
		["whisper_desc"] = "Klang für %s Flüstermitteilungen",
		["whisper_name"] = "Flüstern",
	},
	["Substitutions"] = {
		["%d total user defined substitutions"] = " %d Gesamte vom Benutzer definierte Ersetzungen",
		["|cffff0000warning:|r subtitution \"%s\" already defined as \"%s\", overwriting"] = "|cffff0000Warnung:|r Ersetzung \"%s\" wurde bereits definiert als \"%s\", überschreibe",
		["<noguild>"] = " <keinegilde>",
		["<notarget>"] = "<keinziel>",
		["A module to provide basic chat substitutions."] = "Ein Modul, das grundlegende Ersetzungen zur Verfügung stellt.",
		["Are you sure - this will delete all user defined substitutions and reset defaults?"] = "Bist du sicher - dies wird alle vom Benutzer definierten Ersetzungen löschen und auf Standard zurücksetzen.",
		["Are you sure?"] = "Bist Du sicher?",
		["can't find substitution index for a substitution named '%s'"] = "Kann Ersetzungsindex für eine Ersetzung mit dem Namen '%s' nicht finden.",
		["current-prompt"] = [=[Gegenwärtiger Wert: '%s'
Anklicken, um in den Chat einzufügen.]=],
		["defined %s: expands to => %s"] = "definiert %s: erweitert zu => %s",
		["Delete all"] = "Alle löschen",
		["Delete substitution"] = "Ersetzung löschen",
		["Deletes a user defined substitution"] = "Löscht eine vom Benutzer definierte Ersetzung",
		["Deletes all user defined substitutions"] = "Löscht alle vom Benutzer definierten Ersetzungen",
		["female"] = "weiblich",
		["her"] = "ihr",
		["hers"] = "ihr/ihre",
		["him"] = "ihn/ihm",
		["his"] = "sein/seine",
		["it"] = "es",
		["its"] = "sein",
		["List of available substitutions"] = "Liste der verfügbaren Ersetzungen",
		["List of available substitutions defined by this module. (NB: users may define custom values for existing substitutions, but they will revert to the default value if the user definition is deleted.)"] = "Die List der verfügbaren Ersetzungen wird von diesem Modul definiert. (NB: Benutzer können gebräuchliche Werte für vorhandene Ersetzungen definieren, aber sie werden auf ihre Standardwerte zurückgesetzt, falls die Definitionen des Benutzers gelöscht wurde.)",
		["List substitutions"] = "Ersetzungen auflisten",
		["Lists all current subtitutions in the default chat frame"] = "Alle gegenwärtigen Ersetzungen im Standard-Chatfenster auflisten.",
		["male"] = "männlich",
		["MapLoc"] = "KarteOrt",
		["MapPos"] = "KartePos",
		["MapXPos"] = "KarteXPos",
		["MapYPos"] = "KarteYPos",
		["MapZone"] = "KarteZone",
		["module:buildUserSubsIndex(): warning: module patterns not defined!"] = true,
		["MouseoverTargetName"] = true,
		["NO MATCHFUNC FOUND"] = true,
		["no substitution name given"] = "kein Ersetzungsname vergeben",
		["no substitution name supplied for deletion"] = "kein Ersetzungsname für Löschung geliefert",
		["no user defined subs found"] = "keine benutzerdefinierten Ersetzungen gefunden",
		["no value given for subtitution \"%s\""] = "kein Wert für Ersetzung \"%s\" gegeben",
		["Options for setting and removing user defined substitutions. (NB: users may define custom values for existing substitutions, but they will revert to the default value if the user definition is deleted.)"] = "Optionen zum Einstellen und Entfernen benutzerdefinierter Ersetzungen. (NB: Benutzer können eigeneWerte für vorhandene Ersetzungen definieren, aber diese werden auf ihre Standardwerte zurückgesetzt, wenn die Definition des Benutzers gelöscht wurde.)",
		["PlayerAverageItemLevel"] = [=[Durchschnittliche Gegenstandsstufe des Spielers

Ersatz]=],
		["PlayerCurrentMana"] = "SpielerAktuellesMana",
		["PlayerHealthDeficit"] = "SpielerGesundheitDefizit",
		["PlayerHP"] = "SpielerHP",
		["PlayerManaDeficit"] = "SpielerManaDefizit",
		["PlayerMaxHP"] = "SpielerMaxHP",
		["PlayerMaxMana"] = "SpielerMaxMana",
		["PlayerName"] = "SpielerName",
		["PlayerPercentHP"] = "SpielerProzentHP",
		["PlayerPercentMana"] = "SpielerProzentMana",
		["RandNum"] = "ZufNum",
		["removing user defined substitution \"%s\"; previously expanded to => \"%s\""] = "Benutzerdefinierte Ersetzung \"%s\" wird entfernt; zuvor erweitert zu => \"%s\"",
		["Set substitution"] = "Ersetzung einstellen",
		["Set the value of a user defined substitution (NB: this may be the same as an existing default substitution; to reset it to the default, just remove the user created definition)."] = "Den Wert für eine benutzerdefinierte Ersetzung einstellen. (NB: dies kann einer vorhandenen Standardersetzung gleichen; um sie auf Standard zurückzusetzen, einfach die vom Benutzer erschaffene Definition entfernen.)",
		["subname -- NOTE: sub name without the prefix '%'"] = "Subname -- MERKE: Subname ohne den Vorsatz '%'",
		["subname = text after expansion -- NOTE: sub name without the prefix \"%\""] = "Subname = Text nach Erweiterung -- MERKE: Subname ohne den Vorsatz \"%\"",
		["substitution: %s defined as => %s"] = "Ersetzung: %s definiert als => %s",
		["Substitutions"] = "Ersetzungen",
		["TargetClass"] = "ZielKlasse",
		["TargetGender"] = "ZielGeschlecht",
		["TargetGuild"] = "ZielGilde",
		["TargetHealth"] = "ZielGesundheit",
		["TargetHealthDeficit"] = "ZielGesundheitDefizit",
		["TargetIcon"] = "ZielSymbol",
		["TargetLevel"] = "ZielStufe",
		["TargetManaDeficit"] = "ZielManaDefizit",
		["TargetName"] = "ZielName",
		["TargetPercentHP"] = "ZielProzentHP",
		["TargetPossesive"] = "ZielGierig",
		["TargetPronoun"] = "ZielPronomen",
		["TargetRace"] = "ZielVolk",
		["TargetTargetName"] = "ZielZielName",
		["unknown sex"] = "Geschlecht unbekannt",
		["user defined substition \"%s\" not found"] = "Benutzerdefinierte Ersetzung \"%s\" nicht gefunden",
		["User defined substitutions"] = "Benutzerdefinierte Ersetzungen",
		["user substitutions index (usersubs_idx) doesn't exist! oh dear."] = "Ersetzungsindex des Benutzers (usersubs_idx) existiert nicht! Oh weh!",
		["usersub_"] = [=[ 	 	usersub_]=],
	},
	["TellTarget"] = {
		["/tt"] = true,
		["Adds telltarget slash command (/tt)."] = "Fügt das Slash-Kommando TellTarget (/tt) hinzu",
		["No target selected."] = "Kein Ziel ausgewählt.",
		["NoTarget"] = "KeinZiel",
		["Target does not exist."] = "Ziel existiert nicht.",
		["Target is not a player."] = "Ziel ist kein Spieler.",
		["TellTarget"] = true,
	},
	["Timestamps"] = {
		["Chat window timestamp options."] = "Optionen für Zeitstempel in Chatfenstern.",
		["colortimestamp_desc"] = "Einfärben des Zeitstempels ein- und ausschalten.",
		["colortimestamp_name"] = "Zeitstempel einfärben",
		["Format All Timestamps"] = "Formatiere alle Zeitstempel",
		["HH:MM (12-hour)"] = "HH:MM (12-Stunden)",
		["HH:MM (24-hour)"] = "HH:MM (24-Stunden)",
		["HH:MM:SS (12-hour)"] = "HH:MM:SS (12-Stunden)",
		["HH:MM:SS (24-hour)"] = "HH:MM:SS (24-Stunden)",
		["HH:MM:SS AM (12-hour)"] = "HH:MM:SS AM (12-Stunden)",
		["localtime_desc"] = "Verwendung der Ortszeitein- und ausschalten.",
		["localtime_name"] = "Ortszeit verwenden",
		["MM:SS"] = true,
		["Post-Timestamp"] = "Nach-Zeitstempel",
		["Pre-Timestamp"] = "Vor-Zeitstempel",
		["Set the timestamp format"] = "Format für Zeitstempel einstellen",
		["Set Timestamp Color"] = "Farbe für Zeitstempel einstellen",
		["Sets the color of the timestamp."] = "Stellt die Farbe des Zeitstempels ein.",
		["Show Timestamp"] = "Teitstempel anzeigen",
		["show_desc"] = "Anzeige des Zeitstempels für jedes Fenster ein- und ausschalten.",
		["show_name"] = "Zeitstempel anzeigen",
		["space_desc"] = "Das Einfügen eines Leerzeichens nach dem Zeitstempel ein- und ausschalten.",
		["space_name"] = "Leerzeichen anzeigen",
		["Timestamps"] = "Zeitstempel",
		["Toggle showing timestamp for each window."] = "Anzeige des Zeitstempels für jedes Fenster umschalten.",
		["twocolumn_desc"] = "Platziere die Zeitstempel in einer getrennten Spalte, so dass der Text nicht unterhalb der Zeitstempel dargestellt wird.",
		["twocolumn_name"] = "2-Spalten-Chat",
	},
	["UrlCopy"] = {
		["Change the color of the URL."] = "Farbe einer URL ändern.",
		["Color URL"] = "URL einfärben",
		["Set Color"] = "Farbe einstellen",
		["Show Brackets"] = "Klammern anzeigen",
		["Toggle"] = "Ein-/ausschalten",
		["Toggle showing brackets on and off."] = "Anzeige der Klammern ein-/ausschalten",
		["Toggle the module on and off."] = "Modul ein-/ausschalten",
		["Toggle the URL color on and off."] = "Farbe von URL ein-/ausschalten.",
		["URL formating options."] = "URL-Formatierungsoptionen",
		["UrlCopy"] = "URL-Kopie",
		["Use Popup"] = "Popup benutzen",
		["Use popup window to show URL."] = "Popup-Fenster benutzen, um URL anzuzeigen.",
	}
}

PL:AddLocale(PRAT_MODULE.name, "deDE",L)


L=
{
	["display_desc"] = "대화창 기능 및 외형 설정",
	["display_name"] = "표시 설정",
	["extras_desc"] = "기타 모듈",
	["extras_name"] = "기타 기능",
	["formatting_desc"] = "대화창 글의 외형을 변경합니다.",
	["formatting_name"] = "대화글 형식",
	["load_desc"] = "이 모듈의 로드 방식을 설정합니다.",
	["load_disabled"] = "사용 안 함",
	["load_disabledonrestart"] = "비활성 (reload)",
	["load_enabled"] = "사용",
	["load_enabledonrestart"] = "활성 (reload)",
	["load_no"] = "로드 안함",
	["modulecontrol_desc"] = "Prat 모듈의 로드와 활성화를 제어합니다.",
	["modulecontrol_name"] = "모듈 제어",
	["prat"] = "Prat",
	["reload_required"] = "이 설정은 애드온을 %s 해야 변경된 사항이 적용됩니다.",
	["AddonMsgs"] = {
		["Addon message options."] = "애드온 메시지 옵션입니다.",
		["AddonMsgs"] = "애드온 메시지",
		["show_desc"] = "각 대화창에 숨겨진 애드온 메시지 표시를 켜거나 끕니다.",
		["show_name"] = "애드온 메시지 표시",
		["show_perframedesc"] = "숨겨진 애드온 메시지 표시를 켜거나 끕니다.",
		["show_perframename"] = "대화창%d 애드온 메시지 표시",
	},
	["Alias"] = {
		[" - list all aliases; supply <keyword> to search for matching aliases (cmd aliases: /listallaliases)"] = " - 모든 대체 명령어 목록; 대체 명령어를 찾기 위한 <키워드> 지원 (명령어: /listallaliases)",
		["%s() called with blank string!"] = "%s() 함수가 문자열없이 호출되었습니다!",
		["%s() called with nil argument!"] = "%s() 함수가 nil 인자로 호출되었습니다!",
		["/%s aliased to \"/%s\""] = "/%s |1이;가; \"/%s\"|1으로;로; 대체되었습니다",
		["/%s aliased to: /%s"] = "/%s |1이;가; 다음으로 대체되었습니다: /%s",
		["<alias> - remove the alias <alias> (cmd aliases: /delalias, /remalias)"] = "<alias> - <alias> 대체 명령어 삭제 (명령어: /delalias, /remalias)",
		["<command>[ <value>] - alias <command> to be executed as <value>, or return the value of the currently defined alias for <command> if <command> has not been assigned a value. eg: \"/alias /examplehello /say hello there\" - typing \"/examplehello\" will now cause your character to say \"hello there\"; \"/alias examplehello\" - s \"/examplehello is aliased to /say hello there\" (cmd aliases: /addalias)"] = "<명령어>[ <인자>] - <명령어>로 <인자>를 수행하게 대체하거나, <명령어>에 할당된 인자가 없으면 <명령어>에 설정된 대체 명령어를 출력합니다. 예제: \"/alias /꾸벅 /say 안녕하세요\" - \"/꾸벅\" 명령어로 일반 대화 \"안녕하세요\"가 수행됩니다;\"/alias 꾸벅\" - \"/꾸벅 명령어가 /say 안녕하세요 로 대체되었습니다\"가 표시됩니다 (명령어: /addalias)",
		["<keyword> - finds all aliases matching <keyword> (cmd aliases: /findalias)"] = "<키워드> - <키워드>가 포함된 모든 대체 명령어를 찾습니다. (명령어: /findalias)",
		["add"] = true,
		["add an alias"] = "대체 명령어 추가",
		["alias \"/%s\" does not exist"] = "대체 명령어 \"/%s\"|1이;가; 없습니다",
		["dealiasing command /%s to /%s"] = "/%s|1이;가; /%s|1으로;로; 대체 명령어가 해제됩니다",
		["deleting alias \"/%s\" (previously aliased as \"/%s\")"] = "대체 명령어 \"%s\"|1을;를; 삭제합니다. (\"/%s\"로 설정되어 있었음)",
		["Display extra information in the chat frame when commands are dealiased"] = "대체 명령어가 해제될 때 대화창에 추가 정보를 표시합니다.",
		["Don't overwrite existing aliases when using /addalias"] = "/addalias 를 사용할 때 기존 대체 명령어를 덮어쓰지 마세요",
		["Expand aliases as you are typing"] = "대화창에 입력할 때 대체 명령어를 설정된 값으로 자동으로 바꿉니다.",
		["find aliases matching a given search term"] = "주어진 검색어와 일치하는 대체 명령어 찾기",
		["findaliases"] = true,
		["infinite loop detected for alias /%s - ignoring"] = "대체 명령어 /%s의 무한 반복이 감지되었습니다 - 무시합니다",
		["inline"] = true,
		["list all aliases"] = "모든 대체 명령어 목록",
		["listaliases"] = true,
		["matching aliases found: %d"] = "일치하는 대체 명령어 찾음: %d개",
		["module_desc"] = "UNIX의 alias 명령과 비슷한 방법으로 슬래쉬 명령어를 대체하는데 사용하는 /alias 명령을 추가합니다.",
		["module_name"] = "대체 명령어",
		["No aliases have been defined"] = "설정된 대체 명령어가 없습니다.",
		["noclobber"] = "덮어쓰기 금지",
		["noclobber set - skipping new alias: /%s already expands to /%s"] = "덮어쓰기 금지 - 새로운 대체 명령어를 무시합니다 : /%s |1은;는; 이미 /%s |1으로;로; 설정되어 있습니다",
		["Options"] = "옵션",
		["Options for altering the behaviour of Alias"] = "대체 명령어의 작동을 바꾸는 옵션입니다",
		["overwriting existing alias \"/%s\" (was aliased to \"/%s\")"] = "대체 명령어 \"/%s\"|1을;를; 덮어씁니다 (\"/%s\"의 대체 명령어 였음)",
		["refusing to alias \"/%s\" to anything in the interests of Not Buggering Everything Up"] = "\"/%s\" |1은;는; 중요 명령어로 사용 중이어서 대체 명령어 사용으로 거부되었습니다.",
		["remove an alias"] = "대체 명령어를 제거합니다",
		["There is no alias current defined for \"%s\""] = "\"%s\"|1으로;로; 설정된 대체 명령어가 없습니다.",
		["total aliases: %d"] = "모든 대체 명령어: %d개",
		["tried to show value for alias \"%s\" but undefined in module.Aliases!"] = "대체 명령어 \"%s\"의 값을 표시하려고 했지만 모듈에 설정되어 있지 않습니다. 대체하세요!",
		["unalias"] = true,
		["verbose"] = true,
		["warnUser() called with nil argument!"] = "warnUser() 함수가 nil 인자로 호출되었습니다!",
		["warnUser() called with zero length string!"] = "warnUser() 함수가 문자열 없이 호출되었습니다!",
	},
	["AltNames"] = {
		["%d alts found for %s: %s"] = "%2$s의 부 캐릭터 %1$d개 찾음: %3$s",
		["%s alts imported from LOKWhoIsWho"] = "LOKWhoIsWho에서 %s 부 캐릭터를 가져왔습니다",
		["%s total alts linked to mains"] = "총 %s개의 부 캐릭터가 주 캐릭터와 연결되었습니다",
		["(.-)'s? [Aa]lt"] = "%f[%a\\192-\\255]([%a\\192-\\255]+)%f[^%a\\128-\\255]의 부캐릭터",
		["([^%s%p%d%c%z]+)'s alt"] = "%f[%a\\192-\\255]([%a\\192-\\255]+)%f[^%a\\128-\\255]의 부 캐릭터",
		[".*[Aa]lts?$"] = ".*부캐릭터?$",
		["<alt name> (eg, /altnames del Personyouthoughtwassomeonesaltbutreallyisnt)"] = "<부 캐릭터 이름> (예, /altnames del Personyouthoughtwassomeonesaltbutreallyisnt)",
		["<main> (eg /altnames listalts Fin)"] = "<주 캐릭터> (예 /altnames listalts Fin)",
		["<search term> (eg, /altnames find fin)"] = "<검색 구문> (예, /altnames find fin)",
		["Alt"] = "부 캐릭터",
		["alt"] = "부 캐릭터",
		["alt name exists: %s -> %s; not overwriting as set in preferences"] = "부 캐릭터 이름 존재: %s -> %s; 우선권 설정으로 덮어쓰지 않았습니다",
		["AltNames"] = "부 캐릭터 이름",
		["Alts:"] = "부 캐릭터:",
		["autoguildalts_desc"] = "자동으로 길드 명단에서 가져오기 명령을 실행합니다",
		["autoguildalts_name"] = "자동 길드 부 캐릭터 가져오기",
		["Be quiet"] = "조용하게",
		["character removed: %s"] = "캐릭터 제거됨: %s",
		["Class colour"] = "직업 색상",
		["Clear all"] = "모두 지우기",
		["Clear all links between alts and main names."] = "부 캐릭터와 주 캐릭터 이름 사이의 모든 연결을 지웁니다.",
		["Colour"] = "색상",
		["Delete a character's link to another character as their main."] = "주 캐릭터로 연결된 다른 캐릭터와의 연결을 삭제합니다.",
		["Delete alt"] = "부 캐릭터 삭제",
		["Disabled"] = "비활성",
		["Display a player's alts in the tooltip"] = "툴팁에 플레이어의 부 캐릭터 표시하기",
		["Display a player's main name in the tooltip"] = "툴팁에 플레이어의 주 캐릭터 이름 표시하기",
		["Display main names in the same colour as that of the alt's class (taking the data from the PlayerNames module if it is enabled)"] = "부 캐릭터의 직업과 같은 색상으로 주 캐릭터 이름 표시하기 (플레이어 이름 모듈을 사용 중이면 모듈에서 데이터를 가져옵니다)",
		["Display main names in the same colour as that of the main's class (taking the data from the PlayerNames module if it is enabled)"] = "주 캐릭터의 직업과 같은 색상으로 주 캐릭터 이름 표시하기 (플레이어 이름 모듈을 사용 중이면 모듈에서 데이터를 가져옵니다)",
		["Don't overwrite existing alt <-> main links when importing or adding new alts."] = "새로운 부 캐릭터를 추가하거나 가져올 때 저장된 부 캐릭터 <-> 주 캐릭터 간 연결을 덮어쓰지 않습니다.",
		["Don't overwrite existing links"] = "저장된 연결을 덮어쓰지 않기",
		["don't use"] = "사용하지 않음",
		["Don't use data from the PlayerNames module at all"] = "플레이어 이름 모듈의 데이터 사용하지 않기",
		["ERROR: some function sent a blank message!"] = "오류: 몇몇 함수가 빈 메시지를 보냈습니다!",
		["Find characters"] = "캐릭터 찾기",
		["Fix alts"] = "부 캐릭터 고치기",
		["Fix corrupted entries in your list of alt names."] = "당신의 부 캐릭터 이름 목록에서 잘못된 목록을 수정합니다.",
		["Found alt: %s => main: %s"] = "부 캐릭터 발견: %s => 주 캐릭터: %s",
		["guild member alts found and imported: %s"] = "길드원의 부 캐릭터를 발견하고 가져옴: %s",
		["Import from Guild Greet database"] = "길드 쪽지 데이터베이스에서 가져오기",
		["Import from guild roster"] = "길드 명단에서 가져오기",
		["Import options"] = "옵션 가져오기",
		["Imports alt names from a Guild Greet database, if present"] = "길드 쪽지 데이터베이스에서 부 캐릭터 이름이 있으면 가져옵니다",
		["Imports alt names from the guild roster by checking for members with the rank \"alt\" or \"alts\", or guild / officer notes like \"<name>'s alt\""] = "\"부캐\"나 \"부캐릭터\" 등급, 또는 \"<이름>의 부캐\"같은 길드 / 관리자 쪽지를 확인하여 길드 명단에서 부 캐릭터 이름을 가져옵니다",
		["Imports data from LOKWhoIsWho, if present (drop your SavedVariablesLOKWhoIsWho.lua in the Prat directory to be able to use this)."] = "존재한다면 LOKWhoIsWho에서 데이터를 가져옵니다 (SavedVariablesLOKWhoIsWho.lua 파일을 Prat 디렉토리에 복사해야 사용 가능함).",
		["Left"] = "왼쪽",
		["link <alt name> <main name> (eg, /altnames link Fin Finjathealtoffin)"] = "link <부 캐릭터 이름> <주 캐릭터 이름> (예, /altnames link Fin Finjathealtoffin)",
		["Link alt"] = "부 캐릭터 연결하기",
		["Link someone's alt character with the name of their main."] = "누군가의 부 캐릭터를 그의 주 캐릭터 이름과 연결시킵니다.",
		["linked alt %s => %s"] = "부 캐릭터 연결됨 %s => %s",
		["List all"] = "모든 목록",
		["List all links between alts and their main names."] = "부 캐릭터와 주 캐릭터 이름 사이의 모든 연결 목록입니다.",
		["List alts"] = "부 캐릭터 목록",
		["List alts for a given character"] = "주어진 캐릭터의 부 캐릭터 목록",
		["LOKWhoIsWho data not found"] = "LOKWhoIsWho 데이터 찾을 수 없음",
		["LOKWhoIsWho import"] = "LOKWhoIsWho 가져오기",
		["LOKWhoIsWho lua file not found, sorry."] = "LOKWhoIsWho lua 파일 찾을 수 없음.",
		["Main"] = "주 캐릭터",
		["main"] = "주 캐릭터",
		["Main name position"] = "주 캐릭터 이름 위치",
		["Main:"] = "주 캐릭터:",
		["mainpos_desc"] = "부 캐릭터에 접속 중일 때 주 캐릭터의 이름을 표시할 곳",
		["mainpos_name"] = "주 캐릭터 이름 위치",
		["module_desc"] = "사람들의 부 캐릭터를 그들의 주 캐릭터와 연결합니다, 대화 메시지에서 발견됐을 때 그들의 이름 다음에 표시되게 할 수 있습니다 (기본값=끔).",
		["no alts found for character "] = "캐릭터의 부 캐릭터 찾을 수 없음",
		["no alts or mains found matching \"%s\""] = "\"%s\"|1과;와; 일치하는 부 캐릭터나 주 캐릭터를 찾을 수 없음",
		["No arg string given to :addAlt()"] = ":addAlt()에 변수 구문이 주어지지 않았습니다",
		["no characters called \"%s\" found; nothing deleted"] = "요청한 \"%s\" 캐릭터 찾을 수 없음; 삭제하지 못함",
		["No Guild Greet database found"] = "길드 쪽지 데이터베이스 찾을 수 없음",
		["No main name supplied to link %s to"] = "%s|1과;와; 연결할 주 캐릭터 이름 제공되지 않음",
		["no matches found"] = "일치 하는 것 없음",
		["quiet"] = "조용하게",
		["quiet_desc"] = "대화창에 보고할 지 안할 지 설정합니다.",
		["quiet_name"] = true,
		["Right"] = "오른쪽",
		["Search the list of linked characters for matching main or alt names."] = "주 캐릭터나 부 캐릭터 이름이 일치하는 연결된 캐릭터의 목록을 검색합니다.",
		["searched for: %s - total matches: %s"] = "검색: %s - 총 일치: %s",
		["Show alts in tooltip"] = "툴팁에 부 캐릭터 표시",
		["Show main in tooltip"] = "툴팁에 주 캐릭터 표시",
		["Start"] = "시작",
		["The colour of an alt's main name that will be displayed"] = "표시할 주 캐릭터 이름의 색상",
		["Use class colour (from the PlayerNames module)"] = "직업 색상 사용 (플레이어 이름 모듈로부터)",
		["use class colour of alt"] = "부 캐릭터의 직업 색상 사용",
		["use class colour of main"] = "주 캐릭터의 직업 색상 사용",
		["Use LibAlts Data"] = "LibAlts 데이터 사용",
		["Use the data available via the shared alt information library."] = "공유된 부 캐릭터 정보 라이브러리를 통해 이용 가능한 데이터를 사용합니다.",
		["Various ways to import a main's alts from other addons"] = "다른 애드온에서 주 캐릭터의 부 캐릭터들을 가져올 다양한 방법들",
		["warning: alt %s already linked to %s"] = "경고: 부 캐릭터 %s|1은;는; 이미 %s|1과;와; 연결됨",
		["Where to display a character's main name when on their alt."] = "부 캐릭터에 접속 중일 때 주 캐릭터의 이름을 표시할 곳",
		["Whether to report to the chat frame or not."] = "대화창에 보고 여부",
		["You are not in a guild"] = "당신은 길드에 속해 있지 않습니다",
		["You have not yet linked any alts with their mains."] = "아직 주 캐릭터에 연결한 부 캐릭터가 없습니다.",
	},
	["Bubbles"] = {
		["color_desc"] = "말풍선 테두리 색상을 대화 유형에 맞춥니다.",
		["color_name"] = "말풍선 색상",
		["font_desc"] = "대화창에서 사용중인 글꼴과 같은 글꼴 사용",
		["font_name"] = "대화 글꼴 사용",
		["fontsize_desc"] = "말풍선 글꼴 크기를 설정합니다",
		["fontsize_name"] = "글꼴 크기",
		["format_desc"] = "대화 말풍선 내용에 Prat 서식을 적용합니다.",
		["format_name"] = "문자열 서식",
		["icons_desc"] = "말풍선에 전술 아이콘을 표시합니다.",
		["icons_name"] = "전술 아이콘 표시",
		["module_desc"] = "대화 말풍선과 관련된 사용자 설정",
		["module_name"] = "말풍선",
		["shorten_desc"] = "말풍선을 한 줄로 줄입니다. 말풍선에 마우스를 올리면 내용을 확장합니다.",
		["shorten_name"] = "말풍선 축소",
		["transparent_desc"] = "대화 말풍선의 배경과 테두리 무늬를 숨깁니다. (이 옵션을 취소하려면 /reload 필요)",
		["transparent_name"] = "투명한 말풍선",
	},
	["Buttons"] = {
		["alpha_desc"] = "모든 대화창의 대화 메뉴와 화살표의 투명도를 설정합니다.",
		["alpha_name"] = "투명도 설정",
		["Buttons"] = "버튼",
		["Chat window button options."] = "대화창 버튼 옵션",
		["chatmenu_desc"] = "대화 메뉴를 끄고 켭니다.",
		["chatmenu_name"] = "대화 메뉴 표시",
		["Default"] = "기본값",
		["Right, Inside Frame"] = "우측, 프레임 안쪽",
		["Right, Outside Frame"] = "우측, 프레임 바깥쪽",
		["scrollReminder_desc"] = "대화창을 위로 올렸을 때 맨 아래로 버튼을 표시합니다.",
		["scrollReminder_name"] = "맨 아래로 버튼 표시",
		["Set Position"] = "위치 설정",
		["Sets position of chat menu and arrows for all chat windows."] = "대화창의 메뉴와 화살표의 위치를 설정합니다.",
		["Show Arrows"] = "화살표 표시",
		["Show Chat%d Arrows"] = "대화창%d의 화살표 보이기",
		["showbnet_desc"] = "커뮤니티 메뉴 표시",
		["showbnet_name"] = "커뮤니티 메뉴 표시",
		["showmenu_desc"] = "대화 메뉴 표시",
		["showmenu_name"] = "메뉴 표시",
		["showminimize_desc"] = "최소화 버튼 표시",
		["showminimize_name"] = "최소화 버튼 표시",
		["Toggle showing chat arrows for each chat window."] = "각 채팅창 별로 화살표 표시를 끄고 켭니다.",
		["Toggles navigation arrows on and off."] = "상하 화살표를 끄고 켭니다.",
	},
	["ChannelColorMemory"] = {
		["(%w+)%s?(.*)"] = "(%S+)%s?(.*)",
		["ChannelColorMemory"] = "채널 색상 기억",
		["Remembers the colors of each channel name."] = "각 채널 이름의 색상을 기억합니다.",
	},
	["ChannelNames"] = {
		["%s settings."] = "%s 설정.",
		["<string>"] = "<내용>",
		["Add Channel Abbreviation"] = "채널 이름 줄임 추가",
		["addnick_desc"] = "축약된 채널 이름을 추가합니다. 채널 이름에 #을 붙이면 채널 번호를 포함합니다. (예. '#거래').",
		["Blank"] = "공백",
		["chanlink_desc"] = "채널을 해당 채널에 대화를 여는 클릭가능 한 링크로 만듭니다.",
		["chanlink_name"] = "채널 링크 만들기",
		["Channel %d"] = "채널 %d",
		["Channel name abbreviation options."] = "채널 이름 줄이기 옵션입니다.",
		["ChannelNames"] = "채널 이름",
		["channelnick_desc"] = "채널 이름 줄여쓰기",
		["channelnick_name"] = "채널 이름 줄여쓰기",
		["Clear Channel Abbreviation"] = "채널 줄임 초기화",
		["Clears an abbreviated channel name."] = "축약된 채널 이름을 지웁니다.",
		["colon_desc"] = "대체 채널 이름 뒤에 콜론을 추가합니다.",
		["colon_name"] = "콜론 표시",
		["Dont display the channel/chat type name"] = "채널/대화 유형 이름 표시하지 않기",
		["otheropts_desc"] = "추가적으로 채널 링크를 제어하고 채널을 형식화하는 옵션입니다.",
		["otheropts_name"] = "기타 옵션",
		["Remove Channel Abbreviation"] = "채널 줄임 제거",
		["Removes an an abbreviated channel name."] = "축약된 채널 이름을 제거합니다.",
		["Replace"] = "교체",
		["Set"] = "설정",
		["space_desc"] = "채널 대체 이름 뒤에 공간 추가 기능을 켜거나 끕니다.",
		["space_name"] = "공간 표시",
		["Toggle replacing this channel."] = "이 채널 이름 대체하기",
		["Use a custom replacement for the chat %s text."] = "대화 %s 문자에 사용자 설정 교체를 사용합니다.",
	},
	["ChannelSticky"] = {
		["Channel"] = "채널",
		["ChannelSticky"] = "채널 고정",
		["Chat channel sticky options."] = "대화 채널 고정 옵션입니다.",
		["ChatType"] = "대화 형식",
		["Per chat type options."] = "대화 형식 별 옵션",
		["smartgroup_desc"] = "공격대, 파티 또는 인스턴스 대화 중 자동으로 유효한 대화 유형을 선택하는 /smart와 /smrt 명령어를 추가합니다",
		["smartgroup_name"] = "스마트 그룹",
		["Sticky %s"] = "%s 고정",
		["Sticky Per Chat Frame"] = "대화창 별 고정",
		["Toggle remembering the chat type last used per chat frame."] = "대화창 별로 마지막으로 사용한 대화 형식 기억 기능을 켜거나 끕니다.",
		["Toggles sticky on and off for %s."] = "%s의 입력 고정을 켜거나 끕니다.",
	},
	["ChatFrames"] = {
		["Chat window frame parameter options"] = "대화창 프레임 한도 옵션",
		["framealpha_desc"] = "마우스를 올렸을 때 대화창의 투명도를 조절합니다.",
		["framealpha_name"] = "대화창 투명도 설정",
		["Frames"] = "대화창",
		["mainchatonload_desc"] = "첫번째 대화창을 자동으로 선택하고 로드 시에 활성화 시킵니다.",
		["mainchatonload_name"] = "로드 시 주 대화창 강제 설정",
		["maxchatheight_desc"] = "모든 대화창의 최대 높이를 설정합니다.",
		["maxchatheight_name"] = "최대 높이 설정",
		["maxchatwidth_desc"] = "모든 대화창의 최대 너비를 설정합니다.",
		["maxchatwidth_name"] = "최대 너비 설정",
		["minchatheight_desc"] = "모든 대화창의 최소 높이를 설정합니다.",
		["minchatheight_name"] = "최소 높이 설정",
		["minchatwidth_desc"] = "모든 대화창의 최소 너비를 설정합니다.",
		["minchatwidth_name"] = "최소 너비 설정",
		["rememberframepositions_desc"] = "대화창 위치를 기억하고 로드 시마다 불러옵니다",
		["rememberframepositions_name"] = "위치 기억",
		["removeclamp_desc"] = "대화창이 화면 밖으로 나가지 않도록 방지합니다.",
		["removeclamp_name"] = "Zero 고정 크기",
	},
	["ChatLink"] = {
		["gem_desc"] = "보석 호환 모드 사용",
		["gem_name"] = "보석 호환",
		["module_desc"] = "대화 채널 아이템 링크 옵션입니다.",
		["module_info"] = "이 모듈은 비-거래 대화 채널 예. 공개, 또는 직업 채널같은 사설 채널에 아이템을 링크할 수 있게 해줍니다. 디코딩할 수 있는 애드온을 사용하지 않는 사용자에게는 스팸으로 보여질 수 있습니다.",
		["module_name"] = "채널 링크",
		["Trade"] = "거래",
	},
	["ChatLog"] = {
		["A module to automaticaly enable chat and combat logging."] = "대화 기록과 전투 기록을 자동으로 켜는 모듈입니다.",
		["Chat log recorded to <WoW Installation>\\Logs\\WoWChatLog.txt only upon logout."] = "대화 기록은 접속종료 후, <와우폴더>\\Logs\\WoWChatLog.txt 에 저장됩니다.",
		["Chat Log: Disabled"] = "대화 기록: 꺼짐",
		["Chat Log: Enabled"] = "대화 기록: 켜짐",
		["ChatLog"] = "대화 기록 [ChatLog]",
		["Combat log recorded to <WoW Installation>\\Logs\\WoWCombatLog.txt only upon logout."] = "전투 기록은 접속종료 후, <와우폴더>\\Logs\\WoWCombatLog.txt 에 저장됩니다.",
		["Combat Log: Disabled"] = "전투 기록: 꺼짐",
		["Combat Log: Enabled"] = "전투 기록: 켜짐",
		["quiet_desc"] = "이 모듈이 켜지거나 설정이 변경될 때 알림 메시지를 표시하지 않습니다.",
		["quiet_name"] = "알림 메시지 끄기",
		["Toggle Chat Log"] = "대화 기록 끄고 켜기",
		["Toggle chat log on and off."] = "대화 기록을 끄거나 켭니다.",
		["Toggle Combat Log"] = "전투 기록 끄고 켜기",
		["Toggle combat log on and off."] = "전투 기록을 끄거나 켭니다.",
	},
	["ChatTabs"] = {
		["Active Alpha"] = "활성 탭 투명도",
		["All"] = "모두",
		["Always"] = "항상",
		["Chat window tab options."] = "대화창 탭 옵션입니다.",
		["Default"] = "기본값",
		["disableflash_desc"] = "대화창 탭의 반짝임을 끕니다.",
		["disableflash_name"] = "반짝임 끄기",
		["Hidden"] = "숨김",
		["Individual"] = "개별",
		["Not Active Alpha"] = "비활성 탭 투명도",
		["preventdrag_desc"] = "마우스로 대화창 탭을 이동하지 못하게 합니다",
		["preventdrag_name"] = "탭 이동방지",
		["Set ChatFrame%d Display Mode"] = "대화창%d 표시 모드 설정",
		["Set Display Mode"] = "표시 모드 설정",
		["Set tab display mode for each chat window."] = "각 대화창 별로 탭 표시 모드를 설정합니다. 체크함 (표시), 체크 안함 (표시 안함), 회색 체크 (기본값)",
		["Set tab display to always, hidden or the Blizzard default."] = "탭 표시를 항상 표시, 숨김 또는 블리자드 기본값으로 설정합니다.",
		["Sets alpha of chat tab for active chat frame."] = "활성화 된 대화창 탭의 투명도를 설정합니다.",
		["Sets alpha of chat tab for not active chat frame."] = "비활성화 된 대화창 탭의 투명도를 설정합니다.",
		["Tabs"] = "대화창 탭",
	},
	["Clear"] = {
		["Adds clear text slash commands (/clear)(/cls)(/clearall)(/clsall)."] = "지우기 명령어 /clear, /cls, /clearall, /clsall 을 추가합니다.",
		["Clear"] = "지우기",
		["Clearall"] = "모두 지우기",
		["Clears all chat frames."] = "모든 대화창의 내용을 지웁니다.",
		["Clears the current chat frame."] = "현재 대화창의 내용을 지웁니다.",
	},
	["CopyChat"] = {
		[" Text"] = " 텍스트",
		["BBCode"] = true,
		["BOTTOMLEFT"] = "하단, 좌측",
		["BOTTOMRIGHT"] = "하단, 우측",
		["buttonpos_desc"] = "복사 버튼을 표시할 대화창의 위치",
		["buttonpos_name"] = "버튼 위치",
		["ChatFrame"] = "대화창",
		["Copy all of the text in the selected chat frame into an edit box"] = "선택된 대화창의 모든 내용을 대화 입력창으로 복사합니다",
		["Copy Text"] = "텍스트 복사",
		["Copy Text Format"] = "복사 내용 서식",
		["Copy text from the active chat window."] = "활성 대화창에서 내용을 복사합니다.",
		["Copy To Editbox"] = "대화 입력창에 복사",
		["CopyChat"] = "대화 복사 [CopyChat]",
		["HTML"] = true,
		["Message From : %s"] = "%s|1으로;로;부터 메시지",
		["Plain"] = "보통",
		["Should the copied text be plain, or formatted so you can see the colors."] = "복사된 내용을 보통으로 표시하거나, 또는 색상을 보기 위해 형식화 합니다.",
		["showbutton_desc"] = "대화창에 버튼 표시",
		["showbutton_name"] = "복사 버튼",
		["TOPLEFT"] = "상단, 좌측",
		["TOPRIGHT"] = "상단, 우측",
		["Wowace.com Forums"] = "Wowace.com 포럼",
	},
	["CustomFilters"] = {
		["<string>"] = "<내용>",
		["Add a pattern to search for."] = "검색할 패턴을 추가합니다.",
		["Add Pattern"] = "패턴 추가",
		["Block Message"] = "메시지 차단",
		["Channel Data"] = "채널 데이터",
		["Channel to send output text to."] = "출력 내용을 보낼 채널.",
		["Enabled"] = "사용",
		["Extra data for WHISPER (target) and CHANNEL (channel name or num)"] = "귓속말 (대상)과 채널 (채널 이름 또는 숫자)의 추가 데이터",
		["Filter Name"] = "필터 이름",
		["Forward"] = "보내기",
		["Forward the message to a chat channel."] = "메시지를 대화 채널로 보내기.",
		["Forward the message to a custom chat channel."] = "사설 채널로 출력",
		["ForwardCustom"] = "사설 채널로 보내기",
		["ForwardMessage"] = "메시지 보내기",
		["ForwardMessageCustom"] = "사설 채널",
		["Hilight Color"] = "색상 강조",
		["Hilight Match Text"] = "일치하는 문자 강조",
		["Inbound"] = "받는 메시지",
		["inchannels_desc"] = "특정 채널에서 검색",
		["inchannels_name"] = "채널 검색",
		["Is this pattern enabled for use?"] = "이 패턴을 사용하기 위해 활성화 할까요?",
		["Match Options"] = "일치 옵션",
		["module_desc"] = "사용자 설정 필터를 지원하는 모듈입니다.",
		["module_name"] = "사용자 설정 필터",
		["Only output the message portion of the chat text, leave out the channel, and playername etc."] = "대화 문자열, 채널 나감, 플레이어 이름 등의 메시지 부분만 출력합니다.",
		["Outbound"] = "보낸 메시지",
		["Output Channel"] = "출력 채널",
		["Output Message Only"] = "출력 메시지만",
		["Pattern Info"] = "패턴 정보",
		["Pattern Options"] = "패턴 옵션",
		["Play a sound when this message is output to the chatframe"] = "이 메시지가 대화창에 출력되면 소리를 재생합니다",
		["Play Sound"] = "소리 재생",
		["Prevent the message from being displayed"] = "표시 중인 메시지 차단하기",
		["Remove an existing pattern."] = "저장 중인 패턴을 제거합니다.",
		["Remove Pattern"] = "패턴 삭제",
		["Replacement Text"] = "대체 텍스트",
		["Search Format String"] = "형식 구문 검색",
		["Search Pattern"] = "패턴 검색",
		["Secondary Output"] = "보조 출력",
		["Send to a secondary output"] = "보조 출력으로 전송하기",
		["Supplied pattern is a format string instead of a pattern"] = "제공된 패턴은 패턴이 아닌 형식 구문입니다",
		["Your name for this filter"] = "이 필터의 이름",
	},
	["Editbox"] = {
		["Attach edit box to..."] = "입력창 붙이기...",
		["Attach to..."] = "붙이기...",
		["Background color"] = "배경 색상",
		["Background Inset"] = "배경 삽입",
		["Background texture"] = "배경 무늬",
		["Border color"] = "테두리 색상",
		["Border texture"] = "테두리 무늬",
		["Bottom"] = "아래",
		["Color border by channel"] = "채널에 의한 테두리 색상",
		["currently_broken_alt_behavior"] = [=[화살표 키 동작은 현재 WoW 클라이언트에서 작동하지 않습니다.

기록 접근에 위쪽 아래쪽 키 대신 ALT-위와 ALT-아래 키를 사용하세요]=],
		["Edge Size"] = "모서리 크기",
		["Editbox"] = "대화 입력창",
		["Editbox options."] = "대화 입력창을 설정합니다.",
		["Font"] = "글꼴",
		["Free-floating"] = "자유로운 이동",
		["Free-floating, Locked"] = "자유로운 이동, 잠금",
		["Requires the Alt key to be held down to move the cursor in chat"] = "대화 입력창 커서 이동에 Alt 키를 사용합니다",
		["Select the font to use for the edit box"] = "대화 입력창에 사용할 글꼴 선택",
		["Sets the frame's border color to the color of your currently active channel"] = "대화 입력창 테두리 색상을 현재 채널 색상으로 설정",
		["Tile Size"] = "타일 크기",
		["Top"] = "위",
		["Use Alt key for cursor movement"] = "커서 이동에 Alt 키 사용",
	},
	["EventNames"] = {
		["allevents_desc"] = "모든 대화 이벤트에 Prat 처리 과정을 적용시킵니다.",
		["allevents_name"] = "모든 이벤트 처리",
		["Chat window event name options."] = "대화창에 이벤트 이름을 표시합니다.",
		["EventNames"] = "이벤트 이름",
		["Show"] = "표시",
		["Show events on chatframes"] = "대화창에 이벤트를 표시합니다.",
		["show_desc"] = "각 대화창에 이벤트 이름 표시를 끄고 켭니다.",
		["show_name"] = "이벤트 이름 표시",
	},
	["Fading"] = {
		["duration_desc"] = "대화글이 사라질 때 까지의 대기 시간을 설정합니다.",
		["duration_name"] = "사라짐 대기 시간 설정 (초)",
		["module_desc"] = "대화글의 사라짐 옵션을 설정합니다.",
		["module_name"] = "사라짐",
		["textfade_desc"] = "각 대화창 별로 대화글 사라짐 기능을 켜고 끕니다.",
		["textfade_name"] = "사라짐 켜기",
	},
	["Filtering"] = {
		["A module to provide basic chat filtering."] = "대화 내용을 필터링하는 모듈입니다.",
		["afkdnd_desc"] = "자리비움과 다른 용무중 메시지를 조절합니다.",
		["afkdnd_name"] = "자리비움과 다른 용무중 메시지를 조절합니다.",
		["bgjoin_desc"] = "전장 채널 입장/퇴장 메시지를 숨깁니다.",
		["bgjoin_name"] = "전장 입장/퇴장 필터링",
		["Filtering"] = "필터링",
		["leavejoin_desc"] = "채널 입장/퇴장 메시지를 숨깁니다.",
		["leavejoin_name"] = "채널 입장/퇴장 필터링",
		["notices_desc"] = "사설 채널의 알림 메시지를 숨깁니다, ex. 관리자 변경.",
		["notices_name"] = "채널 알림 메시지 필터링",
		["tradespam_desc"] = "같은 메시지가 여러번 반복되지 않게 방지합니다.",
		["tradespam_name"] = "스팸 조절",
	},
	["Font"] = {
		["Auto Restore Font Size"] = "글꼴 크기 자동 복원",
		["Chat window font options."] = "대화창 글꼴 옵션입니다.",
		["Font"] = "글꼴",
		["monochrome_desc"] = "글꼴 그림자 색을 끄고 켭니다.",
		["monochrome_name"] = "그림자 끄고 켜기",
		["None"] = "없음",
		["Outline"] = "외곽선",
		["outlinemode_desc"] = "글꼴의 외곽선을 설정합니다.",
		["outlinemode_name"] = "외곽선 설정",
		["rememberfont_desc"] = "선택한 글꼴을 기억하고 시작할 때 적용합니다.",
		["rememberfont_name"] = "글꼴 기억",
		["Set ChatFrame%d Font Size"] = "대화창%d의 글꼴 크기를 설정합니다.",
		["Set Font Face"] = "글꼴 설정",
		["Set Font Size"] = "글꼴 크기 설정",
		["Set Separately"] = "개별 설정",
		["Set text font size for each chat window."] = "각 대화창 별로 글꼴 크기를 설정합니다.",
		["Set text font size."] = "글꼴 크기를 설정합니다.",
		["Set the text font face for all chat windows."] = "모든 대화창의 글꼴을 설정합니다.",
		["shadowcolor_desc"] = "그림자 색상을 설정합니다.",
		["shadowcolor_name"] = "그림자 색상 설정",
		["Thick Outline"] = "굵은 외곽선",
		["Toggle setting options separately for each chat window."] = "각 대화창 별로 옵션 설정을 끄고 켭니다.",
		["Workaround a Blizzard bug which changes the font size when you open a system menu."] = "시스템 메뉴를 열 때 글꼴 크기를 변경하는 블리자드 버그를 회피합니다.",
	},
	["History"] = {
		["Chat history options."] = "대화 내역 옵션입니다.",
		["Color GMOTD"] = "오늘의 길드 메시지에 색상입히기",
		["Colors the GMOTD label"] = "오늘의 길드 메시지 제목에 색상입히기",
		["delaygmotd_desc"] = "모든 시작 스팸이 표시 될때까지 오늘의 길드 메시지 지연시키기",
		["delaygmotd_name"] = "오늘의 길드 메시지 지연",
		["divider"] = "========== 이전 대화 목록의 끝 ==========",
		["History"] = "대화 내역",
		["Maximum number of lines of command history to save."] = "저장할 명령어 내역의 최대 갯수입니다.",
		["Save Command History"] = "명령어 내역 저장",
		["Saves command history between sessions (for use with alt+up arrow or just the up arrow)"] = "세션 간 명령어 내역을 저장합니다 (Alt+위 화살표나 위 화살표로 사용하는)",
		["Scrollback"] = "이전 대화 목록",
		["Scrollback Options"] = "이전 대화 목록 옵션",
		["scrollbacklen_desc"] = "이전 대화 목록 저장소에 저장할 대화 내용의 길이입니다.",
		["scrollbacklen_name"] = "이전 대화 목록 길이",
		["Set Chat Lines"] = "대화 내역 설정",
		["Set Command History"] = "명령어 내역 설정",
		["Set the number of lines of chat history for each window."] = "각 대화창 별로 대화 내역의 줄의 갯수를 설정합니다.",
		["Store the chat lines between sessions"] = "세션 간 대화 내용 저장하기",
	},
	["KeyBindings"] = {
		["Channel %d"] = "채널 %d",
		["Copy Selected Chat Frame"] = "선택한 대화창 복사",
		["Guild Channel"] = "길드 채널",
		["Instance Channel"] = "인스턴스 채널",
		["Next Chat Tab"] = "다음 대화 탭",
		["Officer Channel"] = "관리자 채널",
		["Party Channel"] = "파티 채널",
		["Prat CopyChat"] = "Prat 대화 복사",
		["Prat Keybindings"] = "Prat 단축키",
		["Prat TellTarget"] = "Prat 대상 대화",
		["Raid Channel"] = "공격대 채널",
		["Raid Warning Channel"] = "공격대 경보 채널",
		["Say"] = "일반 대화",
		["Smart Group Channel"] = "스마트 그룹 채널",
		["TellTarget"] = "대상 대화",
		["Whisper"] = "귓속말",
		["Yell"] = "외침",
	},
	["OriginalButtons"] = {
		["alpha_desc"] = "모든 대화창의 대화 메뉴와 화살표의 투명도를 설정합니다.",
		["alpha_name"] = "투명도 설정",
		["buttonframe_desc"] = "버튼 프레임 메뉴를 켜거나 끕니다.",
		["buttonframe_name"] = "버튼 프레임 표시",
		["ChannelNames"] = "채널 이름",
		["Chat window button options."] = "대화창 버튼 옵션입니다.",
		["chatmenu_desc"] = "대화 메뉴를 표시하거나 숨깁니다.",
		["chatmenu_name"] = "대화 메뉴 표시",
		["Default"] = "기본값",
		["Original Buttons"] = "오리지날 버튼",
		["reflow_desc"] = "대화창 문자를 버튼과 겹치지 않게 합니다.",
		["reflow_name"] = "문자 겹침 방지",
		["reminder_desc"] = "대화창이 최하단이 아닐 때 맨 아래로 버튼을 표시합니다.",
		["reminder_name"] = "맨 아래로 버튼 표시",
		["Right, Inside Frame"] = "오른쪽, 프레임 내부",
		["Right, Outside Frame"] = "오른쪽, 프레임 외부",
		["Set Position"] = "위치 설정",
		["Sets position of chat menu and arrows for all chat windows."] = "모든 대화창에서 대화 메뉴와 화살표의 위치를 설정합니다.",
		["Show Arrows"] = "화살표 표시",
		["Show Chat%d Arrows"] = "대화창%d 화살표 표시",
		["Toggle showing chat arrows for each chat window."] = "각 대화창 별로 화살표 표시 기능을 켜거나 끕니다.",
		["Toggles navigation arrows on and off."] = "탐색 화살표를 켜거나 끕니다.",
	},
	["OriginalEditbox"] = {
		["Autohide"] = "자동 숨기기",
		["BACKGROUND"] = true,
		["Bar colour"] = "바 색상",
		["Border colour"] = "테두리 색상",
		["Border width"] = "테두리 폭",
		["Bottom"] = "맨 아래로",
		["Click the edit box to open it up for editing. Only available if Autohide is disabled."] = "대화 입력창을 클릭하여 편집할 수 있게 엽니다. 자동 숨기기 기능이 꺼져있을 때만 사용할 수 있습니다.",
		["Clickable"] = "클릭 가능한",
		["DIALOG"] = true,
		["Editbox options."] = "대화 입력창을 설정합니다.",
		["Enable Arrowkeys"] = "방향키 사용",
		["Enable using arrowkeys in editbox without the alt key."] = "입력창에서 Alt 키 없이 방향키 사용이 가능합니다.",
		["Hide Border"] = "테두리 숨기기",
		["Hide the border around the edit box."] = "입력창의 테두리를 숨깁니다.",
		["Hide the edit box after you have pressed enter."] = "엔터를 누른 후에 입력 창을 숨깁니다.",
		["HIGH"] = true,
		["Lock editbox position if undocked."] = "고정 되있지 않으면 대화 입력창의 위치를 잠급니다.",
		["Lock Position"] = "위치 잠그기",
		["LOW"] = true,
		["MEDIUM"] = true,
		["OriginalEditbox"] = "오리지널 대화 입력창",
		["Padding"] = "채우기",
		["Set Alpha"] = "투명도 설정",
		["Set Position"] = "위치 설정",
		["Set Strata"] = "프레임 우선순위 설정",
		["Set the alpha of the editbox."] = "입력창의 투명도를 설정합니다.",
		["Set the amount of padding inside the edit box"] = "대화 입력창 안을 채울 양 설정",
		["Set the edit box background colour"] = "입력창의 배경색을 설정합니다.",
		["Set the edit box border colour"] = "입력창의 테두리 색을 설정합니다.",
		["Set the frame strata of the editbox."] = "입력창의 프레임 우선 순위를 설정합니다.",
		["Set the position of the editbox."] = "입력창의 위치를 설정합니다.",
		["Set the texture of the chat edit box"] = "대화 입력창의 무늬 설정",
		["Set the width of the edit box's border"] = "대화 입력창의 테두리 너비 설정",
		["Set the width of the editbox."] = "입력창의 너비를 설정합니다.",
		["Set Width (NB: only enabled if the editbox is undocked)"] = "폭 설정 (주의: 입력창이 고정되있지 않아야 가능합니다.)",
		["Texture"] = "무늬",
		["Top"] = "위",
		["Undocked"] = "고정안함",
	},
	["Paragraph"] = {
		["adjustlinks_desc"] = "중앙이나 우측 정렬일 때 클릭 기능을 위해 링크 위치를 조절합니다.",
		["adjustlinks_name"] = "플레이어/아이템 링크 위치 수정",
		["Center"] = "중앙",
		["Chat window paragraph options."] = "대화창을 정렬하는 옵션입니다.",
		["justification_desc"] = "각 대화창 별로 가로 정렬을 설정합니다.",
		["justification_name"] = "정렬 설정",
		["Left"] = "왼쪽",
		["Line Spacing"] = "줄 간격",
		["Paragraph"] = "정렬",
		["Right"] = "오른쪽",
		["Set the line spacing for all chat windows."] = "모든 대화창의 줄 간격을 설정합니다.",
	},
	["PlayerNames"] = {
		["Actively Query Player Info"] = "적극적인 플레이어 정보 요청",
		["Angled"] = "<플레이어>",
		["Brackets"] = "괄호 선택",
		["Brackets Common Color"] = "괄호 색상",
		["Brackets Use Common Color"] = "괄호에 색상 사용",
		["Class"] = "직업",
		["Color by Level Difference"] = "레벨 차이에 의한 색상",
		["coloreverywhere_desc"] = "대화 메시지에 나타나는 플레이어 이름에 색상 적용",
		["coloreverywhere_name"] = "모든 곳의 이름에 색상 사용",
		["Enable Alt-Invite"] = "Alt-초대 켜기",
		["Enable Invite Links"] = "초대 링크 켜기",
		["Enable TabComplete"] = "탭 완성 켜기",
		["hoverhilight_desc"] = "플레이어 링크에 마우스를 올리면 특정 플레이어의 대화 내용을 강조합니다",
		["hoverhilight_name"] = "마우스 오버 강조",
		["How to color other player's level."] = "다른 플레이어의 레벨 색상화 방법을 설정합니다.",
		["How to color player's name."] = "플레이어의 이름 색상화 방법을 설정합니다.",
		["Keep Info"] = "친구/길드원 정보 저장",
		["Keep Lots Of Info"] = "모든 플레이어 정보 저장",
		["Keep player information between session for all players except cross-server players"] = "다른 서버를 제외한 모든 플레이어의 정보를 세션 간 유지합니다",
		["Keep player information between session, but limit it to friends and guild members."] = "친구와 길드원의 정보를 세션 간 유지합니다",
		["Let TasteTheNaimbow set the common color for unknown player names."] = "알 수 없는 플레이어 이름에 대한 색상으로 TasteTheNaimBow 애드온의 설정을 사용합니다.",
		["Level Color Mode"] = "레벨 색상 설정",
		["linkifycommon_desc"] = "일반 메시지 링크",
		["linkifycommon_name"] = "일반 메시지 링크",
		["No additional coloring"] = "사용 안함",
		["None"] = "안함",
		["Player Color Mode"] = "플레이어 색상 설정",
		["Player name formating options."] = "플레이어 이름 형식화 설정입니다.",
		["PlayerNames"] = "플레이어 이름",
		["Prat_Playernames: Stored Player Data Cleared"] = "Prat_Playernames: 저장된 플레이어 정보 초기화",
		["Query the server for all player names we do not know. Note: This happpens pretty slowly, and this data is not saved."] = "모르는 모든 플레이어 이름 정보를 서버에 요청합니다. 주의: 작동 시 느려질 수 있으며, 수집된 정보들은 저장되지 않습니다.",
		["Random"] = "무작위",
		["realidcolor_desc"] = "실명ID 이름에 색을 입힙니다",
		["realidcolor_name"] = "실명ID 색 입히기",
		["Reset Settings"] = "설정 초기화",
		["Restore default settings, and delete stored character data."] = "기본 설정을 복구하고 저장된 캐릭터 설정을 지웁니다.",
		["Set common color of unknown player names."] = "알 수 없는 플레이어 이름의 색상을 설정합니다.",
		["Sets common color of brackets to use around player names."] = "플레이어 이름 주위에 사용할 괄호의 색상을 설정합니다.",
		["Sets style of brackets to use around player names."] = "플레이어 이름 주위에 사용할 괄호의 모양을 설정합니다.",
		["Show Group"] = "그룹 표시",
		["Show Level"] = "레벨 표시",
		["Show Raid Target Icon"] = "전술 아이콘 표시",
		["Square"] = "사각형",
		["Tab completion : "] = "탭 완성 :",
		["tabcomplete_name"] = "가능한 이름",
		["Toggle group invites by alt-clicking hyperlinked keywords like 'invite'."] = "'초대' 같은 링크된 단어를 Alt-클릭하여 초대합니다.",
		["Toggle group invites by alt-clicking on player name."] = "플레이어 이름을 Alt-클릭하여 초대합니다.",
		["Toggle level showing."] = "레벨을 표시합니다.",
		["Toggle raid group showing."] = "공격대 파티를 표시합니다.",
		["Toggle showing the raid target icon which is currently on the player."] = "플레이어에게 지정된 전술 아이콘을 표시합니다.",
		["Toggle tab completion of player names."] = "플레이어 이름의 탭 완성을 켭니다.",
		["Toggle using a common color for brackets around player names."] = "플레이어 이름 주위 괄호에 색상을 입힙니다.",
		["Toggle using a common color for unknown player names."] = "알 수 없는 플레이어 이름에 색상을 입힙니다.",
		["Too many matches (%d possible)"] = "너무 많은 일치 (%d 가능)",
		["Unknown Common Color"] = "알 수 없는 색상",
		["Unknown Common Color From TasteTheNaimbow"] = "알 수 없는 이름에 TasteTheNaimbow 색상 사용",
		["Unknown Use Common Color"] = "알 수 없는 이름에 색상 사용",
		["Use Channel Color"] = "채널 색상 사용",
		["Use Player Color"] = "플레이어 색상 사용",
		["Use toon name for RealID"] = "실명ID에 별명 사용",
	},
	["PopupMessage"] = {
		["Add Nickname"] = "별명 추가",
		["Adds an alternate name to show in popups."] = "팝업에 표시할 별명을 추가합니다.",
		["Clear Nickname"] = "별명 전체 삭제",
		["Clears alternate name to show in popups."] = "팝업에 표시할 별명을 전체 삭제합니다.",
		["framealpha_desc"] = "가장 밝아졌을 때 팝업 창의 투명도를 설정합니다.",
		["framealpha_name"] = "팝업 창 투명도",
		["Popup"] = "팝업",
		["PopupMessage"] = "팝업 메시지",
		["Remove Nickname"] = "별명 제거",
		["Removes an alternate name to show in popups."] = "팝업에 표시할 별명을 제거합니다.",
		["Set Separately"] = "개별 설정",
		["Show All Popups"] = "모든 팝업 표시",
		["Show Popups"] = "팝업 표시",
		["Show Popups for all chat windows."] = "모든 대화창에 팝업을 표시합니다.",
		["Show Popups for each window."] = "각 대화창 별로 팝업을 표시합니다.",
		["show_desc"] = "각 창 별로 팝업을 표시합니다.",
		["show_name"] = "팝업 표시",
		["show_perframedesc"] = "팝업 표시 여부를 토글합니다.",
		["show_perframename"] = "%d번 대화창 팝업 표시",
		["showall_desc"] = "모든 대화창에 팝업을 표시합니다.",
		["showall_name"] = "모든 팝업 표시",
		["Shows messages in a popup window."] = "팝업창 안에 메시지를 표시합니다.",
		["Shows messages with your name in a popup."] = "팝업 창에 당신의 이름과 메시지를 같이 표시합니다.",
		["Toggle setting options separately for each chat window."] = "각 대화창 별로 설정 옵션을 끄거나 켭니다.",
	},
	["Scroll"] = {
		["Bottom"] = "밑에서 위로",
		["Chat window scrolling options."] = "대화창 스크롤 옵션입니다.",
		["Control whether text is added to the frame at the top or the bottom."] = "문자가 창의 상단 또는 하단부터 추가될 지 설정합니다.",
		["lowdown_desc"] = "각 대화창 별로 자동 최하단 이동을 끄거나 켭니다.",
		["lowdown_name"] = "최하단 이동 사용",
		["modified_speed"] = "Shift+마우스휠 속도 설정",
		["modified_speed_desc"] = "Shift를 눌렀을 때 마우스 휠로 스크롤할 줄의 숫자를 설정합니다.",
		["mousewheel_desc"] = "각 대화창 별로 마우스 휠 지원을 끄거나 켭니다.",
		["mousewheel_name"] = "마우스 휠 사용",
		["Scroll"] = "스크롤",
		["Set Ctrl+MouseWheel Speed"] = "Ctrl+마우스 휠 속도 설정",
		["Set MouseWheel Speed"] = "마우스 휠 속도 설정",
		["Set number of lines mousewheel will scroll when ctrl is pressed."] = "Ctrl 키를 누르고 마우스 휠을 사용할 때 스크롤할 줄의 수를 설정합니다.",
		["Set number of lines mousewheel will scroll."] = "마우스 휠로 스크롤할 줄의 수를 설정합니다.",
		["Set TheLowDown Delay"] = "최하단 이동 지연 시간 설정",
		["Set time to wait before jumping to the bottom of chat windows."] = "대화창을 하단으로 내리기까지 대기 시간을 설정합니다.",
		["Text scroll direction"] = "문자 스크롤 방향",
		["Top"] = "위에서 아래로",
	},
	["Search"] = {
		["err_notfound"] = "찾을 수 없음",
		["err_tooshort"] = "검색 구문이 너무 짧습니다",
		["find_results"] = "검색 결과:",
		["module_desc"] = "대화창 검색 기능을 추가합니다.",
		["module_info"] = [=[이 모듈은 대화 기록을 검색하는 /find 와 /findall 명령어를 추가합니다

사용법:

/find <문자열>

/findall <문자열>]=],
		["module_name"] = "검색",
	},
	["ServerNames"] = {
		["autoabbreviate_desc"] = "서버 이름을 3글자로 줄입니다",
		["autoabbreviate_name"] = "자동-줄임",
		["colon_desc"] = "서버 대체 이름 뒤에 콜론 추가 기능을 끄거나 켭니다.",
		["colon_name"] = "콜론 표시",
		["randomclr_desc"] = "서버 이름에 무작위 색상을 사용합니다.",
		["randomclr_name"] = "무작위 색상",
		["Server name abbreviation options."] = "서버 이름 줄이기 옵션입니다.",
		["ServerNames"] = "서버 이름",
	},
	["Sounds"] = {
		["A module to play sounds on certain chat messages."] = "특정 대화 메시지에 소리를 재생하는 모듈입니다.",
		["Add a custom channel"] = "사설 채널 추가",
		["bn_whisper_desc"] = "%s Battle.Net 귓속말 메시지 소리",
		["bn_whisper_name"] = "Battle.Net 귓속말",
		["Custom Channels"] = "사설 채널",
		["group_lead_desc"] = "%s 공격대장, 파티장 또는 던전 길잡이 메시지의 소리",
		["group_lead_name"] = "그룹장",
		["guild_desc"] = "%s 길드 메시지 소리",
		["guild_name"] = "길드",
		["incoming"] = "받을 때",
		["Incoming Sounds"] = "받을 때 소리",
		["officer_desc"] = "%s 관리자 채널 메시지 소리",
		["officer_name"] = "관리자",
		["outgoing"] = "보낼 때",
		["Outgoing Sounds"] = "보낼 때 소리",
		["party_desc"] = "%s 파티 메시지 소리",
		["party_name"] = "파티",
		["Play a sound for a certain channel name (can be a substring)"] = "특정 채널 이름에 소리 재생하기 (일치하는 단어 포함)",
		["raid_desc"] = "%s 공격대 또는 전장 파티/장 메시지 소리",
		["raid_name"] = "공격대",
		["Remove a custom channel"] = "사설 채널 제거",
		["Reset settings"] = "설정 초기화",
		["Restore default settings and resets custom channel list"] = "사설 채널 목록을 초기화하고 기본 설정으로 복원",
		["Sound selection for incoming chat messages"] = "대화 메시지를 받을 때 소리 선택",
		["Sound selection for outgoing (from you) chat messages"] = "대화 메시지를 보낼 때(자신이) 소리 선택",
		["Sounds"] = "소리",
		["whisper_desc"] = "%s 귓속말 메시지 소리",
		["whisper_name"] = "귓속말",
	},
	["Substitutions"] = {
		["%d total user defined substitutions"] = "총 %d개의 사용자 설정 대용어",
		["|cffff0000warning:|r subtitution \"%s\" already defined as \"%s\", overwriting"] = "|cffff0000경고:|r 대용어 \"%s\"|1은;는; 이미 \"%s\"|1으로;로; 정의 되었습니다, 덮어씁니다",
		["<noguild>"] = "<길드없음>",
		["<notarget>"] = "<대상없음>",
		["A module to provide basic chat substitutions."] = "기본적인 대화 대용어를 제공하는 모듈입니다.",
		["Are you sure - this will delete all user defined substitutions and reset defaults?"] = "정말로 모든 사용자 정의 대용어를 삭제하고 기본값으로 초기화할까요?",
		["Are you sure?"] = "동의합니까?",
		["can't find substitution index for a substitution named '%s'"] = "'%s' 대용어의 값을 찾을 수 없습니다",
		["current-prompt"] = [=[현재 값: '%s'
클릭하면 대화창에 붙여 넣습니다.]=],
		["defined %s: expands to => %s"] = "'%s' 정의: 확장됨 => %s",
		["Delete all"] = "전부 삭제",
		["Delete substitution"] = "대용어 삭제",
		["Deletes a user defined substitution"] = "사용자 정의 대용어를 삭제합니다",
		["Deletes all user defined substitutions"] = "모든 사용자 정의 대용어를 삭제합니다",
		["female"] = "여자",
		["her"] = "그녀의",
		["hers"] = "그녀의 것",
		["him"] = "그",
		["his"] = "그의",
		["it"] = "그것",
		["its"] = "그것의",
		["List of available substitutions"] = "사용 가능한 대용어 목록",
		["List of available substitutions defined by this module. (NB: users may define custom values for existing substitutions, but they will revert to the default value if the user definition is deleted.)"] = "이 모듈로 사용 가능한 대용어 목록입니다. (NB: 존재하는 대용어에 사용자 설정 값을 정의 할 수 있지만, 사용자 설정 값이 삭제되면 기본 값으로 전환됩니다.)",
		["List substitutions"] = "대용어 목록",
		["Lists all current subtitutions in the default chat frame"] = "기본 대화창에 현재 모든 대용어 목록 표시",
		["male"] = "남자",
		["MapLoc"] = "지도 위치",
		["MapPos"] = "지도 좌표",
		["MapXPos"] = "지도 X좌표",
		["MapYPos"] = "지도 Y좌표",
		["MapZone"] = "지도 지역",
		["module:buildUserSubsIndex(): warning: module patterns not defined!"] = "module:buildUserSubsIndex(): 경고: 모듈 패턴이 정의되지 않았습니다!",
		["MouseoverTargetName"] = "마우스 오버 대상 이름",
		["NO MATCHFUNC FOUND"] = "MATCHFUNC 찾을 수 없음",
		["no substitution name given"] = "주어진 대용어 이름 없음",
		["no substitution name supplied for deletion"] = "삭제할 대용어 이름 없음",
		["no user defined subs found"] = "사용자 정의 대용어 찾을 수 없음",
		["no value given for subtitution \"%s\""] = "\"%s\" 대용어에 주어진 값 없음",
		["Options for setting and removing user defined substitutions. (NB: users may define custom values for existing substitutions, but they will revert to the default value if the user definition is deleted.)"] = "사용자 정의 대용어을 설정하거나 제거하는 옵션입니다. (NB: 존재하는 대용어에 사용자 설정 값을 정의 할 수 있지만, 사용자 설정 값을 삭제하면 기본값으로 전환됩니다.)",
		["PlayerAverageItemLevel"] = "플레이어 평균 아이템 레벨",
		["PlayerCurrentMana"] = "플레이어 현재 마나",
		["PlayerHealthDeficit"] = "플레이어 생명력 결손치",
		["PlayerHP"] = "플레이어 생명력",
		["PlayerManaDeficit"] = "플레이어 마나 결손치",
		["PlayerMaxHP"] = "플레이어 최대 생명력",
		["PlayerMaxMana"] = "플레이어 최대 마나",
		["PlayerName"] = "플레이어 이름",
		["PlayerPercentHP"] = "플레이어 생명력 백분율",
		["PlayerPercentMana"] = "플레이어 마나 백분율",
		["RandNum"] = "무작위 숫자",
		["removing user defined substitution \"%s\"; previously expanded to => \"%s\""] = "\"%s\" 사용자 정의 대용어를 제거합니다, 이전 값으로 복원 => \"%s\"",
		["Set substitution"] = "대용어 설정",
		["Set the value of a user defined substitution (NB: this may be the same as an existing default substitution; to reset it to the default, just remove the user created definition)."] = "사용자 정의 대용어 값 설정 (NB: 존재하는 기본 대용어와 같으면; 기본값으로 초기화하며, 사용자가 생성한 정의를 제거합니다.)",
		["subname -- NOTE: sub name without the prefix '%'"] = "대체이름 -- 참고: 접두사 '%' 없이 대체 이름",
		["subname = text after expansion -- NOTE: sub name without the prefix \"%\""] = "대체이름 = 확장 후 문자 -- 참고: 접두사 '%' 없이 대체 이름",
		["substitution: %s defined as => %s"] = "대용어: %s 정의됨 => %s",
		["Substitutions"] = "대용어",
		["TargetClass"] = "대상 직업",
		["TargetGender"] = "대상 성별",
		["TargetGuild"] = "대상 길드",
		["TargetHealth"] = "대상 생명력",
		["TargetHealthDeficit"] = "대상 생명력 결손치",
		["TargetIcon"] = "대상 아이콘",
		["TargetLevel"] = "대상 레벨",
		["TargetManaDeficit"] = "대상 마나 결손치",
		["TargetName"] = "대상 이름",
		["TargetPercentHP"] = "대상 생명력 백분율",
		["TargetPossesive"] = "대상 소유격",
		["TargetPronoun"] = "대상 대명사",
		["TargetRace"] = "대상 종족",
		["TargetTargetName"] = "대상의 대상 이름",
		["unknown sex"] = "알 수 없는 성별",
		["user defined substition \"%s\" not found"] = "사용자 설정 대용어 \"%s\" 찾을 수 없음",
		["User defined substitutions"] = "사용자 정의 대용어",
		["user substitutions index (usersubs_idx) doesn't exist! oh dear."] = "사용자 대용어 값 (usersubs_idx) 존재하지 않습니다!",
		["usersub_"] = true,
	},
	["TellTarget"] = {
		["/tt"] = true,
		["Adds telltarget slash command (/tt)."] = "대상에게 말하기 슬래쉬 명령어를 추가합니다 (/tt).",
		["No target selected."] = "대상이 선택되지 않았습니다.",
		["NoTarget"] = "대상 없음",
		["Target does not exist."] = "대상이 존재하지 않습니다.",
		["Target is not a player."] = "대상이 플레이어가 아닙니다.",
		["TellTarget"] = "대상에게 말하기",
	},
	["Timestamps"] = {
		["Chat window timestamp options."] = "대화창 시간 표시 옵션입니다.",
		["colortimestamp_desc"] = "시간 표시에 색상을 입히거나 입히지 않습니다.",
		["colortimestamp_name"] = "시간 표시 색상",
		["Format All Timestamps"] = "모든 시간 표시 형식",
		["HH:MM (12-hour)"] = "HH:MM (12시간제)",
		["HH:MM (24-hour)"] = "HH:MM (24시간제)",
		["HH:MM:SS (12-hour)"] = "HH:MM:SS (12시간제)",
		["HH:MM:SS (24-hour)"] = "HH:MM:SS (24시간제)",
		["HH:MM:SS AM (12-hour)"] = "HH:MM:SS AM (12시간제)",
		["localtime_desc"] = "컴퓨터 시간 사용합니다.",
		["localtime_name"] = "컴퓨터 시간 사용",
		["MM:SS"] = true,
		["Post-Timestamp"] = "뒤-시간 표시",
		["Pre-Timestamp"] = "앞-시간 표시",
		["Set the timestamp format"] = "시간 표시 형식 설정",
		["Set Timestamp Color"] = "시간 표시 색상 설정",
		["Sets the color of the timestamp."] = "시간 표시 색상을 설정합니다.",
		["Show Timestamp"] = "시간 표시",
		["show_desc"] = "각 창 별로 시간 표시 여부를 선택합니다.",
		["show_name"] = "시간 표시",
		["space_desc"] = "시간 표시 뒤에 공간을 넣을 지 선택합니다.",
		["space_name"] = "공간 삽입",
		["Timestamps"] = "시간 표시",
		["Toggle showing timestamp for each window."] = "각 창 별로 시간 표시 기능을 끄거나 켭니다.",
		["twocolumn_desc"] = "시간 표시를 분리된 열에 위치시켜 글자가 그 아래쪽을 둘러싸지 않게 합니다",
		["twocolumn_name"] = "열 분리",
	},
	["UrlCopy"] = {
		["Change the color of the URL."] = "URL의 색상을 변경합니다.",
		["Color URL"] = "URL 색상",
		["Set Color"] = "색상 설정",
		["Show Brackets"] = "괄호 표시",
		["Toggle"] = "토글",
		["Toggle showing brackets on and off."] = "괄호 표시를 끄거나 켭니다.",
		["Toggle the module on and off."] = "모듈을 끄거나 켭니다.",
		["Toggle the URL color on and off."] = "URL 색상을 끄거나 켭니다.",
		["URL formating options."] = "URL 형식 옵션입니다.",
		["UrlCopy"] = "Url 복사",
		["Use Popup"] = "팝업창 사용",
		["Use popup window to show URL."] = "URL을 팝업창에 표시합니다.",
	}
}

PL:AddLocale(PRAT_MODULE.name, "koKR",L)


L=
{
	--Translation missing 
	-- ["display_desc"] = "",
	--Translation missing 
	-- ["display_name"] = "",
	--Translation missing 
	-- ["extras_desc"] = "",
	--Translation missing 
	-- ["extras_name"] = "",
	--Translation missing 
	-- ["formatting_desc"] = "",
	--Translation missing 
	-- ["formatting_name"] = "",
	--Translation missing 
	-- ["load_desc"] = "",
	--Translation missing 
	-- ["load_disabled"] = "",
	--Translation missing 
	-- ["load_disabledonrestart"] = "",
	--Translation missing 
	-- ["load_enabled"] = "",
	--Translation missing 
	-- ["load_enabledonrestart"] = "",
	--Translation missing 
	-- ["load_no"] = "",
	--Translation missing 
	-- ["modulecontrol_desc"] = "",
	--Translation missing 
	-- ["modulecontrol_name"] = "",
	--Translation missing 
	-- ["prat"] = "",
	--Translation missing 
	-- ["reload_required"] = "",
	["AddonMsgs"] = {
		--Translation missing 
		-- ["Addon message options."] = "",
		--Translation missing 
		-- ["AddonMsgs"] = "",
		--Translation missing 
		-- ["show_desc"] = "",
		--Translation missing 
		-- ["show_name"] = "",
		--Translation missing 
		-- ["show_perframedesc"] = "",
		--Translation missing 
		-- ["show_perframename"] = "",
	},
	["Alias"] = {
		--Translation missing 
		-- [" - list all aliases; supply <keyword> to search for matching aliases (cmd aliases: /listallaliases)"] = "",
		--Translation missing 
		-- ["%s() called with blank string!"] = "",
		--Translation missing 
		-- ["%s() called with nil argument!"] = "",
		--Translation missing 
		-- ["/%s aliased to \"/%s\""] = "",
		--Translation missing 
		-- ["/%s aliased to: /%s"] = "",
		--Translation missing 
		-- ["<alias> - remove the alias <alias> (cmd aliases: /delalias, /remalias)"] = "",
		--Translation missing 
		-- ["<command>[ <value>] - alias <command> to be executed as <value>, or return the value of the currently defined alias for <command> if <command> has not been assigned a value. eg: \"/alias /examplehello /say hello there\" - typing \"/examplehello\" will now cause your character to say \"hello there\"; \"/alias examplehello\" - s \"/examplehello is aliased to /say hello there\" (cmd aliases: /addalias)"] = "",
		--Translation missing 
		-- ["<keyword> - finds all aliases matching <keyword> (cmd aliases: /findalias)"] = "",
		--Translation missing 
		-- ["add"] = "",
		--Translation missing 
		-- ["add an alias"] = "",
		--Translation missing 
		-- ["alias \"/%s\" does not exist"] = "",
		--Translation missing 
		-- ["dealiasing command /%s to /%s"] = "",
		--Translation missing 
		-- ["deleting alias \"/%s\" (previously aliased as \"/%s\")"] = "",
		--Translation missing 
		-- ["Display extra information in the chat frame when commands are dealiased"] = "",
		--Translation missing 
		-- ["Don't overwrite existing aliases when using /addalias"] = "",
		--Translation missing 
		-- ["Expand aliases as you are typing"] = "",
		--Translation missing 
		-- ["find aliases matching a given search term"] = "",
		--Translation missing 
		-- ["findaliases"] = "",
		--Translation missing 
		-- ["infinite loop detected for alias /%s - ignoring"] = "",
		--Translation missing 
		-- ["inline"] = "",
		--Translation missing 
		-- ["list all aliases"] = "",
		--Translation missing 
		-- ["listaliases"] = "",
		--Translation missing 
		-- ["matching aliases found: %d"] = "",
		--Translation missing 
		-- ["module_desc"] = "",
		--Translation missing 
		-- ["module_name"] = "",
		--Translation missing 
		-- ["No aliases have been defined"] = "",
		--Translation missing 
		-- ["noclobber"] = "",
		--Translation missing 
		-- ["noclobber set - skipping new alias: /%s already expands to /%s"] = "",
		--Translation missing 
		-- ["Options"] = "",
		--Translation missing 
		-- ["Options for altering the behaviour of Alias"] = "",
		--Translation missing 
		-- ["overwriting existing alias \"/%s\" (was aliased to \"/%s\")"] = "",
		--Translation missing 
		-- ["refusing to alias \"/%s\" to anything in the interests of Not Buggering Everything Up"] = "",
		--Translation missing 
		-- ["remove an alias"] = "",
		--Translation missing 
		-- ["There is no alias current defined for \"%s\""] = "",
		--Translation missing 
		-- ["total aliases: %d"] = "",
		--Translation missing 
		-- ["tried to show value for alias \"%s\" but undefined in module.Aliases!"] = "",
		--Translation missing 
		-- ["unalias"] = "",
		--Translation missing 
		-- ["verbose"] = "",
		--Translation missing 
		-- ["warnUser() called with nil argument!"] = "",
		--Translation missing 
		-- ["warnUser() called with zero length string!"] = "",
	},
	["AltNames"] = {
		--Translation missing 
		-- ["%d alts found for %s: %s"] = "",
		--Translation missing 
		-- ["%s alts imported from LOKWhoIsWho"] = "",
		--Translation missing 
		-- ["%s total alts linked to mains"] = "",
		--Translation missing 
		-- ["(.-)'s? [Aa]lt"] = "",
		--Translation missing 
		-- ["([^%s%p%d%c%z]+)'s alt"] = "",
		--Translation missing 
		-- [".*[Aa]lts?$"] = "",
		--Translation missing 
		-- ["<alt name> (eg, /altnames del Personyouthoughtwassomeonesaltbutreallyisnt)"] = "",
		--Translation missing 
		-- ["<main> (eg /altnames listalts Fin)"] = "",
		--Translation missing 
		-- ["<search term> (eg, /altnames find fin)"] = "",
		--Translation missing 
		-- ["Alt"] = "",
		--Translation missing 
		-- ["alt"] = "",
		--Translation missing 
		-- ["alt name exists: %s -> %s; not overwriting as set in preferences"] = "",
		--Translation missing 
		-- ["AltNames"] = "",
		--Translation missing 
		-- ["Alts:"] = "",
		--Translation missing 
		-- ["autoguildalts_desc"] = "",
		--Translation missing 
		-- ["autoguildalts_name"] = "",
		--Translation missing 
		-- ["Be quiet"] = "",
		--Translation missing 
		-- ["character removed: %s"] = "",
		--Translation missing 
		-- ["Class colour"] = "",
		--Translation missing 
		-- ["Clear all"] = "",
		--Translation missing 
		-- ["Clear all links between alts and main names."] = "",
		--Translation missing 
		-- ["Colour"] = "",
		--Translation missing 
		-- ["Delete a character's link to another character as their main."] = "",
		--Translation missing 
		-- ["Delete alt"] = "",
		--Translation missing 
		-- ["Disabled"] = "",
		--Translation missing 
		-- ["Display a player's alts in the tooltip"] = "",
		--Translation missing 
		-- ["Display a player's main name in the tooltip"] = "",
		--Translation missing 
		-- ["Display main names in the same colour as that of the alt's class (taking the data from the PlayerNames module if it is enabled)"] = "",
		--Translation missing 
		-- ["Display main names in the same colour as that of the main's class (taking the data from the PlayerNames module if it is enabled)"] = "",
		--Translation missing 
		-- ["Don't overwrite existing alt <-> main links when importing or adding new alts."] = "",
		--Translation missing 
		-- ["Don't overwrite existing links"] = "",
		--Translation missing 
		-- ["don't use"] = "",
		--Translation missing 
		-- ["Don't use data from the PlayerNames module at all"] = "",
		--Translation missing 
		-- ["ERROR: some function sent a blank message!"] = "",
		--Translation missing 
		-- ["Find characters"] = "",
		--Translation missing 
		-- ["Fix alts"] = "",
		--Translation missing 
		-- ["Fix corrupted entries in your list of alt names."] = "",
		--Translation missing 
		-- ["Found alt: %s => main: %s"] = "",
		--Translation missing 
		-- ["guild member alts found and imported: %s"] = "",
		--Translation missing 
		-- ["Import from Guild Greet database"] = "",
		--Translation missing 
		-- ["Import from guild roster"] = "",
		--Translation missing 
		-- ["Import options"] = "",
		--Translation missing 
		-- ["Imports alt names from a Guild Greet database, if present"] = "",
		--Translation missing 
		-- ["Imports alt names from the guild roster by checking for members with the rank \"alt\" or \"alts\", or guild / officer notes like \"<name>'s alt\""] = "",
		--Translation missing 
		-- ["Imports data from LOKWhoIsWho, if present (drop your SavedVariablesLOKWhoIsWho.lua in the Prat directory to be able to use this)."] = "",
		--Translation missing 
		-- ["Left"] = "",
		--Translation missing 
		-- ["link <alt name> <main name> (eg, /altnames link Fin Finjathealtoffin)"] = "",
		--Translation missing 
		-- ["Link alt"] = "",
		--Translation missing 
		-- ["Link someone's alt character with the name of their main."] = "",
		--Translation missing 
		-- ["linked alt %s => %s"] = "",
		--Translation missing 
		-- ["List all"] = "",
		--Translation missing 
		-- ["List all links between alts and their main names."] = "",
		--Translation missing 
		-- ["List alts"] = "",
		--Translation missing 
		-- ["List alts for a given character"] = "",
		--Translation missing 
		-- ["LOKWhoIsWho data not found"] = "",
		--Translation missing 
		-- ["LOKWhoIsWho import"] = "",
		--Translation missing 
		-- ["LOKWhoIsWho lua file not found, sorry."] = "",
		--Translation missing 
		-- ["Main"] = "",
		--Translation missing 
		-- ["main"] = "",
		--Translation missing 
		-- ["Main name position"] = "",
		--Translation missing 
		-- ["Main:"] = "",
		--Translation missing 
		-- ["mainpos_desc"] = "",
		--Translation missing 
		-- ["mainpos_name"] = "",
		--Translation missing 
		-- ["module_desc"] = "",
		--Translation missing 
		-- ["no alts found for character "] = "",
		--Translation missing 
		-- ["no alts or mains found matching \"%s\""] = "",
		--Translation missing 
		-- ["No arg string given to :addAlt()"] = "",
		--Translation missing 
		-- ["no characters called \"%s\" found; nothing deleted"] = "",
		--Translation missing 
		-- ["No Guild Greet database found"] = "",
		--Translation missing 
		-- ["No main name supplied to link %s to"] = "",
		--Translation missing 
		-- ["no matches found"] = "",
		--Translation missing 
		-- ["quiet"] = "",
		--Translation missing 
		-- ["quiet_desc"] = "",
		--Translation missing 
		-- ["quiet_name"] = "",
		--Translation missing 
		-- ["Right"] = "",
		--Translation missing 
		-- ["Search the list of linked characters for matching main or alt names."] = "",
		--Translation missing 
		-- ["searched for: %s - total matches: %s"] = "",
		--Translation missing 
		-- ["Show alts in tooltip"] = "",
		--Translation missing 
		-- ["Show main in tooltip"] = "",
		--Translation missing 
		-- ["Start"] = "",
		--Translation missing 
		-- ["The colour of an alt's main name that will be displayed"] = "",
		--Translation missing 
		-- ["Use class colour (from the PlayerNames module)"] = "",
		--Translation missing 
		-- ["use class colour of alt"] = "",
		--Translation missing 
		-- ["use class colour of main"] = "",
		--Translation missing 
		-- ["Use LibAlts Data"] = "",
		--Translation missing 
		-- ["Use the data available via the shared alt information library."] = "",
		--Translation missing 
		-- ["Various ways to import a main's alts from other addons"] = "",
		--Translation missing 
		-- ["warning: alt %s already linked to %s"] = "",
		--Translation missing 
		-- ["Where to display a character's main name when on their alt."] = "",
		--Translation missing 
		-- ["Whether to report to the chat frame or not."] = "",
		--Translation missing 
		-- ["You are not in a guild"] = "",
		--Translation missing 
		-- ["You have not yet linked any alts with their mains."] = "",
	},
	["Bubbles"] = {
		--Translation missing 
		-- ["color_desc"] = "",
		--Translation missing 
		-- ["color_name"] = "",
		--Translation missing 
		-- ["font_desc"] = "",
		--Translation missing 
		-- ["font_name"] = "",
		--Translation missing 
		-- ["fontsize_desc"] = "",
		--Translation missing 
		-- ["fontsize_name"] = "",
		--Translation missing 
		-- ["format_desc"] = "",
		--Translation missing 
		-- ["format_name"] = "",
		--Translation missing 
		-- ["icons_desc"] = "",
		--Translation missing 
		-- ["icons_name"] = "",
		--Translation missing 
		-- ["module_desc"] = "",
		--Translation missing 
		-- ["module_name"] = "",
		--Translation missing 
		-- ["shorten_desc"] = "",
		--Translation missing 
		-- ["shorten_name"] = "",
		--Translation missing 
		-- ["transparent_desc"] = "",
		--Translation missing 
		-- ["transparent_name"] = "",
	},
	["Buttons"] = {
		--Translation missing 
		-- ["alpha_desc"] = "",
		--Translation missing 
		-- ["alpha_name"] = "",
		--Translation missing 
		-- ["Buttons"] = "",
		--Translation missing 
		-- ["Chat window button options."] = "",
		--Translation missing 
		-- ["chatmenu_desc"] = "",
		--Translation missing 
		-- ["chatmenu_name"] = "",
		--Translation missing 
		-- ["Default"] = "",
		--Translation missing 
		-- ["Right, Inside Frame"] = "",
		--Translation missing 
		-- ["Right, Outside Frame"] = "",
		--Translation missing 
		-- ["scrollReminder_desc"] = "",
		--Translation missing 
		-- ["scrollReminder_name"] = "",
		--Translation missing 
		-- ["Set Position"] = "",
		--Translation missing 
		-- ["Sets position of chat menu and arrows for all chat windows."] = "",
		--Translation missing 
		-- ["Show Arrows"] = "",
		--Translation missing 
		-- ["Show Chat%d Arrows"] = "",
		--Translation missing 
		-- ["showbnet_desc"] = "",
		--Translation missing 
		-- ["showbnet_name"] = "",
		--Translation missing 
		-- ["showmenu_desc"] = "",
		--Translation missing 
		-- ["showmenu_name"] = "",
		--Translation missing 
		-- ["showminimize_desc"] = "",
		--Translation missing 
		-- ["showminimize_name"] = "",
		--Translation missing 
		-- ["Toggle showing chat arrows for each chat window."] = "",
		--Translation missing 
		-- ["Toggles navigation arrows on and off."] = "",
	},
	["ChannelColorMemory"] = {
		--Translation missing 
		-- ["(%w+)%s?(.*)"] = "",
		--Translation missing 
		-- ["ChannelColorMemory"] = "",
		--Translation missing 
		-- ["Remembers the colors of each channel name."] = "",
	},
	["ChannelNames"] = {
		--Translation missing 
		-- ["%s settings."] = "",
		--Translation missing 
		-- ["<string>"] = "",
		--Translation missing 
		-- ["Add Channel Abbreviation"] = "",
		--Translation missing 
		-- ["addnick_desc"] = "",
		--Translation missing 
		-- ["Blank"] = "",
		--Translation missing 
		-- ["chanlink_desc"] = "",
		--Translation missing 
		-- ["chanlink_name"] = "",
		--Translation missing 
		-- ["Channel %d"] = "",
		--Translation missing 
		-- ["Channel name abbreviation options."] = "",
		--Translation missing 
		-- ["ChannelNames"] = "",
		--Translation missing 
		-- ["channelnick_desc"] = "",
		--Translation missing 
		-- ["channelnick_name"] = "",
		--Translation missing 
		-- ["Clear Channel Abbreviation"] = "",
		--Translation missing 
		-- ["Clears an abbreviated channel name."] = "",
		--Translation missing 
		-- ["colon_desc"] = "",
		--Translation missing 
		-- ["colon_name"] = "",
		--Translation missing 
		-- ["Dont display the channel/chat type name"] = "",
		--Translation missing 
		-- ["otheropts_desc"] = "",
		--Translation missing 
		-- ["otheropts_name"] = "",
		--Translation missing 
		-- ["Remove Channel Abbreviation"] = "",
		--Translation missing 
		-- ["Removes an an abbreviated channel name."] = "",
		--Translation missing 
		-- ["Replace"] = "",
		--Translation missing 
		-- ["Set"] = "",
		--Translation missing 
		-- ["space_desc"] = "",
		--Translation missing 
		-- ["space_name"] = "",
		--Translation missing 
		-- ["Toggle replacing this channel."] = "",
		--Translation missing 
		-- ["Use a custom replacement for the chat %s text."] = "",
	},
	["ChannelSticky"] = {
		--Translation missing 
		-- ["Channel"] = "",
		--Translation missing 
		-- ["ChannelSticky"] = "",
		--Translation missing 
		-- ["Chat channel sticky options."] = "",
		--Translation missing 
		-- ["ChatType"] = "",
		--Translation missing 
		-- ["Per chat type options."] = "",
		--Translation missing 
		-- ["smartgroup_desc"] = "",
		--Translation missing 
		-- ["smartgroup_name"] = "",
		--Translation missing 
		-- ["Sticky %s"] = "",
		--Translation missing 
		-- ["Sticky Per Chat Frame"] = "",
		--Translation missing 
		-- ["Toggle remembering the chat type last used per chat frame."] = "",
		--Translation missing 
		-- ["Toggles sticky on and off for %s."] = "",
	},
	["ChatFrames"] = {
		--Translation missing 
		-- ["Chat window frame parameter options"] = "",
		--Translation missing 
		-- ["framealpha_desc"] = "",
		--Translation missing 
		-- ["framealpha_name"] = "",
		--Translation missing 
		-- ["Frames"] = "",
		--Translation missing 
		-- ["mainchatonload_desc"] = "",
		--Translation missing 
		-- ["mainchatonload_name"] = "",
		--Translation missing 
		-- ["maxchatheight_desc"] = "",
		--Translation missing 
		-- ["maxchatheight_name"] = "",
		--Translation missing 
		-- ["maxchatwidth_desc"] = "",
		--Translation missing 
		-- ["maxchatwidth_name"] = "",
		--Translation missing 
		-- ["minchatheight_desc"] = "",
		--Translation missing 
		-- ["minchatheight_name"] = "",
		--Translation missing 
		-- ["minchatwidth_desc"] = "",
		--Translation missing 
		-- ["minchatwidth_name"] = "",
		--Translation missing 
		-- ["rememberframepositions_desc"] = "",
		--Translation missing 
		-- ["rememberframepositions_name"] = "",
		--Translation missing 
		-- ["removeclamp_desc"] = "",
		--Translation missing 
		-- ["removeclamp_name"] = "",
	},
	["ChatLink"] = {
		--Translation missing 
		-- ["gem_desc"] = "",
		--Translation missing 
		-- ["gem_name"] = "",
		--Translation missing 
		-- ["module_desc"] = "",
		--Translation missing 
		-- ["module_info"] = "",
		--Translation missing 
		-- ["module_name"] = "",
		--Translation missing 
		-- ["Trade"] = "",
	},
	["ChatLog"] = {
		--Translation missing 
		-- ["A module to automaticaly enable chat and combat logging."] = "",
		--Translation missing 
		-- ["Chat log recorded to <WoW Installation>\\Logs\\WoWChatLog.txt only upon logout."] = "",
		--Translation missing 
		-- ["Chat Log: Disabled"] = "",
		--Translation missing 
		-- ["Chat Log: Enabled"] = "",
		--Translation missing 
		-- ["ChatLog"] = "",
		--Translation missing 
		-- ["Combat log recorded to <WoW Installation>\\Logs\\WoWCombatLog.txt only upon logout."] = "",
		--Translation missing 
		-- ["Combat Log: Disabled"] = "",
		--Translation missing 
		-- ["Combat Log: Enabled"] = "",
		--Translation missing 
		-- ["quiet_desc"] = "",
		--Translation missing 
		-- ["quiet_name"] = "",
		--Translation missing 
		-- ["Toggle Chat Log"] = "",
		--Translation missing 
		-- ["Toggle chat log on and off."] = "",
		--Translation missing 
		-- ["Toggle Combat Log"] = "",
		--Translation missing 
		-- ["Toggle combat log on and off."] = "",
	},
	["ChatTabs"] = {
		--Translation missing 
		-- ["Active Alpha"] = "",
		--Translation missing 
		-- ["All"] = "",
		--Translation missing 
		-- ["Always"] = "",
		--Translation missing 
		-- ["Chat window tab options."] = "",
		--Translation missing 
		-- ["Default"] = "",
		--Translation missing 
		-- ["disableflash_desc"] = "",
		--Translation missing 
		-- ["disableflash_name"] = "",
		--Translation missing 
		-- ["Hidden"] = "",
		--Translation missing 
		-- ["Individual"] = "",
		--Translation missing 
		-- ["Not Active Alpha"] = "",
		--Translation missing 
		-- ["preventdrag_desc"] = "",
		--Translation missing 
		-- ["preventdrag_name"] = "",
		--Translation missing 
		-- ["Set ChatFrame%d Display Mode"] = "",
		--Translation missing 
		-- ["Set Display Mode"] = "",
		--Translation missing 
		-- ["Set tab display mode for each chat window."] = "",
		--Translation missing 
		-- ["Set tab display to always, hidden or the Blizzard default."] = "",
		--Translation missing 
		-- ["Sets alpha of chat tab for active chat frame."] = "",
		--Translation missing 
		-- ["Sets alpha of chat tab for not active chat frame."] = "",
		--Translation missing 
		-- ["Tabs"] = "",
	},
	["Clear"] = {
		--Translation missing 
		-- ["Adds clear text slash commands (/clear)(/cls)(/clearall)(/clsall)."] = "",
		--Translation missing 
		-- ["Clear"] = "",
		--Translation missing 
		-- ["Clearall"] = "",
		--Translation missing 
		-- ["Clears all chat frames."] = "",
		--Translation missing 
		-- ["Clears the current chat frame."] = "",
	},
	["CopyChat"] = {
		--Translation missing 
		-- [" Text"] = "",
		--Translation missing 
		-- ["BBCode"] = "",
		--Translation missing 
		-- ["BOTTOMLEFT"] = "",
		--Translation missing 
		-- ["BOTTOMRIGHT"] = "",
		--Translation missing 
		-- ["buttonpos_desc"] = "",
		--Translation missing 
		-- ["buttonpos_name"] = "",
		--Translation missing 
		-- ["ChatFrame"] = "",
		--Translation missing 
		-- ["Copy all of the text in the selected chat frame into an edit box"] = "",
		--Translation missing 
		-- ["Copy Text"] = "",
		--Translation missing 
		-- ["Copy Text Format"] = "",
		--Translation missing 
		-- ["Copy text from the active chat window."] = "",
		--Translation missing 
		-- ["Copy To Editbox"] = "",
		--Translation missing 
		-- ["CopyChat"] = "",
		--Translation missing 
		-- ["HTML"] = "",
		--Translation missing 
		-- ["Message From : %s"] = "",
		--Translation missing 
		-- ["Plain"] = "",
		--Translation missing 
		-- ["Should the copied text be plain, or formatted so you can see the colors."] = "",
		--Translation missing 
		-- ["showbutton_desc"] = "",
		--Translation missing 
		-- ["showbutton_name"] = "",
		--Translation missing 
		-- ["TOPLEFT"] = "",
		--Translation missing 
		-- ["TOPRIGHT"] = "",
		--Translation missing 
		-- ["Wowace.com Forums"] = "",
	},
	["CustomFilters"] = {
		--Translation missing 
		-- ["<string>"] = "",
		--Translation missing 
		-- ["Add a pattern to search for."] = "",
		--Translation missing 
		-- ["Add Pattern"] = "",
		--Translation missing 
		-- ["Block Message"] = "",
		--Translation missing 
		-- ["Channel Data"] = "",
		--Translation missing 
		-- ["Channel to send output text to."] = "",
		--Translation missing 
		-- ["Enabled"] = "",
		--Translation missing 
		-- ["Extra data for WHISPER (target) and CHANNEL (channel name or num)"] = "",
		--Translation missing 
		-- ["Filter Name"] = "",
		--Translation missing 
		-- ["Forward"] = "",
		--Translation missing 
		-- ["Forward the message to a chat channel."] = "",
		--Translation missing 
		-- ["Forward the message to a custom chat channel."] = "",
		--Translation missing 
		-- ["ForwardCustom"] = "",
		--Translation missing 
		-- ["ForwardMessage"] = "",
		--Translation missing 
		-- ["ForwardMessageCustom"] = "",
		--Translation missing 
		-- ["Hilight Color"] = "",
		--Translation missing 
		-- ["Hilight Match Text"] = "",
		--Translation missing 
		-- ["Inbound"] = "",
		--Translation missing 
		-- ["inchannels_desc"] = "",
		--Translation missing 
		-- ["inchannels_name"] = "",
		--Translation missing 
		-- ["Is this pattern enabled for use?"] = "",
		--Translation missing 
		-- ["Match Options"] = "",
		--Translation missing 
		-- ["module_desc"] = "",
		--Translation missing 
		-- ["module_name"] = "",
		--Translation missing 
		-- ["Only output the message portion of the chat text, leave out the channel, and playername etc."] = "",
		--Translation missing 
		-- ["Outbound"] = "",
		--Translation missing 
		-- ["Output Channel"] = "",
		--Translation missing 
		-- ["Output Message Only"] = "",
		--Translation missing 
		-- ["Pattern Info"] = "",
		--Translation missing 
		-- ["Pattern Options"] = "",
		--Translation missing 
		-- ["Play a sound when this message is output to the chatframe"] = "",
		--Translation missing 
		-- ["Play Sound"] = "",
		--Translation missing 
		-- ["Prevent the message from being displayed"] = "",
		--Translation missing 
		-- ["Remove an existing pattern."] = "",
		--Translation missing 
		-- ["Remove Pattern"] = "",
		--Translation missing 
		-- ["Replacement Text"] = "",
		--Translation missing 
		-- ["Search Format String"] = "",
		--Translation missing 
		-- ["Search Pattern"] = "",
		--Translation missing 
		-- ["Secondary Output"] = "",
		--Translation missing 
		-- ["Send to a secondary output"] = "",
		--Translation missing 
		-- ["Supplied pattern is a format string instead of a pattern"] = "",
		--Translation missing 
		-- ["Your name for this filter"] = "",
	},
	["Editbox"] = {
		--Translation missing 
		-- ["Attach edit box to..."] = "",
		--Translation missing 
		-- ["Attach to..."] = "",
		--Translation missing 
		-- ["Background color"] = "",
		--Translation missing 
		-- ["Background Inset"] = "",
		--Translation missing 
		-- ["Background texture"] = "",
		--Translation missing 
		-- ["Border color"] = "",
		--Translation missing 
		-- ["Border texture"] = "",
		--Translation missing 
		-- ["Bottom"] = "",
		--Translation missing 
		-- ["Color border by channel"] = "",
		--Translation missing 
		-- ["currently_broken_alt_behavior"] = "",
		--Translation missing 
		-- ["Edge Size"] = "",
		--Translation missing 
		-- ["Editbox"] = "",
		--Translation missing 
		-- ["Editbox options."] = "",
		--Translation missing 
		-- ["Font"] = "",
		--Translation missing 
		-- ["Free-floating"] = "",
		--Translation missing 
		-- ["Free-floating, Locked"] = "",
		--Translation missing 
		-- ["Requires the Alt key to be held down to move the cursor in chat"] = "",
		--Translation missing 
		-- ["Select the font to use for the edit box"] = "",
		--Translation missing 
		-- ["Sets the frame's border color to the color of your currently active channel"] = "",
		--Translation missing 
		-- ["Tile Size"] = "",
		--Translation missing 
		-- ["Top"] = "",
		--Translation missing 
		-- ["Use Alt key for cursor movement"] = "",
	},
	["EventNames"] = {
		--Translation missing 
		-- ["allevents_desc"] = "",
		--Translation missing 
		-- ["allevents_name"] = "",
		--Translation missing 
		-- ["Chat window event name options."] = "",
		--Translation missing 
		-- ["EventNames"] = "",
		--Translation missing 
		-- ["Show"] = "",
		--Translation missing 
		-- ["Show events on chatframes"] = "",
		--Translation missing 
		-- ["show_desc"] = "",
		--Translation missing 
		-- ["show_name"] = "",
	},
	["Fading"] = {
		--Translation missing 
		-- ["duration_desc"] = "",
		--Translation missing 
		-- ["duration_name"] = "",
		--Translation missing 
		-- ["module_desc"] = "",
		--Translation missing 
		-- ["module_name"] = "",
		--Translation missing 
		-- ["textfade_desc"] = "",
		--Translation missing 
		-- ["textfade_name"] = "",
	},
	["Filtering"] = {
		--Translation missing 
		-- ["A module to provide basic chat filtering."] = "",
		--Translation missing 
		-- ["afkdnd_desc"] = "",
		--Translation missing 
		-- ["afkdnd_name"] = "",
		--Translation missing 
		-- ["bgjoin_desc"] = "",
		--Translation missing 
		-- ["bgjoin_name"] = "",
		--Translation missing 
		-- ["Filtering"] = "",
		--Translation missing 
		-- ["leavejoin_desc"] = "",
		--Translation missing 
		-- ["leavejoin_name"] = "",
		--Translation missing 
		-- ["notices_desc"] = "",
		--Translation missing 
		-- ["notices_name"] = "",
		--Translation missing 
		-- ["tradespam_desc"] = "",
		--Translation missing 
		-- ["tradespam_name"] = "",
	},
	["Font"] = {
		--Translation missing 
		-- ["Auto Restore Font Size"] = "",
		--Translation missing 
		-- ["Chat window font options."] = "",
		--Translation missing 
		-- ["Font"] = "",
		--Translation missing 
		-- ["monochrome_desc"] = "",
		--Translation missing 
		-- ["monochrome_name"] = "",
		--Translation missing 
		-- ["None"] = "",
		--Translation missing 
		-- ["Outline"] = "",
		--Translation missing 
		-- ["outlinemode_desc"] = "",
		--Translation missing 
		-- ["outlinemode_name"] = "",
		--Translation missing 
		-- ["rememberfont_desc"] = "",
		--Translation missing 
		-- ["rememberfont_name"] = "",
		--Translation missing 
		-- ["Set ChatFrame%d Font Size"] = "",
		--Translation missing 
		-- ["Set Font Face"] = "",
		--Translation missing 
		-- ["Set Font Size"] = "",
		--Translation missing 
		-- ["Set Separately"] = "",
		--Translation missing 
		-- ["Set text font size for each chat window."] = "",
		--Translation missing 
		-- ["Set text font size."] = "",
		--Translation missing 
		-- ["Set the text font face for all chat windows."] = "",
		--Translation missing 
		-- ["shadowcolor_desc"] = "",
		--Translation missing 
		-- ["shadowcolor_name"] = "",
		--Translation missing 
		-- ["Thick Outline"] = "",
		--Translation missing 
		-- ["Toggle setting options separately for each chat window."] = "",
		--Translation missing 
		-- ["Workaround a Blizzard bug which changes the font size when you open a system menu."] = "",
	},
	["History"] = {
		--Translation missing 
		-- ["Chat history options."] = "",
		--Translation missing 
		-- ["Color GMOTD"] = "",
		--Translation missing 
		-- ["Colors the GMOTD label"] = "",
		--Translation missing 
		-- ["delaygmotd_desc"] = "",
		--Translation missing 
		-- ["delaygmotd_name"] = "",
		--Translation missing 
		-- ["divider"] = "",
		--Translation missing 
		-- ["History"] = "",
		--Translation missing 
		-- ["Maximum number of lines of command history to save."] = "",
		--Translation missing 
		-- ["Save Command History"] = "",
		--Translation missing 
		-- ["Saves command history between sessions (for use with alt+up arrow or just the up arrow)"] = "",
		--Translation missing 
		-- ["Scrollback"] = "",
		--Translation missing 
		-- ["Scrollback Options"] = "",
		--Translation missing 
		-- ["scrollbacklen_desc"] = "",
		--Translation missing 
		-- ["scrollbacklen_name"] = "",
		--Translation missing 
		-- ["Set Chat Lines"] = "",
		--Translation missing 
		-- ["Set Command History"] = "",
		--Translation missing 
		-- ["Set the number of lines of chat history for each window."] = "",
		--Translation missing 
		-- ["Store the chat lines between sessions"] = "",
	},
	["KeyBindings"] = {
		--Translation missing 
		-- ["Channel %d"] = "",
		--Translation missing 
		-- ["Copy Selected Chat Frame"] = "",
		--Translation missing 
		-- ["Guild Channel"] = "",
		--Translation missing 
		-- ["Instance Channel"] = "",
		--Translation missing 
		-- ["Next Chat Tab"] = "",
		--Translation missing 
		-- ["Officer Channel"] = "",
		--Translation missing 
		-- ["Party Channel"] = "",
		--Translation missing 
		-- ["Prat CopyChat"] = "",
		--Translation missing 
		-- ["Prat Keybindings"] = "",
		--Translation missing 
		-- ["Prat TellTarget"] = "",
		--Translation missing 
		-- ["Raid Channel"] = "",
		--Translation missing 
		-- ["Raid Warning Channel"] = "",
		--Translation missing 
		-- ["Say"] = "",
		--Translation missing 
		-- ["Smart Group Channel"] = "",
		--Translation missing 
		-- ["TellTarget"] = "",
		--Translation missing 
		-- ["Whisper"] = "",
		--Translation missing 
		-- ["Yell"] = "",
	},
	["OriginalButtons"] = {
		--Translation missing 
		-- ["alpha_desc"] = "",
		--Translation missing 
		-- ["alpha_name"] = "",
		--Translation missing 
		-- ["buttonframe_desc"] = "",
		--Translation missing 
		-- ["buttonframe_name"] = "",
		--Translation missing 
		-- ["ChannelNames"] = "",
		--Translation missing 
		-- ["Chat window button options."] = "",
		--Translation missing 
		-- ["chatmenu_desc"] = "",
		--Translation missing 
		-- ["chatmenu_name"] = "",
		--Translation missing 
		-- ["Default"] = "",
		--Translation missing 
		-- ["Original Buttons"] = "",
		--Translation missing 
		-- ["reflow_desc"] = "",
		--Translation missing 
		-- ["reflow_name"] = "",
		--Translation missing 
		-- ["reminder_desc"] = "",
		--Translation missing 
		-- ["reminder_name"] = "",
		--Translation missing 
		-- ["Right, Inside Frame"] = "",
		--Translation missing 
		-- ["Right, Outside Frame"] = "",
		--Translation missing 
		-- ["Set Position"] = "",
		--Translation missing 
		-- ["Sets position of chat menu and arrows for all chat windows."] = "",
		--Translation missing 
		-- ["Show Arrows"] = "",
		--Translation missing 
		-- ["Show Chat%d Arrows"] = "",
		--Translation missing 
		-- ["Toggle showing chat arrows for each chat window."] = "",
		--Translation missing 
		-- ["Toggles navigation arrows on and off."] = "",
	},
	["OriginalEditbox"] = {
		--Translation missing 
		-- ["Autohide"] = "",
		--Translation missing 
		-- ["BACKGROUND"] = "",
		--Translation missing 
		-- ["Bar colour"] = "",
		--Translation missing 
		-- ["Border colour"] = "",
		--Translation missing 
		-- ["Border width"] = "",
		--Translation missing 
		-- ["Bottom"] = "",
		--Translation missing 
		-- ["Click the edit box to open it up for editing. Only available if Autohide is disabled."] = "",
		--Translation missing 
		-- ["Clickable"] = "",
		--Translation missing 
		-- ["DIALOG"] = "",
		--Translation missing 
		-- ["Editbox options."] = "",
		--Translation missing 
		-- ["Enable Arrowkeys"] = "",
		--Translation missing 
		-- ["Enable using arrowkeys in editbox without the alt key."] = "",
		--Translation missing 
		-- ["Hide Border"] = "",
		--Translation missing 
		-- ["Hide the border around the edit box."] = "",
		--Translation missing 
		-- ["Hide the edit box after you have pressed enter."] = "",
		--Translation missing 
		-- ["HIGH"] = "",
		--Translation missing 
		-- ["Lock editbox position if undocked."] = "",
		--Translation missing 
		-- ["Lock Position"] = "",
		--Translation missing 
		-- ["LOW"] = "",
		--Translation missing 
		-- ["MEDIUM"] = "",
		--Translation missing 
		-- ["OriginalEditbox"] = "",
		--Translation missing 
		-- ["Padding"] = "",
		--Translation missing 
		-- ["Set Alpha"] = "",
		--Translation missing 
		-- ["Set Position"] = "",
		--Translation missing 
		-- ["Set Strata"] = "",
		--Translation missing 
		-- ["Set the alpha of the editbox."] = "",
		--Translation missing 
		-- ["Set the amount of padding inside the edit box"] = "",
		--Translation missing 
		-- ["Set the edit box background colour"] = "",
		--Translation missing 
		-- ["Set the edit box border colour"] = "",
		--Translation missing 
		-- ["Set the frame strata of the editbox."] = "",
		--Translation missing 
		-- ["Set the position of the editbox."] = "",
		--Translation missing 
		-- ["Set the texture of the chat edit box"] = "",
		--Translation missing 
		-- ["Set the width of the edit box's border"] = "",
		--Translation missing 
		-- ["Set the width of the editbox."] = "",
		--Translation missing 
		-- ["Set Width (NB: only enabled if the editbox is undocked)"] = "",
		--Translation missing 
		-- ["Texture"] = "",
		--Translation missing 
		-- ["Top"] = "",
		--Translation missing 
		-- ["Undocked"] = "",
	},
	["Paragraph"] = {
		--Translation missing 
		-- ["adjustlinks_desc"] = "",
		--Translation missing 
		-- ["adjustlinks_name"] = "",
		--Translation missing 
		-- ["Center"] = "",
		--Translation missing 
		-- ["Chat window paragraph options."] = "",
		--Translation missing 
		-- ["justification_desc"] = "",
		--Translation missing 
		-- ["justification_name"] = "",
		--Translation missing 
		-- ["Left"] = "",
		--Translation missing 
		-- ["Line Spacing"] = "",
		--Translation missing 
		-- ["Paragraph"] = "",
		--Translation missing 
		-- ["Right"] = "",
		--Translation missing 
		-- ["Set the line spacing for all chat windows."] = "",
	},
	["PlayerNames"] = {
		--Translation missing 
		-- ["Actively Query Player Info"] = "",
		--Translation missing 
		-- ["Angled"] = "",
		--Translation missing 
		-- ["Brackets"] = "",
		--Translation missing 
		-- ["Brackets Common Color"] = "",
		--Translation missing 
		-- ["Brackets Use Common Color"] = "",
		--Translation missing 
		-- ["Class"] = "",
		--Translation missing 
		-- ["Color by Level Difference"] = "",
		--Translation missing 
		-- ["coloreverywhere_desc"] = "",
		--Translation missing 
		-- ["coloreverywhere_name"] = "",
		--Translation missing 
		-- ["Enable Alt-Invite"] = "",
		--Translation missing 
		-- ["Enable Invite Links"] = "",
		--Translation missing 
		-- ["Enable TabComplete"] = "",
		--Translation missing 
		-- ["hoverhilight_desc"] = "",
		--Translation missing 
		-- ["hoverhilight_name"] = "",
		--Translation missing 
		-- ["How to color other player's level."] = "",
		--Translation missing 
		-- ["How to color player's name."] = "",
		--Translation missing 
		-- ["Keep Info"] = "",
		--Translation missing 
		-- ["Keep Lots Of Info"] = "",
		--Translation missing 
		-- ["Keep player information between session for all players except cross-server players"] = "",
		--Translation missing 
		-- ["Keep player information between session, but limit it to friends and guild members."] = "",
		--Translation missing 
		-- ["Let TasteTheNaimbow set the common color for unknown player names."] = "",
		--Translation missing 
		-- ["Level Color Mode"] = "",
		--Translation missing 
		-- ["linkifycommon_desc"] = "",
		--Translation missing 
		-- ["linkifycommon_name"] = "",
		--Translation missing 
		-- ["No additional coloring"] = "",
		--Translation missing 
		-- ["None"] = "",
		--Translation missing 
		-- ["Player Color Mode"] = "",
		--Translation missing 
		-- ["Player name formating options."] = "",
		--Translation missing 
		-- ["PlayerNames"] = "",
		--Translation missing 
		-- ["Prat_Playernames: Stored Player Data Cleared"] = "",
		--Translation missing 
		-- ["Query the server for all player names we do not know. Note: This happpens pretty slowly, and this data is not saved."] = "",
		--Translation missing 
		-- ["Random"] = "",
		--Translation missing 
		-- ["realidcolor_desc"] = "",
		--Translation missing 
		-- ["realidcolor_name"] = "",
		--Translation missing 
		-- ["Reset Settings"] = "",
		--Translation missing 
		-- ["Restore default settings, and delete stored character data."] = "",
		--Translation missing 
		-- ["Set common color of unknown player names."] = "",
		--Translation missing 
		-- ["Sets common color of brackets to use around player names."] = "",
		--Translation missing 
		-- ["Sets style of brackets to use around player names."] = "",
		--Translation missing 
		-- ["Show Group"] = "",
		--Translation missing 
		-- ["Show Level"] = "",
		--Translation missing 
		-- ["Show Raid Target Icon"] = "",
		--Translation missing 
		-- ["Square"] = "",
		--Translation missing 
		-- ["Tab completion : "] = "",
		--Translation missing 
		-- ["tabcomplete_name"] = "",
		--Translation missing 
		-- ["Toggle group invites by alt-clicking hyperlinked keywords like 'invite'."] = "",
		--Translation missing 
		-- ["Toggle group invites by alt-clicking on player name."] = "",
		--Translation missing 
		-- ["Toggle level showing."] = "",
		--Translation missing 
		-- ["Toggle raid group showing."] = "",
		--Translation missing 
		-- ["Toggle showing the raid target icon which is currently on the player."] = "",
		--Translation missing 
		-- ["Toggle tab completion of player names."] = "",
		--Translation missing 
		-- ["Toggle using a common color for brackets around player names."] = "",
		--Translation missing 
		-- ["Toggle using a common color for unknown player names."] = "",
		--Translation missing 
		-- ["Too many matches (%d possible)"] = "",
		--Translation missing 
		-- ["Unknown Common Color"] = "",
		--Translation missing 
		-- ["Unknown Common Color From TasteTheNaimbow"] = "",
		--Translation missing 
		-- ["Unknown Use Common Color"] = "",
		--Translation missing 
		-- ["Use Channel Color"] = "",
		--Translation missing 
		-- ["Use Player Color"] = "",
		--Translation missing 
		-- ["Use toon name for RealID"] = "",
	},
	["PopupMessage"] = {
		--Translation missing 
		-- ["Add Nickname"] = "",
		--Translation missing 
		-- ["Adds an alternate name to show in popups."] = "",
		--Translation missing 
		-- ["Clear Nickname"] = "",
		--Translation missing 
		-- ["Clears alternate name to show in popups."] = "",
		--Translation missing 
		-- ["framealpha_desc"] = "",
		--Translation missing 
		-- ["framealpha_name"] = "",
		--Translation missing 
		-- ["Popup"] = "",
		--Translation missing 
		-- ["PopupMessage"] = "",
		--Translation missing 
		-- ["Remove Nickname"] = "",
		--Translation missing 
		-- ["Removes an alternate name to show in popups."] = "",
		--Translation missing 
		-- ["Set Separately"] = "",
		--Translation missing 
		-- ["Show All Popups"] = "",
		--Translation missing 
		-- ["Show Popups"] = "",
		--Translation missing 
		-- ["Show Popups for all chat windows."] = "",
		--Translation missing 
		-- ["Show Popups for each window."] = "",
		--Translation missing 
		-- ["show_desc"] = "",
		--Translation missing 
		-- ["show_name"] = "",
		--Translation missing 
		-- ["show_perframedesc"] = "",
		--Translation missing 
		-- ["show_perframename"] = "",
		--Translation missing 
		-- ["showall_desc"] = "",
		--Translation missing 
		-- ["showall_name"] = "",
		--Translation missing 
		-- ["Shows messages in a popup window."] = "",
		--Translation missing 
		-- ["Shows messages with your name in a popup."] = "",
		--Translation missing 
		-- ["Toggle setting options separately for each chat window."] = "",
	},
	["Scroll"] = {
		--Translation missing 
		-- ["Bottom"] = "",
		--Translation missing 
		-- ["Chat window scrolling options."] = "",
		--Translation missing 
		-- ["Control whether text is added to the frame at the top or the bottom."] = "",
		--Translation missing 
		-- ["lowdown_desc"] = "",
		--Translation missing 
		-- ["lowdown_name"] = "",
		--Translation missing 
		-- ["modified_speed"] = "",
		--Translation missing 
		-- ["modified_speed_desc"] = "",
		--Translation missing 
		-- ["mousewheel_desc"] = "",
		--Translation missing 
		-- ["mousewheel_name"] = "",
		--Translation missing 
		-- ["Scroll"] = "",
		--Translation missing 
		-- ["Set Ctrl+MouseWheel Speed"] = "",
		--Translation missing 
		-- ["Set MouseWheel Speed"] = "",
		--Translation missing 
		-- ["Set number of lines mousewheel will scroll when ctrl is pressed."] = "",
		--Translation missing 
		-- ["Set number of lines mousewheel will scroll."] = "",
		--Translation missing 
		-- ["Set TheLowDown Delay"] = "",
		--Translation missing 
		-- ["Set time to wait before jumping to the bottom of chat windows."] = "",
		--Translation missing 
		-- ["Text scroll direction"] = "",
		--Translation missing 
		-- ["Top"] = "",
	},
	["Search"] = {
		--Translation missing 
		-- ["err_notfound"] = "",
		--Translation missing 
		-- ["err_tooshort"] = "",
		--Translation missing 
		-- ["find_results"] = "",
		--Translation missing 
		-- ["module_desc"] = "",
		--Translation missing 
		-- ["module_info"] = "",
		--Translation missing 
		-- ["module_name"] = "",
	},
	["ServerNames"] = {
		--Translation missing 
		-- ["autoabbreviate_desc"] = "",
		--Translation missing 
		-- ["autoabbreviate_name"] = "",
		--Translation missing 
		-- ["colon_desc"] = "",
		--Translation missing 
		-- ["colon_name"] = "",
		--Translation missing 
		-- ["randomclr_desc"] = "",
		--Translation missing 
		-- ["randomclr_name"] = "",
		--Translation missing 
		-- ["Server name abbreviation options."] = "",
		--Translation missing 
		-- ["ServerNames"] = "",
	},
	["Sounds"] = {
		--Translation missing 
		-- ["A module to play sounds on certain chat messages."] = "",
		--Translation missing 
		-- ["Add a custom channel"] = "",
		--Translation missing 
		-- ["bn_whisper_desc"] = "",
		--Translation missing 
		-- ["bn_whisper_name"] = "",
		--Translation missing 
		-- ["Custom Channels"] = "",
		--Translation missing 
		-- ["group_lead_desc"] = "",
		--Translation missing 
		-- ["group_lead_name"] = "",
		--Translation missing 
		-- ["guild_desc"] = "",
		--Translation missing 
		-- ["guild_name"] = "",
		--Translation missing 
		-- ["incoming"] = "",
		--Translation missing 
		-- ["Incoming Sounds"] = "",
		--Translation missing 
		-- ["officer_desc"] = "",
		--Translation missing 
		-- ["officer_name"] = "",
		--Translation missing 
		-- ["outgoing"] = "",
		--Translation missing 
		-- ["Outgoing Sounds"] = "",
		--Translation missing 
		-- ["party_desc"] = "",
		--Translation missing 
		-- ["party_name"] = "",
		--Translation missing 
		-- ["Play a sound for a certain channel name (can be a substring)"] = "",
		--Translation missing 
		-- ["raid_desc"] = "",
		--Translation missing 
		-- ["raid_name"] = "",
		--Translation missing 
		-- ["Remove a custom channel"] = "",
		--Translation missing 
		-- ["Reset settings"] = "",
		--Translation missing 
		-- ["Restore default settings and resets custom channel list"] = "",
		--Translation missing 
		-- ["Sound selection for incoming chat messages"] = "",
		--Translation missing 
		-- ["Sound selection for outgoing (from you) chat messages"] = "",
		--Translation missing 
		-- ["Sounds"] = "",
		--Translation missing 
		-- ["whisper_desc"] = "",
		--Translation missing 
		-- ["whisper_name"] = "",
	},
	["Substitutions"] = {
		--Translation missing 
		-- ["%d total user defined substitutions"] = "",
		--Translation missing 
		-- ["|cffff0000warning:|r subtitution \"%s\" already defined as \"%s\", overwriting"] = "",
		--Translation missing 
		-- ["<noguild>"] = "",
		--Translation missing 
		-- ["<notarget>"] = "",
		--Translation missing 
		-- ["A module to provide basic chat substitutions."] = "",
		--Translation missing 
		-- ["Are you sure - this will delete all user defined substitutions and reset defaults?"] = "",
		--Translation missing 
		-- ["Are you sure?"] = "",
		--Translation missing 
		-- ["can't find substitution index for a substitution named '%s'"] = "",
		--Translation missing 
		-- ["current-prompt"] = "",
		--Translation missing 
		-- ["defined %s: expands to => %s"] = "",
		--Translation missing 
		-- ["Delete all"] = "",
		--Translation missing 
		-- ["Delete substitution"] = "",
		--Translation missing 
		-- ["Deletes a user defined substitution"] = "",
		--Translation missing 
		-- ["Deletes all user defined substitutions"] = "",
		--Translation missing 
		-- ["female"] = "",
		--Translation missing 
		-- ["her"] = "",
		--Translation missing 
		-- ["hers"] = "",
		--Translation missing 
		-- ["him"] = "",
		--Translation missing 
		-- ["his"] = "",
		--Translation missing 
		-- ["it"] = "",
		--Translation missing 
		-- ["its"] = "",
		--Translation missing 
		-- ["List of available substitutions"] = "",
		--Translation missing 
		-- ["List of available substitutions defined by this module. (NB: users may define custom values for existing substitutions, but they will revert to the default value if the user definition is deleted.)"] = "",
		--Translation missing 
		-- ["List substitutions"] = "",
		--Translation missing 
		-- ["Lists all current subtitutions in the default chat frame"] = "",
		--Translation missing 
		-- ["male"] = "",
		--Translation missing 
		-- ["MapLoc"] = "",
		--Translation missing 
		-- ["MapPos"] = "",
		--Translation missing 
		-- ["MapXPos"] = "",
		--Translation missing 
		-- ["MapYPos"] = "",
		--Translation missing 
		-- ["MapZone"] = "",
		--Translation missing 
		-- ["module:buildUserSubsIndex(): warning: module patterns not defined!"] = "",
		--Translation missing 
		-- ["MouseoverTargetName"] = "",
		--Translation missing 
		-- ["NO MATCHFUNC FOUND"] = "",
		--Translation missing 
		-- ["no substitution name given"] = "",
		--Translation missing 
		-- ["no substitution name supplied for deletion"] = "",
		--Translation missing 
		-- ["no user defined subs found"] = "",
		--Translation missing 
		-- ["no value given for subtitution \"%s\""] = "",
		--Translation missing 
		-- ["Options for setting and removing user defined substitutions. (NB: users may define custom values for existing substitutions, but they will revert to the default value if the user definition is deleted.)"] = "",
		--Translation missing 
		-- ["PlayerAverageItemLevel"] = "",
		--Translation missing 
		-- ["PlayerCurrentMana"] = "",
		--Translation missing 
		-- ["PlayerHealthDeficit"] = "",
		--Translation missing 
		-- ["PlayerHP"] = "",
		--Translation missing 
		-- ["PlayerManaDeficit"] = "",
		--Translation missing 
		-- ["PlayerMaxHP"] = "",
		--Translation missing 
		-- ["PlayerMaxMana"] = "",
		--Translation missing 
		-- ["PlayerName"] = "",
		--Translation missing 
		-- ["PlayerPercentHP"] = "",
		--Translation missing 
		-- ["PlayerPercentMana"] = "",
		--Translation missing 
		-- ["RandNum"] = "",
		--Translation missing 
		-- ["removing user defined substitution \"%s\"; previously expanded to => \"%s\""] = "",
		--Translation missing 
		-- ["Set substitution"] = "",
		--Translation missing 
		-- ["Set the value of a user defined substitution (NB: this may be the same as an existing default substitution; to reset it to the default, just remove the user created definition)."] = "",
		--Translation missing 
		-- ["subname -- NOTE: sub name without the prefix '%'"] = "",
		--Translation missing 
		-- ["subname = text after expansion -- NOTE: sub name without the prefix \"%\""] = "",
		--Translation missing 
		-- ["substitution: %s defined as => %s"] = "",
		--Translation missing 
		-- ["Substitutions"] = "",
		--Translation missing 
		-- ["TargetClass"] = "",
		--Translation missing 
		-- ["TargetGender"] = "",
		--Translation missing 
		-- ["TargetGuild"] = "",
		--Translation missing 
		-- ["TargetHealth"] = "",
		--Translation missing 
		-- ["TargetHealthDeficit"] = "",
		--Translation missing 
		-- ["TargetIcon"] = "",
		--Translation missing 
		-- ["TargetLevel"] = "",
		--Translation missing 
		-- ["TargetManaDeficit"] = "",
		--Translation missing 
		-- ["TargetName"] = "",
		--Translation missing 
		-- ["TargetPercentHP"] = "",
		--Translation missing 
		-- ["TargetPossesive"] = "",
		--Translation missing 
		-- ["TargetPronoun"] = "",
		--Translation missing 
		-- ["TargetRace"] = "",
		--Translation missing 
		-- ["TargetTargetName"] = "",
		--Translation missing 
		-- ["unknown sex"] = "",
		--Translation missing 
		-- ["user defined substition \"%s\" not found"] = "",
		--Translation missing 
		-- ["User defined substitutions"] = "",
		--Translation missing 
		-- ["user substitutions index (usersubs_idx) doesn't exist! oh dear."] = "",
		--Translation missing 
		-- ["usersub_"] = "",
	},
	["TellTarget"] = {
		--Translation missing 
		-- ["/tt"] = "",
		--Translation missing 
		-- ["Adds telltarget slash command (/tt)."] = "",
		--Translation missing 
		-- ["No target selected."] = "",
		--Translation missing 
		-- ["NoTarget"] = "",
		--Translation missing 
		-- ["Target does not exist."] = "",
		--Translation missing 
		-- ["Target is not a player."] = "",
		--Translation missing 
		-- ["TellTarget"] = "",
	},
	["Timestamps"] = {
		--Translation missing 
		-- ["Chat window timestamp options."] = "",
		--Translation missing 
		-- ["colortimestamp_desc"] = "",
		--Translation missing 
		-- ["colortimestamp_name"] = "",
		--Translation missing 
		-- ["Format All Timestamps"] = "",
		--Translation missing 
		-- ["HH:MM (12-hour)"] = "",
		--Translation missing 
		-- ["HH:MM (24-hour)"] = "",
		--Translation missing 
		-- ["HH:MM:SS (12-hour)"] = "",
		--Translation missing 
		-- ["HH:MM:SS (24-hour)"] = "",
		--Translation missing 
		-- ["HH:MM:SS AM (12-hour)"] = "",
		--Translation missing 
		-- ["localtime_desc"] = "",
		--Translation missing 
		-- ["localtime_name"] = "",
		--Translation missing 
		-- ["MM:SS"] = "",
		--Translation missing 
		-- ["Post-Timestamp"] = "",
		--Translation missing 
		-- ["Pre-Timestamp"] = "",
		--Translation missing 
		-- ["Set the timestamp format"] = "",
		--Translation missing 
		-- ["Set Timestamp Color"] = "",
		--Translation missing 
		-- ["Sets the color of the timestamp."] = "",
		--Translation missing 
		-- ["Show Timestamp"] = "",
		--Translation missing 
		-- ["show_desc"] = "",
		--Translation missing 
		-- ["show_name"] = "",
		--Translation missing 
		-- ["space_desc"] = "",
		--Translation missing 
		-- ["space_name"] = "",
		--Translation missing 
		-- ["Timestamps"] = "",
		--Translation missing 
		-- ["Toggle showing timestamp for each window."] = "",
		--Translation missing 
		-- ["twocolumn_desc"] = "",
		--Translation missing 
		-- ["twocolumn_name"] = "",
	},
	["UrlCopy"] = {
		--Translation missing 
		-- ["Change the color of the URL."] = "",
		--Translation missing 
		-- ["Color URL"] = "",
		--Translation missing 
		-- ["Set Color"] = "",
		--Translation missing 
		-- ["Show Brackets"] = "",
		--Translation missing 
		-- ["Toggle"] = "",
		--Translation missing 
		-- ["Toggle showing brackets on and off."] = "",
		--Translation missing 
		-- ["Toggle the module on and off."] = "",
		--Translation missing 
		-- ["Toggle the URL color on and off."] = "",
		--Translation missing 
		-- ["URL formating options."] = "",
		--Translation missing 
		-- ["UrlCopy"] = "",
		--Translation missing 
		-- ["Use Popup"] = "",
		--Translation missing 
		-- ["Use popup window to show URL."] = "",
	}
}

PL:AddLocale(PRAT_MODULE.name, "esMX",L)


L=
{
	["display_desc"] = "Настройка отображения чата",
	["display_name"] = "Настройка отображения",
	["extras_desc"] = "Различные дополнительные модули",
	["extras_name"] = "Другие модули",
	["formatting_desc"] = "Изменение отображения строк чата",
	["formatting_name"] = "Форматирование чата",
	["load_desc"] = "Настройка поведения этого модуля.",
	["load_disabled"] = "Отключено",
	["load_disabledonrestart"] = "Отключён (перезагрузка)",
	["load_enabled"] = "Включено",
	["load_enabledonrestart"] = "Включён (перезагрузка)",
	["load_no"] = "Не загружать",
	["modulecontrol_desc"] = "Настройка загрузки модулей Prat",
	["modulecontrol_name"] = "Настройка модулей",
	["prat"] = "Prat",
	["reload_required"] = "Эта настройка вступит в силу только после %s вашего интерфейса.",
	["AddonMsgs"] = {
		["Addon message options."] = "Настройки сообщений модификаций.",
		["AddonMsgs"] = "Сообщения аддонов",
		["show_desc"] = "Включить отображение сообщений аддонов в каждой закладке чата.",
		["show_name"] = "Показывать сообщения аддонов",
		["show_perframedesc"] = "Вкл/Выкл отображение сообщений аддонов.",
		["show_perframename"] = "ChatFrame%d AddonMsgsShow",
	},
	["Alias"] = {
		[" - list all aliases; supply <keyword> to search for matching aliases (cmd aliases: /listallaliases)"] = " - список всех псевдонимов; источник <keyword> для поиска псевдонимов (команда: /listallaliases)",
		["%s() called with blank string!"] = "Функция %s() вызвана с пустой строкой!",
		["%s() called with nil argument!"] = "Функция %s() вызвана с нулевым аргументом!",
		["/%s aliased to \"/%s\""] = "/%s теперь псевдоним на \"/%s\"",
		["/%s aliased to: /%s"] = "/%s теперь псевдоним: /%s",
		["<alias> - remove the alias <alias> (cmd aliases: /delalias, /remalias)"] = "<alias> - удалить все псевдонимы <alias> (cmd псевдонимы: /delalias, /remalias)",
		["<command>[ <value>] - alias <command> to be executed as <value>, or return the value of the currently defined alias for <command> if <command> has not been assigned a value. eg: \"/alias /examplehello /say hello there\" - typing \"/examplehello\" will now cause your character to say \"hello there\"; \"/alias examplehello\" - s \"/examplehello is aliased to /say hello there\" (cmd aliases: /addalias)"] = "<command>[ <value>] - псевдоним <command> будет исполняться как <value>, или возвращать значение value в качестве определённого в настоящий момент значения для <command>. Например: \"/alias /examplehello /say всем привет\" - набрав \"/examplehello\" ваш персонаж скажет \"всем привет\"; \"/alias examplehello\" - \"/examplehello is aliased to /say всем привет\" (cmd aliases: /addalias)",
		["<keyword> - finds all aliases matching <keyword> (cmd aliases: /findalias)"] = "<keyword> - найти все псевдонимы, совпадающие с <keyword> (команда: /findalias)",
		["add"] = "добавить",
		["add an alias"] = "добавить псевдоним",
		["alias \"/%s\" does not exist"] = "псевдонима \"/%s\" не существует",
		["dealiasing command /%s to /%s"] = "раскрытие псевдонима /%s в /%s",
		["deleting alias \"/%s\" (previously aliased as \"/%s\")"] = "удаление псевдонима \"/%s\" (перед этим назывался как \"/%s\")",
		["Display extra information in the chat frame when commands are dealiased"] = "Отображать дополнительную информацию в рамке чата при раскрытии псевдонимов команд",
		["Don't overwrite existing aliases when using /addalias"] = "Не перезаписывать существующие псевдонимы при использовани /addalias",
		["Expand aliases as you are typing"] = "Раскрыть псевдонимы, которые вы вводили",
		["find aliases matching a given search term"] = "найти псевдонимы соответствующие критериям поиска",
		["findaliases"] = true,
		["infinite loop detected for alias /%s - ignoring"] = "обнаружен бесконечный цикл при раскрытии псевдонима /%s - игнорируется",
		["inline"] = "на линии",
		["list all aliases"] = "список всех псевдонимов",
		["listaliases"] = "вывести список псевдонимов",
		["matching aliases found: %d"] = "совпавших псевдонимов найдено: %d",
		["module_desc"] = "Добовляет команду /alias, which can be used to alias slash commands in a similar way to the Unix alias command.",
		["module_name"] = "Псевдонимы",
		["No aliases have been defined"] = "Псевдонимов не обнаружено",
		["noclobber"] = "защита настроек",
		["noclobber set - skipping new alias: /%s already expands to /%s"] = "защита настроек - пропускаем новый псевдоним:  /%s уже задано как /%s",
		["Options"] = "Настройки",
		["Options for altering the behaviour of Alias"] = "Опции для изменения поведения Псевдонимов",
		["overwriting existing alias \"/%s\" (was aliased to \"/%s\")"] = "перезапись сужествующего псевдонима \"/%s\" (теперь псевдоним \"/%s\")",
		["refusing to alias \"/%s\" to anything in the interests of Not Buggering Everything Up"] = "отказ псевдониму \"/%s\" в чём-либо, чтобы не испортить ВСЁ",
		["remove an alias"] = "убрать псевдоним",
		["There is no alias current defined for \"%s\""] = "Нет псевдонимов для \"%s\"",
		["total aliases: %d"] = "всего псевдонимов: %d",
		["tried to show value for alias \"%s\" but undefined in module.Aliases!"] = "\"%s\" не определено в модуле \"Псевдонимы\" при попытке показать значение!",
		["unalias"] = "удалить псевдоним",
		["verbose"] = "подробно",
		["warnUser() called with nil argument!"] = "Функция warnUser() вызвана с нулевым аргументом!",
		["warnUser() called with zero length string!"] = "Функция warnUser() вызвана со строкой нулевой длины!",
	},
	["AltNames"] = {
		["%d alts found for %s: %s"] = "%d альтов найдено для %s: %s",
		["%s alts imported from LOKWhoIsWho"] = "Импортировано альтов из LOKWhoIsWho: %s",
		["%s total alts linked to mains"] = "всего альтов связано с основным %s",
		["(.-)'s? [Aa]lt"] = "%f[%a\\192-\\255]([%a\\192-\\255]+)%f[^%a\\128-\\255]'s [Аа]льт",
		["([^%s%p%d%c%z]+)'s alt"] = "[Аа]льт %f[%a\\192-\\255]([%a\\192-\\255]+)%f[^%a\\128-\\255]",
		[".*[Aa]lts?$"] = ".*[Аа]льты?$",
		["<alt name> (eg, /altnames del Personyouthoughtwassomeonesaltbutreallyisnt)"] = "<имя альта> (к примеру, /altnames del Загзаг)",
		["<main> (eg /altnames listalts Fin)"] = "<основной> (к примеру: /altnames listalts Загзаг)",
		["<search term> (eg, /altnames find fin)"] = "<элемент поиска> (к примеру, /altnames find Загзаг)",
		["Alt"] = "Альт",
		["alt"] = "альт",
		["alt name exists: %s -> %s; not overwriting as set in preferences"] = "имя альта уже существует: %s -> %s; перезапись запрещена настройками",
		["AltNames"] = "Имя альтов",
		["Alts:"] = "Альты:",
		["autoguildalts_desc"] = "Автоматически и без отчета выполнять команду импорта из списка гильдии",
		["autoguildalts_name"] = "Авто-импорт альтов гильдии",
		["Be quiet"] = "Молчи",
		["character removed: %s"] = "персонаж удалён: %s",
		["Class colour"] = "Окраска по классу",
		["Clear all"] = "Очистить все",
		["Clear all links between alts and main names."] = "Очистить все ссылки между альтами и основными именами.",
		["Colour"] = "Цвет",
		["Delete a character's link to another character as their main."] = "Удалить ссылку персонажа на другого персонажа если он основной.",
		["Delete alt"] = "Удалить альта",
		["Disabled"] = "Отключено",
		["Display a player's alts in the tooltip"] = "Отображать альтов игрока в подсказке",
		["Display a player's main name in the tooltip"] = "Отображать основных персонажей игрока в подсказке",
		["Display main names in the same colour as that of the alt's class (taking the data from the PlayerNames module if it is enabled)"] = "Отображать имена основного персонажа по классу альта (данные берутся из модуля PlayerNames, если он включен)",
		["Display main names in the same colour as that of the main's class (taking the data from the PlayerNames module if it is enabled)"] = "Отображать имена основного персонажа по его основному классу (данные берутся из модуля PlayerNames, если он включен)",
		["Don't overwrite existing alt <-> main links when importing or adding new alts."] = "Не перезаписывать существующии связки альтов <-> основных при импортировании или добавлении нового.",
		["Don't overwrite existing links"] = "Не перезаписывать существующие связки",
		["don't use"] = "не окрашивать",
		["Don't use data from the PlayerNames module at all"] = "Не использовать для всех данные из модуля PlayerNames",
		["ERROR: some function sent a blank message!"] = "ОШИБКА: одна из функций послала пустое сообщение!",
		["Find characters"] = "Найти персонажи",
		["Fix alts"] = "Исправить альтов",
		["Fix corrupted entries in your list of alt names."] = "Исправить неправельные записи в вашем списке имен альтов.",
		["Found alt: %s => main: %s"] = "Альт найден: %s => основной: %s",
		["guild member alts found and imported: %s"] = "%s: найдено альтов участников гильдии и импортированно",
		["Import from Guild Greet database"] = "Импорт базы данных Guild Greet",
		["Import from guild roster"] = "Импорт из списка гильдии",
		["Import options"] = "Настройки импорта",
		["Imports alt names from a Guild Greet database, if present"] = "Импорт альтов из базы данных Guild Greet, если есть",
		["Imports alt names from the guild roster by checking for members with the rank \"alt\" or \"alts\", or guild / officer notes like \"<name>'s alt\""] = "Импорт имен альтов из списка гильдии определяя участника по званию \"alt\" или \"alts\", или общие / офицерские заметки типо \"<name> alt\"",
		["Imports data from LOKWhoIsWho, if present (drop your SavedVariablesLOKWhoIsWho.lua in the Prat directory to be able to use this)."] = "Импортировать данные из LOKWhoIsWho, если есть (перекиньте ваш SavedVariables/LOKWhoIsWho.lua в папку Pratа для использования).",
		["Left"] = "Слева",
		["link <alt name> <main name> (eg, /altnames link Fin Finjathealtoffin)"] = "link <имя альта> <имя основного> (пример, /altnames link Загзаг Загзаговичюс)",
		["Link alt"] = "Связать альта",
		["Link someone's alt character with the name of their main."] = "Связать определённого альта с именем его основного персонажа.",
		["linked alt %s => %s"] = "альт %s связан с => %s",
		["List all"] = "Весь список",
		["List all links between alts and their main names."] = "Весь список ссылок между альтами и основными именами.",
		["List alts"] = "Список альтов",
		["List alts for a given character"] = "Список альтов для заданных персонажей",
		["LOKWhoIsWho data not found"] = "Данные LOKWhoIsWho не найдены",
		["LOKWhoIsWho import"] = "Импорт из LOKWhoIsWho",
		["LOKWhoIsWho lua file not found, sorry."] = "Lua файл LOKWhoIsWho не найден, извените.",
		["Main"] = "Основной",
		["main"] = "основной",
		["Main name position"] = "Позиция основного имени",
		["Main:"] = "Основной:",
		["mainpos_desc"] = "Где отображать имя главного персонажа если он на альте.",
		["mainpos_name"] = "Позиция основного имени",
		["module_desc"] = "Позволяет привязывать имена альтов к именам основных персонажей, а потом отображать их рядом в сообщениях в чате (по умолчанию=выключено).",
		["no alts found for character "] = "не найдено альтов для персонажа",
		["no alts or mains found matching \"%s\""] = "совпавших альтов или основных \"%s\"",
		["No arg string given to :addAlt()"] = "Не задано значение строки для: :addAlt()",
		["no characters called \"%s\" found; nothing deleted"] = "не найден персонаж по имени \"%s\"; нечего удалять",
		["No Guild Greet database found"] = "База данных Guild Greet не найдена",
		["No main name supplied to link %s to"] = "Не предоставлено основное имя для связки %s к",
		["no matches found"] = "совпадений не найдено",
		["quiet"] = "тихий",
		["quiet_desc"] = "Отчитываться о действиях в чат или нет.",
		["quiet_name"] = true,
		["Right"] = "Справа",
		["Search the list of linked characters for matching main or alt names."] = "Поиск в списке связанных персонажей.",
		["searched for: %s - total matches: %s"] = "поиск для: %s - всего совподений: %s",
		["Show alts in tooltip"] = "Альты в подсказке",
		["Show main in tooltip"] = "Основные в подсказке",
		["Start"] = "Начать",
		["The colour of an alt's main name that will be displayed"] = "Отображать цвет имени альта по основному персонажу",
		["Use class colour (from the PlayerNames module)"] = "Использовать окраску по цвету класса (из модуля PlayerNames)",
		["use class colour of alt"] = "цвета класса для альтов",
		["use class colour of main"] = "цвета класса для основных",
		["Use LibAlts Data"] = "Использовать LibAlts",
		["Use the data available via the shared alt information library."] = "Использовать данные посредством совместно используемой библиотеки информации об альтах.",
		["Various ways to import a main's alts from other addons"] = "Различные варианты импорта альтов основных персонажей из других аддонов",
		["warning: alt %s already linked to %s"] = "внимание: альт %s уже связан с %s",
		["Where to display a character's main name when on their alt."] = "Где отображать имя главного персонажа если он на альте.",
		["Whether to report to the chat frame or not."] = "Сообщать в чат или нет.",
		["You are not in a guild"] = "Вы не состоитев гильдии",
		["You have not yet linked any alts with their mains."] = "Вы еще не связали не одного альта с их основными.",
	},
	["Bubbles"] = {
		["color_desc"] = "Окрашивать границу облачка чата в цвет канала чата.",
		["color_name"] = "Окрашивать облачка",
		["font_desc"] = "Использовать тот же шрифт, что и в окне чата",
		["font_name"] = "Шрифт чата",
		["fontsize_desc"] = "Размер шрифта чата",
		["fontsize_name"] = "Размер шрифта",
		["format_desc"] = "Применить форматирование чата к тексту в облачках чата.",
		["format_name"] = "Формат Текста",
		["icons_desc"] = "Показать иконки рейда в облачках чата.",
		["icons_name"] = "Показать метки цели рейда",
		["module_desc"] = "Настройки, относящиеся к облачкам чата",
		["module_name"] = "Облачка",
		["shorten_desc"] = "Уменьшать облачка чата до одной строки. Наведите курсор на облачко, чтобы открыть текст полностью.",
		["shorten_name"] = "Уменьшать облачка",
		["transparent_desc"] = "Скрыть фон и границы у всплывающих сообщений (требуется /reload для отмены опции)",
		["transparent_name"] = "Прозрачные всплывающие сообщения",
	},
	["Buttons"] = {
		["alpha_desc"] = "Настройка прозрачности кнопки чата и всех цтрелок.",
		["alpha_name"] = "Прозрачность",
		["Buttons"] = "Кнопки",
		["Chat window button options."] = "Настройки кнопок окна чата.",
		["chatmenu_desc"] = "Вкл/выкл кнопки чата.",
		["chatmenu_name"] = "Показать кнопку чата",
		["Default"] = "По умолчанию",
		["Right, Inside Frame"] = "Справа, внутри окна",
		["Right, Outside Frame"] = "Справа, вне окна",
		["scrollReminder_desc"] = "Вкл/выкл указателя, сигнализирующего о том, что окно чата можно прокручивать вниз.",
		["scrollReminder_name"] = "Указатель прокрутки вниз",
		["Set Position"] = "Положение",
		["Sets position of chat menu and arrows for all chat windows."] = "Установить положение стрелок и кнопок чата для всех окон.",
		["Show Arrows"] = "Показывать стрелки",
		["Show Chat%d Arrows"] = "Показывать стрелки %d чата",
		["showbnet_desc"] = "Показать меню Общение",
		["showbnet_name"] = "Показать меню Общение",
		["showmenu_desc"] = "Отображать меню команд",
		["showmenu_name"] = "Отображать меню",
		["showminimize_desc"] = "Показать Кнопку минимизации",
		["showminimize_name"] = "Показать Кнопку минимизации",
		["Toggle showing chat arrows for each chat window."] = "Показывать стрелки для каждого окна чата.",
		["Toggles navigation arrows on and off."] = "Вкл/выкл навигационных стрелок.",
	},
	["ChannelColorMemory"] = {
		["(%w+)%s?(.*)"] = true,
		["ChannelColorMemory"] = "Сохранение цветов каналов",
		["Remembers the colors of each channel name."] = "Запоминает цвета названия каждого канала.",
	},
	["ChannelNames"] = {
		["%s settings."] = "Настройки канала \"%s\".",
		["<string>"] = true,
		["Add Channel Abbreviation"] = "Добавить сокращение канала",
		["addnick_desc"] = "Добавляет сокращение названий каналов. Префикс названия с '#' включает номер канала. (например '#Торговля').",
		["Blank"] = "Пустой",
		["chanlink_desc"] = "Сделать название канала ссылкой, щелчок по которой открывает окно чата этого канала.",
		["chanlink_name"] = "Создать ссылку на канал",
		["Channel %d"] = "Канал %d",
		["Channel name abbreviation options."] = "Настройки сокращения названий каналов.",
		["ChannelNames"] = "Названия каналов",
		["channelnick_desc"] = "Сокращение канала",
		["channelnick_name"] = "Сокращение канала",
		["Clear Channel Abbreviation"] = "Очистить сокращение канала",
		["Clears an abbreviated channel name."] = "Очищает сокращение названия канала.",
		["colon_desc"] = "Вкл/Выкл добавление двоеточия после замены канала.",
		["colon_name"] = "Показывать двоеточие",
		["Dont display the channel/chat type name"] = "Не показывать название канала/тип чата",
		["otheropts_desc"] = "Дополнительные настройки форматирования канала, и управление ссылками канала.",
		["otheropts_name"] = "Другие настройки",
		["Remove Channel Abbreviation"] = "Удалить сокращение канала",
		["Removes an an abbreviated channel name."] = "Удаляет сокращение названий каналов.",
		["Replace"] = "Заменить",
		["Set"] = "Задать",
		["space_desc"] = "Вкл/Выкл добавление пробела после замены канала.",
		["space_name"] = "Показывать пробел",
		["Toggle replacing this channel."] = "Включить замену данного канала.",
		["Use a custom replacement for the chat %s text."] = "Использовать заданную замену текста %s канала.",
	},
	["ChannelSticky"] = {
		["Channel"] = "Канал",
		["ChannelSticky"] = "Совмещение каналов",
		["Chat channel sticky options."] = "Настройки прилипания каналов чата.",
		["ChatType"] = "Тип чата",
		["Per chat type options."] = "Настройки по типу чата.",
		["smartgroup_desc"] = "Добавляет команду /gr , автоматически выбирающую корректный тип чата, РЕЙД, ГРУППА, или ПОЛЕ БОЯ",
		["smartgroup_name"] = "Быстрая сортировка",
		["Sticky %s"] = "Прилепить к %s",
		["Sticky Per Chat Frame"] = "Прилипать к окнам чата",
		["Toggle remembering the chat type last used per chat frame."] = "Вкл/Выкл запоминание тип чата при последнем использовании чата.",
		["Toggles sticky on and off for %s."] = "Вкл/Выкл прилипание для %s.",
	},
	["ChatFrames"] = {
		["Chat window frame parameter options"] = "Параметры окна чата",
		["framealpha_desc"] = "Настройка прозрачности окна чата при наведении на него курсора мыши.",
		["framealpha_name"] = "Прозрачность окна чата",
		["Frames"] = "Фреймы",
		["mainchatonload_desc"] = "Автоматически выбирает первое окно чата, и делает его активным при загрузке.",
		["mainchatonload_name"] = "Задействовать главное окно чата при загрузке",
		["maxchatheight_desc"] = "Устанавливает максимальную высоту для всех окон чата.",
		["maxchatheight_name"] = "Максимальная высоты",
		["maxchatwidth_desc"] = "Устанавливает максимальную ширину для всех окон чата.",
		["maxchatwidth_name"] = "Максимальная ширина",
		["minchatheight_desc"] = "Устанавливает минимальную высоту для всех окон чата.",
		["minchatheight_name"] = "Минимальная высоты",
		["minchatwidth_desc"] = "Устанавливает минимальную ширину для всех окон чата.",
		["minchatwidth_name"] = "Минимальная ширина",
		["rememberframepositions_desc"] = "Запомнить положение окна чата и восстановить при загрузке",
		["rememberframepositions_name"] = "Запомнить положение",
		["removeclamp_desc"] = "Позволить окну чата прижиматься вплотную к краю экрана",
		["removeclamp_name"] = "Вплотную к краю экрана",
	},
	["ChatLink"] = {
		["gem_desc"] = "Включить режим совместимости GEM",
		["gem_name"] = "Cовместимость GEM",
		["module_desc"] = "Настройки ссылок на предметы в каналах чата.",
		["module_info"] = "Этот модуль позволяет вывести ссылку на предмет в неторговый канал чата, например в Общий или частный канал. Для пользователей, которые не используют аддон, способный декодировать ссылки, это будет выглядеть как спам, так что будьте учтивы.",
		["module_name"] = "ChannelLinks",
		["Trade"] = "Торговля",
	},
	["ChatLog"] = {
		["A module to automaticaly enable chat and combat logging."] = "Модуль автоматического включения записи чата и журнала боя.",
		["Chat log recorded to <WoW Installation>\\Logs\\WoWChatLog.txt only upon logout."] = "Запись чата, записано в <директория инсталляции WoW>\\Logs\\WoWChatLog.txt  (только после выхода из игры).",
		["Chat Log: Disabled"] = "Запись чатa: выключена",
		["Chat Log: Enabled"] = "Запись чатa: включена",
		["ChatLog"] = "Логи чата",
		["Combat log recorded to <WoW Installation>\\Logs\\WoWCombatLog.txt only upon logout."] = "Журнал боя записывается в <директория инсталляции WoW>\\Logs\\WoWCombatLog.txt только до выхода из игры.",
		["Combat Log: Disabled"] = "Запись журнала боя: выключена",
		["Combat Log: Enabled"] = "Запись журнала боя: включена",
		["quiet_desc"] = "Не отображать никаких сообщений, если данный модуль включен, или при изменении им настроек записи.",
		["quiet_name"] = "Подавлять инфо сообщения",
		["Toggle Chat Log"] = "Запись чата",
		["Toggle chat log on and off."] = "Вкл/Выкл запись чата.",
		["Toggle Combat Log"] = "Запись журнала боя",
		["Toggle combat log on and off."] = "Вкл/Выкл запись журнала боя.",
	},
	["ChatTabs"] = {
		["Active Alpha"] = "Прозрачность активной",
		["All"] = "Все",
		["Always"] = "Всегда",
		["Chat window tab options."] = "Настройки вкладок чата.",
		["Default"] = "По умолчанию",
		["disableflash_desc"] = "Отключить мигание вкладок чата.",
		["disableflash_name"] = "Отключить мигание",
		["Hidden"] = "Скрывать",
		["Individual"] = "Индивидуально",
		["Not Active Alpha"] = "Прозрачность неактивных",
		["preventdrag_desc"] = "Запретить перетаскивание вкладок чата с помощью мыши",
		["preventdrag_name"] = "Запретить перетаскивание",
		["Set ChatFrame%d Display Mode"] = "Установить режим отображения %d вкладки",
		["Set Display Mode"] = "Режим отображения",
		["Set tab display mode for each chat window."] = "Установить режим отображения каждой вкладки окна чата. Отмечено (вкл), Не отмечено (выкл), Отмечено серым (по умолчанию)",
		["Set tab display to always, hidden or the Blizzard default."] = "Установить режим отображения вкладки на 'всегда показывать', 'скрывать' или 'поведение по умолчанию, как у Blizzard'.",
		["Sets alpha of chat tab for active chat frame."] = "Прозрачность активной вкладки чата.",
		["Sets alpha of chat tab for not active chat frame."] = "Прозрачность неактивных вкладок чата.",
		["Tabs"] = "Вкладки чата",
	},
	["Clear"] = {
		["Adds clear text slash commands (/clear)(/cls)(/clearall)(/clsall)."] = "Добавляет слаш команды очистки текста (/clear)(/cls)(/clearall)(/clsall).",
		["Clear"] = "Очистить",
		["Clearall"] = "Очистить все",
		["Clears all chat frames."] = "Очистить все окна чата.",
		["Clears the current chat frame."] = "Очистить текущее окно чата.",
	},
	["CopyChat"] = {
		[" Text"] = " Текст",
		["BBCode"] = true,
		["BOTTOMLEFT"] = "Снизу, Слева",
		["BOTTOMRIGHT"] = "Снизу, Справа",
		["buttonpos_desc"] = "Где в окне чата показывать кнопку копирования",
		["buttonpos_name"] = "Положение кнопки",
		["ChatFrame"] = "Окно чата",
		["Copy all of the text in the selected chat frame into an edit box"] = "Копировать весь текст из выбранного окна чата в поле ввода.",
		["Copy Text"] = "Копировать текст",
		["Copy Text Format"] = "Формат копирования текста",
		["Copy text from the active chat window."] = "Копировать текст из активного окна чата.",
		["Copy To Editbox"] = "Копировать чат",
		["CopyChat"] = "Копия Чата",
		["HTML"] = true,
		["Message From : %s"] = "Сообщение от : %s",
		["Plain"] = "Обычный текст",
		["Should the copied text be plain, or formatted so you can see the colors."] = "Копировать информацию как обычный текст или же форматированный, с сохранением цветов и т.п.",
		["showbutton_desc"] = "Показывать кнопку копирования в окне чата",
		["showbutton_name"] = "Кнопка копирования",
		["TOPLEFT"] = "Сверху, Слева",
		["TOPRIGHT"] = "Сверху, Справа",
		["Wowace.com Forums"] = "Форумы Wowace.com",
	},
	["CustomFilters"] = {
		["<string>"] = true,
		["Add a pattern to search for."] = "Добавить образец для поиска.",
		["Add Pattern"] = "Добавить образец",
		["Block Message"] = "Блокировка сообщения",
		["Channel Data"] = "Канал данных",
		["Channel to send output text to."] = "Канал для отсылки выходящего текста.",
		["Enabled"] = "Включено",
		["Extra data for WHISPER (target) and CHANNEL (channel name or num)"] = "Добавочные данные для ШЕПОТА (цель) и КАНАЛА (название канала или номер)",
		["Filter Name"] = "Название фильтра",
		["Forward"] = "Пересылать",
		["Forward the message to a chat channel."] = "Пересылать сообщение в канал чата.",
		["Forward the message to a custom chat channel."] = "Вывод в частный канал",
		["ForwardCustom"] = true,
		["ForwardMessage"] = true,
		["ForwardMessageCustom"] = "Частный канал",
		["Hilight Color"] = "Цвет выделения",
		["Hilight Match Text"] = "Выделение текста",
		["Inbound"] = "Входящие",
		["inchannels_desc"] = "Поиск в определённых каналах",
		["inchannels_name"] = "Поиск канала",
		["Is this pattern enabled for use?"] = "Включить в использование данный шаблон?",
		["Match Options"] = "Опции совпадения",
		["module_desc"] = "Модуль поддерживающий пользовательские фильтры.",
		["module_name"] = "CustomFilters",
		["Only output the message portion of the chat text, leave out the channel, and playername etc."] = "Вывод только части сообщений, выход с канала, имя игрока и т.д.",
		["Outbound"] = "Исходящие",
		["Output Channel"] = "Канал вывода",
		["Output Message Only"] = "Только вывод сообщения",
		["Pattern Info"] = "Шаблон",
		["Pattern Options"] = "Настройки образца",
		["Play a sound when this message is output to the chatframe"] = "Проиграть звук когда данное сообщение выводится в окно чата.",
		["Play Sound"] = "Проиграть звук",
		["Prevent the message from being displayed"] = "Предотвращает отображение сообщения",
		["Remove an existing pattern."] = "Удалить существующий образец.",
		["Remove Pattern"] = "Удалить образец",
		["Replacement Text"] = "Замена текста",
		["Search Format String"] = "Формат строки поиска",
		["Search Pattern"] = "Образец поиска",
		["Secondary Output"] = "Вторичный вывод",
		["Send to a secondary output"] = "Отослать на вторичный вывод",
		["Supplied pattern is a format string instead of a pattern"] = "Поставляется оброзец формата строки вместо шаблона",
		["Your name for this filter"] = "Ваше имя для данного фильтра",
	},
	["Editbox"] = {
		["Attach edit box to..."] = "Закрепить поле ввода...",
		["Attach to..."] = "Закрепить...",
		["Background color"] = "Цвет фона",
		["Background Inset"] = "Фоновая врезка",
		["Background texture"] = "Текстура фона",
		["Border color"] = "Цвет границ",
		["Border texture"] = "Текстура границы",
		["Bottom"] = "Внизу",
		["Color border by channel"] = "Окраска границы по цвету канала",
		["currently_broken_alt_behavior"] = [=[Поведение стрелок сломано в текущей версии WoW

Используйте ALT-СтрелкаВверх и ALT-СтрелкаВниз вместо просто стрелок вверх и вниз чтобы открыть историю]=],
		["Edge Size"] = "Размер контура",
		["Editbox"] = "Поле ввода",
		["Editbox options."] = "Настройки поля ввода.",
		["Font"] = "Шрифт",
		["Free-floating"] = "Свободно",
		["Free-floating, Locked"] = "Свободно, заблокировано",
		["Requires the Alt key to be held down to move the cursor in chat"] = "Для перемещения курсора в чате требуется нажатая клавиша Alt",
		["Select the font to use for the edit box"] = "Выбор шрифта для области редактирования",
		["Sets the frame's border color to the color of your currently active channel"] = "Установить окраску границы в цвет вашего активного канала",
		["Tile Size"] = "Размер мозаики",
		["Top"] = "Вверху",
		["Use Alt key for cursor movement"] = "Исп. кливишу Alt для перемещения курсора",
	},
	["EventNames"] = {
		["allevents_desc"] = "Обрабатывать Prat'ом все сообщения в чате.",
		["allevents_name"] = "Обрабатывать все сообщения",
		["Chat window event name options."] = "Настройки названий событий в окне чата.",
		["EventNames"] = true,
		["Show"] = "Отображать",
		["Show events on chatframes"] = "Отображать события в окне чата",
		["show_desc"] = "Вкл/Выкл отображение названий событий во всех окнах.",
		["show_name"] = "Названия событий",
	},
	["Fading"] = {
		["duration_desc"] = "Задайте значение в секундах для задержки затухания текста в окне чата.",
		["duration_name"] = "Задержка затухания (в секундах)",
		["module_desc"] = "Настройки затухания текста в окне чата.",
		["module_name"] = "Затухание",
		["textfade_desc"] = "Вкл/Выкл затухание текста во всех окнах чата.",
		["textfade_name"] = "Включить затухание",
	},
	["Filtering"] = {
		["A module to provide basic chat filtering."] = "Модуль для обеспечения базовый фильтрации чата.",
		["afkdnd_desc"] = "Заглушать сообщения AFK и DND.",
		["afkdnd_name"] = "Заглушать сообщения AFK и DND.",
		["bgjoin_desc"] = "Отфильтровывать сообщения входа и выхода на/из Поля Сражения (БГ)",
		["bgjoin_name"] = "Отфильтровывать вход/выход на ПС",
		["Filtering"] = "Фильтрование",
		["leavejoin_desc"] = "Отфильтровывать сообщения входа и выхода из/в канал.",
		["leavejoin_name"] = "Вход/выход в/из канала",
		["notices_desc"] = "Отфильтровывать извещения в каналах (такие как смета модератора и т.п.).",
		["notices_name"] = "Извещения в канале",
		["tradespam_desc"] = "Скрывать повторяющиеся сообщения",
		["tradespam_name"] = "Скрывать спам",
	},
	["Font"] = {
		["Auto Restore Font Size"] = "Авто-восстановление размера",
		["Chat window font options."] = "Настройки шрифта окна чата.",
		["Font"] = "Шрифт",
		["monochrome_desc"] = "Вкл/Выкл чёрно-белое окрашивание шрифта.",
		["monochrome_name"] = "Чёрно-белое",
		["None"] = "Нет",
		["Outline"] = "Обычная обводка",
		["outlinemode_desc"] = "Выбор типа обводки вокруг символов.",
		["outlinemode_name"] = "Обводка",
		["rememberfont_desc"] = "Запомнить выбранный шрифт и использовать его при следующей загрузке.",
		["rememberfont_name"] = "Запомнить шрифт",
		["Set ChatFrame%d Font Size"] = "Размер шрифта окна %d",
		["Set Font Face"] = "Основной шрифт",
		["Set Font Size"] = "Размер шрифта",
		["Set Separately"] = "Разделение",
		["Set text font size for each chat window."] = "Установка размера шрифта во всех окнах чата.",
		["Set text font size."] = "Размер шрифта.",
		["Set the text font face for all chat windows."] = "Установка главного шрифта для всех окон чата.",
		["shadowcolor_desc"] = "Установка цвета эффекта тени.",
		["shadowcolor_name"] = "Цвет тени",
		["Thick Outline"] = "Жирная обводка",
		["Toggle setting options separately for each chat window."] = "Вкл/Выкл настройки разделения для всех окон чата.",
		["Workaround a Blizzard bug which changes the font size when you open a system menu."] = "Метод обхода ошибки Blizzard, изменяющей размер шрифта при открытии системного меню.",
	},
	["History"] = {
		["Chat history options."] = "Настройки истории чата.",
		["Color GMOTD"] = "Цвет  GMOTD",
		["Colors the GMOTD label"] = "Цвета названия СДГ",
		["delaygmotd_desc"] = "Задерживать отображение СДГ вплоть до окончания спама при входе в игру",
		["delaygmotd_name"] = "задержка GMOTD",
		["divider"] = "========== Конец истории сообщений ==========",
		["History"] = "История",
		["Maximum number of lines of command history to save."] = "Максимальное число строк сохранённых в истории команд.",
		["Save Command History"] = "Сохранять историю команд",
		["Saves command history between sessions (for use with alt+up arrow or just the up arrow)"] = "Сохранять историю команд между сеансами (для использования используйте alt+ стрелка вверх или просто стрелку вверх)",
		["Scrollback"] = "История сообщений",
		["Scrollback Options"] = "Вернуть опции",
		["scrollbacklen_desc"] = "Количество строк чата, которое надо сохранять в буфере истории сообщений.",
		["scrollbacklen_name"] = "Длина истории сообщений",
		["Set Chat Lines"] = "Задать число строк чата",
		["Set Command History"] = "История команд",
		["Set the number of lines of chat history for each window."] = "Установите число строк истории чата для всех окон чата.",
		["Store the chat lines between sessions"] = "Сохранять строки чата между сессиями",
	},
	["KeyBindings"] = {
		["Channel %d"] = "Канал %d",
		["Copy Selected Chat Frame"] = "Копирование выбранного окна чата",
		["Guild Channel"] = "Канал Гильдии",
		["Instance Channel"] = "Канал Подземелий",
		["Next Chat Tab"] = "Следующее окно чата",
		["Officer Channel"] = "Офицерский Канал",
		["Party Channel"] = "Канал Группы",
		["Prat CopyChat"] = "Копирование чата Prat",
		["Prat Keybindings"] = true,
		["Prat TellTarget"] = "Prat Сказать обьекту",
		["Raid Channel"] = "Канал Рейда",
		["Raid Warning Channel"] = "Канал объявлений рейду",
		["Say"] = "Сказать",
		["Smart Group Channel"] = "Групирование каналов",
		["TellTarget"] = "Сказать обьекту",
		["Whisper"] = "Шепнуть",
		["Yell"] = "Крикнуть",
	},
	["OriginalButtons"] = {
		["alpha_desc"] = "Установить прозрачность меню чата, а также стрелок для всех окон чата.",
		["alpha_name"] = "Прозрачность",
		["buttonframe_desc"] = "Включить или выключить меню Окна кнопок.",
		["buttonframe_name"] = "Показать Окно кнопок",
		["ChannelNames"] = "Названия каналов",
		["Chat window button options."] = "Опции кнопок чата.",
		["chatmenu_desc"] = "Вкл/выкл меню чата.",
		["chatmenu_name"] = "Показать меню чата",
		["Default"] = "По умолчанию",
		["Original Buttons"] = "Обычные кнопки",
		["reflow_desc"] = "Текст в окне чата должен обтекать кнопки, а не уходить под них.",
		["reflow_name"] = "Текст обтекает кнопки",
		["reminder_desc"] = "Показать кнопку прокрутки чата вниз, когда последнее сообщение не в нижней части окна чата.",
		["reminder_name"] = "Показать прокрутку вниз",
		["Right, Inside Frame"] = "Справа, внутри рамки",
		["Right, Outside Frame"] = "Справа, вне рамки",
		["Set Position"] = "Установить позицию",
		["Sets position of chat menu and arrows for all chat windows."] = "Устанавливает позицию меню чата и стрелок для всех окон чата",
		["Show Arrows"] = "Отображать стрелки",
		["Show Chat%d Arrows"] = "Отображает стрелки чата %d",
		["Toggle showing chat arrows for each chat window."] = "Вкл/Откл отображение стрелок для всех окон чата.",
		["Toggles navigation arrows on and off."] = "Вкл/Откл отображение стрелок прокрутки чата",
	},
	["OriginalEditbox"] = {
		["Autohide"] = "Авто-сокрытие",
		["BACKGROUND"] = "ФОН",
		["Bar colour"] = "Цвет панели",
		["Border colour"] = "Цвет границ",
		["Border width"] = "Ширина границ",
		["Bottom"] = "Внизу",
		["Click the edit box to open it up for editing. Only available if Autohide is disabled."] = "Нажмите на поле ввода, чтобы открыть его для редактирования. Доступно только если авто-сокрытие отключено.",
		["Clickable"] = "Реагировать на щелчки мыши",
		["DIALOG"] = "ДИАЛОГ",
		["Editbox options."] = "Настройки поле ввода.",
		["Enable Arrowkeys"] = "Включить стрелки",
		["Enable using arrowkeys in editbox without the alt key."] = "Включить использование стрелок напровления в поле ввода без клавиши alt.",
		["Hide Border"] = "Скрыть границы",
		["Hide the border around the edit box."] = "Скрыть границы в окружности поле ввода.",
		["Hide the edit box after you have pressed enter."] = "Скрыть поле ввода после того как вы нажали enter.",
		["HIGH"] = "ВЫСОКИЙ",
		["Lock editbox position if undocked."] = "Закрепить позицию поле ввода если разблокировано.",
		["Lock Position"] = "Закрепить пазицию",
		["LOW"] = "НИЗКИЙ",
		["MEDIUM"] = "СРЕДНИЙ",
		["OriginalEditbox"] = true,
		["Padding"] = "Выравнивание",
		["Set Alpha"] = "Установить прозрачность",
		["Set Position"] = "Установить позицию",
		["Set Strata"] = "Установить слой",
		["Set the alpha of the editbox."] = "Установка прозрачности поле ввода.",
		["Set the amount of padding inside the edit box"] = "Установка значения отступа в поле ввода",
		["Set the edit box background colour"] = "Установка цвета фона поля ввода",
		["Set the edit box border colour"] = "Установка цвета границ поля ввода",
		["Set the frame strata of the editbox."] = "Установить рамку слоёв окна редактирования",
		["Set the position of the editbox."] = "Задать позицию окна редактирования",
		["Set the texture of the chat edit box"] = "Задать текстуру в окне редактирования для чата",
		["Set the width of the edit box's border"] = "Задать ширину границы окна редактирования",
		["Set the width of the editbox."] = "Задать ширину окна редактирования",
		["Set Width (NB: only enabled if the editbox is undocked)"] = "Уст. ширину (Пометка: включено только если поле ввода разблокировано)",
		["Texture"] = "Текстура",
		["Top"] = "Верх",
		["Undocked"] = "Отстыкован",
	},
	["Paragraph"] = {
		["adjustlinks_desc"] = "Регулировка текста кликабельных сссылок способностей по центру или в право/лево.",
		["adjustlinks_name"] = "Размещение ссылок игроков/предметов",
		["Center"] = "Центр",
		["Chat window paragraph options."] = "Настройки абзаца окна чата.",
		["justification_desc"] = "Горизонтальное выравнивание всех окон чата.",
		["justification_name"] = "Выравнивание",
		["Left"] = "Влево",
		["Line Spacing"] = "Промежуток строк",
		["Paragraph"] = "Абзац",
		["Right"] = "Вправо",
		["Set the line spacing for all chat windows."] = "Установка промежутка строк во всех окнах чата.",
	},
	["PlayerNames"] = {
		["Actively Query Player Info"] = "Активный запрос инфы о игроке",
		["Angled"] = "Треугольные",
		["Brackets"] = "Скобки",
		["Brackets Common Color"] = "Основной цвет скобок",
		["Brackets Use Common Color"] = "Скобки общего цвета",
		["Class"] = "Класс",
		["Color by Level Difference"] = "Окрашивание по отличию в уровне",
		["coloreverywhere_desc"] = "Окраска текст сообщения в цвет имени игрока, если цвет задан",
		["coloreverywhere_name"] = "Цвет имени везде",
		["Enable Alt-Invite"] = "Включить приглашение с кнопкой Alt",
		["Enable Invite Links"] = "Включить приглашение по ссылкам",
		["Enable TabComplete"] = "Включить TabComplete",
		["hoverhilight_desc"] = "Подсвечивает строки чата от определенных игроков при наведении мышкой на их никнейм.",
		["hoverhilight_name"] = "Подсветка при наведении мышкой",
		["How to color other player's level."] = "Как окрашивать уповень игрока.",
		["How to color player's name."] = "Как окрашивать имя игрока.",
		["Keep Info"] = "Хранить информацию",
		["Keep Lots Of Info"] = "Хранить большое количество информации",
		["Keep player information between session for all players except cross-server players"] = "Хранить информацию о всех собеседниках между сессиями за исключением игроков с других серверов",
		["Keep player information between session, but limit it to friends and guild members."] = "Хранить информацию о собеседниках между сессиями, но ограничить этот список только друзьями и членами гильдии.",
		["Let TasteTheNaimbow set the common color for unknown player names."] = "Позволить TasteTheNaimbow установить общий цветдля неизвестных играков.",
		["Level Color Mode"] = "Режим окрашивания уровня",
		["linkifycommon_desc"] = "Общие сообщения с сылками",
		["linkifycommon_name"] = "Общие сообщения с сылками",
		["No additional coloring"] = "Отключить дополнительное цвето-выделение",
		["None"] = "Нет",
		["Player Color Mode"] = "Режим цвета игрока",
		["Player name formating options."] = "Настройки форматирования имени собеседника.",
		["PlayerNames"] = "Имя игрока",
		["Prat_Playernames: Stored Player Data Cleared"] = "Prat_Playernames: Информация о собеседниках очищена",
		["Query the server for all player names we do not know. Note: This happpens pretty slowly, and this data is not saved."] = "Запрос сервера для всех неизвестных играков. Заметка: Это происходит дастаточно медленно, и их данные не сохраняются.",
		["Random"] = "Случайно",
		["realidcolor_desc"] = "Окрашивание имен RealID",
		["realidcolor_name"] = "RealID Цвет",
		["Reset Settings"] = "Сброс настроек",
		["Restore default settings, and delete stored character data."] = "Восстановить настройки по умолчанию и удалить сохраненную информацию о собеседниках.",
		["Set common color of unknown player names."] = "Выбор цвета, которым будут окрашены неизвестные игроки.",
		["Sets common color of brackets to use around player names."] = "Установить цвет скобок, окружающих имя игрока.",
		["Sets style of brackets to use around player names."] = "Установить стиль скобок вокруг имени собеседника.",
		["Show Group"] = "Показывать группу",
		["Show Level"] = "Показывать уровень",
		["Show Raid Target Icon"] = "Показать иконку цели рейда",
		["Square"] = "Квадратные",
		["Tab completion : "] = "Завершение закладки : ",
		["tabcomplete_name"] = "Возможные имена",
		["Toggle group invites by alt-clicking hyperlinked keywords like 'invite'."] = "Вкл/выкл приглашение в группу с помощью alt+клик по ключевому слову типа: 'инвайт'.",
		["Toggle group invites by alt-clicking on player name."] = "Включить режим, в котором можно пригласить игрока в группу щелкнув по его имени  с нажатой клавишей Alt.",
		["Toggle level showing."] = "Вкл/выкл отображения уровня собеседника.",
		["Toggle raid group showing."] = "Вкл/выкл отображения рейдовой группы.",
		["Toggle showing the raid target icon which is currently on the player."] = "Вкл/Выкл отображение иконки цели рейда которой помечен игрок.",
		["Toggle tab completion of player names."] = "Вкл/выкл завершение закладки именами играка.",
		["Toggle using a common color for brackets around player names."] = "Включить окрашивание скобок вокруг имени игрока общим, выбранным цветом.",
		["Toggle using a common color for unknown player names."] = "Включить окрашивание имен всех неизвестных собеседников в общий цвет.",
		["Too many matches (%d possible)"] = "За много совпадение (%d возможных)",
		["Unknown Common Color"] = "Общий цвет неизвестных",
		["Unknown Common Color From TasteTheNaimbow"] = "Общая окраска неизвестных из TasteTheNaimbow",
		["Unknown Use Common Color"] = "Общий цвет для неизвестных",
		["Use Channel Color"] = "Использовать цвет канала",
		["Use Player Color"] = "Использовать цвет игрока",
		["Use toon name for RealID"] = "Использовать имя персонажа вместо RealID",
	},
	["PopupMessage"] = {
		["Add Nickname"] = "Добавить ник",
		["Adds an alternate name to show in popups."] = "Добавить альтернативное имя для отображения при всплывании.",
		["Clear Nickname"] = "Очистить ники",
		["Clears alternate name to show in popups."] = "Очистить альтернативные имена для отображения при всплывании.",
		["framealpha_desc"] = "Установка прозрачности всплывающего окна при полном затухании.",
		["framealpha_name"] = "Прозрачность окна всплывания",
		["Popup"] = "Всплывающий",
		["PopupMessage"] = "Всплывающее окно",
		["Remove Nickname"] = "Удалить ник",
		["Removes an alternate name to show in popups."] = "Удалить альтернативное имя для отображения при всплывании.",
		["Set Separately"] = "Разделение",
		["Show All Popups"] = "Все всплывающие",
		["Show Popups"] = "Показывать всплывания",
		["Show Popups for all chat windows."] = "Показывать всплывающие окна для всего чата.",
		["Show Popups for each window."] = "Показывать всплывания для всех окон.",
		["show_desc"] = "Отображать всплывние для всех окон чата.",
		["show_name"] = "Показывать всплывание",
		["show_perframedesc"] = "Вкл/Выкл отображение всплывания.",
		["show_perframename"] = "Показать всплывание окна %d",
		["showall_desc"] = "Показывать всплывающие окна для всего чата.",
		["showall_name"] = "Все всплывающие",
		["Shows messages in a popup window."] = "Показывать сообщение во всплывающем окне.",
		["Shows messages with your name in a popup."] = "Показывать сообщение с вашим именем во всплывающем окне.",
		["Toggle setting options separately for each chat window."] = "Вкл/Выкл настройки разделения для всех окон чата.",
	},
	["Scroll"] = {
		["Bottom"] = "Снизу вверх",
		["Chat window scrolling options."] = "Настройки прокрутки окна чата.",
		["Control whether text is added to the frame at the top or the bottom."] = "Регулировка текста добавленного в окно в вверх или низ.",
		["lowdown_desc"] = "Вкл/Выкл авто прокрутку в низ для во всех окнах чата.",
		["lowdown_name"] = "Включить спад в низ",
		["modified_speed"] = "Установка скорости прокрутки колеса мышки+Shift",
		["modified_speed_desc"] = "Установите количество прокручиваемых строк с помощью колеса мыши+shift.",
		["mousewheel_desc"] = "Вкл/Выкл поддержку колесика мыши во всех оконах чата.",
		["mousewheel_name"] = "Включить КолесоМыши",
		["Scroll"] = "Прокрутка",
		["Set Ctrl+MouseWheel Speed"] = "Задать скорость Ctrl+КолесоМыши",
		["Set MouseWheel Speed"] = "Скорость КолесаМыши",
		["Set number of lines mousewheel will scroll when ctrl is pressed."] = "Установите число строк прокручиваемых колёсиком мыши при удерживании ctrl.",
		["Set number of lines mousewheel will scroll."] = "Устанавите число строк прокручиваемых колёсиком мыши за раз.",
		["Set TheLowDown Delay"] = "Задержка спада в низ",
		["Set time to wait before jumping to the bottom of chat windows."] = "Установите время ожидания перед прокруткой в низ окна чата.",
		["Text scroll direction"] = "Направление текста прокрутки",
		["Top"] = "С верху вниз",
	},
	["Search"] = {
		["err_notfound"] = "Не Найденно",
		["err_tooshort"] = "Критерий поиска слишком короток",
		["find_results"] = "Найти Результаты:",
		["module_desc"] = "Добавляет возможность поиска текста в чате.",
		["module_info"] = [=[Этот модуль добавляет команды /find и /findall для поиска в истории чата

Использование:

/find <текст>

/findall <текст>]=],
		["module_name"] = "Поиск",
	},
	["ServerNames"] = {
		["autoabbreviate_desc"] = "Сокращает название сервера до трех букв",
		["autoabbreviate_name"] = "Авто-сокращение",
		["colon_desc"] = "Вкл/Выкл добавление двоеточия после замещения сервера.",
		["colon_name"] = "Показывать двоеточие",
		["randomclr_desc"] = "Использовать случайные цвета для всех серверов.",
		["randomclr_name"] = "Случайные цвета",
		["Server name abbreviation options."] = "Настройки сокращений имен серверов.",
		["ServerNames"] = "Названия серверов",
	},
	["Sounds"] = {
		["A module to play sounds on certain chat messages."] = "Модуль проигрывает зуки для определённых сообщений в чате.",
		["Add a custom channel"] = "Добавить свой канал",
		["bn_whisper_desc"] = "Звук для %s Battle.Net при шепоте",
		["bn_whisper_name"] = "Battle.Net Шепот",
		["Custom Channels"] = "Личные каналы",
		["group_lead_desc"] = "Звук для сообщений %s лидера рейда, лидера группы или проводника подземелья",
		["group_lead_name"] = "Лидер группы",
		["guild_desc"] = "Звук %s для сообщений гильдии",
		["guild_name"] = "Гильдия",
		["incoming"] = "Входящие",
		["Incoming Sounds"] = "Звук входящих",
		["officer_desc"] = "Звук %s для сообщений офицеров или личного канала",
		["officer_name"] = "Офицеры",
		["outgoing"] = "Исходящие",
		["Outgoing Sounds"] = "Звуки исходящего",
		["party_desc"] = "Звук %s для сообщений группы",
		["party_name"] = "Группа",
		["Play a sound for a certain channel name (can be a substring)"] = "Проигрывает зук для определённого канала чата (can be a substring)",
		["raid_desc"] = "Звук %s для сообщений группы/лидера рейда или поля сражений",
		["raid_name"] = "Рейд",
		["Remove a custom channel"] = "Удалить свой канал",
		["Reset settings"] = "Сброс настроек",
		["Restore default settings and resets custom channel list"] = "Восстановление стандартных настроек и сброс списка своих каналов чата.",
		["Sound selection for incoming chat messages"] = "Выбор звука для входящих сообщений в чате",
		["Sound selection for outgoing (from you) chat messages"] = "Выбор звука для исходящих (от вас) сообщений в чате",
		["Sounds"] = "Звуки",
		["whisper_desc"] = "Звук  %s для личных сообщений",
		["whisper_name"] = "Шепот",
	},
	["Substitutions"] = {
		["%d total user defined substitutions"] = "всего %d пользовательских замен",
		["|cffff0000warning:|r subtitution \"%s\" already defined as \"%s\", overwriting"] = "|cffff0000предупреждение:|r замена \"%s\" уже определена как \"%s\", переписываем",
		["<noguild>"] = "<без гильдии>",
		["<notarget>"] = "<нет цели>",
		["A module to provide basic chat substitutions."] = "Модуль для простых замен текста в чате.",
		["Are you sure - this will delete all user defined substitutions and reset defaults?"] = "Вы уверены - будут удалены все пользовательские замены и установлены значения по умолчанию?",
		["Are you sure?"] = "Ты уверен?",
		["can't find substitution index for a substitution named '%s'"] = "не могу найти номер замены в списке замен для '%s'",
		["current-prompt"] = [=[Текущее значение: '%s'
Кликнуть для копирования в чат.]=],
		["defined %s: expands to => %s"] = "определено %s: раскрывается в => %s",
		["Delete all"] = "Удалить все",
		["Delete substitution"] = "Удалить замену",
		["Deletes a user defined substitution"] = "Удаляет пользовательскую замену",
		["Deletes all user defined substitutions"] = "Удалить все замены заданные пользователем",
		["female"] = "женский",
		["her"] = "её",
		["hers"] = "ей",
		["him"] = "им",
		["his"] = "его",
		["it"] = "это",
		["its"] = "его",
		["List of available substitutions"] = "Список доступных замен",
		["List of available substitutions defined by this module. (NB: users may define custom values for existing substitutions, but they will revert to the default value if the user definition is deleted.)"] = "Список доступных подмен, определённых в этом модуле. (Примечание: пользователи могут присваивать собственные значения существующим подменам, но они вернутся в значения по умолчанию, если пользовательское определение будет удалено.",
		["List substitutions"] = "Вывести список замен",
		["Lists all current subtitutions in the default chat frame"] = "Вывести все текущие замены в основное окно чата",
		["male"] = "мужской",
		["MapLoc"] = "Блокировка карты",
		["MapPos"] = "Позиция на карте",
		["MapXPos"] = "Позиция Х на карте",
		["MapYPos"] = "Поз.по Y",
		["MapZone"] = "Зона карты",
		["module:buildUserSubsIndex(): warning: module patterns not defined!"] = "module:buildUserSubsIndex(): предупреждение: шаблоны модуля не определены!",
		["MouseoverTargetName"] = true,
		["NO MATCHFUNC FOUND"] = "Нет соответствующих ",
		["no substitution name given"] = "не задано имя замены",
		["no substitution name supplied for deletion"] = "не задано имя замены для удаления",
		["no user defined subs found"] = "не найдено замен определяемых пользователем",
		["no value given for subtitution \"%s\""] = "не задано значение для замены \"%s\"",
		["Options for setting and removing user defined substitutions. (NB: users may define custom values for existing substitutions, but they will revert to the default value if the user definition is deleted.)"] = "Опции для назначения и отмены пользовательских замен. (Внимание: пользователи могут назначать свои значения для существующих замен, однако будет использовано значение по умолчанию если определение пользователя удалено).",
		["PlayerAverageItemLevel"] = true,
		["PlayerCurrentMana"] = "текушая мана игрока",
		["PlayerHealthDeficit"] = true,
		["PlayerHP"] = true,
		["PlayerManaDeficit"] = "нехватка маны",
		["PlayerMaxHP"] = true,
		["PlayerMaxMana"] = true,
		["PlayerName"] = "Имя игрока",
		["PlayerPercentHP"] = true,
		["PlayerPercentMana"] = true,
		["RandNum"] = true,
		["removing user defined substitution \"%s\"; previously expanded to => \"%s\""] = "удаляется определяемая пользователем замена \"%s\", раскрывавшаяся в => \"%s\"",
		["Set substitution"] = "Назначить замену",
		["Set the value of a user defined substitution (NB: this may be the same as an existing default substitution; to reset it to the default, just remove the user created definition)."] = "Установить значение для определяемой пользователем замены (Внимание: может совпадать с существующей заменой по умолчанию; чтобы сбросить к первоначальному значению удалите пользовательское определение).",
		["subname -- NOTE: sub name without the prefix '%'"] = "subname -- ВАЖНО: sub name указывать без префикса '%'",
		["subname = text after expansion -- NOTE: sub name without the prefix \"%\""] = "subname = text after expansion -- ВАЖНО: sub name указывать без префикса '%'",
		["substitution: %s defined as => %s"] = "замена: %s определен как => %s",
		["Substitutions"] = "Замены",
		["TargetClass"] = true,
		["TargetGender"] = true,
		["TargetGuild"] = "показать гильдию",
		["TargetHealth"] = "показать жизнь",
		["TargetHealthDeficit"] = "Деф. здоровья цели",
		["TargetIcon"] = "показать иконку",
		["TargetLevel"] = "показать уровень",
		["TargetManaDeficit"] = "Деф. маны цели",
		["TargetName"] = "показать имя",
		["TargetPercentHP"] = "% здоровья цели",
		["TargetPossesive"] = true,
		["TargetPronoun"] = true,
		["TargetRace"] = "Раса цели",
		["TargetTargetName"] = "Имя цели цели",
		["unknown sex"] = "неизвестный пол",
		["user defined substition \"%s\" not found"] = "пользовательская замена \"%s\" не найдена",
		["User defined substitutions"] = "Пользовательские подмены",
		["user substitutions index (usersubs_idx) doesn't exist! oh dear."] = "таблица пользовательских замен (usersubs_idx) не существует! о боже.",
		["usersub_"] = true,
	},
	["TellTarget"] = {
		["/tt"] = true,
		["Adds telltarget slash command (/tt)."] = "Добавляет слеш-команду 'сказать о цели' (/tt).",
		["No target selected."] = "Нет выбранной цели.",
		["NoTarget"] = "Нет цели",
		["Target does not exist."] = "Цель не существует.",
		["Target is not a player."] = "Выбранная цель не является игроком.",
		["TellTarget"] = "Сказать цели",
	},
	["Timestamps"] = {
		["Chat window timestamp options."] = "Настройки времени в окне чата.",
		["colortimestamp_desc"] = "Вкл/Выкл окрасу времени.",
		["colortimestamp_name"] = "Окраска времени",
		["Format All Timestamps"] = "Формат всего времени",
		["HH:MM (12-hour)"] = "HH:MM (12-ч)",
		["HH:MM (24-hour)"] = "HH:MM (24-ч)",
		["HH:MM:SS (12-hour)"] = "HH:MM:SS (12-ч)",
		["HH:MM:SS (24-hour)"] = "HH:MM:SS (24-ч)",
		["HH:MM:SS AM (12-hour)"] = "HH:MM:SS AM (12-ч)",
		["localtime_desc"] = "Вкл/Выкл использование местного времени.",
		["localtime_name"] = "Местное время",
		["MM:SS"] = true,
		["Post-Timestamp"] = "Перед-временем",
		["Pre-Timestamp"] = "После-времени",
		["Set the timestamp format"] = "Установите формат времени ",
		["Set Timestamp Color"] = "Цвет времени",
		["Sets the color of the timestamp."] = "Установка цвета времени.",
		["Show Timestamp"] = "Показывать время",
		["show_desc"] = "Вкл/Выкл отображение времени во всех окнах.",
		["show_name"] = "Показывать время",
		["space_desc"] = "Вкл/Выкл добавление пробела после времени.",
		["space_name"] = "Пробел",
		["Timestamps"] = "Отображение времени",
		["Toggle showing timestamp for each window."] = "Вкл/Выкл отображение времени во всех окнах.",
		["twocolumn_desc"] = "Помещает время в отдельную колонку, чтобы текст не переносился на строку под ним.",
		["twocolumn_name"] = "Чат в 2 колонки",
	},
	["UrlCopy"] = {
		["Change the color of the URL."] = "Изменение цвета ссылок.",
		["Color URL"] = "Цвет ссылки",
		["Set Color"] = "Цвет",
		["Show Brackets"] = "Показывать скобки",
		["Toggle"] = "Вкл/выкл",
		["Toggle showing brackets on and off."] = "Вкл/Выкл отображение скобок.",
		["Toggle the module on and off."] = "Вкл/Выкл данный модуль.",
		["Toggle the URL color on and off."] = "Вкл/Выкл окраску ссылок.",
		["URL formating options."] = "Настройки формата URL-адреса.",
		["UrlCopy"] = "Копировать ссылку",
		["Use Popup"] = "Всплывающее окно",
		["Use popup window to show URL."] = "Использовать всплывающее окно для показа ссылки.",
	}
}

PL:AddLocale(PRAT_MODULE.name, "ruRU",L)


L=
{
	["display_desc"] = "聊天框管理与插件",
	["display_name"] = "显示设置",
	["extras_desc"] = "杂项模块",
	["extras_name"] = "扩展选项",
	["formatting_desc"] = "改变行的感观",
	["formatting_name"] = "聊天格式",
	["load_desc"] = "控制这个模块的载入状态",
	["load_disabled"] = "禁用",
	["load_disabledonrestart"] = "停用 (重载)",
	["load_enabled"] = "启用",
	["load_enabledonrestart"] = "启用 (重载)",
	["load_no"] = "不加载",
	["modulecontrol_desc"] = "控制Prat模块的读取和启用",
	["modulecontrol_name"] = "模块控制",
	["prat"] = "Prat",
	["reload_required"] = "在%s您的插件以前,此选项不会完全生效",
	["AddonMsgs"] = {
		["Addon message options."] = "插件信息选项",
		["AddonMsgs"] = "插件信息",
		["show_desc"] = "在各自聊天窗口中显示隐藏的插件消息",
		["show_name"] = "显示插件信息",
		["show_perframedesc"] = "显示隐藏的插件消息",
		["show_perframename"] = "聊天框体%d插件消息显示",
	},
	["Alias"] = {
		[" - list all aliases; supply <keyword> to search for matching aliases (cmd aliases: /listallaliases)"] = "-列出全部替换词;支持<关键字>搜索匹配的替换词(替换词命令:/listallaliases)",
		["%s() called with blank string!"] = "%s()为空白字符!",
		["%s() called with nil argument!"] = "%s()不能为空!",
		["/%s aliased to \"/%s\""] = "/%s替换为\"/%s\"",
		["/%s aliased to: /%s"] = "/%s替换为:/%s",
		["<alias> - remove the alias <alias> (cmd aliases: /delalias, /remalias)"] = "<alias> - 移除替换词<alias> (命令: /delalias, /remalias)",
		["<command>[ <value>] - alias <command> to be executed as <value>, or return the value of the currently defined alias for <command> if <command> has not been assigned a value. eg: \"/alias /examplehello /say hello there\" - typing \"/examplehello\" will now cause your character to say \"hello there\"; \"/alias examplehello\" - s \"/examplehello is aliased to /say hello there\" (cmd aliases: /addalias)"] = "<命令>[<值>] - 替换词<命令>被实现为<值>，如果<命令>没有被定义一个值,就为<命令>返回当前确定了值的替换词.例: \"/alias /好 /s 你好啊\" - 键入\"/好\"就会马上让你的角色去说\"你好啊\";\"/alias 好\"是\"/好 去替换/s 你好啊\"(替换词命令:/addalias)",
		["<keyword> - finds all aliases matching <keyword> (cmd aliases: /findalias)"] = "<关键字> - 寻找所有匹配<关键字>的替换词(命令: /findalias)",
		["add"] = "添加",
		["add an alias"] = "添加一个替换词",
		["alias \"/%s\" does not exist"] = "替换词\"/%s\"不存在",
		["dealiasing command /%s to /%s"] = "/%s到/%s非替换词命令",
		["deleting alias \"/%s\" (previously aliased as \"/%s\")"] = "删除替换词\"/%s\"(先前被命名为\"/%s\")",
		["Display extra information in the chat frame when commands are dealiased"] = "当命令取消替换名时在聊天框显示额外信息",
		["Don't overwrite existing aliases when using /addalias"] = "使用/addalias时不能覆盖一个已存在的替换词",
		["Expand aliases as you are typing"] = "输入时展开替换词",
		["find aliases matching a given search term"] = "寻找匹配替换词的特定搜索字词",
		["findaliases"] = "寻找替换词",
		["infinite loop detected for alias /%s - ignoring"] = "死循环替换名/%s - 忽略",
		["inline"] = "内联",
		["list all aliases"] = "列出全部替换词",
		["listaliases"] = "替换词一览表",
		["matching aliases found: %d"] = "发现匹配替换词:%d",
		["module_desc"] = "添加命令/alias,用Unix alias command类似的方法替换来消减命令",
		["module_name"] = "替换词",
		["No aliases have been defined"] = "无替换名被定义",
		["noclobber"] = "无冲突",
		["noclobber set - skipping new alias: /%s already expands to /%s"] = "无冲突设置-跳过新的替换词:/%s已经扩展到/%s",
		["Options"] = "选项",
		["Options for altering the behaviour of Alias"] = "变更替换词状况的选项",
		["overwriting existing alias \"/%s\" (was aliased to \"/%s\")"] = "覆盖现有替换词\"/%s\"(替换为\"/%s\")",
		["refusing to alias \"/%s\" to anything in the interests of Not Buggering Everything Up"] = "拒绝替换词\"/%s\"的任何权利以不破坏重要的东西",
		["remove an alias"] = "移除一个替换词",
		["There is no alias current defined for \"%s\""] = "无任何替换词目前定义为\"%s\"",
		["total aliases: %d"] = "替换词总数:%d",
		["tried to show value for alias \"%s\" but undefined in module.Aliases!"] = "模块未定义试图显示的替换词的值\"%s\".替换词!",
		["unalias"] = "无替换词",
		["verbose"] = "详细",
		["warnUser() called with nil argument!"] = "您注意()为无效参数!",
		["warnUser() called with zero length string!"] = "您注意()为零长度字符串!",
	},
	["AltNames"] = {
		["%d alts found for %s: %s"] = "%d 马甲找到 %s: %s",
		["%s alts imported from LOKWhoIsWho"] = "%s马甲从LOKWhoIsWho导入",
		["%s total alts linked to mains"] = "%s全部马甲联结到本尊",
		["(.-)'s? [Aa]lt"] = true,
		["([^%s%p%d%c%z]+)'s alt"] = true,
		[".*[Aa]lts?$"] = true,
		["<alt name> (eg, /altnames del Personyouthoughtwassomeonesaltbutreallyisnt)"] = "<马甲名称> (例, /altnames del 某个你以为是但不是的某人分身)",
		["<main> (eg /altnames listalts Fin)"] = "<本尊> (例 /altnames listalts 顶尖战士)",
		["<search term> (eg, /altnames find fin)"] = "<搜索条件>(例, /altnames find 顶尖战士)",
		["Alt"] = "马甲",
		["alt"] = "马甲",
		["alt name exists: %s -> %s; not overwriting as set in preferences"] = "马甲名称存在: %s -> %s;没有覆盖参数设置",
		["AltNames"] = "马甲名称",
		["Alts:"] = "马甲:",
		["autoguildalts_desc"] = [=[后台自动从公会信息中导入
]=],
		["autoguildalts_name"] = "自动导入公会名",
		["Be quiet"] = "禁言",
		["character removed: %s"] = "删除角色: %s",
		["Class colour"] = "职业颜色",
		["Clear all"] = "全部清除",
		["Clear all links between alts and main names."] = "清除所有马甲与本尊名称间的联结",
		["Colour"] = "颜色",
		["Delete a character's link to another character as their main."] = "删除一个角色作为另一个角色本尊的联结",
		["Delete alt"] = "删除马甲",
		["Disabled"] = "禁用",
		["Display a player's alts in the tooltip"] = "在提示里显示玩家的马甲名称",
		["Display a player's main name in the tooltip"] = "在提示里显示玩家的本尊名称",
		["Display main names in the same colour as that of the alt's class (taking the data from the PlayerNames module if it is enabled)"] = "用和马甲职业相同的颜色显示本尊名称(如果玩家名称模块启用,从中采集数据)",
		["Display main names in the same colour as that of the main's class (taking the data from the PlayerNames module if it is enabled)"] = "用和本尊职业相同的颜色显示本尊名称(如果玩家名称模块启用,从中采集数据)",
		["Don't overwrite existing alt <-> main links when importing or adding new alts."] = "不要在导入或添加新马甲时覆盖已有的马甲 <-> 本尊",
		["Don't overwrite existing links"] = "不要覆盖已有联结",
		["don't use"] = "不使用",
		["Don't use data from the PlayerNames module at all"] = "不要从玩家名称模块使用数据",
		["ERROR: some function sent a blank message!"] = "错误:一些参数发送了一条空白信息!",
		["Find characters"] = "发现角色",
		["Fix alts"] = "修复马甲",
		["Fix corrupted entries in your list of alt names."] = "在你的马甲名称列表里修复损坏的条目",
		["Found alt: %s => main: %s"] = "发现马甲: %s => 本尊: %s",
		["guild member alts found and imported: %s"] = "公会成员马甲发现并导入: %s",
		["Import from Guild Greet database"] = "从公会欢迎数据库导入",
		["Import from guild roster"] = "从工会名单导入",
		["Import options"] = "导入选项",
		["Imports alt names from a Guild Greet database, if present"] = "导入马甲名称从公会欢迎数据库,如果可以",
		["Imports alt names from the guild roster by checking for members with the rank \"alt\" or \"alts\", or guild / officer notes like \"<name>'s alt\""] = "导入马甲名称从公会名单中检查到的成员头衔为“马甲”或“马甲们”的,或者公会官员备注为\"<某某>的马甲\"",
		["Imports data from LOKWhoIsWho, if present (drop your SavedVariablesLOKWhoIsWho.lua in the Prat directory to be able to use this)."] = "从LOKWhoIsWho导入数据,如果可以(你的Prat目录丢失SavedVariablesLOKWhoIsWho.lua可以使用这个).",
		["Left"] = "左边",
		["link <alt name> <main name> (eg, /altnames link Fin Finjathealtoffin)"] = "联结 <马甲名称> <本尊名称>(例,/altnames link 顶尖战士 苍天哥)",
		["Link alt"] = "联结马甲",
		["Link someone's alt character with the name of their main."] = "联结某人的马甲角色与他们的本尊名称",
		["linked alt %s => %s"] = "联结的马甲 %s => %s",
		["List all"] = "全部列出",
		["List all links between alts and their main names."] = "列出所有马甲与他们的本尊名称间的联结",
		["List alts"] = "列出马甲",
		["List alts for a given character"] = "列出特定角色的马甲",
		["LOKWhoIsWho data not found"] = "未发现LOKWhoIsWho数据",
		["LOKWhoIsWho import"] = "LOKWhoIsWho导入",
		["LOKWhoIsWho lua file not found, sorry."] = "未发现LOKWhoIsWho权限文件,息怒",
		["Main"] = "本尊",
		["main"] = "本尊",
		["Main name position"] = "本尊名称位置",
		["Main:"] = "本尊:",
		["mainpos_desc"] = "当角色在马甲上时本尊名称的显示位置",
		["mainpos_name"] = "本尊名称位置",
		["module_desc"] = "把某人的马甲角色联结到他们的本尊,在聊天信息中的名字旁边显示(默认=关闭).",
		["no alts found for character "] = "未发现角色马甲",
		["no alts or mains found matching \"%s\""] = "未发现匹配\"%s\"马甲或本尊",
		["No arg string given to :addAlt()"] = "无字符串参数到:addAlt()",
		["no characters called \"%s\" found; nothing deleted"] = "未发现称作\"%s\"角色;无删除",
		["No Guild Greet database found"] = "未发现公会欢迎数据库",
		["No main name supplied to link %s to"] = "没有本尊名称以供联结%s",
		["no matches found"] = "无匹配发现",
		["quiet"] = "安静",
		["quiet_desc"] = "是否在聊天框报告",
		["quiet_name"] = "无声_名字",
		["Right"] = "右边",
		["Search the list of linked characters for matching main or alt names."] = "搜索已联结的角色列表匹配本尊或马甲名称",
		["searched for: %s - total matches: %s"] = "搜索: %s - 完全匹配: %s",
		["Show alts in tooltip"] = "在提示里显示马甲",
		["Show main in tooltip"] = "在提示里显示本尊",
		["Start"] = "起始",
		["The colour of an alt's main name that will be displayed"] = "马甲的本尊名称将显示的颜色",
		["Use class colour (from the PlayerNames module)"] = "使用职业颜色(从玩家名称模块)",
		["use class colour of alt"] = "马甲职业的颜色",
		["use class colour of main"] = "本尊职业的颜色",
		["Use LibAlts Data"] = "使用LibAlts数据",
		["Use the data available via the shared alt information library."] = "使数据可通过共享的马甲信息库",
		["Various ways to import a main's alts from other addons"] = "用各种途径从其他插件导入本尊的马甲",
		["warning: alt %s already linked to %s"] = "注意:马甲%s已联结到%s",
		["Where to display a character's main name when on their alt."] = "当角色在马甲上时本尊名称显示何处",
		["Whether to report to the chat frame or not."] = "是否报告在聊天框",
		["You are not in a guild"] = "你不在一个公会里",
		["You have not yet linked any alts with their mains."] = "尚未有任何马甲联结到他们的本尊",
	},
	["Bubbles"] = {
		["color_desc"] = "把聊天泡泡颜色设为与聊天类型一致",
		["color_name"] = "泡泡颜色",
		["font_desc"] = "使用与聊天框相同的字体",
		["font_name"] = "使用聊天字体",
		["fontsize_desc"] = "设置聊天泡泡字体大小",
		["fontsize_name"] = "字体大小",
		["format_desc"] = "聊天泡泡文字应用 Prat's 格式",
		["format_name"] = "格式化文字",
		["icons_desc"] = "在聊天泡泡里显示团队图标。",
		["icons_name"] = "显示团队图标",
		["module_desc"] = "聊天泡泡相关自定义",
		["module_name"] = "泡泡",
		["shorten_desc"] = [=[缩短每个聊天气泡至一行. 鼠标移过气泡时展开文本.
]=],
		["shorten_name"] = "缩短气泡",
		["transparent_desc"] = "隐藏聊天泡泡中的背景和边框材质.(撤销此选项需要/reload)",
		["transparent_name"] = "透明泡泡",
	},
	["Buttons"] = {
		["alpha_desc"] = "设置所有聊天窗口的聊天目录及箭头透明度",
		["alpha_name"] = "设置透明度",
		["Buttons"] = "按钮",
		["Chat window button options."] = "聊天窗口按钮选项",
		["chatmenu_desc"] = "聊天菜单开与关",
		["chatmenu_name"] = "聊天菜单_名称",
		["Default"] = "默认",
		["Right, Inside Frame"] = "框体内右侧",
		["Right, Outside Frame"] = "框体外右侧",
		["scrollReminder_desc"] = "当聊天信息不在底部时显示提醒按钮",
		["scrollReminder_name"] = "显示向下滚动提醒",
		["Set Position"] = "设置位置",
		["Sets position of chat menu and arrows for all chat windows."] = "设置所有聊天窗口的聊天目录及箭头位置",
		["Show Arrows"] = "显示箭头",
		["Show Chat%d Arrows"] = "显示聊天%d箭头",
		["showbnet_desc"] = "显示社交菜单",
		["showbnet_name"] = "显示社交菜单",
		["showmenu_desc"] = "显示聊天菜单",
		["showmenu_name"] = "显示菜单",
		["showminimize_desc"] = "显示最小化按钮",
		["showminimize_name"] = "显示最小化按钮",
		["Toggle showing chat arrows for each chat window."] = "为各个聊天窗口显示上下翻页箭头",
		["Toggles navigation arrows on and off."] = "切换导航箭头开与关",
	},
	["ChannelColorMemory"] = {
		["(%w+)%s?(.*)"] = true,
		["ChannelColorMemory"] = "频道颜色存储",
		["Remembers the colors of each channel name."] = "记住每个频道名称的颜色",
	},
	["ChannelNames"] = {
		["%s settings."] = "%s 设置.",
		["<string>"] = "<字符串>",
		["Add Channel Abbreviation"] = "添加频道缩写",
		["addnick_desc"] = "添加一个缩写的频道名称.名称前缀为 '#' 来包含频道数字(例如'#贸易')",
		["Blank"] = "空白",
		["chanlink_desc"] = "使频道可以点击链接打开频道聊天",
		["chanlink_name"] = "创建频道链接",
		["Channel %d"] = "频道 %d",
		["Channel name abbreviation options."] = "频道名称缩写选项",
		["ChannelNames"] = "频道名称",
		["channelnick_desc"] = "频道缩写",
		["channelnick_name"] = "频道缩写",
		["Clear Channel Abbreviation"] = "清除频道缩写",
		["Clears an abbreviated channel name."] = "清除一个频道名称缩写",
		["colon_desc"] = "频道后添加冒号",
		["colon_name"] = "显示冒号",
		["Dont display the channel/chat type name"] = "不要显示频道/聊天分类名称",
		["otheropts_desc"] = "额外的频道格式选项，以及频道链接控制",
		["otheropts_name"] = "其他选项",
		["Remove Channel Abbreviation"] = "移除频道缩写",
		["Removes an an abbreviated channel name."] = "移除一个频道名称缩写",
		["Replace"] = "替换",
		["Set"] = "设置",
		["space_desc"] = "频道后添加空格",
		["space_name"] = "显示空格",
		["Toggle replacing this channel."] = "替换频道",
		["Use a custom replacement for the chat %s text."] = "使用自定义替换此聊天 %s 文本",
	},
	["ChannelSticky"] = {
		["Channel"] = "频道",
		["ChannelSticky"] = "频道粘连",
		["Chat channel sticky options."] = "聊天频道粘连选项",
		["ChatType"] = "聊天分类",
		["Per chat type options."] = "每个聊天分类选项",
		["smartgroup_desc"] = "添加一个/gr命令用来自动选择正确的聊天分类,比如团队,小队或战场",
		["smartgroup_name"] = "智能分组",
		["Sticky %s"] = "粘连 %s",
		["Sticky Per Chat Frame"] = "粘连每个聊天框",
		["Toggle remembering the chat type last used per chat frame."] = "记住每个聊天框上一次使用的聊天分类",
		["Toggles sticky on and off for %s."] = "切换%s的粘连开关",
	},
	["ChatFrames"] = {
		["Chat window frame parameter options"] = "聊天窗口参数选项",
		["framealpha_desc"] = "控制鼠标移过时聊天框架的透明度.",
		["framealpha_name"] = "设定聊天框架透明度",
		["Frames"] = "框架",
		["mainchatonload_desc"] = "加载时自动选择并激活第1个聊天框架.",
		["mainchatonload_name"] = "加载时焦点于主聊天框架.",
		["maxchatheight_desc"] = "设定所有聊天窗口的最大高度.",
		["maxchatheight_name"] = "设定最大高度",
		["maxchatwidth_desc"] = "设定所有聊天窗口的最大宽度.",
		["maxchatwidth_name"] = "设定最大宽度",
		["minchatheight_desc"] = "设定所有聊天窗口的最小高度.",
		["minchatheight_name"] = "设定最小高度.",
		["minchatwidth_desc"] = "设定所有聊天窗口的最小宽度.",
		["minchatwidth_name"] = "设定最小宽度.",
		["rememberframepositions_desc"] = "记住聊天框的位置,在加载时恢复.",
		["rememberframepositions_name"] = "记住位置",
		["removeclamp_desc"] = "允许聊天框架移动至屏幕边缘齐平",
		--Translation missing 
		-- ["removeclamp_name"] = "",
	},
	["ChatLink"] = {
		["gem_desc"] = "启动宝石镶嵌模式",
		["gem_name"] = "宝石镶嵌",
		["module_desc"] = "聊天频道物品链接选项",
		["module_info"] = "这个模块允许你把物体链接发到非交易频道，比如通用、私人、或者你的种族频道。对于没有安装解码扩展的用户来看, 就像是乱码，所以注意礼貌。",
		["module_name"] = "频道链接",
		["Trade"] = "商业",
	},
	["ChatLog"] = {
		["A module to automaticaly enable chat and combat logging."] = "自动启用聊天和战斗记录的模块",
		["Chat log recorded to <WoW Installation>\\Logs\\WoWChatLog.txt only upon logout."] = "退出游戏时保存聊天记录在<魔兽世界安装目录>\\Logs\\WoWChatLog.txt",
		["Chat Log: Disabled"] = "聊天记录：禁用",
		["Chat Log: Enabled"] = "聊天记录：启用",
		["ChatLog"] = "聊天记录",
		["Combat log recorded to <WoW Installation>\\Logs\\WoWCombatLog.txt only upon logout."] = "退出游戏后保存战斗记录在<魔兽世界安装目录>\\Logs\\WoWCombatLog.txt",
		["Combat Log: Disabled"] = "战斗记录：禁用",
		["Combat Log: Enabled"] = "战斗记录：启用",
		["quiet_desc"] = "模块启用或改变记录设置时不显示任何信息",
		["quiet_name"] = "禁止反馈信息",
		["Toggle Chat Log"] = "聊天记录",
		["Toggle chat log on and off."] = "切换聊天记录开关",
		["Toggle Combat Log"] = "战斗记录",
		["Toggle combat log on and off."] = "切换战斗记录开关",
	},
	["ChatTabs"] = {
		["Active Alpha"] = "活跃的透明度",
		["All"] = "全部",
		["Always"] = "总是",
		["Chat window tab options."] = "聊天窗口页签选项",
		["Default"] = "预设",
		["disableflash_desc"] = "禁用聊天页签闪动",
		["disableflash_name"] = "禁用闪动",
		["Hidden"] = "隐藏",
		["Individual"] = "个别",
		["Not Active Alpha"] = "非活跃的透明度",
		["preventdrag_desc"] = "阻止聊天页签随鼠标拖动",
		["preventdrag_name"] = "拖动阻止",
		["Set ChatFrame%d Display Mode"] = "设置聊天框%d显示模式",
		["Set Display Mode"] = "设置显示模式",
		["Set tab display mode for each chat window."] = "设置每个聊天窗口的页签显示模式.检查(开),不检查(关),暂停检查(预设)",
		["Set tab display to always, hidden or the Blizzard default."] = "设置页签永久显示,隐藏或暴雪预设",
		["Sets alpha of chat tab for active chat frame."] = "设置活跃聊天框页签透明度",
		["Sets alpha of chat tab for not active chat frame."] = "设置非活跃聊天框页签透明度",
		["Tabs"] = "页签",
	},
	["Clear"] = {
		["Adds clear text slash commands (/clear)(/cls)(/clearall)(/clsall)."] = "添加清除文本斜杠命令(/clear)(/cls)(/clearall)(/clsall).",
		["Clear"] = "清除",
		["Clearall"] = "全部清除",
		["Clears all chat frames."] = "清除所有聊天框架",
		["Clears the current chat frame."] = "清除当前聊天框架",
	},
	["CopyChat"] = {
		[" Text"] = "文本",
		["BBCode"] = "BB代码",
		["BOTTOMLEFT"] = "左下",
		["BOTTOMRIGHT"] = "右下",
		["buttonpos_desc"] = "复制按钮在聊天框的位置",
		["buttonpos_name"] = "按钮位置",
		["ChatFrame"] = "聊天框",
		["Copy all of the text in the selected chat frame into an edit box"] = "在选定的聊天框复制全部文本到输入框",
		["Copy Text"] = "复制文本",
		["Copy Text Format"] = "复制文本格式",
		["Copy text from the active chat window."] = "从活跃的聊天窗口复制文本",
		["Copy To Editbox"] = "复制到编辑框",
		["CopyChat"] = "聊天复制",
		["HTML"] = "超文本标记语言",
		["Message From : %s"] = "信息来自: %s",
		["Plain"] = "简洁",
		["Should the copied text be plain, or formatted so you can see the colors."] = "如果用简洁或排版复制的文本,你可以看到颜色",
		["showbutton_desc"] = "在聊天框显示按钮",
		["showbutton_name"] = "复制按钮",
		["TOPLEFT"] = "左上",
		["TOPRIGHT"] = "右上",
		["Wowace.com Forums"] = "Wowace.com论坛",
	},
	["CustomFilters"] = {
		["<string>"] = true,
		["Add a pattern to search for."] = "添加一个搜索模板",
		["Add Pattern"] = "添加模板",
		["Block Message"] = "消息阻止",
		["Channel Data"] = "频道数据",
		["Channel to send output text to."] = "频道发送输出文本",
		["Enabled"] = "启用",
		["Extra data for WHISPER (target) and CHANNEL (channel name or num)"] = "密语(目标)和频道(频道名称或数字)的扩展数据",
		["Filter Name"] = "过滤器名字",
		["Forward"] = "转发",
		["Forward the message to a chat channel."] = "转发信息到聊天频道",
		["Forward the message to a custom chat channel."] = "输出到一个私人频道",
		["ForwardCustom"] = "自定义传送",
		["ForwardMessage"] = "信息转发",
		["ForwardMessageCustom"] = "私有频道",
		["Hilight Color"] = "颜色高亮",
		["Hilight Match Text"] = "高亮匹配文本",
		["Inbound"] = "输入范围",
		["inchannels_desc"] = "在当前频道搜索",
		["inchannels_name"] = "搜索频道",
		["Is this pattern enabled for use?"] = "这个样式启用了吗？",
		["Match Options"] = "适配选项",
		["module_desc"] = "支持自定义过滤的模块",
		["module_name"] = "自定义过滤",
		["Only output the message portion of the chat text, leave out the channel, and playername etc."] = "仅在聊天文本中输出部分信息，移除频道和玩家姓名等",
		["Outbound"] = "输出范围",
		["Output Channel"] = "输出频道",
		["Output Message Only"] = "只输出信息",
		["Pattern Info"] = "样式信息",
		["Pattern Options"] = "模块选项",
		["Play a sound when this message is output to the chatframe"] = "当信息在聊天框输出时播放声音",
		["Play Sound"] = "播放声音",
		["Prevent the message from being displayed"] = "阻止信息被现实",
		["Remove an existing pattern."] = "移除现有模板",
		["Remove Pattern"] = "移除模板",
		["Replacement Text"] = "替换文本",
		["Search Format String"] = "搜索格式字符串",
		["Search Pattern"] = "搜索模板",
		["Secondary Output"] = "二次输出",
		["Send to a secondary output"] = "发送二次输出",
		["Supplied pattern is a format string instead of a pattern"] = "支持模板是格式字符串而非模板",
		["Your name for this filter"] = "这个过滤器的名字",
	},
	["Editbox"] = {
		["Attach edit box to..."] = "把输入框附加到……",
		["Attach to..."] = "附加到……",
		["Background color"] = "背景颜色",
		["Background Inset"] = "背景嵌入",
		["Background texture"] = "背景纹理",
		["Border color"] = "边框颜色",
		["Border texture"] = "边框纹理",
		["Bottom"] = "底部",
		["Color border by channel"] = "频道颜色边框",
		["currently_broken_alt_behavior"] = [=[在现在WoW客户端里，方向键的行为已损坏，

使用Alt+上和Alt+下来替代上下键浏览历史]=],
		["Edge Size"] = "边缘尺寸",
		["Editbox"] = "输入框",
		["Editbox options."] = "输入框选项",
		["Font"] = "字体",
		["Free-floating"] = "自由浮动",
		["Free-floating, Locked"] = "自由浮动，锁定",
		["Requires the Alt key to be held down to move the cursor in chat"] = "需要在聊天中按住Alt键移动光标",
		["Select the font to use for the edit box"] = "选择输入框的字体",
		["Sets the frame's border color to the color of your currently active channel"] = "设置边框颜色到你当前激活的频道颜色",
		["Tile Size"] = "平铺尺寸",
		["Top"] = "顶部",
		["Use Alt key for cursor movement"] = "使用Alt键令光标移动",
	},
	["EventNames"] = {
		["allevents_desc"] = "为所有聊天事件开启Phat处理",
		["allevents_name"] = "处理所有事件",
		["Chat window event name options."] = "聊天窗口项目名称选项",
		["EventNames"] = "事件名称",
		["Show"] = "显示",
		["Show events on chatframes"] = "在聊天框显示事件",
		["show_desc"] = "显示事件名称在每个聊天窗口",
		["show_name"] = "显示事件名称",
	},
	["Fading"] = {
		["duration_desc"] = "设置聊天窗口文本消隐前等待秒数",
		["duration_name"] = "设置消隐延时(秒)",
		["module_desc"] = "聊天窗口文本消隐选项",
		["module_name"] = "消隐",
		["textfade_desc"] = "为每个聊天窗口启用文本消隐",
		["textfade_name"] = "启用消隐",
	},
	["Filtering"] = {
		["A module to provide basic chat filtering."] = "提供基础的聊天过滤的模块",
		["afkdnd_desc"] = "节流AFK和DND消息.",
		["afkdnd_name"] = "节流AFK和DND消息.",
		["bgjoin_desc"] = "过滤战场频道离开/加入信息",
		["bgjoin_name"] = "过滤战场出/入",
		["Filtering"] = "过滤",
		["leavejoin_desc"] = "滤掉频道离开/加入信息",
		["leavejoin_name"] = "过滤频道离开/加入",
		["notices_desc"] = "滤掉其他自定义频道通知信息,例如改变频道所有者",
		["notices_name"] = "频道通知过滤",
		["tradespam_desc"] = "节流消息以防止连续多次收到同样的消息",
		["tradespam_name"] = "屏蔽垃圾",
	},
	["Font"] = {
		["Auto Restore Font Size"] = "自动还原字体尺寸",
		["Chat window font options."] = "聊天窗口字体选项",
		["Font"] = "字体",
		["monochrome_desc"] = "单色字体",
		["monochrome_name"] = "单色",
		["None"] = "无",
		["Outline"] = "轮廓",
		["outlinemode_desc"] = "字体轮廓样式设置",
		["outlinemode_name"] = "轮廓样式",
		["rememberfont_desc"] = "记住您的字体选择并在启动时恢复",
		["rememberfont_name"] = "记住字体",
		["Set ChatFrame%d Font Size"] = "聊天框%d字体尺寸",
		["Set Font Face"] = "字体设置",
		["Set Font Size"] = "设置字体大小",
		["Set Separately"] = "个别设置",
		["Set text font size for each chat window."] = "每个聊天窗口的文本字体尺寸",
		["Set text font size."] = "文本字体尺寸",
		["Set the text font face for all chat windows."] = "所有聊天窗口的文本字体",
		["shadowcolor_desc"] = "阴影效果的颜色",
		["shadowcolor_name"] = "阴影色彩",
		["Thick Outline"] = "厚轮廓",
		["Toggle setting options separately for each chat window."] = "每个聊天窗口的个别选项设置",
		["Workaround a Blizzard bug which changes the font size when you open a system menu."] = "当你打开系统菜单时改变暴雪错误提示字体尺寸",
	},
	["History"] = {
		["Chat history options."] = "历史聊天记录选项",
		["Color GMOTD"] = "每日公会信息颜色",
		["Colors the GMOTD label"] = "为每日公会信息标签着色",
		["delaygmotd_desc"] = "延迟每日公会信息直到起始垃圾信息显示完毕为止",
		["delaygmotd_name"] = "延迟 GMOTD",
		["divider"] = "========== 回卷结束 ==========",
		["History"] = "历史记录",
		["Maximum number of lines of command history to save."] = "存储命令记录最大行数",
		["Save Command History"] = "命令记录存储",
		["Saves command history between sessions (for use with alt+up arrow or just the up arrow)"] = "存储会话之间命令的历史记录(使用alt+上箭头键或仅上箭头键)",
		["Scrollback"] = "回卷",
		["Scrollback Options"] = "回滚选项",
		["scrollbacklen_desc"] = "聊天内容回滚缓冲数量",
		["scrollbacklen_name"] = "回卷长度",
		["Set Chat Lines"] = "聊天行设置",
		["Set Command History"] = "命令历史记录",
		["Set the number of lines of chat history for each window."] = "为每个聊天窗口设置聊天历史记录行数",
		["Store the chat lines between sessions"] = "在会话之间存储聊天内容",
	},
	["KeyBindings"] = {
		["Channel %d"] = "频道 %d",
		["Copy Selected Chat Frame"] = "复制选定的聊天框体",
		["Guild Channel"] = "公会频道",
		["Instance Channel"] = "战场频道",
		["Next Chat Tab"] = "下一个聊天标签",
		["Officer Channel"] = "官员频道",
		["Party Channel"] = "小队频道",
		["Prat CopyChat"] = "Prat聊天复制",
		["Prat Keybindings"] = "Prat键位绑定",
		["Prat TellTarget"] = "Prat目标告知",
		["Raid Channel"] = "团队频道",
		["Raid Warning Channel"] = "团队警告频道",
		["Say"] = "说",
		["Smart Group Channel"] = "频道智能分组",
		["TellTarget"] = "目标告知",
		["Whisper"] = "密语",
		["Yell"] = "喊话",
	},
	["OriginalButtons"] = {
		["alpha_desc"] = "设置所有聊天窗口里聊天菜单和聊天箭头的透明度。",
		["alpha_name"] = "设置透明度",
		["buttonframe_desc"] = "切换框架菜单按钮开关.",
		["buttonframe_name"] = "显示框架按钮",
		["ChannelNames"] = "频道名字",
		["Chat window button options."] = "聊天窗口按钮选项.",
		["chatmenu_desc"] = "开启或关闭聊天菜单。",
		["chatmenu_name"] = "显示聊天菜单",
		["Default"] = "默认",
		["Original Buttons"] = "初始按钮",
		["reflow_desc"] = "聊天框文字应该此按钮而非位于其下方",
		["reflow_name"] = "文字环绕",
		["reminder_desc"] = "当不在聊天窗口底部时显示提醒按钮。",
		["reminder_name"] = "显示鼠标滚动提醒器",
		["Right, Inside Frame"] = "右边,框体内",
		["Right, Outside Frame"] = "右边,框体外",
		["Set Position"] = "设置位置",
		["Sets position of chat menu and arrows for all chat windows."] = "设置所有聊天窗口的聊天菜单和箭头的位置.",
		["Show Arrows"] = "显示箭头",
		["Show Chat%d Arrows"] = "显示 聊天框%d 箭头",
		["Toggle showing chat arrows for each chat window."] = "在每个聊天窗口显示聊天箭头。",
		["Toggles navigation arrows on and off."] = "开启或关闭导航箭头。",
	},
	["OriginalEditbox"] = {
		["Autohide"] = "自动隐藏",
		["BACKGROUND"] = "背景",
		["Bar colour"] = "工具条颜色",
		["Border colour"] = "边框颜色",
		["Border width"] = "边框宽度",
		["Bottom"] = "按钮",
		["Click the edit box to open it up for editing. Only available if Autohide is disabled."] = "点击编辑框以打开进行编辑. 仅自动隐藏关闭时可用.",
		["Clickable"] = "可点击",
		["DIALOG"] = "对话框",
		["Editbox options."] = "输入框选项",
		["Enable Arrowkeys"] = "允许方向键",
		["Enable using arrowkeys in editbox without the alt key."] = "在编辑框中开启不使用alt键的方向键.",
		["Hide Border"] = "隐藏边框",
		["Hide the border around the edit box."] = "隐藏编辑框周围的边框.",
		["Hide the edit box after you have pressed enter."] = "按回车键后隐藏编辑框.",
		["HIGH"] = "高",
		["Lock editbox position if undocked."] = "非停靠时锁定编辑框位置.",
		["Lock Position"] = "锁定位置",
		["LOW"] = "低",
		["MEDIUM"] = "中",
		["OriginalEditbox"] = "原始编辑框",
		["Padding"] = "填白",
		["Set Alpha"] = "设置透明度",
		["Set Position"] = "设置位置",
		["Set Strata"] = "设置阶层",
		["Set the alpha of the editbox."] = "设置编辑框的透明度.",
		["Set the amount of padding inside the edit box"] = "设置编辑框的内填白值.",
		["Set the edit box background colour"] = "设置编辑框的背景颜色.",
		["Set the edit box border colour"] = "设置编辑框边框的颜色.",
		["Set the frame strata of the editbox."] = "设置编辑框的框架阶层.",
		["Set the position of the editbox."] = "设置编辑框的位置.",
		["Set the texture of the chat edit box"] = "设置聊天编辑框的材质.",
		["Set the width of the edit box's border"] = "设置编辑框边框的宽度.",
		["Set the width of the editbox."] = "设置编辑框的宽度.",
		["Set Width (NB: only enabled if the editbox is undocked)"] = "设置宽度 (仅编辑框未停靠时开启)",
		["Texture"] = "材质",
		["Top"] = "顶部",
		["Undocked"] = "非停靠",
	},
	["Paragraph"] = {
		["adjustlinks_desc"] = "调整链接以恢复在中心或右对齐文本上的可点击性",
		["adjustlinks_name"] = "修复玩家/物品位置链接",
		["Center"] = "中心",
		["Chat window paragraph options."] = "聊天窗口段落选项",
		["justification_desc"] = "为每个聊天窗口设置水平对齐",
		["justification_name"] = "设置对齐",
		["Left"] = "左",
		["Line Spacing"] = "行距",
		["Paragraph"] = "段落",
		["Right"] = "右",
		["Set the line spacing for all chat windows."] = "为所有聊天窗口设置行间距",
	},
	["PlayerNames"] = {
		["Actively Query Player Info"] = "活跃的查询玩家信息",
		["Angled"] = "折角",
		["Brackets"] = "括号",
		["Brackets Common Color"] = "同一颜色括号",
		["Brackets Use Common Color"] = "使用同一颜色括号",
		["Class"] = "职业",
		["Color by Level Difference"] = "彩色的等级差别",
		["coloreverywhere_desc"] = "彩色显示聊天信息中出现的玩家姓名",
		["coloreverywhere_name"] = "彩色显示姓名在所有地方",
		["Enable Alt-Invite"] = "启用Alt-邀请",
		["Enable Invite Links"] = "启用邀请链接",
		["Enable TabComplete"] = "启用Tab键补全",
		["hoverhilight_desc"] = "当悬停在玩家链接上时高亮该玩家的聊天语句",
		["hoverhilight_name"] = "悬停高亮",
		["How to color other player's level."] = "如何着色其他玩家的等级",
		["How to color player's name."] = "如何着色玩家的名称",
		["Keep Info"] = "保持信息",
		["Keep Lots Of Info"] = "保持大量的信息",
		["Keep player information between session for all players except cross-server players"] = "为除跨服玩家外的所有玩家在会话间保持玩家信息",
		["Keep player information between session, but limit it to friends and guild members."] = "在会话间保持玩家信息,但仅限于朋友和公会成员",
		["Let TasteTheNaimbow set the common color for unknown player names."] = "让TasteTheNaimbow(插件)为未知玩家名称设置公共颜色",
		["Level Color Mode"] = "等级着色模式",
		["linkifycommon_desc"] = "自助链接公共信息",
		["linkifycommon_name"] = "自助链接公共信息",
		["No additional coloring"] = "无额外着色",
		["None"] = "无",
		["Player Color Mode"] = "玩家着色模式",
		["Player name formating options."] = "玩家名称格式选项",
		["PlayerNames"] = "玩家名称",
		["Prat_Playernames: Stored Player Data Cleared"] = "Prat_玩家名称: 玩家数据存储已清除",
		["Query the server for all player names we do not know. Note: This happpens pretty slowly, and this data is not saved."] = "为所有未知玩家查询服务器,注意:这将非常缓慢,并且数据不会被存储",
		["Random"] = "随机",
		["realidcolor_desc"] = "实名名字颜色",
		["realidcolor_name"] = "实名颜色",
		["Reset Settings"] = "重置设置",
		["Restore default settings, and delete stored character data."] = "恢复默认设置并删除已存角色数据",
		["Set common color of unknown player names."] = "设置未知玩家名称共有颜色",
		["Sets common color of brackets to use around player names."] = "设置用来围绕玩家名称的括号颜色",
		["Sets style of brackets to use around player names."] = "设置用来围绕玩家名称的括号类型",
		["Show Group"] = "显示团队",
		["Show Level"] = "显示等级",
		["Show Raid Target Icon"] = "显示团队目标图标",
		["Square"] = "直角",
		["Tab completion : "] = "Tab键补全",
		["tabcomplete_name"] = "可能的名称",
		["Toggle group invites by alt-clicking hyperlinked keywords like 'invite'."] = "组队邀请用alt-点击超链接的关键词如'邀请'",
		["Toggle group invites by alt-clicking on player name."] = "组队邀请用alt-点击玩家名称",
		["Toggle level showing."] = "等级显示",
		["Toggle raid group showing."] = "团队分组显示",
		["Toggle showing the raid target icon which is currently on the player."] = "显示当前玩家的团队目标图标",
		["Toggle tab completion of player names."] = "Tab键补全玩家姓名",
		["Toggle using a common color for brackets around player names."] = "为括号内玩家姓名使用公共颜色",
		["Toggle using a common color for unknown player names."] = "为位置未知玩家名称使用公共颜色",
		["Too many matches (%d possible)"] = "太多的匹配 (%d可能的)",
		["Unknown Common Color"] = "未知公共颜色",
		["Unknown Common Color From TasteTheNaimbow"] = "未知公共颜色自TasteTheNaimbow",
		["Unknown Use Common Color"] = "未知使用公共颜色",
		["Use Channel Color"] = "使用频道颜色",
		["Use Player Color"] = "使用玩家颜色",
		["Use toon name for RealID"] = "使用角色名代替战网ID",
	},
	["PopupMessage"] = {
		["Add Nickname"] = "添加昵称",
		["Adds an alternate name to show in popups."] = "添加一个显示在弹出中的替换名",
		["Clear Nickname"] = "清除昵称",
		["Clears alternate name to show in popups."] = "弹出显示清除候补名称",
		["framealpha_desc"] = "设置完全消失时弹出框体透明度值",
		["framealpha_name"] = "弹出框体透明度",
		["Popup"] = "弹出",
		["PopupMessage"] = "弹出信息",
		["Remove Nickname"] = "移除昵称",
		["Removes an alternate name to show in popups."] = "移除在弹出里显示的候补名称",
		["Set Separately"] = "个别设置",
		["Show All Popups"] = "显示所有弹出",
		["Show Popups"] = "显示弹出",
		["Show Popups for all chat windows."] = "为所有聊天窗后显示弹出",
		["Show Popups for each window."] = "为每个窗口显示弹出",
		["show_desc"] = "在每个窗口显示弹出",
		["show_name"] = "显示弹出",
		["show_perframedesc"] = "弹出开关",
		["show_perframename"] = "显示聊天框体%d弹出",
		["showall_desc"] = "在所有聊天窗口显示弹出",
		["showall_name"] = "显示所有弹出",
		["Shows messages in a popup window."] = "在弹出窗口显示信息",
		["Shows messages with your name in a popup."] = "在弹出中显示含有你名字的信息",
		["Toggle setting options separately for each chat window."] = "分别为每个聊天窗口设置选项",
	},
	["Scroll"] = {
		["Bottom"] = "从下到上",
		["Chat window scrolling options."] = "聊天窗口滚动选项",
		["Control whether text is added to the frame at the top or the bottom."] = "控制文本被添加到框体顶端还是底端",
		["lowdown_desc"] = "为每个聊天窗口自动跳至底端",
		["lowdown_name"] = "启用回到底端",
		["modified_speed"] = "设置 Shift+鼠标滚轮 速度",
		["modified_speed_desc"] = "设定按住Shift键时鼠标滚轮滚动的行数",
		["mousewheel_desc"] = "为每个聊天窗口选取鼠标滚轮支持",
		["mousewheel_name"] = "启用鼠标滚轮",
		["Scroll"] = "滚动",
		["Set Ctrl+MouseWheel Speed"] = "设置Ctrl+鼠标滚轮速度",
		["Set MouseWheel Speed"] = "设置鼠标滚轮速度",
		["Set number of lines mousewheel will scroll when ctrl is pressed."] = "设置按下ctrl时鼠标滚轮滚动行数",
		["Set number of lines mousewheel will scroll."] = "设置鼠标滚轮滚动行数",
		["Set TheLowDown Delay"] = "设置回到底端延迟",
		["Set time to wait before jumping to the bottom of chat windows."] = "设置聊天窗口跳至底部前等待时间",
		["Text scroll direction"] = "文本滚动方向",
		["Top"] = "从上到下",
	},
	["Search"] = {
		["err_notfound"] = "没找到",
		["err_tooshort"] = "搜索文字太短",
		["find_results"] = "查找结果：",
		["module_desc"] = "增加搜索聊天框的能力",
		["module_info"] = [=[此模块增加 /find 和 /findall 命令搜索聊天历史

用法:

 /find <文字>

 /findall <文字>]=],
		["module_name"] = "搜索",
	},
	["ServerNames"] = {
		["autoabbreviate_desc"] = "把服务器名缩到3个字符",
		["autoabbreviate_name"] = "自动缩写",
		["colon_desc"] = "在服务器后添加冒号",
		["colon_name"] = "显示冒号",
		["randomclr_desc"] = "为每个服务器使用随机颜色",
		["randomclr_name"] = "随机颜色",
		["Server name abbreviation options."] = "服务器名称缩写选项",
		["ServerNames"] = "服务器名称",
	},
	["Sounds"] = {
		["A module to play sounds on certain chat messages."] = "在某些聊天信息播放声音的模块",
		["Add a custom channel"] = "添加自定义频道",
		["bn_whisper_desc"] = "为 %s 战网密语提示音乐",
		["bn_whisper_name"] = "战网密语",
		["Custom Channels"] = "自定义频道",
		["group_lead_desc"] = "为团队领袖, 队伍领袖或地下城领袖 %s 发出声音提示",
		["group_lead_name"] = "队伍领袖",
		["guild_desc"] = "公会信息声音",
		["guild_name"] = "公会",
		["incoming"] = "收到",
		["Incoming Sounds"] = "收入声音",
		["officer_desc"] = "官员或自定义频道信息声音",
		["officer_name"] = "官员",
		["outgoing"] = "送出",
		["Outgoing Sounds"] = "送出声音",
		["party_desc"] = " %s 小队信息声音",
		["party_name"] = "小队",
		["Play a sound for a certain channel name (can be a substring)"] = "为特定频道名(可以是子字符串)播放声音",
		["raid_desc"] = " %s 团队或战场分组/领袖信息声音",
		["raid_name"] = "团队",
		["Remove a custom channel"] = "移除自定义频道",
		["Reset settings"] = "重制设置",
		["Restore default settings and resets custom channel list"] = "恢复默认设置并且重制自定义频道列表",
		["Sound selection for incoming chat messages"] = "收到聊天信息声音设置",
		["Sound selection for outgoing (from you) chat messages"] = "送出(由你)聊天信息音乐设置",
		["Sounds"] = "声音",
		["whisper_desc"] = "密语信息 %s 声音",
		["whisper_name"] = "密语",
	},
	["Substitutions"] = {
		["%d total user defined substitutions"] = "%d 全部用户定义的置换",
		["|cffff0000warning:|r subtitution \"%s\" already defined as \"%s\", overwriting"] = "|cffff0000注意:|r 置换\"%s\"已定义为\"%s\",覆盖",
		["<noguild>"] = "<无公会>",
		["<notarget>"] = "<无目标>",
		["A module to provide basic chat substitutions."] = "提供基础聊天替换的模块",
		["Are you sure - this will delete all user defined substitutions and reset defaults?"] = "您确定? - 这样将删除全部用户定义的替换并恢复默认",
		["Are you sure?"] = "您确定？",
		["can't find substitution index for a substitution named '%s'"] = "无法为置换名称 '%s' 找到置换索引",
		["current-prompt"] = "当前值: '%s'Click to paste into the chat.",
		["defined %s: expands to => %s"] = "定义 %s: 扩展到 => %s",
		["Delete all"] = "删除全部",
		["Delete substitution"] = "删除置换",
		["Deletes a user defined substitution"] = "删除用户定义的置换",
		["Deletes all user defined substitutions"] = "删除所有用户定义的置换",
		["female"] = "女",
		["her"] = "她",
		["hers"] = "她的",
		["him"] = "他",
		["his"] = "他的",
		["it"] = "它",
		["its"] = "它的",
		["List of available substitutions"] = "列出有效替换",
		["List of available substitutions defined by this module. (NB: users may define custom values for existing substitutions, but they will revert to the default value if the user definition is deleted.)"] = "在此模块列出有效替换定义..(注:用户可以为已存在的置换定义自定义值,如果用户定义被删除将恢复默认值)",
		["List substitutions"] = "替换列表",
		["Lists all current subtitutions in the default chat frame"] = "在默认聊天框体列出所有当前替换",
		["male"] = "男",
		["MapLoc"] = "地图地点",
		["MapPos"] = "地图坐标",
		["MapXPos"] = "地图X坐标",
		["MapYPos"] = "地图Y坐标",
		["MapZone"] = "地图区域",
		["module:buildUserSubsIndex(): warning: module patterns not defined!"] = "模块:buildUserSubsIndex(): 警告: 模块模板未定义!",
		["MouseoverTargetName"] = "鼠标滑过目标名",
		["NO MATCHFUNC FOUND"] = "未发现匹配函数",
		["no substitution name given"] = "无特定置换名称",
		["no substitution name supplied for deletion"] = "没有删除部分的替换名称支持",
		["no user defined subs found"] = "未发现用户定义置换",
		["no value given for subtitution \"%s\""] = "置换 \"%s\"没有赋值",
		["Options for setting and removing user defined substitutions. (NB: users may define custom values for existing substitutions, but they will revert to the default value if the user definition is deleted.)"] = "设置和移除用户定义置换的选项.(注:用户可以为已存在的置换定义自定义值,如果用户定义被删除将恢复默认值)",
		["PlayerAverageItemLevel"] = "替换",
		["PlayerCurrentMana"] = "玩家当前法力",
		["PlayerHealthDeficit"] = "玩家生命不足",
		["PlayerHP"] = "玩家血量",
		["PlayerManaDeficit"] = "玩家法力不足",
		["PlayerMaxHP"] = "玩家血量上限",
		["PlayerMaxMana"] = "玩家法力上限",
		["PlayerName"] = "玩家名称",
		["PlayerPercentHP"] = "玩家血量百分比",
		["PlayerPercentMana"] = "玩家法力百分比",
		["RandNum"] = "随机数字",
		["removing user defined substitution \"%s\"; previously expanded to => \"%s\""] = "移除用户定义的置换 \"%s\"; 以前扩展到=> \"%s\"",
		["Set substitution"] = "设置置换",
		["Set the value of a user defined substitution (NB: this may be the same as an existing default substitution; to reset it to the default, just remove the user created definition)."] = "设置用户定义替换的值(注:这可能与现有的默认替换相同;若重置为默认,仅移除用户创建的定义)",
		["subname -- NOTE: sub name without the prefix '%'"] = "置换名称 -- 注意: 置换名称无前缀 '%'",
		["subname = text after expansion -- NOTE: sub name without the prefix \"%\""] = "置换名称 = 扩展后文本-- 注意: 置换名称无前缀 \"%\"",
		["substitution: %s defined as => %s"] = "替换: %s 定义为 => %s",
		["Substitutions"] = "置换",
		["TargetClass"] = "目标等级",
		["TargetGender"] = "目标性别",
		["TargetGuild"] = "目标公会",
		["TargetHealth"] = "目标生命",
		["TargetHealthDeficit"] = "目标生命不足",
		["TargetIcon"] = "目标图标",
		["TargetLevel"] = "目标等级",
		["TargetManaDeficit"] = "目标法力不足",
		["TargetName"] = "目标名称",
		["TargetPercentHP"] = "目标血量百分比",
		["TargetPossesive"] = "目标阵营",
		["TargetPronoun"] = "目标代词",
		["TargetRace"] = "目标种族",
		["TargetTargetName"] = "目标的目标名称",
		["unknown sex"] = "未知性别",
		["user defined substition \"%s\" not found"] = "未发现用户定义替换\"%s\" ",
		["User defined substitutions"] = "用户自定义置换",
		["user substitutions index (usersubs_idx) doesn't exist! oh dear."] = "用户替换指数(子用户_索引) 不存在!哦,亲爱的.",
		["usersub_"] = "子用户_",
	},
	["TellTarget"] = {
		["/tt"] = true,
		["Adds telltarget slash command (/tt)."] = "添加目标告知斜杠命令(/tt).",
		["No target selected."] = "无目标被选取",
		["NoTarget"] = "无目标",
		["Target does not exist."] = "目标不存在",
		["Target is not a player."] = "目标不是一个玩家",
		["TellTarget"] = "告知目标",
	},
	["Timestamps"] = {
		["Chat window timestamp options."] = "聊天窗口时间戳选项",
		["colortimestamp_desc"] = "时间戳着色开关",
		["colortimestamp_name"] = "彩色时间戳",
		["Format All Timestamps"] = "所有时间戳格式",
		["HH:MM (12-hour)"] = "时:分 (12-小时)",
		["HH:MM (24-hour)"] = "时:分 (24-小时)",
		["HH:MM:SS (12-hour)"] = "时:分:秒 (12-小时)",
		["HH:MM:SS (24-hour)"] = "时:分:秒 (24-小时)",
		["HH:MM:SS AM (12-hour)"] = "时:分:秒 上午(12-小时)",
		["localtime_desc"] = "本地时间使用开关",
		["localtime_name"] = "使用本地时间",
		["MM:SS"] = "分:秒",
		["Post-Timestamp"] = "后缀-时间戳",
		["Pre-Timestamp"] = "前缀-时间戳",
		["Set the timestamp format"] = "设置时间戳格式",
		["Set Timestamp Color"] = "设置时间戳颜色",
		["Sets the color of the timestamp."] = "设置时间戳颜色",
		["Show Timestamp"] = "显示时间戳",
		["show_desc"] = "为各个窗口选取显示时间戳开关",
		["show_name"] = "显示时间戳",
		["space_desc"] = "在时间戳后添加空格",
		["space_name"] = "显示空格",
		["Timestamps"] = "时间戳",
		["Toggle showing timestamp for each window."] = "为各个窗口切换显示时间戳",
		["twocolumn_desc"] = "放置时间戳在一个单独的栏，文本不包括其中",
		["twocolumn_name"] = "2栏聊天",
	},
	["UrlCopy"] = {
		["Change the color of the URL."] = "更改链接颜色",
		["Color URL"] = "彩色链接",
		["Set Color"] = "设置颜色",
		["Show Brackets"] = "显示括号",
		["Toggle"] = "切换",
		["Toggle showing brackets on and off."] = "开关显示括号",
		["Toggle the module on and off."] = "模块开关",
		["Toggle the URL color on and off."] = "网址颜色开关",
		["URL formating options."] = "网址格式选项",
		["UrlCopy"] = "网址复制",
		["Use Popup"] = "使用弹出",
		["Use popup window to show URL."] = "用弹出窗口显示网址",
	}
}

PL:AddLocale(PRAT_MODULE.name, "zhCN",L)


L=
{
	["display_desc"] = "Control y Aspecto del Marco del Chat",
	["display_name"] = "Mostrar Ajustes",
	["extras_desc"] = "Módulos Extra",
	["extras_name"] = "Material adicional",
	["formatting_desc"] = "Cambiar la forma del aspecto de las líneas",
	["formatting_name"] = "Formato del Chat",
	["load_desc"] = "Controla el comportamiento de carga de este módulo.",
	["load_disabled"] = "Desactivado",
	--Translation missing 
	-- ["load_disabledonrestart"] = "",
	["load_enabled"] = "Activado",
	--Translation missing 
	-- ["load_enabledonrestart"] = "",
	["load_no"] = "No cargar",
	["modulecontrol_desc"] = "Control de las cargas y activaciones de los módulos de Prat",
	["modulecontrol_name"] = "Control de módulos",
	["prat"] = "Prat",
	["reload_required"] = "Esta opción requiere que reinicies la IU para que entre en funcionamiento",
	["AddonMsgs"] = {
		["Addon message options."] = "Opciones de mensaje del Addon.",
		["AddonMsgs"] = "MensajesAddon",
		["show_desc"] = "Alterna el mostrar mensajes ocultos del addon en cada ventana de chat.",
		["show_name"] = "Mostrar Mensajes de Addons",
		["show_perframedesc"] = "Alterna la activación de mostrar mensajes ocultos del addon.",
		["show_perframename"] = "MarchoChat %d AddonMsgsShow",
	},
	["Alias"] = {
		[" - list all aliases; supply <keyword> to search for matching aliases (cmd aliases: /listallaliases)"] = " - lista todos los alias; proporciona una <palabra clave> para buscar alias coincidentes (cmd alias: /listallaliases)",
		["%s() called with blank string!"] = "%s() llamado con cadena vacía! ",
		["%s() called with nil argument!"] = "%s() llamado con argumento nulo! ",
		["/%s aliased to \"/%s\""] = "/%s alias de \"/%s\"",
		["/%s aliased to: /%s"] = "/%s alias de: /%s",
		["<alias> - remove the alias <alias> (cmd aliases: /delalias, /remalias)"] = "<alias> - eliminar el <alias> (cmd alias: /delalias, /remalias",
		["<command>[ <value>] - alias <command> to be executed as <value>, or return the value of the currently defined alias for <command> if <command> has not been assigned a value. eg: \"/alias /examplehello /say hello there\" - typing \"/examplehello\" will now cause your character to say \"hello there\"; \"/alias examplehello\" - s \"/examplehello is aliased to /say hello there\" (cmd aliases: /addalias)"] = "<comando> [<valor>] - alias <comando> a ejecutarse como <valor> o devolver el valor del alias definido actualmente para <comando> si <comando> no se ha asignado un valor. p.ej.: \"/alias /ejemplohola /decir hola allí\" - tecleando \"/ejemplohola\" hará que su carácter diga \"hola allí\"; \"/alias ejemplohola\" -s \"/ejemplohola es alias de /decir hola allí\" (cmd alias: /addalias)",
		["<keyword> - finds all aliases matching <keyword> (cmd aliases: /findalias)"] = "<palabra clave> - encontrar todos los alias coincidentes con <palabra clave> (cmd alias: /findalias",
		["add"] = "Añadir",
		["add an alias"] = "Añadir un alias",
		["alias \"/%s\" does not exist"] = "El alias \"/%s\" no existe",
		--Translation missing 
		-- ["dealiasing command /%s to /%s"] = "",
		--Translation missing 
		-- ["deleting alias \"/%s\" (previously aliased as \"/%s\")"] = "",
		["Display extra information in the chat frame when commands are dealiased"] = "Muestra información extra en el marco de chat cuando los comandos no tienen alias",
		["Don't overwrite existing aliases when using /addalias"] = "No sobreescribir alias existentes usando /addalias",
		["Expand aliases as you are typing"] = "Expandir alias mientras tecleas",
		["find aliases matching a given search term"] = "encontrar alias que coinciden con un término de búsqueda dado",
		["findaliases"] = "encontraralias",
		["infinite loop detected for alias /%s - ignoring"] = "bucle infinito detectado por el alias /%s - ignorando",
		["inline"] = "en línea",
		["list all aliases"] = "Lista de todos los alias",
		["listaliases"] = "listaralias",
		["matching aliases found: %d"] = "alias coincidentes encontrados: %d",
		["module_desc"] = "Agrega el comando /alias, que puede utilizarse para comandos de la barra de alias de una manera similar a la orden de alias de UNIX.",
		["module_name"] = "Alias",
		["No aliases have been defined"] = "Ningún alias ha sido definido",
		--Translation missing 
		-- ["noclobber"] = "",
		--Translation missing 
		-- ["noclobber set - skipping new alias: /%s already expands to /%s"] = "",
		["Options"] = "Opciones",
		["Options for altering the behaviour of Alias"] = "Opciones para alterar el comportamiento de Alias",
		["overwriting existing alias \"/%s\" (was aliased to \"/%s\")"] = "sobrescribiendo alias existente \"/%s\" (era alias de \"/%s\")",
		--Translation missing 
		-- ["refusing to alias \"/%s\" to anything in the interests of Not Buggering Everything Up"] = "",
		["remove an alias"] = "Eliminar un alias",
		["There is no alias current defined for \"%s\""] = "No hay ningún alias definido para \"%s\"",
		["total aliases: %d"] = "total alias: %d",
		["tried to show value for alias \"%s\" but undefined in module.Aliases!"] = "se ha intentado mostrar un valor para el alias \"%s\" pero no está definido en el módulo. ¡Crea un Alias!",
		["unalias"] = "sin alias",
		["verbose"] = "detallado",
		["warnUser() called with nil argument!"] = "warnUser() llamado con argumento nulo!",
		["warnUser() called with zero length string!"] = "warnUser() llamado con cadena de longitud cero!",
	},
	["AltNames"] = {
		["%d alts found for %s: %s"] = "%d alternativos encontrados para %s: %s",
		["%s alts imported from LOKWhoIsWho"] = "%s alternativos importados desde LOKWhoIsWho",
		["%s total alts linked to mains"] = "alternativos total %s vinculados a principales",
		["(.-)'s? [Aa]lt"] = "%f[%a\\192-\\255]([%a\\192-\\255]+)%f[^%a\\128-\\255]'s [Aa]lt",
		["([^%s%p%d%c%z]+)'s alt"] = "%f[%a\\192-\\255]([%a\\192-\\255]+)%f[^%a\\128-\\255]'s [Aa]lt",
		[".*[Aa]lts?$"] = true,
		["<alt name> (eg, /altnames del Personyouthoughtwassomeonesaltbutreallyisnt)"] = "<nombre alt> (ej, /altnames del Personyouthoughtwassomeonesaltbutreallyisnt)",
		["<main> (eg /altnames listalts Fin)"] = "<principal> (ej /altnames listalts Fin)",
		["<search term> (eg, /altnames find fin)"] = "<término búsqueda> (ej, /altnames find fin)",
		["Alt"] = true,
		["alt"] = true,
		["alt name exists: %s -> %s; not overwriting as set in preferences"] = "existe el nombre alternativo: %s -> %s; sin sobrescribir como está establecido en las preferencias",
		["AltNames"] = "AltNombres",
		["Alts:"] = true,
		--Translation missing 
		-- ["autoguildalts_desc"] = "",
		--Translation missing 
		-- ["autoguildalts_name"] = "",
		["Be quiet"] = "Silencio",
		["character removed: %s"] = "Personaje eliminado: %s",
		["Class colour"] = "Color Clase",
		["Clear all"] = "Limpiar todo",
		["Clear all links between alts and main names."] = "Borrar todos los enlaces entre nombres alternativos y principales.",
		["Colour"] = "Color",
		--Translation missing 
		-- ["Delete a character's link to another character as their main."] = "",
		["Delete alt"] = "Eliminar alternativo",
		["Disabled"] = "Desactivado",
		["Display a player's alts in the tooltip"] = "Mostrar los alters de los jugadores en el tooltip",
		["Display a player's main name in the tooltip"] = "Mostrar el nombre del main del jugador en el tooltip",
		["Display main names in the same colour as that of the alt's class (taking the data from the PlayerNames module if it is enabled)"] = "Mostrar nombres de personajes principales (mains) en el mismo color que la clase del alter (obteniendo los datos del módulo PlayerNames si está habilitado)",
		["Display main names in the same colour as that of the main's class (taking the data from the PlayerNames module if it is enabled)"] = "Mostrar nombres principales en el mismo color que el de su clase principal (tomando los datos del módulo PlayerNames si está habilitado)",
		["Don't overwrite existing alt <-> main links when importing or adding new alts."] = "No sobreescribir enlaces alternativo <-> principal existentes al importar o añadir nuevos alternativos.",
		["Don't overwrite existing links"] = "No sobreescribir enlaces existentes",
		["don't use"] = "No utilizar",
		["Don't use data from the PlayerNames module at all"] = "No utilizar datos del módulo PlayerNames en absoluto",
		["ERROR: some function sent a blank message!"] = "ERROR: alguna función envió un mensaje en blanco!",
		["Find characters"] = "Encontrar caracteres",
		["Fix alts"] = "Arreglar alternativos",
		["Fix corrupted entries in your list of alt names."] = "Arreglar entradas corruptas en su lista de nombres alternativos.",
		["Found alt: %s => main: %s"] = "Alternativo encontrado: %s => principal: %s",
		["guild member alts found and imported: %s"] = "Miembros de hermandad alternativos encontrados e importados: %s",
		--Translation missing 
		-- ["Import from Guild Greet database"] = "",
		["Import from guild roster"] = "Importar desde la lista de la hermandad",
		["Import options"] = "Opciones de Importación",
		--Translation missing 
		-- ["Imports alt names from a Guild Greet database, if present"] = "",
		--Translation missing 
		-- ["Imports alt names from the guild roster by checking for members with the rank \"alt\" or \"alts\", or guild / officer notes like \"<name>'s alt\""] = "",
		["Imports data from LOKWhoIsWho, if present (drop your SavedVariablesLOKWhoIsWho.lua in the Prat directory to be able to use this)."] = "Importa datos de LOKWhoIsWho, si está presente (colocar su SavedVariablesLOKWhoIsWho.lua en el directorio Prat para poder usar este).",
		["Left"] = "Izquierda",
		["link <alt name> <main name> (eg, /altnames link Fin Finjathealtoffin)"] = "enlace <nombre alt> <nombre principal> (ej, /nombrealt enlace Fin Finjathealtoffin)",
		--Translation missing 
		-- ["Link alt"] = "",
		--Translation missing 
		-- ["Link someone's alt character with the name of their main."] = "",
		["linked alt %s => %s"] = "alternativo enlazado %s => %s",
		["List all"] = "Listar todo",
		["List all links between alts and their main names."] = "Lista todos los enlaces entre alternativos y sus nombres principales.",
		["List alts"] = "Lista alternativos",
		["List alts for a given character"] = "Lista alternativos para un personaje dado",
		["LOKWhoIsWho data not found"] = "LOKWhoIsWho datos no encontrados",
		["LOKWhoIsWho import"] = "importar LOKWhoIsWho",
		["LOKWhoIsWho lua file not found, sorry."] = "LOKWhoIsWho archivo lua no encontrado, lo siento.",
		["Main"] = "Principal",
		["main"] = "principal",
		["Main name position"] = "Posición del nombre principal",
		["Main:"] = "Principal:",
		["mainpos_desc"] = "Donde mostrar nombre principal de un personaje cuando es su alternativa.",
		["mainpos_name"] = "Posición del nombre principal",
		--Translation missing 
		-- ["module_desc"] = "",
		["no alts found for character "] = "sin alternativos encontrados para el personaje",
		["no alts or mains found matching \"%s\""] = "sin alternativos o principales coincidentes con \"%s\" encontrados",
		["No arg string given to :addAlt()"] = "Sin cadena de argumento dado a: addAlt()",
		["no characters called \"%s\" found; nothing deleted"] = "no se han encontrado personajes llamados \"%s\"; nada eliminado",
		--Translation missing 
		-- ["No Guild Greet database found"] = "",
		["No main name supplied to link %s to"] = "Sin nombre principal proporcionado para el enlace %s",
		["no matches found"] = "Ninguna coincidencia encontrada",
		["quiet"] = "Silencioso",
		["quiet_desc"] = "Si desea informar al marco de chat o no.",
		--Translation missing 
		-- ["quiet_name"] = "",
		["Right"] = "Derecha",
		--Translation missing 
		-- ["Search the list of linked characters for matching main or alt names."] = "",
		["searched for: %s - total matches: %s"] = "buscado: %s - total de coincidencias: %s",
		["Show alts in tooltip"] = "Muestra alternativos en ayuda contextual",
		["Show main in tooltip"] = "Mostrar principal en ayuda contextual",
		["Start"] = "Inicio",
		--Translation missing 
		-- ["The colour of an alt's main name that will be displayed"] = "",
		["Use class colour (from the PlayerNames module)"] = "Utilizar el color de clase (desde el módulo de NombresJugador)",
		["use class colour of alt"] = "utilizar color de clase de alt",
		["use class colour of main"] = "utilizar el color de la clase principal",
		["Use LibAlts Data"] = "Utiilizar Datos de LibAlts",
		["Use the data available via the shared alt information library."] = "Utilice los datos disponibles a través de la biblioteca compartida de información alternativa.",
		--Translation missing 
		-- ["Various ways to import a main's alts from other addons"] = "",
		["warning: alt %s already linked to %s"] = "advertencia: alt %s ya vinculado a %s",
		--Translation missing 
		-- ["Where to display a character's main name when on their alt."] = "",
		["Whether to report to the chat frame or not."] = "Si se debe reportar al marco de chat o no.",
		["You are not in a guild"] = "No está en una hermandad",
		["You have not yet linked any alts with their mains."] = "Aún no ha vinculado algún alternativo con su principal.",
	},
	["Bubbles"] = {
		--Translation missing 
		-- ["color_desc"] = "",
		--Translation missing 
		-- ["color_name"] = "",
		--Translation missing 
		-- ["font_desc"] = "",
		--Translation missing 
		-- ["font_name"] = "",
		--Translation missing 
		-- ["fontsize_desc"] = "",
		--Translation missing 
		-- ["fontsize_name"] = "",
		--Translation missing 
		-- ["format_desc"] = "",
		--Translation missing 
		-- ["format_name"] = "",
		--Translation missing 
		-- ["icons_desc"] = "",
		--Translation missing 
		-- ["icons_name"] = "",
		--Translation missing 
		-- ["module_desc"] = "",
		--Translation missing 
		-- ["module_name"] = "",
		--Translation missing 
		-- ["shorten_desc"] = "",
		--Translation missing 
		-- ["shorten_name"] = "",
		--Translation missing 
		-- ["transparent_desc"] = "",
		--Translation missing 
		-- ["transparent_name"] = "",
	},
	["Buttons"] = {
		["alpha_desc"] = "Establece la transparencia del menu del chat y de las flechas para todas las ventanas.",
		["alpha_name"] = "Establecer Transparencia",
		["Buttons"] = "Botones",
		["Chat window button options."] = "Opciones de los botones de la ventana del chat",
		["chatmenu_desc"] = "Alterna la activación del menú del chat.",
		["chatmenu_name"] = "Mostrar Menú del Chat",
		["Default"] = "Predeterminado",
		["Right, Inside Frame"] = "Derecha, Dentro del Marco",
		["Right, Outside Frame"] = "Derecha, Fuera del Marco",
		["scrollReminder_desc"] = "Muestra el botón recordatorio cuando no se está en la parte inferior de la ventana de chat.",
		["scrollReminder_name"] = "Mostrar Recordatorio de Desplazamiento Abajo",
		["Set Position"] = "Establecer Posición",
		["Sets position of chat menu and arrows for all chat windows."] = "Establece la posición del menú y de las flechas de todas las ventanas de chat.",
		["Show Arrows"] = "Mostar Flechas",
		["Show Chat%d Arrows"] = "Mostar Flechas del Chat %d",
		--Translation missing 
		-- ["showbnet_desc"] = "",
		--Translation missing 
		-- ["showbnet_name"] = "",
		--Translation missing 
		-- ["showmenu_desc"] = "",
		--Translation missing 
		-- ["showmenu_name"] = "",
		--Translation missing 
		-- ["showminimize_desc"] = "",
		--Translation missing 
		-- ["showminimize_name"] = "",
		["Toggle showing chat arrows for each chat window."] = "Alterna el mostrar las flechas para cada ventana de chat.",
		["Toggles navigation arrows on and off."] = "Alterna la activación de las flechas de navegación.",
	},
	["ChannelColorMemory"] = {
		["(%w+)%s?(.*)"] = "(%S+)%s?(.*)",
		["ChannelColorMemory"] = "MemoriaColorCanal",
		["Remembers the colors of each channel name."] = "Recordar los colores de cada nombre de canal.",
	},
	["ChannelNames"] = {
		["%s settings."] = "opciones %s.",
		["<string>"] = "<cadena>",
		["Add Channel Abbreviation"] = "Añadir Abreviatura del Canal",
		["addnick_desc"] = "Agrega un nombre abreviado del canal. El nombre con '#' para incluir el número de canal. (por ejemplo, '#Comercio').",
		["Blank"] = "Blanco",
		["chanlink_desc"] = "Hacer del canal un vínculo clickable que abre el chat para ese canal.",
		["chanlink_name"] = "Crear Enlace del Canal",
		["Channel %d"] = "Canal %d",
		["Channel name abbreviation options."] = "Opciones de abreviatura del nombre del canal.",
		["ChannelNames"] = "NombresCanales",
		["channelnick_desc"] = "Abreviaturas de Canal",
		["channelnick_name"] = "Abreviaturas de Canal",
		["Clear Channel Abbreviation"] = "Limpiar Abreviatura de Canal",
		["Clears an abbreviated channel name."] = "Limpia un nombre de canal abreviado.",
		["colon_desc"] = "Añade dos puntos después del canal reemplazado.",
		["colon_name"] = "Mostrar dos puntos",
		["Dont display the channel/chat type name"] = "No mostrar el nombre del tipo de canal/chat",
		["otheropts_desc"] = "Opciones de formato de canal adicionales y controles de enlace del canal.",
		["otheropts_name"] = "Otras Opciones",
		["Remove Channel Abbreviation"] = "Eliminar Abreviatura de Canal",
		["Removes an an abbreviated channel name."] = "Elimina un nombre de canal abreviado.",
		["Replace"] = "Sustituir",
		["Set"] = "Establecer",
		["space_desc"] = "Alternar añadir un espacio después del canal reemplazado.",
		["space_name"] = "Mostrar Espacio",
		["Toggle replacing this channel."] = "Alterna reemplazar este canal.",
		["Use a custom replacement for the chat %s text."] = "Utilizarr un reemplazo personalizado para el texto del chat %s.",
	},
	["ChannelSticky"] = {
		["Channel"] = "Canal",
		["ChannelSticky"] = "CanalAdhesivo",
		["Chat channel sticky options."] = "Opciones de canal adhesivo de chat.",
		["ChatType"] = "TipoChat",
		["Per chat type options."] = "Opciones por tipo de chat.",
		["smartgroup_desc"] = "Agrega un comando /gr que escoge automáticamente el tipo correcto de chat, BANDA, GRUPO, o CAMPO DE BATALLA",
		["smartgroup_name"] = "Grupos Inteligentes",
		["Sticky %s"] = "Adhesivo %s",
		["Sticky Per Chat Frame"] = "Adhesivo Por Marco de Chat",
		["Toggle remembering the chat type last used per chat frame."] = "Alternar recordar el último tipo de chat utilizado por el marco de chat.",
		["Toggles sticky on and off for %s."] = "Alterna activar adhesivo para %s.",
	},
	["ChatFrames"] = {
		--Translation missing 
		-- ["Chat window frame parameter options"] = "",
		--Translation missing 
		-- ["framealpha_desc"] = "",
		--Translation missing 
		-- ["framealpha_name"] = "",
		--Translation missing 
		-- ["Frames"] = "",
		--Translation missing 
		-- ["mainchatonload_desc"] = "",
		--Translation missing 
		-- ["mainchatonload_name"] = "",
		--Translation missing 
		-- ["maxchatheight_desc"] = "",
		--Translation missing 
		-- ["maxchatheight_name"] = "",
		--Translation missing 
		-- ["maxchatwidth_desc"] = "",
		--Translation missing 
		-- ["maxchatwidth_name"] = "",
		--Translation missing 
		-- ["minchatheight_desc"] = "",
		--Translation missing 
		-- ["minchatheight_name"] = "",
		--Translation missing 
		-- ["minchatwidth_desc"] = "",
		--Translation missing 
		-- ["minchatwidth_name"] = "",
		--Translation missing 
		-- ["rememberframepositions_desc"] = "",
		--Translation missing 
		-- ["rememberframepositions_name"] = "",
		--Translation missing 
		-- ["removeclamp_desc"] = "",
		--Translation missing 
		-- ["removeclamp_name"] = "",
	},
	["ChatLink"] = {
		["gem_desc"] = "Activar Modo de Compatibilidad GEM",
		["gem_name"] = "Compatibilidad GEM",
		["module_desc"] = "Opciones de enlace de elementos del canal de chat.",
		--Translation missing 
		-- ["module_info"] = "",
		["module_name"] = "EnlacesCanal",
		["Trade"] = "Comercio",
	},
	["ChatLog"] = {
		["A module to automaticaly enable chat and combat logging."] = "Un módulo que automáticamente activa el chat y el registro de combate.",
		["Chat log recorded to <WoW Installation>\\Logs\\WoWChatLog.txt only upon logout."] = "Registro del chat guardado en <Instalación WoW>\\Logs\\WoWChatLog.txt sólo al cierre de la sesión.",
		["Chat Log: Disabled"] = "Registro del Chat: Desactivado",
		["Chat Log: Enabled"] = "Registro del Chat: Activado",
		["ChatLog"] = "Registro del Chat",
		["Combat log recorded to <WoW Installation>\\Logs\\WoWCombatLog.txt only upon logout."] = "Registro del combate guardado en <Instalación WoW>\\Logs\\WoWCombatLog.txt sólo al cierre de la sesión.",
		["Combat Log: Disabled"] = "Registro de Combate: Desactivado",
		["Combat Log: Enabled"] = "Registro de Combate: Activado",
		["quiet_desc"] = "No mostrar algún mensaje cuando este mod esté activdo, o cuando cambie la configuración del registro.",
		["quiet_name"] = "Suprimir Mensaje de Respuesta",
		["Toggle Chat Log"] = "Alternar Registro del Chat",
		["Toggle chat log on and off."] = "Alterna la activación del registro del chat.",
		["Toggle Combat Log"] = "Alternar Registro de Combate",
		["Toggle combat log on and off."] = "Alterna la activación del registro de combate.",
	},
	["ChatTabs"] = {
		["Active Alpha"] = "Activar Transparencia",
		["All"] = "Todo/s",
		["Always"] = "Siempre",
		["Chat window tab options."] = "Opciones de la pestaña de la ventana de chat.",
		["Default"] = "Predeterminado",
		["disableflash_desc"] = "Deshabilitar destello de las pestañas del chat.",
		["disableflash_name"] = "Desactivar Destello",
		["Hidden"] = "Oculto",
		["Individual"] = true,
		["Not Active Alpha"] = "No Activar Transparencia",
		["preventdrag_desc"] = "Evitar arrastrar pestañas de chat con el ratón",
		["preventdrag_name"] = "Evitar arrastrar",
		["Set ChatFrame%d Display Mode"] = "Establecer Modo de Visualización del Marco de Chat %d",
		["Set Display Mode"] = "Establecer Modo Visualización",
		["Set tab display mode for each chat window."] = "Establecer modo de pantalla de la pestaña para cada ventana de chat. Marcado (encendido), Desmarcado (apagado), Deshabilitado (predeterminado)",
		["Set tab display to always, hidden or the Blizzard default."] = "Establecer mostrar pestaña a siempre, oculta o por defecto (Blizzard).",
		["Sets alpha of chat tab for active chat frame."] = "Establece la transparencia de la pestaña de chat para el marco activo.",
		["Sets alpha of chat tab for not active chat frame."] = "Establece la transparencia de la pestaña de chat para el marco no activo.",
		["Tabs"] = "Pestañas",
	},
	["Clear"] = {
		["Adds clear text slash commands (/clear)(/cls)(/clearall)(/clsall)."] = "Añade comandos para limpiar texto (/clear)(/cls)(/clearall)(/clsall).",
		["Clear"] = "Limpiar",
		["Clearall"] = "Limpiar todo",
		["Clears all chat frames."] = "Limpiar todas las ventanas de chat",
		["Clears the current chat frame."] = "Limpiar la ventana de chat actual",
	},
	["CopyChat"] = {
		[" Text"] = "Texto",
		["BBCode"] = true,
		--Translation missing 
		-- ["BOTTOMLEFT"] = "",
		--Translation missing 
		-- ["BOTTOMRIGHT"] = "",
		--Translation missing 
		-- ["buttonpos_desc"] = "",
		--Translation missing 
		-- ["buttonpos_name"] = "",
		["ChatFrame"] = "MarcoChat",
		["Copy all of the text in the selected chat frame into an edit box"] = "Copiar todo el texto seleccionado en el marco del chat a una caja de edición",
		["Copy Text"] = "Copiar Texto",
		["Copy Text Format"] = "Copiar Texto con fomato",
		["Copy text from the active chat window."] = "Copiar texto desde la ventana de chat activa.",
		--Translation missing 
		-- ["Copy To Editbox"] = "",
		["CopyChat"] = "ChatCopiar",
		["HTML"] = true,
		["Message From : %s"] = "Mensaje de : %s",
		["Plain"] = "Liso",
		["Should the copied text be plain, or formatted so you can see the colors."] = "El texto copiado debería ser llano, o con formato para que pueda ver los colores. ",
		["showbutton_desc"] = "Muestra un botón en el marco del chat",
		["showbutton_name"] = "Botón Copiar",
		--Translation missing 
		-- ["TOPLEFT"] = "",
		--Translation missing 
		-- ["TOPRIGHT"] = "",
		["Wowace.com Forums"] = "Foros Wowace.com",
	},
	["CustomFilters"] = {
		["<string>"] = "<cadena>",
		["Add a pattern to search for."] = "Añadir un patrón de búsqueda.",
		["Add Pattern"] = "Añadir Patrón",
		["Block Message"] = "Bloque de Mensaje",
		["Channel Data"] = "Datos de Canal",
		["Channel to send output text to."] = "Canal a enviar el texto de salida",
		["Enabled"] = "Activado",
		["Extra data for WHISPER (target) and CHANNEL (channel name or num)"] = "Datos extra para SUSURRAR (objetivo) y CANAL (nombre de canal o número)",
		["Filter Name"] = "Nombre del Filtro",
		["Forward"] = "Reenviar",
		["Forward the message to a chat channel."] = "Reenviar el mensaje a un canal de chat.",
		["Forward the message to a custom chat channel."] = "Salida a un canal privado de chat",
		["ForwardCustom"] = "Reenviar Personalizado",
		["ForwardMessage"] = "ReenviarMensaje",
		["ForwardMessageCustom"] = "Canal Privado",
		["Hilight Color"] = "Color Resaltado",
		["Hilight Match Text"] = "Texto Coincidente Resaltado",
		["Inbound"] = "Entrante",
		["inchannels_desc"] = "Buscar en algunos canales",
		["inchannels_name"] = "Buscar canales",
		["Is this pattern enabled for use?"] = "¿Está habilitado este patrón para su uso?",
		["Match Options"] = "Opciones de Coincidencias",
		["module_desc"] = "Módulo para soportar filtros personalizados.",
		["module_name"] = "Filtros Personalizados",
		["Only output the message portion of the chat text, leave out the channel, and playername etc."] = "Sólo mostrar la parte del mensaje del chat de texto, omitir el canal, nombre de jugador, etc.",
		["Outbound"] = "Saliente",
		["Output Channel"] = "Canal de Salida",
		["Output Message Only"] = "Solo Mensajes Salientes",
		["Pattern Info"] = "Patrón de Información",
		["Pattern Options"] = "Opciones de Patrón",
		["Play a sound when this message is output to the chatframe"] = "Reproducir un sonido cuando este mensaje sale en el marco de chat",
		["Play Sound"] = "Reproducir Sonido",
		["Prevent the message from being displayed"] = "Impedir que el mensaje sea visualizado",
		["Remove an existing pattern."] = "Elimina un patrón existente.",
		["Remove Pattern"] = "Eliminar Patrón",
		["Replacement Text"] = "Sustitución de texto",
		["Search Format String"] = "Cadena de Formato de Búsqueda",
		["Search Pattern"] = "Patrón de Búsqueda",
		["Secondary Output"] = "Salida Secundaria",
		["Send to a secondary output"] = "Enviar a un salida secundaria",
		["Supplied pattern is a format string instead of a pattern"] = "El patrón suministrado es una cadena de formato en lugar de un patrón",
		["Your name for this filter"] = "Su nombre para este filtro",
	},
	["Editbox"] = {
		--Translation missing 
		-- ["Attach edit box to..."] = "",
		--Translation missing 
		-- ["Attach to..."] = "",
		["Background color"] = "Color de fondo",
		--Translation missing 
		-- ["Background Inset"] = "",
		["Background texture"] = "Textura de fondo",
		["Border color"] = "Color del borde",
		["Border texture"] = "Textura del borde",
		["Bottom"] = "Abajo",
		["Color border by channel"] = "Color del borde por canal",
		--Translation missing 
		-- ["currently_broken_alt_behavior"] = "",
		["Edge Size"] = "Tamaño del borde",
		["Editbox"] = "Caja de edición",
		["Editbox options."] = "Opciones de la caja de edición.",
		["Font"] = "Fuente",
		["Free-floating"] = "Flotar-libre",
		["Free-floating, Locked"] = "Flotar-libre, Bloqueado",
		--Translation missing 
		-- ["Requires the Alt key to be held down to move the cursor in chat"] = "",
		--Translation missing 
		-- ["Select the font to use for the edit box"] = "",
		--Translation missing 
		-- ["Sets the frame's border color to the color of your currently active channel"] = "",
		--Translation missing 
		-- ["Tile Size"] = "",
		["Top"] = "Arriba",
		--Translation missing 
		-- ["Use Alt key for cursor movement"] = "",
	},
	["EventNames"] = {
		--Translation missing 
		-- ["allevents_desc"] = "",
		--Translation missing 
		-- ["allevents_name"] = "",
		["Chat window event name options."] = "Opciones de nombre de evento de la ventana del chat.",
		["EventNames"] = "NombresEventos",
		["Show"] = "Mostrar",
		["Show events on chatframes"] = "Mostrar eventos en los marcos de chat",
		["show_desc"] = "Alterna el mostrar nombres de eventos en cada ventana.",
		["show_name"] = "Mostrar Nombres de Eventos",
	},
	["Fading"] = {
		["duration_desc"] = "Establece el número de segundos a esperar antes de desvanecer el texto de la ventana de chat.",
		["duration_name"] = "Establecer Retraso Desvanecer (Segundos)",
		["module_desc"] = "Opciones de desvanecer texto en ventana de chat.",
		["module_name"] = "Desvanecerse",
		["textfade_desc"] = "Alterna la activación de desvanecer texto para cada ventana de chat.",
		["textfade_name"] = "Activar Desvanecerse",
	},
	["Filtering"] = {
		["A module to provide basic chat filtering."] = "Un módulo que proporciona el filtrado básico del chat.",
		--Translation missing 
		-- ["afkdnd_desc"] = "",
		--Translation missing 
		-- ["afkdnd_name"] = "",
		["bgjoin_desc"] = "Filtrar en canal Campo de Batlla spam ha abandonado/se ha unido",
		["bgjoin_name"] = "Filtrar mensajes de unión/dejadas de Campos de Batalla",
		["Filtering"] = "Filtrado",
		["leavejoin_desc"] = "Filtrar en canal spam ha abandonado/se ha unido",
		["leavejoin_name"] = "Filtro de Canal  Ha abandonado / Se ha unido",
		["notices_desc"] = "Filtrar otros mensajes de notificación de canal personalizado, por ejemplo, los cambios de moderador.",
		["notices_name"] = "Filtrar Noticias del Canal",
		--Translation missing 
		-- ["tradespam_desc"] = "",
		--Translation missing 
		-- ["tradespam_name"] = "",
	},
	["Font"] = {
		["Auto Restore Font Size"] = "Restaurar Tamaño Fuentes Automáticamente",
		["Chat window font options."] = "Opciones de la fuente de la ventana del chat.",
		["Font"] = "Fuente",
		["monochrome_desc"] = "Alterna el color monocromo de la fuente.",
		["monochrome_name"] = "Alternar Monocromo",
		["None"] = "Ninguna",
		["Outline"] = "Contorno",
		["outlinemode_desc"] = "Estable el modo para el contorno alrededor de la fuente.",
		["outlinemode_name"] = "Establecer Modo de Cotorno",
		["rememberfont_desc"] = "Recordar la elección de la fuente y restaurarla al reiniciar.",
		["rememberfont_name"] = "Recordar Fuente",
		["Set ChatFrame%d Font Size"] = "Establecer Tamaño Fuente de Chat %d",
		["Set Font Face"] = "Establecer Tipo de Fuente",
		["Set Font Size"] = "Establecer Tamaño de Fuente",
		["Set Separately"] = "Establecer por separado",
		["Set text font size for each chat window."] = "Establece el tamaño de la fuente del texto de cada ventana de chat.",
		["Set text font size."] = "Establece el tamaño de la fuente del texto.",
		["Set the text font face for all chat windows."] = "Establece el tipo de fuente de texto para todas las ventanas de chat.",
		["shadowcolor_desc"] = "Establece el color del efecto de sombra.",
		["shadowcolor_name"] = "Establecer Color de la Sombra",
		["Thick Outline"] = "Contorno Grueso",
		["Toggle setting options separately for each chat window."] = "Cambiar opciones de configuración por separado para cada ventana de chat.",
		["Workaround a Blizzard bug which changes the font size when you open a system menu."] = "Solución a un error de Blizzard que cambia el tamaño de la fuente cuando se abre un menú de sistema.",
	},
	["History"] = {
		["Chat history options."] = "Opciones del historial del chat.",
		--Translation missing 
		-- ["Color GMOTD"] = "",
		--Translation missing 
		-- ["Colors the GMOTD label"] = "",
		--Translation missing 
		-- ["delaygmotd_desc"] = "",
		--Translation missing 
		-- ["delaygmotd_name"] = "",
		--Translation missing 
		-- ["divider"] = "",
		["History"] = "Historial",
		["Maximum number of lines of command history to save."] = "Máximo número de líneas a guardar por el comando historial.",
		["Save Command History"] = "Comando Guardar Historial",
		["Saves command history between sessions (for use with alt+up arrow or just the up arrow)"] = "Guarda el historial de comandos entre sesiones (para utilizar con alt+flecha arriba o sólo la flecha arriba)",
		--Translation missing 
		-- ["Scrollback"] = "",
		--Translation missing 
		-- ["Scrollback Options"] = "",
		--Translation missing 
		-- ["scrollbacklen_desc"] = "",
		--Translation missing 
		-- ["scrollbacklen_name"] = "",
		["Set Chat Lines"] = "Establecer Líneas de Chat",
		["Set Command History"] = "Establecer Historial de Comandos",
		["Set the number of lines of chat history for each window."] = "Establece el número de líneas del historial de chat para cada ventana.",
		--Translation missing 
		-- ["Store the chat lines between sessions"] = "",
	},
	["KeyBindings"] = {
		["Channel %d"] = "Canal %d",
		["Copy Selected Chat Frame"] = "Copiar el Marco de Chat Seleccionado",
		["Guild Channel"] = "Canal de Hermandad",
		["Instance Channel"] = "Canal Campo de Batalla",
		["Next Chat Tab"] = "Siguiente Pestaña de Chat",
		["Officer Channel"] = "Canal Oficial",
		["Party Channel"] = "Canal del Grupo",
		["Prat CopyChat"] = "Prat ChatCopiar",
		["Prat Keybindings"] = "Combinaciones de teclas Prat",
		["Prat TellTarget"] = "Prat DecirObjetivo",
		["Raid Channel"] = "Canal de Banda",
		["Raid Warning Channel"] = "Canal Aviso de Banda",
		["Say"] = "Decir",
		["Smart Group Channel"] = "Canal de Grupo Inteligente",
		["TellTarget"] = "DecirObjetivo",
		["Whisper"] = "Susurrar",
		["Yell"] = "Gritar",
	},
	["OriginalButtons"] = {
		["alpha_desc"] = "Establece la transparencia del menú y de las flechas en todas las ventanas de chat.",
		["alpha_name"] = "Establecer Transparencia",
		--Translation missing 
		-- ["buttonframe_desc"] = "",
		--Translation missing 
		-- ["buttonframe_name"] = "",
		["ChannelNames"] = "NombreCanales",
		["Chat window button options."] = "Opciones de los botones de la ventana de chat.",
		["chatmenu_desc"] = "Alterna activación del menú de chat.",
		["chatmenu_name"] = "Mostrar Ménu de Chat",
		["Default"] = "Predeterminado",
		["Original Buttons"] = "Botones Originales",
		["reflow_desc"] = "Flujo del texto del marco de chat alrededor de los botones no por debajo de ellos.",
		["reflow_name"] = "Flujo Texto Alrededor",
		["reminder_desc"] = "Muestra el botón de recordatorio cuando no se está en la parte inferior de la ventana de chat.",
		["reminder_name"] = "Mostrar Recordatorio de Desplazamiento Abajo",
		["Right, Inside Frame"] = "Derecha, Interior del Marco",
		["Right, Outside Frame"] = "Derecha, Exterior del Marco",
		["Set Position"] = "Establecer Posición",
		["Sets position of chat menu and arrows for all chat windows."] = "Establece la posición del menú y de las flechas para todas las ventanas de chat.",
		["Show Arrows"] = "Mostrar Flechas",
		["Show Chat%d Arrows"] = "Mostrar Flechas del Chat %d",
		["Toggle showing chat arrows for each chat window."] = "Alterna mostrar las flechas en cada ventana de chat.",
		["Toggles navigation arrows on and off."] = "Alterna activación de flechas de navegación.",
	},
	["OriginalEditbox"] = {
		["Autohide"] = "Auto Ocultar",
		["BACKGROUND"] = "FONDO",
		["Bar colour"] = "Color de la barra",
		--Translation missing 
		-- ["Border colour"] = "",
		--Translation missing 
		-- ["Border width"] = "",
		--Translation missing 
		-- ["Bottom"] = "",
		--Translation missing 
		-- ["Click the edit box to open it up for editing. Only available if Autohide is disabled."] = "",
		["Clickable"] = "Clickeable",
		["DIALOG"] = "DIÁLOGO",
		--Translation missing 
		-- ["Editbox options."] = "",
		["Enable Arrowkeys"] = "Habilitar flechas del teclado",
		["Enable using arrowkeys in editbox without the alt key."] = "Permite usar las flechas del teclado en la caja de texto sin usar la tecla alt.",
		["Hide Border"] = "Ocultar Borde",
		["Hide the border around the edit box."] = "Ocultar el borde alrededor de la caja de edición.",
		["Hide the edit box after you have pressed enter."] = "Oculta la caja de texto después de pulsar enter.",
		--Translation missing 
		-- ["HIGH"] = "",
		["Lock editbox position if undocked."] = "Bloquea la posición de la caja de texto si está desbloqueada.",
		["Lock Position"] = "Bloquear posición",
		--Translation missing 
		-- ["LOW"] = "",
		--Translation missing 
		-- ["MEDIUM"] = "",
		--Translation missing 
		-- ["OriginalEditbox"] = "",
		--Translation missing 
		-- ["Padding"] = "",
		--Translation missing 
		-- ["Set Alpha"] = "",
		--Translation missing 
		-- ["Set Position"] = "",
		--Translation missing 
		-- ["Set Strata"] = "",
		--Translation missing 
		-- ["Set the alpha of the editbox."] = "",
		--Translation missing 
		-- ["Set the amount of padding inside the edit box"] = "",
		--Translation missing 
		-- ["Set the edit box background colour"] = "",
		--Translation missing 
		-- ["Set the edit box border colour"] = "",
		--Translation missing 
		-- ["Set the frame strata of the editbox."] = "",
		--Translation missing 
		-- ["Set the position of the editbox."] = "",
		--Translation missing 
		-- ["Set the texture of the chat edit box"] = "",
		--Translation missing 
		-- ["Set the width of the edit box's border"] = "",
		--Translation missing 
		-- ["Set the width of the editbox."] = "",
		--Translation missing 
		-- ["Set Width (NB: only enabled if the editbox is undocked)"] = "",
		--Translation missing 
		-- ["Texture"] = "",
		--Translation missing 
		-- ["Top"] = "",
		--Translation missing 
		-- ["Undocked"] = "",
	},
	["Paragraph"] = {
		["adjustlinks_desc"] = "Ajustar los vínculos para restaurar la capacidad de hacer click en texto centrado o alineado a la derecha.",
		["adjustlinks_name"] = "Corregir la colocación de enlaces de jugador/objeto",
		["Center"] = "Centro",
		["Chat window paragraph options."] = "Opciones de párrafo en ventanas de chat.",
		["justification_desc"] = "Establecer alineación horizontal para cada ventana de chat",
		["justification_name"] = "Establecer Alineación",
		["Left"] = "Izquierda",
		["Line Spacing"] = "Espaciado de Linea",
		["Paragraph"] = "Párrafo",
		["Right"] = "Derecha",
		["Set the line spacing for all chat windows."] = "Establece el espaciado de línea para todas las ventanas de chat.",
	},
	["PlayerNames"] = {
		["Actively Query Player Info"] = "Pedir Información de Jugador Activamente",
		["Angled"] = "Angulo",
		["Brackets"] = "Corchetes",
		["Brackets Common Color"] = "Color Común Corchetes",
		["Brackets Use Common Color"] = "Utilizar Color Común Corchetes",
		["Class"] = "Clase",
		["Color by Level Difference"] = "Color por Diferencia de Nivel",
		["coloreverywhere_desc"] = "Colorear nombres de jugadores si ellos aparecen en el texto de los mensajes del chat.",
		["coloreverywhere_name"] = "Colorear Nombres Siempre",
		["Enable Alt-Invite"] = "Habilitar Alt-Invitar",
		["Enable Invite Links"] = "Habilitar Enlaces Invitar",
		["Enable TabComplete"] = "Habilitar Ficha completa",
		["hoverhilight_desc"] = "Resaltar líneas de chat de un jugador al situarse sobre su enlace de jugador",
		--Translation missing 
		-- ["hoverhilight_name"] = "",
		["How to color other player's level."] = "Cómo el color de otro jugador de nivel.",
		["How to color player's name."] = "Cómo el color de nombre del jugador.",
		["Keep Info"] = "Mantener Información",
		["Keep Lots Of Info"] = "Mantener Mucha Información",
		["Keep player information between session for all players except cross-server players"] = "Mantiene información de jugadores entre sesiones para todos los jugadores excepto entre servidores",
		["Keep player information between session, but limit it to friends and guild members."] = "Mantiene información de jugadores entre sesiones, pero lo limita a amigos y miembros de la hermandad.",
		["Let TasteTheNaimbow set the common color for unknown player names."] = "Deje a TasteTheNaimbow establecer el color común para nombres de jugador desconocidos.",
		["Level Color Mode"] = "Modo Color por Nivel",
		["linkifycommon_desc"] = "Linkify Common Messages",
		["linkifycommon_name"] = "Enlazar Mensajes Comunes",
		["No additional coloring"] = "Sin color adicional",
		["None"] = "Ninguno",
		["Player Color Mode"] = "Modo Color del Jugador",
		["Player name formating options."] = "Opciones de formato del nombre de jugador.",
		["PlayerNames"] = "Nombre del Jugador",
		["Prat_Playernames: Stored Player Data Cleared"] = "Prat_Playernames: Limpiados los Datos de Jugador Guardados",
		["Query the server for all player names we do not know. Note: This happpens pretty slowly, and this data is not saved."] = "Consulta el servidor para todos los nombres de jugador que desconocemos. Nota: esto sucede muy lentamente, y estos datos no se guardan.",
		["Random"] = "Aleatorio",
		--Translation missing 
		-- ["realidcolor_desc"] = "",
		--Translation missing 
		-- ["realidcolor_name"] = "",
		["Reset Settings"] = "Restablecer Ajustes",
		["Restore default settings, and delete stored character data."] = "Restablece ajustes por defecto, y eliminar información del jugador guardada.",
		["Set common color of unknown player names."] = "Establece el color común para los nombres de jugadores desconocidos.",
		["Sets common color of brackets to use around player names."] = "Establece el color común de los corchetes a utilizar en torno a los nombres de jugador.",
		["Sets style of brackets to use around player names."] = "Establece el estilo de los corchetes a utilizar en torno a los nombres de jugador.",
		["Show Group"] = "Mostrar Grupo",
		["Show Level"] = "Mostrar Nivel",
		["Show Raid Target Icon"] = "Mostrar Icono Objetivo Banda",
		["Square"] = "Cuadrado",
		["Tab completion : "] = "Finalización de Pestaña : ",
		["tabcomplete_name"] = "Nombres Posibles",
		--Translation missing 
		-- ["Toggle group invites by alt-clicking hyperlinked keywords like 'invite'."] = "",
		["Toggle group invites by alt-clicking on player name."] = "Activa invitar a grupo al hacer alt-click en el nombre del jugador.",
		["Toggle level showing."] = "Alterna mostrar nivel.",
		["Toggle raid group showing."] = "Alterna mostrar grupo de raid.",
		["Toggle showing the raid target icon which is currently on the player."] = "Altterna mostrar el icono de objetivo de banda que está en el jugador.",
		["Toggle tab completion of player names."] = "Alterna la finalización de la pestaña de nombres de jugador.",
		["Toggle using a common color for brackets around player names."] = "Alterna utilizar un color común de corchetes en torno a los nombres de jugador.",
		["Toggle using a common color for unknown player names."] = "Alterna el utilizar un color común para los nombres de jugadores desconocidos.",
		["Too many matches (%d possible)"] = "Demasiadas coincidencias (%d posibles)",
		["Unknown Common Color"] = "Color Común Desconocido",
		["Unknown Common Color From TasteTheNaimbow"] = "Color Común Desconocido de TasteTheNaimbow",
		["Unknown Use Common Color"] = "Desconocido Color de Uso Común",
		["Use Channel Color"] = "Utilizar Color Canal",
		["Use Player Color"] = "Utilizar Color Jugador",
		--Translation missing 
		-- ["Use toon name for RealID"] = "",
	},
	["PopupMessage"] = {
		["Add Nickname"] = "Añadir un Apodo",
		["Adds an alternate name to show in popups."] = "Añade un nombre alternativo para mostrar en las ventanas emergentes.",
		["Clear Nickname"] = "Limpiar Apodo",
		["Clears alternate name to show in popups."] = "Limpia el nombre alternativo a mostrar en las ventanas emergentes.",
		["framealpha_desc"] = "Establece el valor de transparencia del marco emergente al desaparecer completamente.",
		["framealpha_name"] = "Transparencia Marco Emergente",
		["Popup"] = "Emergente",
		["PopupMessage"] = "Mensaje Emergente",
		["Remove Nickname"] = "Eliminar Apodo",
		["Removes an alternate name to show in popups."] = "Quita un nombre alternativo para mostrar en las ventanas emergentes.",
		["Set Separately"] = "Establecer por Separado",
		["Show All Popups"] = "Mostrar Todas las Emergentes",
		["Show Popups"] = "Mostrar Emergentes",
		["Show Popups for all chat windows."] = "Mostrar Emergentes para todas las ventanas de chat.",
		["Show Popups for each window."] = "Mostrar Emergentes para cada ventana.",
		["show_desc"] = "Muestra Emergentes para cada ventana.",
		["show_name"] = "Mostar Emergentes",
		["show_perframedesc"] = "Alterna activación de mostrar ventanas emergentes.",
		["show_perframename"] = "Mostrar Marcos Emergentes de Chat %d",
		["showall_desc"] = "Mostrar Ventanas Emergentes para todas las ventanas de chat.",
		["showall_name"] = "Mostrar Todas las Emergentes",
		["Shows messages in a popup window."] = "Muestra mensajes en una ventana emergente.",
		["Shows messages with your name in a popup."] = "Muestra mensajes con tu nombre en una ventana emergente.",
		["Toggle setting options separately for each chat window."] = "Cambiar opciones de configuración por separado para cada ventana de chat.",
	},
	["Scroll"] = {
		["Bottom"] = "De Abajo a Arriba",
		["Chat window scrolling options."] = "Opciones de desplazamiento de la ventana de chat.",
		["Control whether text is added to the frame at the top or the bottom."] = "Controla si el texto se añade al marco en la parte superior o inferior.",
		["lowdown_desc"] = "Alternar saltar automáticamente a la parte inferior de cada ventana de chat.",
		["lowdown_name"] = "Activar TheLowDown",
		--Translation missing 
		-- ["modified_speed"] = "",
		--Translation missing 
		-- ["modified_speed_desc"] = "",
		["mousewheel_desc"] = "Alterna soporte para rueda de ratón para cada ventana de chat.",
		["mousewheel_name"] = "Activar Rueda del Ratón",
		["Scroll"] = "Desplazamiento",
		["Set Ctrl+MouseWheel Speed"] = "Establecer Velocidad Ctrl+Rueda Ratón",
		["Set MouseWheel Speed"] = "Establecer Velocidad de la Rueda del Ratón",
		["Set number of lines mousewheel will scroll when ctrl is pressed."] = "Establece el número de líneas que la rueda del ratón desplazará cuando ctrl está pulsada.",
		["Set number of lines mousewheel will scroll."] = "Establece el número de lineas que la rueda del ratón desplazará.",
		["Set TheLowDown Delay"] = "Establecer Retraso TheLowDown",
		["Set time to wait before jumping to the bottom of chat windows."] = "Estable el tiempo de espera antes de saltar a la parte inferior de las ventanas de chat.",
		["Text scroll direction"] = "Dirección de desplazamiento del texto",
		["Top"] = "De arriba a abajo",
	},
	["Search"] = {
		--Translation missing 
		-- ["err_notfound"] = "",
		--Translation missing 
		-- ["err_tooshort"] = "",
		--Translation missing 
		-- ["find_results"] = "",
		--Translation missing 
		-- ["module_desc"] = "",
		--Translation missing 
		-- ["module_info"] = "",
		--Translation missing 
		-- ["module_name"] = "",
	},
	["ServerNames"] = {
		--Translation missing 
		-- ["autoabbreviate_desc"] = "",
		--Translation missing 
		-- ["autoabbreviate_name"] = "",
		["colon_desc"] = "Alterna añadir dos puntos despues del servidor reemplazado.",
		["colon_name"] = "Mostrar dos puntos",
		["randomclr_desc"] = "Utiliza un color aleatorio para cada servidor.",
		["randomclr_name"] = "Colores Aleatorios",
		["Server name abbreviation options."] = "Opciones de la abreviatura del nombre del servidor.",
		["ServerNames"] = "NombreServidor",
	},
	["Sounds"] = {
		["A module to play sounds on certain chat messages."] = "Un módulo que reproduce sonidos con ciertos mensajes del chat.",
		["Add a custom channel"] = "Añadir un canal personalizado",
		--Translation missing 
		-- ["bn_whisper_desc"] = "",
		--Translation missing 
		-- ["bn_whisper_name"] = "",
		["Custom Channels"] = "Canales Personalizados",
		--Translation missing 
		-- ["group_lead_desc"] = "",
		--Translation missing 
		-- ["group_lead_name"] = "",
		["guild_desc"] = "Sonido para mensajes de hermandad %s",
		["guild_name"] = "Hermandad",
		["incoming"] = "Recibido",
		["Incoming Sounds"] = "Sonidos Entrantes",
		["officer_desc"] = "Sonido para mensajes del canal oficial o personalizado %s",
		["officer_name"] = "Oficial",
		["outgoing"] = "Saliente",
		["Outgoing Sounds"] = "Sonidos Salientes",
		["party_desc"] = "Sonido para mensajes del grupo %s",
		["party_name"] = "Grupo",
		["Play a sound for a certain channel name (can be a substring)"] = "Reproduce un sonido para un cierto nombre de canal (puede ser una subcadena)",
		["raid_desc"] = "Sonido para mensajes de banda %s o líder/grupo de campo de batalla",
		["raid_name"] = "Banda",
		["Remove a custom channel"] = "Eliminar un canal personalizado.",
		["Reset settings"] = "Restablecer ajustes",
		["Restore default settings and resets custom channel list"] = "Reestable ajustes por defecto y reestablece la lista de canales personalizados",
		["Sound selection for incoming chat messages"] = "Selección de sonido para mensajes de chat entrantes",
		["Sound selection for outgoing (from you) chat messages"] = "Selección de sonido para mensajes de chat salientes (de ti)",
		["Sounds"] = "Sonidos",
		["whisper_desc"] = "Sonido para susurros %s",
		["whisper_name"] = "Susurrar",
	},
	["Substitutions"] = {
		["%d total user defined substitutions"] = "Total de sustituciones definidas por el usuario %d",
		["|cffff0000warning:|r subtitution \"%s\" already defined as \"%s\", overwriting"] = "|cffff0000advertencia:|r sustitución \"%s\" ya definida como \"%s\", sobrescribiendo",
		["<noguild>"] = "<sin hermandad>",
		["<notarget>"] = "<sin objetivo>",
		["A module to provide basic chat substitutions."] = "Un módulo que proporciona sustituciones básicas del chat.",
		["Are you sure - this will delete all user defined substitutions and reset defaults?"] = "¿Está seguro - esto eliminará todas las sustituciones definidas por el usuario y restablece los valores predeterminados?",
		["Are you sure?"] = "¿Está seguro?",
		["can't find substitution index for a substitution named '%s'"] = "No se encuentra el índice de sustitución para una sustitución con el nombre '%s'",
		["current-prompt"] = [=[Valor actual: '%s'
Click para pegar en el chat.]=],
		["defined %s: expands to => %s"] = "definido %s: se expande a => %s",
		["Delete all"] = "Eliminar todo",
		["Delete substitution"] = "Eliminar sustitución",
		["Deletes a user defined substitution"] = "Elimina una sustitución del usuario",
		["Deletes all user defined substitutions"] = "Elimina todas las sustituciones del usuario",
		["female"] = "Femenino",
		["her"] = "ella",
		["hers"] = "suya",
		["him"] = "él",
		["his"] = "suyo",
		--Translation missing 
		-- ["it"] = "",
		--Translation missing 
		-- ["its"] = "",
		["List of available substitutions"] = "Listado de sustituciones disponibles",
		["List of available substitutions defined by this module. (NB: users may define custom values for existing substitutions, but they will revert to the default value if the user definition is deleted.)"] = "Lista de sustituciones definidas por este módulo. (Nota: los usuarios pueden definir valores personalizados para las sustituciones, pero volverá al valor por defecto si la definición del usuario se suprime.)",
		["List substitutions"] = "Listado de sustituciones",
		["Lists all current subtitutions in the default chat frame"] = "Lista todas las sustituciones actuales en el marco de chat por defecto.",
		["male"] = "Masculino",
		["MapLoc"] = true,
		["MapPos"] = true,
		["MapXPos"] = true,
		["MapYPos"] = true,
		["MapZone"] = "MapZona",
		["module:buildUserSubsIndex(): warning: module patterns not defined!"] = "módulo: buildUserSubsIndex(): advertencia: ¡patrones del módulo no definidos!",
		--Translation missing 
		-- ["MouseoverTargetName"] = "",
		["NO MATCHFUNC FOUND"] = "SIN FUNCIONCOINCIDENCIAS ENCONTRADA",
		["no substitution name given"] = "ningún nombre de sustitución dado",
		["no substitution name supplied for deletion"] = "ningún nombre de sustitución proporcionado para su eliminación",
		["no user defined subs found"] = "sustituciones definidas por el usuario no encontradas",
		["no value given for subtitution \"%s\""] = "ningún valor dado para sustitución \"%s\"",
		["Options for setting and removing user defined substitutions. (NB: users may define custom values for existing substitutions, but they will revert to the default value if the user definition is deleted.)"] = "Opciones para establecer y eliminar sustituciones definidas por el usuario. (Nota: los usuarios pueden definir valores personalizados para las sustituciones, pero volverán al valor por defecto si las definiciones del usuario son suprimidas.)",
		--Translation missing 
		-- ["PlayerAverageItemLevel"] = "",
		["PlayerCurrentMana"] = "ManaActualJugador",
		["PlayerHealthDeficit"] = "DéficitSaludJugador",
		["PlayerHP"] = "VidaJugador",
		["PlayerManaDeficit"] = "DéficitManaJugador",
		["PlayerMaxHP"] = "VidaMaxJugador",
		["PlayerMaxMana"] = "ManaMaxJugador",
		["PlayerName"] = "NombreJugador",
		["PlayerPercentHP"] = "PorcentVidaJugador",
		["PlayerPercentMana"] = "PorcentManaJugador",
		["RandNum"] = "NumAleat",
		["removing user defined substitution \"%s\"; previously expanded to => \"%s\""] = "Quitando sustitución definida por el usuario \"%s\"; anteriormente ampliada a => \"%s\"",
		["Set substitution"] = "Establecer sustitución",
		["Set the value of a user defined substitution (NB: this may be the same as an existing default substitution; to reset it to the default, just remove the user created definition)."] = "Establecer el valor de una sustitución definida por el usuario (Nota: puede ser la misma que una sustitución predeterminada, para restablecerla a la predeterminada, sólo quitar la definición de usuario creada).",
		["subname -- NOTE: sub name without the prefix '%'"] = "subnombre -- NOTA: sub nombre sin el prefijo '%'",
		["subname = text after expansion -- NOTE: sub name without the prefix \"%\""] = "subnombre = texto después de expansión --NOTA: sub nombre sin el prefijo \"%\"",
		["substitution: %s defined as => %s"] = "sustitución: %s definido como => %s",
		["Substitutions"] = "Sustituciones",
		["TargetClass"] = "ClaseObjetivo",
		["TargetGender"] = "GéneroObjetivo",
		["TargetGuild"] = "HermandadObjetivo",
		["TargetHealth"] = "SaludObjetivo",
		["TargetHealthDeficit"] = "DéficitSaludObjetivo",
		["TargetIcon"] = "IconoObjetivo",
		["TargetLevel"] = "NivelObjetivo",
		["TargetManaDeficit"] = "DéficitManaObjetivo",
		["TargetName"] = "NombreObjetivo",
		["TargetPercentHP"] = "PorcentVidaObjetivo",
		["TargetPossesive"] = "PosesiónObjetivo",
		["TargetPronoun"] = "PronombreObjetivo",
		["TargetRace"] = "RazaObjetivo",
		["TargetTargetName"] = "ObjetivoObjetivoNombre",
		["unknown sex"] = "Sexo desconocido",
		["user defined substition \"%s\" not found"] = "sustitución definida por el usuario \"%s\" no encontrada",
		["User defined substitutions"] = "Sustituciones definidas por el usuario",
		["user substitutions index (usersubs_idx) doesn't exist! oh dear."] = "¡no existe un índice de sustituciones de usuario (usersubs_idx)!.",
		["usersub_"] = "sub usuario_",
	},
	["TellTarget"] = {
		["/tt"] = true,
		["Adds telltarget slash command (/tt)."] = "Añade comando decir a objetivo (/tt).",
		["No target selected."] = "Sin objetivo seleccionado.",
		["NoTarget"] = "SinObjetivo",
		["Target does not exist."] = "El Objetivo no existe.",
		["Target is not a player."] = "El Objetivo no es un jugador.",
		["TellTarget"] = "DecirObjetivo",
	},
	["Timestamps"] = {
		["Chat window timestamp options."] = "Opciones de MáscaraTiempo de la ventana de chat.",
		["colortimestamp_desc"] = "Alterna activación de colorear máscara de tiempo.",
		["colortimestamp_name"] = "Color Máscara de Tiempo",
		["Format All Timestamps"] = "Formatear Todas las Mascaras de Tiempo",
		["HH:MM (12-hour)"] = "HH:MM (12-horas)",
		["HH:MM (24-hour)"] = "HH:MM (24-horas)",
		["HH:MM:SS (12-hour)"] = "HH:MM:SS (12-horas)",
		["HH:MM:SS (24-hour)"] = "HH:MM:SS (24-horas)",
		["HH:MM:SS AM (12-hour)"] = "HH:MM:SS AM (12-horas)",
		["localtime_desc"] = "Activa o desactiva el uso de la hora local.",
		["localtime_name"] = "Utilizar Hora Local",
		["MM:SS"] = true,
		["Post-Timestamp"] = "Post-MáscaraTiempo",
		["Pre-Timestamp"] = "Pre-MáscaraTiempo",
		["Set the timestamp format"] = "Establecer el formato de la Máscara de Tiempo",
		["Set Timestamp Color"] = "Establecer Color MáscaraTiempo",
		["Sets the color of the timestamp."] = "Establece el Color de la Máscara de Tiempo.",
		["Show Timestamp"] = "Mostrar MáscaraTiempo",
		["show_desc"] = "Alterna activación de mostrar máscara de tiempo para cada ventana.",
		["show_name"] = "Mostrar Máscara de Tiempo",
		["space_desc"] = "Alterna activación de añadir un espacio tras la máscara de tiempo.",
		["space_name"] = "Mostrar Espacio",
		["Timestamps"] = "Máscara de Tiempo",
		["Toggle showing timestamp for each window."] = "Alterna mostrar máscara de tiempo para cada ventana.",
		["twocolumn_desc"] = "Colocar las máscaras de hora en una columna separada por lo que el texto no se ajustará debajo de ellas",
		["twocolumn_name"] = "2 Columnas Chat",
	},
	["UrlCopy"] = {
		["Change the color of the URL."] = "Cambia el color de la URL.",
		["Color URL"] = true,
		["Set Color"] = "Establecer Color",
		["Show Brackets"] = "Mostrar Corchetes",
		["Toggle"] = "Alternar",
		["Toggle showing brackets on and off."] = "Alterna activación de mostrar corchetes.",
		["Toggle the module on and off."] = "Alterna la activación del módulo.",
		["Toggle the URL color on and off."] = "Alterna activación del color de la URL.",
		["URL formating options."] = "Opciones de formateo de URL.",
		["UrlCopy"] = "CopiarURL",
		["Use Popup"] = "Utilizar Ventanas Emergentes",
		["Use popup window to show URL."] = "Utilizar ventanas emergentes para mostrar URL.",
	}
}

PL:AddLocale(PRAT_MODULE.name, "esES",L)


L=
{
	["display_desc"] = "控制及檢視聊天視窗",
	["display_name"] = "顯示設定",
	["extras_desc"] = "Msc. 模組",
	["extras_name"] = "附加擴充",
	["formatting_desc"] = "改變行的外觀以及感覺",
	["formatting_name"] = "聊天格式化",
	["load_desc"] = "控制此模組載入狀態。",
	["load_disabled"] = "已停用",
	["load_disabledonrestart"] = "已停用(重新載入)",
	["load_enabled"] = "已啟用",
	["load_enabledonrestart"] = "已啟用(重新載入)",
	["load_no"] = "不會載入",
	["modulecontrol_desc"] = "控制載入以及啟用的 Prat 模組。",
	["modulecontrol_name"] = "模組控制",
	["prat"] = "Prat",
	["reload_required"] = "變更此選項後仍無法發揮完整功能，除非你%s你的插件。",
	["AddonMsgs"] = {
		["Addon message options."] = "插件訊息選項",
		["AddonMsgs"] = "插件訊息",
		["show_desc"] = "切換是否在每個聊天視窗顯示隱藏的插件訊息。",
		["show_name"] = "顯示插件訊息",
		["show_perframedesc"] = "切換是否顯示隱藏的插件訊息",
		["show_perframename"] = "聊天框架%d 插件訊息顯示",
	},
	["Alias"] = {
		[" - list all aliases; supply <keyword> to search for matching aliases (cmd aliases: /listallaliases)"] = "- 列出所有別稱；提供 <keyword> 以搜尋所需的別稱（別稱指令：/listallaliases）",
		["%s() called with blank string!"] = "%s() 為空白字串！",
		["%s() called with nil argument!"] = "%s() 為無效參數！",
		["/%s aliased to \"/%s\""] = "/%s 別稱連結至 \"/%s\"",
		["/%s aliased to: /%s"] = "/%s 別稱連結至 \"/%s\"",
		["<alias> - remove the alias <alias> (cmd aliases: /delalias, /remalias)"] = "<alias> - 移除別稱 <alias>（別稱指令： /delalias，/remalias)",
		["<command>[ <value>] - alias <command> to be executed as <value>, or return the value of the currently defined alias for <command> if <command> has not been assigned a value. eg: \"/alias /examplehello /say hello there\" - typing \"/examplehello\" will now cause your character to say \"hello there\"; \"/alias examplehello\" - s \"/examplehello is aliased to /say hello there\" (cmd aliases: /addalias)"] = "<command>[ <value>] - 以代稱指令 <command> 來執行指令 <value>, 或當 <command> 後方沒有指定指令時通報目前設定給<command>之指定指令。 例如 \"/alias /examplehello /說 打招呼\" - 輸入 \"/examplehello\" 將使你的角色說 \"hello there\"; \"/alias examplehello\" - s \"/examplehello is aliased to /say hello there\" (cmd aliases: /addalias)",
		["<keyword> - finds all aliases matching <keyword> (cmd aliases: /findalias)"] = "<keyword> - 搜尋所有符合<keyword>的別稱（別稱指令： /findalias）",
		["add"] = "新增",
		["add an alias"] = "新增別稱",
		["alias \"/%s\" does not exist"] = "別稱 \"/%s\" 不存在",
		["dealiasing command /%s to /%s"] = "別稱的指令範圍/%s到/%s",
		["deleting alias \"/%s\" (previously aliased as \"/%s\")"] = "刪除別稱 \"/%s\"（先前別稱為 \"/%s\"）",
		["Display extra information in the chat frame when commands are dealiased"] = "當候選字的指令執行時在聊天視窗中顯示額外的訊息",
		["Don't overwrite existing aliases when using /addalias"] = "當使用 /addalias 禁止複寫已存在別稱",
		["Expand aliases as you are typing"] = "輸入文字時提示別稱",
		["find aliases matching a given search term"] = "搜尋與特定搜尋條件相符合之別稱",
		["findaliases"] = "搜尋別稱",
		["infinite loop detected for alias /%s - ignoring"] = "無限循環檢測別稱 /%s - 忽視",
		["inline"] = "內建",
		["list all aliases"] = "列出所有別稱",
		["listaliases"] = "列出別稱",
		["matching aliases found: %d"] = "相符合別稱: %d",
		["module_desc"] = "新增命令 /alias，其可將被使用於快捷指令如同 Unix系統中別稱指令。",
		["module_name"] = "別稱",
		["No aliases have been defined"] = "尚未定義任何別稱",
		["noclobber"] = "禁止複寫",
		["noclobber set - skipping new alias: /%s already expands to /%s"] = "禁止複寫設定 - 跳過新別稱：/%s 已擴充至 /%s",
		["Options"] = "選項",
		["Options for altering the behaviour of Alias"] = "修改別稱執行狀態選項",
		["overwriting existing alias \"/%s\" (was aliased to \"/%s\")"] = "複寫已存在別稱 \"/%s\"（為 \"/%s\" 之別稱）",
		--Translation missing 
		-- ["refusing to alias \"/%s\" to anything in the interests of Not Buggering Everything Up"] = "",
		["remove an alias"] = "移除別稱",
		["There is no alias current defined for \"%s\""] = "\"%s\" 尚未定義至任何別稱",
		["total aliases: %d"] = "總計別稱：%d",
		["tried to show value for alias \"%s\" but undefined in module.Aliases!"] = "試圖顯示縮寫指令\"%s\"的結果，但在module.Aliases中並未定義!",
		["unalias"] = "無別稱",
		["verbose"] = "詳細",
		["warnUser() called with nil argument!"] = "warnUser() 為無效參數！",
		["warnUser() called with zero length string!"] = "warnUser() 為零字元字串！",
	},
	["AltNames"] = {
		["%d alts found for %s: %s"] = "%d 分身找到於 %s: %s",
		["%s alts imported from LOKWhoIsWho"] = "%s 分身匯入來自 LOKWhoIsWho",
		["%s total alts linked to mains"] = "%s 總分身連結本尊",
		["(.-)'s? [Aa]lt"] = "%f[%a\\192-\\255]([%a\\192-\\255]+)%f[^%a\\128-\\255]'s [Aa]lt",
		["([^%s%p%d%c%z]+)'s alt"] = "%f[%a\\192-\\255]([%a\\192-\\255]+)%f[^%a\\128-\\255]'s [Aa]lt",
		[".*[Aa]lts?$"] = true,
		["<alt name> (eg, /altnames del Personyouthoughtwassomeonesaltbutreallyisnt)"] = "<alt name> (例如, /altnames del Personyouthoughtwassomeonesaltbutreallyisnt)",
		["<main> (eg /altnames listalts Fin)"] = "<main> (例如 /altnames listalts Fin)",
		["<search term> (eg, /altnames find fin)"] = "<search term> (例如, /altnames find fin)",
		["Alt"] = "分身",
		["alt"] = "分身",
		--Translation missing 
		-- ["alt name exists: %s -> %s; not overwriting as set in preferences"] = "",
		["AltNames"] = "分身名字",
		["Alts:"] = "分身:",
		--Translation missing 
		-- ["autoguildalts_desc"] = "",
		["autoguildalts_name"] = "自動匯入公會分身",
		["Be quiet"] = "安靜",
		["character removed: %s"] = "已移除角色：%s",
		["Class colour"] = "職業色彩",
		["Clear all"] = "清除所有",
		--Translation missing 
		-- ["Clear all links between alts and main names."] = "",
		["Colour"] = "顏色",
		--Translation missing 
		-- ["Delete a character's link to another character as their main."] = "",
		["Delete alt"] = "刪除別稱",
		["Disabled"] = "停用",
		["Display a player's alts in the tooltip"] = "顯示在提示玩家的分身",
		["Display a player's main name in the tooltip"] = "顯示在提示玩家的本尊名稱",
		--Translation missing 
		-- ["Display main names in the same colour as that of the alt's class (taking the data from the PlayerNames module if it is enabled)"] = "",
		--Translation missing 
		-- ["Display main names in the same colour as that of the main's class (taking the data from the PlayerNames module if it is enabled)"] = "",
		--Translation missing 
		-- ["Don't overwrite existing alt <-> main links when importing or adding new alts."] = "",
		["Don't overwrite existing links"] = "不要覆蓋現存的連接",
		["don't use"] = "不要使用",
		--Translation missing 
		-- ["Don't use data from the PlayerNames module at all"] = "",
		["ERROR: some function sent a blank message!"] = "錯誤：某些功能傳送空白訊息！",
		["Find characters"] = "搜尋角色",
		["Fix alts"] = "修正別稱",
		["Fix corrupted entries in your list of alt names."] = "修正列表中別稱損毀的項目",
		["Found alt: %s => main: %s"] = "搜尋別稱：%s => 主要名稱：%s",
		["guild member alts found and imported: %s"] = "公會成員別稱搜尋以及匯入：%s",
		["Import from Guild Greet database"] = "匯入來自公會問候資料庫",
		["Import from guild roster"] = "匯入公會名冊",
		["Import options"] = "匯入選項設定",
		--Translation missing 
		-- ["Imports alt names from a Guild Greet database, if present"] = "",
		--Translation missing 
		-- ["Imports alt names from the guild roster by checking for members with the rank \"alt\" or \"alts\", or guild / officer notes like \"<name>'s alt\""] = "",
		--Translation missing 
		-- ["Imports data from LOKWhoIsWho, if present (drop your SavedVariablesLOKWhoIsWho.lua in the Prat directory to be able to use this)."] = "",
		["Left"] = "左方",
		["link <alt name> <main name> (eg, /altnames link Fin Finjathealtoffin)"] = "link <alt name> <main name> (例如, /altnames link Fin Finjathealtoffin)",
		["Link alt"] = "連結分身",
		--Translation missing 
		-- ["Link someone's alt character with the name of their main."] = "",
		["linked alt %s => %s"] = "連結分身 %s=> %s",
		["List all"] = "列出所有",
		--Translation missing 
		-- ["List all links between alts and their main names."] = "",
		["List alts"] = "列出別稱",
		--Translation missing 
		-- ["List alts for a given character"] = "",
		["LOKWhoIsWho data not found"] = "LOKWhoIsWho 資料找不到",
		["LOKWhoIsWho import"] = "LOKWhoIsWho 匯入",
		["LOKWhoIsWho lua file not found, sorry."] = " LOKWhoIsWho lua 檔案找不到, 抱歉。 ",
		["Main"] = "主要",
		["main"] = "主要",
		["Main name position"] = "主要名稱位置",
		["Main:"] = "主要：",
		--Translation missing 
		-- ["mainpos_desc"] = "",
		["mainpos_name"] = "主要名稱位置",
		--Translation missing 
		-- ["module_desc"] = "",
		["no alts found for character "] = "未發現此角色分身",
		["no alts or mains found matching \"%s\""] = "找不到分身或本尊符合\"%s\"",
		--Translation missing 
		-- ["No arg string given to :addAlt()"] = "",
		["no characters called \"%s\" found; nothing deleted"] = "找不到角色\"%s\"; 沒有刪除",
		["No Guild Greet database found"] = "找不到公會問候資料庫",
		--Translation missing 
		-- ["No main name supplied to link %s to"] = "",
		["no matches found"] = "找不到符合",
		["quiet"] = "安靜",
		["quiet_desc"] = "是否回報至聊天視窗。",
		["quiet_name"] = true,
		["Right"] = "右",
		--Translation missing 
		-- ["Search the list of linked characters for matching main or alt names."] = "",
		["searched for: %s - total matches: %s"] = "搜索於: %s - 總符合: %s",
		["Show alts in tooltip"] = "顯示在提示分身",
		["Show main in tooltip"] = "顯示提示主要",
		["Start"] = "開始",
		--Translation missing 
		-- ["The colour of an alt's main name that will be displayed"] = "",
		["Use class colour (from the PlayerNames module)"] = "使用職業色彩（來自玩家名稱模組）",
		["use class colour of alt"] = "使用職業色彩於玩家次要人物",
		["use class colour of main"] = "使用職業色彩於玩家主要人物",
		["Use LibAlts Data"] = "使用 LibAlts 資料",
		--Translation missing 
		-- ["Use the data available via the shared alt information library."] = "",
		["Various ways to import a main's alts from other addons"] = "由其他插件以各種方法匯入非主要人物。",
		["warning: alt %s already linked to %s"] = "警告: 分身 %s 已經連結至 %s",
		["Where to display a character's main name when on their alt."] = "用以顯示人物主要名稱於其其他角色名稱。",
		["Whether to report to the chat frame or not."] = "是否回報至聊天框架裡。",
		["You are not in a guild"] = "你並沒有加入任何公會",
		--Translation missing 
		-- ["You have not yet linked any alts with their mains."] = "",
	},
	["Bubbles"] = {
		--Translation missing 
		-- ["color_desc"] = "",
		["color_name"] = "顏色氣泡",
		--Translation missing 
		-- ["font_desc"] = "",
		["font_name"] = "使用聊天字型",
		["fontsize_desc"] = "設定聊天氣泡字型尺寸",
		["fontsize_name"] = "字型尺寸",
		--Translation missing 
		-- ["format_desc"] = "",
		["format_name"] = "格式文字",
		["icons_desc"] = "顯示在聊天氣泡團隊圖示。",
		["icons_name"] = "顯示團隊圖示",
		["module_desc"] = "自訂對話泡泡",
		["module_name"] = "對話泡泡",
		--Translation missing 
		-- ["shorten_desc"] = "",
		["shorten_name"] = "縮短氣泡",
		--Translation missing 
		-- ["transparent_desc"] = "",
		--Translation missing 
		-- ["transparent_name"] = "",
	},
	["Buttons"] = {
		["alpha_desc"] = "設定所有聊天視窗的聊天選單以及箭頭。",
		["alpha_name"] = "設定透明度",
		["Buttons"] = "按鈕",
		["Chat window button options."] = "聊天視窗按鈕選單。",
		["chatmenu_desc"] = "切換聊天選單的開和關。",
		["chatmenu_name"] = "顯示聊天選單",
		["Default"] = "預設值",
		["Right, Inside Frame"] = "右側，內部框架",
		["Right, Outside Frame"] = "右側，外部框架",
		["scrollReminder_desc"] = "當不在聊天視窗底部時顯示剩餘按鈕",
		["scrollReminder_name"] = "顯示視窗可下卷的提示信號",
		["Set Position"] = "設定位置",
		["Sets position of chat menu and arrows for all chat windows."] = "設定聊天選單的位置與所有聊天視窗的箭頭。",
		["Show Arrows"] = "顯示箭頭",
		["Show Chat%d Arrows"] = "顯示聊天 %d 的箭頭",
		["showbnet_desc"] = "顯示社交選單",
		["showbnet_name"] = "顯示社交選單",
		["showmenu_desc"] = "顯示聊天選單",
		["showmenu_name"] = "顯示選單",
		["showminimize_desc"] = "顯示最小化按鈕",
		["showminimize_name"] = "顯示最小化按鈕",
		["Toggle showing chat arrows for each chat window."] = "點擊顯示每個聊天視窗的聊天箭頭",
		["Toggles navigation arrows on and off."] = "開啟/關閉輸入箭頭",
	},
	["ChannelColorMemory"] = {
		["(%w+)%s?(.*)"] = "(%S+)%s?(.*)",
		["ChannelColorMemory"] = "頻道顏色記憶",
		["Remembers the colors of each channel name."] = "記住每個頻道顏色的名稱。",
	},
	["ChannelNames"] = {
		["%s settings."] = "%s 設定。",
		["<string>"] = true,
		["Add Channel Abbreviation"] = "新增頻道縮寫",
		--Translation missing 
		-- ["addnick_desc"] = "",
		["Blank"] = "空白",
		--Translation missing 
		-- ["chanlink_desc"] = "",
		["chanlink_name"] = "新建聊天連結",
		["Channel %d"] = "頻道 %d",
		["Channel name abbreviation options."] = "頻道名稱縮寫選項",
		["ChannelNames"] = "頻道名稱",
		["channelnick_desc"] = "頻道簡稱",
		["channelnick_name"] = "頻道簡稱",
		["Clear Channel Abbreviation"] = "清除頻道名稱縮寫",
		["Clears an abbreviated channel name."] = "清除縮短頻道名稱。",
		--Translation missing 
		-- ["colon_desc"] = "",
		["colon_name"] = "顯示冒號",
		["Dont display the channel/chat type name"] = "不要顯示頻道/聊天類型名稱",
		--Translation missing 
		-- ["otheropts_desc"] = "",
		["otheropts_name"] = "其他選項",
		["Remove Channel Abbreviation"] = "移除頻道縮寫",
		["Removes an an abbreviated channel name."] = "移除縮短頻道名稱。",
		["Replace"] = "替換",
		["Set"] = "設定",
		--Translation missing 
		-- ["space_desc"] = "",
		["space_name"] = "顯示空格",
		["Toggle replacing this channel."] = "切換替代此頻道。",
		["Use a custom replacement for the chat %s text."] = "用自訂更換聊天 %s 文字。",
	},
	["ChannelSticky"] = {
		["Channel"] = "頻道",
		["ChannelSticky"] = "固定頻道",
		["Chat channel sticky options."] = "聊天頻道固定選項",
		["ChatType"] = "聊天類型",
		["Per chat type options."] = "每聊天類型選項。",
		--Translation missing 
		-- ["smartgroup_desc"] = "",
		["smartgroup_name"] = "智慧化群組",
		["Sticky %s"] = "固定 %s",
		["Sticky Per Chat Frame"] = "個別聊天視窗固定",
		--Translation missing 
		-- ["Toggle remembering the chat type last used per chat frame."] = "",
		--Translation missing 
		-- ["Toggles sticky on and off for %s."] = "",
	},
	["ChatFrames"] = {
		["Chat window frame parameter options"] = "聊天視窗框架參數選項",
		--Translation missing 
		-- ["framealpha_desc"] = "",
		["framealpha_name"] = "設定聊天欄透明度",
		["Frames"] = "框架",
		--Translation missing 
		-- ["mainchatonload_desc"] = "",
		["mainchatonload_name"] = "強制主聊天框在載入",
		["maxchatheight_desc"] = "設定最大高度全部聊天視窗。",
		["maxchatheight_name"] = "設定最大高度",
		["maxchatwidth_desc"] = "設定最大寬度全部聊天視窗。",
		["maxchatwidth_name"] = "設定最大寬度",
		["minchatheight_desc"] = "設定對話視窗最小高度",
		["minchatheight_name"] = "設定最小高度",
		["minchatwidth_desc"] = "設定對話視窗最小寬度",
		["minchatwidth_name"] = "設定最小寬度",
		--Translation missing 
		-- ["rememberframepositions_desc"] = "",
		--Translation missing 
		-- ["rememberframepositions_name"] = "",
		--Translation missing 
		-- ["removeclamp_desc"] = "",
		--Translation missing 
		-- ["removeclamp_name"] = "",
	},
	["ChatLink"] = {
		["gem_desc"] = "啟用珠寶鑲嵌模式",
		["gem_name"] = "珠寶鑲嵌",
		["module_desc"] = "聊天頻道連結選項",
		--Translation missing 
		-- ["module_info"] = "",
		["module_name"] = "頻道連結",
		["Trade"] = "交易",
	},
	["ChatLog"] = {
		["A module to automaticaly enable chat and combat logging."] = "模組：自動啟用聊天以及戰鬥紀錄。",
		["Chat log recorded to <WoW Installation>\\Logs\\WoWChatLog.txt only upon logout."] = "聊天紀錄至 <WoW Installation>\\Logs\\WoWChatLog.txt 僅於遊戲登出時。",
		["Chat Log: Disabled"] = "聊天記錄：已停用",
		["Chat Log: Enabled"] = "聊天記錄：已啟用",
		["ChatLog"] = "聊天記錄",
		["Combat log recorded to <WoW Installation>\\Logs\\WoWCombatLog.txt only upon logout."] = "戰鬥紀錄至 <WoW Installation>\\Logs\\WoWChatLog.txt 僅於遊戲登出時。",
		["Combat Log: Disabled"] = "戰鬥記錄：已停用",
		["Combat Log: Enabled"] = "戰鬥記錄：已啟用",
		["quiet_desc"] = "禁止顯示任何訊息當插件啟用時的訊息或者插件改變紀錄設定時。",
		["quiet_name"] = "禁止回饋訊息",
		["Toggle Chat Log"] = "切換聊天記錄",
		["Toggle chat log on and off."] = "切換聊天記錄啟用",
		["Toggle Combat Log"] = "切換戰鬥記錄",
		["Toggle combat log on and off."] = "切換戰鬥記錄啟用",
	},
	["ChatTabs"] = {
		["Active Alpha"] = "使用中透明度",
		["All"] = "所有",
		["Always"] = "總是",
		["Chat window tab options."] = "聊天視窗標籤選單",
		["Default"] = "預設值",
		["disableflash_desc"] = "停用聊天標籤閃爍",
		["disableflash_name"] = "停用閃爍",
		["Hidden"] = "隱藏",
		["Individual"] = "個人",
		["Not Active Alpha"] = "非使用中透明度",
		["preventdrag_desc"] = "預防以滑鼠拖曳聊天標籤",
		["preventdrag_name"] = "防止拖曳",
		["Set ChatFrame%d Display Mode"] = "設定聊天框架 %d 的顯示模式",
		["Set Display Mode"] = "設定顯示模式",
		["Set tab display mode for each chat window."] = "為個別聊天標籤顯示模式設定. 核選（啟用），取消（停用），灰階（預設值）",
		["Set tab display to always, hidden or the Blizzard default."] = "設定是否顯示聊天標籤或者是 Blizzard預設值",
		["Sets alpha of chat tab for active chat frame."] = "設定使用中聊天視窗標籤透明度",
		["Sets alpha of chat tab for not active chat frame."] = "設定非使用中聊天視窗標籤透明度",
		["Tabs"] = "標籤",
	},
	["Clear"] = {
		["Adds clear text slash commands (/clear)(/cls)(/clearall)(/clsall)."] = "新增清除文字的快捷命令 (/clear)(/cls)(/clearall)(/clsall)",
		["Clear"] = "清除",
		["Clearall"] = "全部清除",
		["Clears all chat frames."] = "清除所有聊天視窗。",
		["Clears the current chat frame."] = "清除當前聊天視窗。",
	},
	["CopyChat"] = {
		[" Text"] = "文字",
		["BBCode"] = true,
		["BOTTOMLEFT"] = "下, 左",
		["BOTTOMRIGHT"] = "下, 右",
		--Translation missing 
		-- ["buttonpos_desc"] = "",
		["buttonpos_name"] = "按鈕位置",
		["ChatFrame"] = "聊天視窗",
		--Translation missing 
		-- ["Copy all of the text in the selected chat frame into an edit box"] = "",
		["Copy Text"] = "複製文字",
		["Copy Text Format"] = "複製文字格式",
		["Copy text from the active chat window."] = "複製使用中聊天視窗文字",
		["Copy To Editbox"] = "複製至編輯盒",
		["CopyChat"] = true,
		["HTML"] = true,
		["Message From : %s"] = "來自 %s 的訊息",
		--Translation missing 
		-- ["Plain"] = "",
		--Translation missing 
		-- ["Should the copied text be plain, or formatted so you can see the colors."] = "",
		["showbutton_desc"] = "於聊天視窗中顯示按鈕",
		["showbutton_name"] = "複製按鈕",
		["TOPLEFT"] = "上, 左",
		["TOPRIGHT"] = "上, 右",
		["Wowace.com Forums"] = "Wowace.com 論壇",
	},
	["CustomFilters"] = {
		["<string>"] = true,
		["Add a pattern to search for."] = "新增模式搜索。",
		["Add Pattern"] = "新增樣式",
		["Block Message"] = "屏蔽訊息",
		["Channel Data"] = "頻道資料",
		["Channel to send output text to."] = "頻道發送輸出文字至。",
		["Enabled"] = "已啟用",
		["Extra data for WHISPER (target) and CHANNEL (channel name or num)"] = "額外資料密話(目標)和頻道(頻道名稱或數字)",
		["Filter Name"] = "過濾名稱",
		["Forward"] = "轉送",
		["Forward the message to a chat channel."] = "轉送訊息至聊天頻道",
		["Forward the message to a custom chat channel."] = "轉送名稱至自訂聊天頻道",
		["ForwardCustom"] = "自訂轉送",
		["ForwardMessage"] = "轉送訊息",
		["ForwardMessageCustom"] = "私人頻道",
		["Hilight Color"] = "高亮提示色彩",
		["Hilight Match Text"] = "符合高亮提示文字",
		["Inbound"] = "傳入",
		["inchannels_desc"] = "搜尋某些頻道",
		["inchannels_name"] = "搜尋頻道",
		--Translation missing 
		-- ["Is this pattern enabled for use?"] = "",
		["Match Options"] = "匹配選項",
		["module_desc"] = "支援自訂過濾的模組",
		["module_name"] = "自定義過濾",
		--Translation missing 
		-- ["Only output the message portion of the chat text, leave out the channel, and playername etc."] = "",
		["Outbound"] = "傳出",
		["Output Channel"] = "輸出頻道",
		["Output Message Only"] = "僅輸出訊息",
		["Pattern Info"] = "樣式資訊",
		["Pattern Options"] = "模式選項",
		--Translation missing 
		-- ["Play a sound when this message is output to the chatframe"] = "",
		["Play Sound"] = "播放音效",
		--Translation missing 
		-- ["Prevent the message from being displayed"] = "",
		["Remove an existing pattern."] = "替換文本",
		["Remove Pattern"] = "移除模板",
		["Replacement Text"] = "替換文字",
		["Search Format String"] = "搜尋格式字串",
		["Search Pattern"] = "搜尋樣式",
		["Secondary Output"] = "次要輸出",
		["Send to a secondary output"] = "發送次要輸出",
		--Translation missing 
		-- ["Supplied pattern is a format string instead of a pattern"] = "",
		["Your name for this filter"] = "你的名字此過濾",
	},
	["Editbox"] = {
		["Attach edit box to..."] = "附上編輯框...",
		["Attach to..."] = "附上...",
		["Background color"] = "背景色彩",
		["Background Inset"] = "背景插入",
		["Background texture"] = "背景材質",
		["Border color"] = "邊緣色彩",
		["Border texture"] = "邊緣材質",
		["Bottom"] = "底部",
		["Color border by channel"] = "顏色邊框由道頻",
		--Translation missing 
		-- ["currently_broken_alt_behavior"] = "",
		["Edge Size"] = "邊框尺寸",
		["Editbox"] = "輸入框",
		["Editbox options."] = "輸入框選單",
		["Font"] = "字型",
		["Free-floating"] = "自由浮動",
		["Free-floating, Locked"] = "自由浮動, 已鎖定",
		--Translation missing 
		-- ["Requires the Alt key to be held down to move the cursor in chat"] = "",
		["Select the font to use for the edit box"] = "選擇字型使用編輯框",
		--Translation missing 
		-- ["Sets the frame's border color to the color of your currently active channel"] = "",
		["Tile Size"] = "並排尺寸",
		["Top"] = "頂部",
		["Use Alt key for cursor movement"] = "使用 Alt 鍵游標移動",
	},
	["EventNames"] = {
		--Translation missing 
		-- ["allevents_desc"] = "",
		--Translation missing 
		-- ["allevents_name"] = "",
		["Chat window event name options."] = "聊天視窗事件名稱選項。",
		["EventNames"] = "事件名稱",
		["Show"] = "顯示",
		["Show events on chatframes"] = "於聊天視窗顯示事件",
		["show_desc"] = "切換顯示在每個視窗事件名稱。",
		["show_name"] = "顯示事件名稱",
	},
	["Fading"] = {
		["duration_desc"] = "設定視窗消褪秒數",
		["duration_name"] = "設定淡化延遲（秒數）",
		["module_desc"] = "聊天室窗淡化選項",
		["module_name"] = "淡化",
		["textfade_desc"] = "切換視窗文字消褪",
		["textfade_name"] = "啟用淡化",
	},
	["Filtering"] = {
		["A module to provide basic chat filtering."] = "模組：提供基本聊天過濾。",
		--Translation missing 
		-- ["afkdnd_desc"] = "",
		--Translation missing 
		-- ["afkdnd_name"] = "",
		["bgjoin_desc"] = "濾除戰場頻道離開/加入訊息",
		["bgjoin_name"] = "過濾戰場離開/參加",
		["Filtering"] = "過濾",
		["leavejoin_desc"] = "濾除頻道離開/加入訊息",
		["leavejoin_name"] = "過濾頻道離開/加入",
		["notices_desc"] = "濾除自訂頻道通知訊息，像是主持人變動",
		["notices_name"] = "過濾頻道通知",
		--Translation missing 
		-- ["tradespam_desc"] = "",
		--Translation missing 
		-- ["tradespam_name"] = "",
	},
	["Font"] = {
		["Auto Restore Font Size"] = "自動還原字型大小",
		["Chat window font options."] = "聊天視窗字型選項。",
		["Font"] = "字型",
		["monochrome_desc"] = "切換字型的灰階色彩。",
		["monochrome_name"] = "切換灰階",
		["None"] = "無",
		["Outline"] = "輪廓",
		["outlinemode_desc"] = "設定字體是否加粗輪廓",
		["outlinemode_name"] = "設定輪廓模式",
		["rememberfont_desc"] = "記住字型設定",
		["rememberfont_name"] = "記憶字型",
		["Set ChatFrame%d Font Size"] = "設定聊天視窗 %d 之字型大小",
		["Set Font Face"] = "設定字體",
		["Set Font Size"] = "設定字型大小",
		["Set Separately"] = "個別設定",
		["Set text font size for each chat window."] = "設定個別聊天視窗字型大小",
		["Set text font size."] = "設定文字字型大小",
		["Set the text font face for all chat windows."] = "設定所有聊天視窗字體",
		["shadowcolor_desc"] = "設定陰影效果色彩",
		["shadowcolor_name"] = "設定陰影色彩",
		["Thick Outline"] = "粗邊",
		["Toggle setting options separately for each chat window."] = "切換設定選項分開地每個聊天視窗。",
		["Workaround a Blizzard bug which changes the font size when you open a system menu."] = "開啟系統選單時變更Blizzard錯誤訊息的字型大小。",
	},
	["History"] = {
		["Chat history options."] = "歷史訊息選項。",
		["Color GMOTD"] = "顏色 GMOTD",
		["Colors the GMOTD label"] = "顏色 GMOTD 標籤",
		--Translation missing 
		-- ["delaygmotd_desc"] = "",
		["delaygmotd_name"] = "延遲 GMOTD",
		["divider"] = "========== 捲動結束 ==========",
		["History"] = "歷史訊息",
		["Maximum number of lines of command history to save."] = "最大行數的指令記錄儲存。",
		["Save Command History"] = "儲存指令歷史",
		--Translation missing 
		-- ["Saves command history between sessions (for use with alt+up arrow or just the up arrow)"] = "",
		["Scrollback"] = "捲動",
		["Scrollback Options"] = "捲動選項",
		--Translation missing 
		-- ["scrollbacklen_desc"] = "",
		["scrollbacklen_name"] = "捲動長度",
		["Set Chat Lines"] = "設定聊天行數",
		["Set Command History"] = "設定指令歷史",
		["Set the number of lines of chat history for each window."] = "設定行數的聊天記錄每個視窗。",
		--Translation missing 
		-- ["Store the chat lines between sessions"] = "",
	},
	["KeyBindings"] = {
		["Channel %d"] = "頻道 %d",
		["Copy Selected Chat Frame"] = "複製選取的聊天視窗",
		["Guild Channel"] = "公會頻道",
		["Instance Channel"] = "戰場頻道",
		["Next Chat Tab"] = "次個聊天標籤",
		["Officer Channel"] = "幹部頻道",
		["Party Channel"] = "小隊頻道",
		["Prat CopyChat"] = "Prat 聊天複製",
		["Prat Keybindings"] = "Prat按鍵綁定",
		["Prat TellTarget"] = true,
		["Raid Channel"] = "團隊頻道",
		["Raid Warning Channel"] = "團隊警告頻道",
		["Say"] = "說",
		["Smart Group Channel"] = "按鍵綁定",
		["TellTarget"] = true,
		["Whisper"] = "密語",
		["Yell"] = "大喊",
	},
	["OriginalButtons"] = {
		["alpha_desc"] = "為所有聊天視窗選單以及箭頭設定透明度",
		["alpha_name"] = "設定透明度",
		["buttonframe_desc"] = "切換按鍵框架選項",
		["buttonframe_name"] = "顯示按鍵框架",
		["ChannelNames"] = "頻道名稱",
		["Chat window button options."] = "聊天視窗按鈕選項。",
		["chatmenu_desc"] = "切換聊天選單開啟/關閉",
		["chatmenu_name"] = "顯示聊天選單",
		["Default"] = "預設值",
		["Original Buttons"] = "預設按鈕",
		--Translation missing 
		-- ["reflow_desc"] = "",
		["reflow_name"] = "文字流動環繞",
		["reminder_desc"] = "顯示按鈕提醒當聊天視窗未在最底層時",
		["reminder_name"] = "顯示下方箭頭提示",
		["Right, Inside Frame"] = "右側，視窗內部",
		["Right, Outside Frame"] = "左側，視窗外部",
		["Set Position"] = "設置位置",
		["Sets position of chat menu and arrows for all chat windows."] = "為所有聊天視窗設定聊天選單以及箭頭位置",
		["Show Arrows"] = "顯示箭頭",
		["Show Chat%d Arrows"] = "顯示聊天 %d 箭頭",
		["Toggle showing chat arrows for each chat window."] = "為所有聊天視窗啟用聊天箭頭。",
		["Toggles navigation arrows on and off."] = "切換是否啟用導覽箭頭",
	},
	["OriginalEditbox"] = {
		["Autohide"] = "自動隱藏",
		["BACKGROUND"] = "背景",
		["Bar colour"] = "條列顏色",
		["Border colour"] = [=[邊框顏色
]=],
		["Border width"] = "邊框寬度",
		["Bottom"] = "底部",
		--Translation missing 
		-- ["Click the edit box to open it up for editing. Only available if Autohide is disabled."] = "",
		["Clickable"] = "可用點擊",
		["DIALOG"] = true,
		["Editbox options."] = "編輯選項。",
		["Enable Arrowkeys"] = "啟用箭頭鍵",
		--Translation missing 
		-- ["Enable using arrowkeys in editbox without the alt key."] = "",
		["Hide Border"] = "隱藏邊緣",
		["Hide the border around the edit box."] = "隱藏邊框環繞編輯框。",
		--Translation missing 
		-- ["Hide the edit box after you have pressed enter."] = "",
		["HIGH"] = "高",
		--Translation missing 
		-- ["Lock editbox position if undocked."] = "",
		["Lock Position"] = "鎖住位置",
		["LOW"] = "低",
		["MEDIUM"] = "中",
		["OriginalEditbox"] = "原始編輯框",
		["Padding"] = "填料",
		["Set Alpha"] = "設定透明度",
		["Set Position"] = "設定位置",
		["Set Strata"] = "設定階層",
		["Set the alpha of the editbox."] = "設定編輯框透明度",
		--Translation missing 
		-- ["Set the amount of padding inside the edit box"] = "",
		["Set the edit box background colour"] = "設定編輯框背景色彩",
		["Set the edit box border colour"] = "設定編輯框邊緣色彩",
		["Set the frame strata of the editbox."] = "設定編輯框的顯示層級",
		["Set the position of the editbox."] = "設定編輯框位置",
		["Set the texture of the chat edit box"] = "設定編輯框材質",
		["Set the width of the edit box's border"] = "設定輸入框邊緣寬度",
		["Set the width of the editbox."] = "設定輸入框寬度",
		--Translation missing 
		-- ["Set Width (NB: only enabled if the editbox is undocked)"] = "",
		["Texture"] = "材質",
		["Top"] = "頂部",
		["Undocked"] = "取消停靠",
	},
	["Paragraph"] = {
		["adjustlinks_desc"] = "在置中或靠右排列文字時，調整連結並復原點擊開啟能力",
		["adjustlinks_name"] = "修正玩家或物品連結",
		["Center"] = "中央",
		["Chat window paragraph options."] = "聊天視窗段落設定",
		["justification_desc"] = "設定所有聊天視窗水平對齊",
		["justification_name"] = "設定對齊",
		["Left"] = "左方",
		["Line Spacing"] = "行間距",
		["Paragraph"] = "段落",
		["Right"] = "右",
		["Set the line spacing for all chat windows."] = "設定聊天視窗段落間隔",
	},
	["PlayerNames"] = {
		["Actively Query Player Info"] = "主動查詢玩家資訊",
		["Angled"] = "角",
		["Brackets"] = "括號",
		["Brackets Common Color"] = "括號通用色彩",
		["Brackets Use Common Color"] = "括號使用的通用色彩",
		["Class"] = "職業",
		["Color by Level Difference"] = "等級差異色彩",
		["coloreverywhere_desc"] = "當玩家名稱出現在聊天訊息文字中時，為其上色。",
		["coloreverywhere_name"] = "顏色名字到處",
		["Enable Alt-Invite"] = "啟用 Alt 按鍵邀請",
		["Enable Invite Links"] = "啟用邀請連結",
		["Enable TabComplete"] = "啟用 TabComplete",
		--Translation missing 
		-- ["hoverhilight_desc"] = "",
		["hoverhilight_name"] = "滑鼠懸停高亮",
		["How to color other player's level."] = "如何為玩家等級著色",
		["How to color player's name."] = "如何為玩家名稱著色",
		["Keep Info"] = "保存資訊",
		["Keep Lots Of Info"] = "保存大量資訊",
		["Keep player information between session for all players except cross-server players"] = "保存此階段所有玩家資訊，除了跨伺服器人物。",
		["Keep player information between session, but limit it to friends and guild members."] = "保存此階段玩家資訊，但限制為好友以及公會成員。",
		--Translation missing 
		-- ["Let TasteTheNaimbow set the common color for unknown player names."] = "",
		["Level Color Mode"] = "等級色彩模式",
		["linkifycommon_desc"] = "製作連結共同的訊息",
		["linkifycommon_name"] = "製作連結共同的訊息",
		["No additional coloring"] = "無額外著色",
		["None"] = "無",
		["Player Color Mode"] = "玩家色彩模式",
		["Player name formating options."] = "玩家名稱格式化選項。",
		["PlayerNames"] = "玩家名稱",
		["Prat_Playernames: Stored Player Data Cleared"] = "Prat_Playernames：已清除儲存的玩家資料",
		["Query the server for all player names we do not know. Note: This happpens pretty slowly, and this data is not saved."] = "查詢所有此伺服器我們不知道的角色名稱。備註：這個程序相當緩慢且並不會儲存此資料。",
		["Random"] = "隨機",
		["realidcolor_desc"] = "RealID 名稱著色",
		["realidcolor_name"] = "RealID 著色",
		["Reset Settings"] = "重置設定",
		["Restore default settings, and delete stored character data."] = "恢復至預設值且刪除儲存的角色資料。",
		["Set common color of unknown player names."] = "設定未知角色的顯示色彩",
		["Sets common color of brackets to use around player names."] = "設定用來圍繞玩家名稱的括號顏色。",
		["Sets style of brackets to use around player names."] = "設定用來圍繞玩家名稱的括號類型。",
		["Show Group"] = "顯示隊伍編號",
		["Show Level"] = "顯示等級",
		["Show Raid Target Icon"] = "顯示團隊標記",
		["Square"] = "方框",
		["Tab completion : "] = "標籤完成:",
		["tabcomplete_name"] = "可能的名稱 ",
		--Translation missing 
		-- ["Toggle group invites by alt-clicking hyperlinked keywords like 'invite'."] = "",
		["Toggle group invites by alt-clicking on player name."] = "組隊邀請用alt-點擊玩家名稱。",
		["Toggle level showing."] = "切換等級顯示。",
		["Toggle raid group showing."] = "切換團隊組隊顯示。",
		["Toggle showing the raid target icon which is currently on the player."] = "顯示當前玩家的團隊目標圖標",
		["Toggle tab completion of player names."] = "切換玩家名稱的標籤完成。",
		["Toggle using a common color for brackets around player names."] = "選擇是否為玩家名稱外的括號使用一個通用顏色",
		["Toggle using a common color for unknown player names."] = "切換未知玩家以一般色彩顯示",
		["Too many matches (%d possible)"] = "太多符合 (可能 %d)",
		["Unknown Common Color"] = "未知的文字通用顏色",
		["Unknown Common Color From TasteTheNaimbow"] = "來自TasteTheNaimbow 的未知的文字通用顏色",
		["Unknown Use Common Color"] = "未知的文字使用通用顏色",
		["Use Channel Color"] = "使用頻道文字顏色",
		["Use Player Color"] = "使用腳色名稱文字色彩",
		--Translation missing 
		-- ["Use toon name for RealID"] = "",
	},
	["PopupMessage"] = {
		["Add Nickname"] = "新增暱稱",
		--Translation missing 
		-- ["Adds an alternate name to show in popups."] = "",
		["Clear Nickname"] = "清除暱稱",
		--Translation missing 
		-- ["Clears alternate name to show in popups."] = "",
		["framealpha_desc"] = "設定彈出視窗完全淡入時的透明度值",
		["framealpha_name"] = "彈出視窗透明度",
		["Popup"] = "彈出",
		["PopupMessage"] = "彈出訊息",
		["Remove Nickname"] = "移除暱稱",
		--Translation missing 
		-- ["Removes an alternate name to show in popups."] = "",
		["Set Separately"] = "單獨設定",
		["Show All Popups"] = "顯示所有彈出視窗",
		["Show Popups"] = "顯示彈出視窗",
		["Show Popups for all chat windows."] = "顯示彈出全部聊天視窗。",
		["Show Popups for each window."] = "顯示彈出每個視窗。",
		["show_desc"] = "顯示彈出每個視窗。",
		["show_name"] = "顯示彈出",
		["show_perframedesc"] = "換顯示彈出開動和關閉。",
		["show_perframename"] = "顯示 ChatFrame%d 彈出",
		["showall_desc"] = "顯示彈出全部聊天視窗。",
		["showall_name"] = "顯示全部彈出",
		["Shows messages in a popup window."] = "顯示在彈出視窗訊息。",
		--Translation missing 
		-- ["Shows messages with your name in a popup."] = "",
		--Translation missing 
		-- ["Toggle setting options separately for each chat window."] = "",
	},
	["Scroll"] = {
		["Bottom"] = "由下而上",
		["Chat window scrolling options."] = "聊天視窗滾動選項",
		--Translation missing 
		-- ["Control whether text is added to the frame at the top or the bottom."] = "",
		["lowdown_desc"] = "切換是否於個別聊天視窗自動跳轉至最新訊息",
		["lowdown_name"] = "啟用 TheLowDown",
		["modified_speed"] = "設定 Shift+滑鼠滾輪速度",
		--Translation missing 
		-- ["modified_speed_desc"] = "",
		["mousewheel_desc"] = "切換是否於個別聊天視窗支援滑鼠滾輪",
		["mousewheel_name"] = "啟用滑鼠滾輪",
		["Scroll"] = "滾動",
		["Set Ctrl+MouseWheel Speed"] = "設定 Ctrl 及滑鼠滾輪速度",
		["Set MouseWheel Speed"] = "設定滑鼠滾輪速度",
		["Set number of lines mousewheel will scroll when ctrl is pressed."] = "設定當按下 Ctrl時滑鼠滾輪滾動的行數",
		["Set number of lines mousewheel will scroll."] = "設定滑鼠滾輪將滾動行數數字",
		["Set TheLowDown Delay"] = "設定上下延遲",
		--Translation missing 
		-- ["Set time to wait before jumping to the bottom of chat windows."] = "",
		["Text scroll direction"] = "文字滾動方向",
		["Top"] = "由上而下",
	},
	["Search"] = {
		["err_notfound"] = "找不到",
		["err_tooshort"] = "尋找物品太短",
		["find_results"] = "找到結果:",
		--Translation missing 
		-- ["module_desc"] = "",
		--Translation missing 
		-- ["module_info"] = "",
		["module_name"] = "尋找",
	},
	["ServerNames"] = {
		--Translation missing 
		-- ["autoabbreviate_desc"] = "",
		["autoabbreviate_name"] = "自動縮短",
		--Translation missing 
		-- ["colon_desc"] = "",
		["colon_name"] = "顯示冒號",
		["randomclr_desc"] = "伺服器名稱使用隨機色彩",
		["randomclr_name"] = "隨機色彩",
		["Server name abbreviation options."] = "伺服器名稱縮寫選項",
		["ServerNames"] = "伺服器名稱",
	},
	["Sounds"] = {
		["A module to play sounds on certain chat messages."] = "模組：於特定聊天訊息播放音效。",
		["Add a custom channel"] = "加入自訂頻道",
		["bn_whisper_desc"] = "聲音於 %s Battle.Net 密話訊息",
		["bn_whisper_name"] = "Battle.Net 密話",
		["Custom Channels"] = "自訂頻道",
		--Translation missing 
		-- ["group_lead_desc"] = "",
		["group_lead_name"] = "隊長",
		["guild_desc"] = "公會訊息音效：%s",
		["guild_name"] = "公會",
		["incoming"] = "收入",
		["Incoming Sounds"] = "收入聲音",
		["officer_desc"] = "幹部頻道音效：%s",
		["officer_name"] = "幹部",
		["outgoing"] = "外出",
		["Outgoing Sounds"] = "外出聲音",
		["party_desc"] = "小隊訊息音效：%s",
		["party_name"] = "小隊",
		["Play a sound for a certain channel name (can be a substring)"] = "於此頻道播放音效（可為字串）",
		["raid_desc"] = "戰場以及戰場領導訊息音效：%s",
		["raid_name"] = "團隊",
		["Remove a custom channel"] = "移除自訂頻道",
		["Reset settings"] = "重置設定",
		["Restore default settings and resets custom channel list"] = "恢復預設設定以及重置自訂聊天列表",
		["Sound selection for incoming chat messages"] = "發送選擇收入聊天訊息",
		["Sound selection for outgoing (from you) chat messages"] = "發送選擇外出(從你)聊天訊息",
		["Sounds"] = "音效",
		["whisper_desc"] = "密語訊息音效：%s",
		["whisper_name"] = "密語",
	},
	["Substitutions"] = {
		["%d total user defined substitutions"] = "%d 總使用者定義代替",
		--Translation missing 
		-- ["|cffff0000warning:|r subtitution \"%s\" already defined as \"%s\", overwriting"] = "",
		["<noguild>"] = "<無公會>",
		["<notarget>"] = "<無目標>",
		["A module to provide basic chat substitutions."] = "提供基本聊天標題的模組",
		["Are you sure - this will delete all user defined substitutions and reset defaults?"] = "你確定嗎 - 這將刪除所有使用者替換且重置至預設值？",
		["Are you sure?"] = "你確定嗎？",
		--Translation missing 
		-- ["can't find substitution index for a substitution named '%s'"] = "",
		["current-prompt"] = [=[當前值：%s
點擊以在聊天視窗中貼上]=],
		["defined %s: expands to => %s"] = "定義 %s：擴張至 => %s",
		["Delete all"] = "刪除所有",
		["Delete substitution"] = "刪除標題",
		["Deletes a user defined substitution"] = "刪除一個由使用者自定義的標題",
		["Deletes all user defined substitutions"] = "刪除所有由使用者自定義的標題",
		["female"] = "女性",
		["her"] = "她",
		["hers"] = "她的",
		["him"] = "他",
		["his"] = "他的",
		["it"] = "它",
		["its"] = "它的",
		["List of available substitutions"] = "可用標題清單",
		["List of available substitutions defined by this module. (NB: users may define custom values for existing substitutions, but they will revert to the default value if the user definition is deleted.)"] = "由此模組定義的可用標題之清單",
		["List substitutions"] = "標題清單",
		["Lists all current subtitutions in the default chat frame"] = "默認聊天框中所有現用標題清單",
		["male"] = "男性",
		["MapLoc"] = true,
		["MapPos"] = "地圖位置",
		["MapXPos"] = "地圖X軸",
		["MapYPos"] = "地圖Y軸",
		["MapZone"] = "地圖地區",
		--Translation missing 
		-- ["module:buildUserSubsIndex(): warning: module patterns not defined!"] = "",
		["MouseoverTargetName"] = "鼠標懸停目標名字",
		["NO MATCHFUNC FOUND"] = true,
		--Translation missing 
		-- ["no substitution name given"] = "",
		--Translation missing 
		-- ["no substitution name supplied for deletion"] = "",
		["no user defined subs found"] = "找不到使用者定義的代替",
		--Translation missing 
		-- ["no value given for subtitution \"%s\""] = "",
		--Translation missing 
		-- ["Options for setting and removing user defined substitutions. (NB: users may define custom values for existing substitutions, but they will revert to the default value if the user definition is deleted.)"] = "",
		["PlayerAverageItemLevel"] = true,
		["PlayerCurrentMana"] = "玩家當前法力值",
		["PlayerHealthDeficit"] = "玩家生命不足",
		["PlayerHP"] = "玩家生命值",
		["PlayerManaDeficit"] = "玩家法力不足",
		["PlayerMaxHP"] = "玩家最大血量",
		["PlayerMaxMana"] = "玩家最大法力",
		["PlayerName"] = "玩家名字",
		["PlayerPercentHP"] = "玩家百分比血量",
		["PlayerPercentMana"] = "玩家百分比法力",
		["RandNum"] = true,
		--Translation missing 
		-- ["removing user defined substitution \"%s\"; previously expanded to => \"%s\""] = "",
		["Set substitution"] = "設定代替",
		--Translation missing 
		-- ["Set the value of a user defined substitution (NB: this may be the same as an existing default substitution; to reset it to the default, just remove the user created definition)."] = "",
		--Translation missing 
		-- ["subname -- NOTE: sub name without the prefix '%'"] = "",
		--Translation missing 
		-- ["subname = text after expansion -- NOTE: sub name without the prefix \"%\""] = "",
		["substitution: %s defined as => %s"] = "代替: %s 定義為 => %s",
		["Substitutions"] = "代替",
		["TargetClass"] = "目標職業",
		["TargetGender"] = "目標性別",
		["TargetGuild"] = "目標公會",
		["TargetHealth"] = "目標生命",
		["TargetHealthDeficit"] = "目標生命不足",
		["TargetIcon"] = "目標圖示",
		["TargetLevel"] = "目標等級",
		["TargetManaDeficit"] = "目標法力不足",
		["TargetName"] = "目標名字",
		["TargetPercentHP"] = "目標百比分血量",
		--Translation missing 
		-- ["TargetPossesive"] = "",
		["TargetPronoun"] = "目標代名詞",
		["TargetRace"] = "目標種族",
		["TargetTargetName"] = "目標的目標名字",
		["unknown sex"] = "未知的性別",
		["user defined substition \"%s\" not found"] = "未搜尋到使用者自定義替換 \"%s\"",
		["User defined substitutions"] = "使用者自定義的替換",
		["user substitutions index (usersubs_idx) doesn't exist! oh dear."] = "親愛的使用者自替換索引(usersubs_idx)並不存在。",
		["usersub_"] = true,
	},
	["TellTarget"] = {
		["/tt"] = true,
		["Adds telltarget slash command (/tt)."] = "新增 telltarget 快捷命令（/tt）",
		["No target selected."] = "未選取目標",
		["NoTarget"] = "沒有目標",
		["Target does not exist."] = "目標並不存在",
		["Target is not a player."] = "目標並不是玩家",
		["TellTarget"] = true,
	},
	["Timestamps"] = {
		["Chat window timestamp options."] = "聊天視窗時間戳選項",
		["colortimestamp_desc"] = "切換是否為時間戳著色。",
		["colortimestamp_name"] = "時間戳色彩",
		["Format All Timestamps"] = "所有時間戳格式",
		["HH:MM (12-hour)"] = "HH:MM (12時制)",
		["HH:MM (24-hour)"] = "HH:MM (24時制)",
		["HH:MM:SS (12-hour)"] = "HH:MM:SS (12時制)",
		["HH:MM:SS (24-hour)"] = "HH:MM:SS (24時制)",
		["HH:MM:SS AM (12-hour)"] = "HH:MM:SS AM (12時制)",
		["localtime_desc"] = "切換是否使用本地時間",
		["localtime_name"] = "使用本地時間",
		["MM:SS"] = true,
		["Post-Timestamp"] = "貼出時間戳",
		["Pre-Timestamp"] = "時間標籤",
		["Set the timestamp format"] = "設定時間戳格式",
		["Set Timestamp Color"] = "設定時間戳色彩",
		["Sets the color of the timestamp."] = "設定時間戳色彩。",
		["Show Timestamp"] = "顯示時間戳",
		["show_desc"] = "切換顯示時間標籤",
		["show_name"] = "顯示時間戳",
		--Translation missing 
		-- ["space_desc"] = "",
		["space_name"] = "顯示空白",
		["Timestamps"] = "時間戳",
		["Toggle showing timestamp for each window."] = "切換是否在個別視窗顯示時間戳。",
		--Translation missing 
		-- ["twocolumn_desc"] = "",
		["twocolumn_name"] = "兩欄式聊天",
	},
	["UrlCopy"] = {
		["Change the color of the URL."] = "改變網址顯示的色彩",
		["Color URL"] = "網址色彩",
		["Set Color"] = "設定色彩",
		["Show Brackets"] = "顯示括號",
		["Toggle"] = "切換",
		["Toggle showing brackets on and off."] = "切換是否顯示括號。",
		["Toggle the module on and off."] = "切換是否啟用模組。",
		["Toggle the URL color on and off."] = "切換是否顯示網址色彩。",
		["URL formating options."] = "網址格式化選項",
		["UrlCopy"] = "網址複製",
		["Use Popup"] = "使用彈出視窗",
		["Use popup window to show URL."] = "使用彈出視窗用以顯示網址",
	}
}

PL:AddLocale(PRAT_MODULE.name, "zhTW",L)


L=
{
	--Translation missing 
	-- ["display_desc"] = "",
	--Translation missing 
	-- ["display_name"] = "",
	--Translation missing 
	-- ["extras_desc"] = "",
	--Translation missing 
	-- ["extras_name"] = "",
	--Translation missing 
	-- ["formatting_desc"] = "",
	--Translation missing 
	-- ["formatting_name"] = "",
	--Translation missing 
	-- ["load_desc"] = "",
	--Translation missing 
	-- ["load_disabled"] = "",
	--Translation missing 
	-- ["load_disabledonrestart"] = "",
	--Translation missing 
	-- ["load_enabled"] = "",
	--Translation missing 
	-- ["load_enabledonrestart"] = "",
	--Translation missing 
	-- ["load_no"] = "",
	--Translation missing 
	-- ["modulecontrol_desc"] = "",
	--Translation missing 
	-- ["modulecontrol_name"] = "",
	--Translation missing 
	-- ["prat"] = "",
	--Translation missing 
	-- ["reload_required"] = "",
	["AddonMsgs"] = {
		--Translation missing 
		-- ["Addon message options."] = "",
		--Translation missing 
		-- ["AddonMsgs"] = "",
		--Translation missing 
		-- ["show_desc"] = "",
		--Translation missing 
		-- ["show_name"] = "",
		--Translation missing 
		-- ["show_perframedesc"] = "",
		--Translation missing 
		-- ["show_perframename"] = "",
	},
	["Alias"] = {
		--Translation missing 
		-- [" - list all aliases; supply <keyword> to search for matching aliases (cmd aliases: /listallaliases)"] = "",
		--Translation missing 
		-- ["%s() called with blank string!"] = "",
		--Translation missing 
		-- ["%s() called with nil argument!"] = "",
		--Translation missing 
		-- ["/%s aliased to \"/%s\""] = "",
		--Translation missing 
		-- ["/%s aliased to: /%s"] = "",
		--Translation missing 
		-- ["<alias> - remove the alias <alias> (cmd aliases: /delalias, /remalias)"] = "",
		--Translation missing 
		-- ["<command>[ <value>] - alias <command> to be executed as <value>, or return the value of the currently defined alias for <command> if <command> has not been assigned a value. eg: \"/alias /examplehello /say hello there\" - typing \"/examplehello\" will now cause your character to say \"hello there\"; \"/alias examplehello\" - s \"/examplehello is aliased to /say hello there\" (cmd aliases: /addalias)"] = "",
		--Translation missing 
		-- ["<keyword> - finds all aliases matching <keyword> (cmd aliases: /findalias)"] = "",
		--Translation missing 
		-- ["add"] = "",
		--Translation missing 
		-- ["add an alias"] = "",
		--Translation missing 
		-- ["alias \"/%s\" does not exist"] = "",
		--Translation missing 
		-- ["dealiasing command /%s to /%s"] = "",
		--Translation missing 
		-- ["deleting alias \"/%s\" (previously aliased as \"/%s\")"] = "",
		--Translation missing 
		-- ["Display extra information in the chat frame when commands are dealiased"] = "",
		--Translation missing 
		-- ["Don't overwrite existing aliases when using /addalias"] = "",
		--Translation missing 
		-- ["Expand aliases as you are typing"] = "",
		--Translation missing 
		-- ["find aliases matching a given search term"] = "",
		--Translation missing 
		-- ["findaliases"] = "",
		--Translation missing 
		-- ["infinite loop detected for alias /%s - ignoring"] = "",
		--Translation missing 
		-- ["inline"] = "",
		--Translation missing 
		-- ["list all aliases"] = "",
		--Translation missing 
		-- ["listaliases"] = "",
		--Translation missing 
		-- ["matching aliases found: %d"] = "",
		--Translation missing 
		-- ["module_desc"] = "",
		--Translation missing 
		-- ["module_name"] = "",
		--Translation missing 
		-- ["No aliases have been defined"] = "",
		--Translation missing 
		-- ["noclobber"] = "",
		--Translation missing 
		-- ["noclobber set - skipping new alias: /%s already expands to /%s"] = "",
		--Translation missing 
		-- ["Options"] = "",
		--Translation missing 
		-- ["Options for altering the behaviour of Alias"] = "",
		--Translation missing 
		-- ["overwriting existing alias \"/%s\" (was aliased to \"/%s\")"] = "",
		--Translation missing 
		-- ["refusing to alias \"/%s\" to anything in the interests of Not Buggering Everything Up"] = "",
		--Translation missing 
		-- ["remove an alias"] = "",
		--Translation missing 
		-- ["There is no alias current defined for \"%s\""] = "",
		--Translation missing 
		-- ["total aliases: %d"] = "",
		--Translation missing 
		-- ["tried to show value for alias \"%s\" but undefined in module.Aliases!"] = "",
		--Translation missing 
		-- ["unalias"] = "",
		--Translation missing 
		-- ["verbose"] = "",
		--Translation missing 
		-- ["warnUser() called with nil argument!"] = "",
		--Translation missing 
		-- ["warnUser() called with zero length string!"] = "",
	},
	["AltNames"] = {
		--Translation missing 
		-- ["%d alts found for %s: %s"] = "",
		--Translation missing 
		-- ["%s alts imported from LOKWhoIsWho"] = "",
		--Translation missing 
		-- ["%s total alts linked to mains"] = "",
		--Translation missing 
		-- ["(.-)'s? [Aa]lt"] = "",
		--Translation missing 
		-- ["([^%s%p%d%c%z]+)'s alt"] = "",
		--Translation missing 
		-- [".*[Aa]lts?$"] = "",
		--Translation missing 
		-- ["<alt name> (eg, /altnames del Personyouthoughtwassomeonesaltbutreallyisnt)"] = "",
		--Translation missing 
		-- ["<main> (eg /altnames listalts Fin)"] = "",
		--Translation missing 
		-- ["<search term> (eg, /altnames find fin)"] = "",
		--Translation missing 
		-- ["Alt"] = "",
		--Translation missing 
		-- ["alt"] = "",
		--Translation missing 
		-- ["alt name exists: %s -> %s; not overwriting as set in preferences"] = "",
		--Translation missing 
		-- ["AltNames"] = "",
		--Translation missing 
		-- ["Alts:"] = "",
		--Translation missing 
		-- ["autoguildalts_desc"] = "",
		--Translation missing 
		-- ["autoguildalts_name"] = "",
		--Translation missing 
		-- ["Be quiet"] = "",
		--Translation missing 
		-- ["character removed: %s"] = "",
		--Translation missing 
		-- ["Class colour"] = "",
		--Translation missing 
		-- ["Clear all"] = "",
		--Translation missing 
		-- ["Clear all links between alts and main names."] = "",
		--Translation missing 
		-- ["Colour"] = "",
		--Translation missing 
		-- ["Delete a character's link to another character as their main."] = "",
		--Translation missing 
		-- ["Delete alt"] = "",
		--Translation missing 
		-- ["Disabled"] = "",
		--Translation missing 
		-- ["Display a player's alts in the tooltip"] = "",
		--Translation missing 
		-- ["Display a player's main name in the tooltip"] = "",
		--Translation missing 
		-- ["Display main names in the same colour as that of the alt's class (taking the data from the PlayerNames module if it is enabled)"] = "",
		--Translation missing 
		-- ["Display main names in the same colour as that of the main's class (taking the data from the PlayerNames module if it is enabled)"] = "",
		--Translation missing 
		-- ["Don't overwrite existing alt <-> main links when importing or adding new alts."] = "",
		--Translation missing 
		-- ["Don't overwrite existing links"] = "",
		--Translation missing 
		-- ["don't use"] = "",
		--Translation missing 
		-- ["Don't use data from the PlayerNames module at all"] = "",
		--Translation missing 
		-- ["ERROR: some function sent a blank message!"] = "",
		--Translation missing 
		-- ["Find characters"] = "",
		--Translation missing 
		-- ["Fix alts"] = "",
		--Translation missing 
		-- ["Fix corrupted entries in your list of alt names."] = "",
		--Translation missing 
		-- ["Found alt: %s => main: %s"] = "",
		--Translation missing 
		-- ["guild member alts found and imported: %s"] = "",
		--Translation missing 
		-- ["Import from Guild Greet database"] = "",
		--Translation missing 
		-- ["Import from guild roster"] = "",
		--Translation missing 
		-- ["Import options"] = "",
		--Translation missing 
		-- ["Imports alt names from a Guild Greet database, if present"] = "",
		--Translation missing 
		-- ["Imports alt names from the guild roster by checking for members with the rank \"alt\" or \"alts\", or guild / officer notes like \"<name>'s alt\""] = "",
		--Translation missing 
		-- ["Imports data from LOKWhoIsWho, if present (drop your SavedVariablesLOKWhoIsWho.lua in the Prat directory to be able to use this)."] = "",
		--Translation missing 
		-- ["Left"] = "",
		--Translation missing 
		-- ["link <alt name> <main name> (eg, /altnames link Fin Finjathealtoffin)"] = "",
		--Translation missing 
		-- ["Link alt"] = "",
		--Translation missing 
		-- ["Link someone's alt character with the name of their main."] = "",
		--Translation missing 
		-- ["linked alt %s => %s"] = "",
		--Translation missing 
		-- ["List all"] = "",
		--Translation missing 
		-- ["List all links between alts and their main names."] = "",
		--Translation missing 
		-- ["List alts"] = "",
		--Translation missing 
		-- ["List alts for a given character"] = "",
		--Translation missing 
		-- ["LOKWhoIsWho data not found"] = "",
		--Translation missing 
		-- ["LOKWhoIsWho import"] = "",
		--Translation missing 
		-- ["LOKWhoIsWho lua file not found, sorry."] = "",
		--Translation missing 
		-- ["Main"] = "",
		--Translation missing 
		-- ["main"] = "",
		--Translation missing 
		-- ["Main name position"] = "",
		--Translation missing 
		-- ["Main:"] = "",
		--Translation missing 
		-- ["mainpos_desc"] = "",
		--Translation missing 
		-- ["mainpos_name"] = "",
		--Translation missing 
		-- ["module_desc"] = "",
		--Translation missing 
		-- ["no alts found for character "] = "",
		--Translation missing 
		-- ["no alts or mains found matching \"%s\""] = "",
		--Translation missing 
		-- ["No arg string given to :addAlt()"] = "",
		--Translation missing 
		-- ["no characters called \"%s\" found; nothing deleted"] = "",
		--Translation missing 
		-- ["No Guild Greet database found"] = "",
		--Translation missing 
		-- ["No main name supplied to link %s to"] = "",
		--Translation missing 
		-- ["no matches found"] = "",
		--Translation missing 
		-- ["quiet"] = "",
		--Translation missing 
		-- ["quiet_desc"] = "",
		--Translation missing 
		-- ["quiet_name"] = "",
		--Translation missing 
		-- ["Right"] = "",
		--Translation missing 
		-- ["Search the list of linked characters for matching main or alt names."] = "",
		--Translation missing 
		-- ["searched for: %s - total matches: %s"] = "",
		--Translation missing 
		-- ["Show alts in tooltip"] = "",
		--Translation missing 
		-- ["Show main in tooltip"] = "",
		--Translation missing 
		-- ["Start"] = "",
		--Translation missing 
		-- ["The colour of an alt's main name that will be displayed"] = "",
		--Translation missing 
		-- ["Use class colour (from the PlayerNames module)"] = "",
		--Translation missing 
		-- ["use class colour of alt"] = "",
		--Translation missing 
		-- ["use class colour of main"] = "",
		--Translation missing 
		-- ["Use LibAlts Data"] = "",
		--Translation missing 
		-- ["Use the data available via the shared alt information library."] = "",
		--Translation missing 
		-- ["Various ways to import a main's alts from other addons"] = "",
		--Translation missing 
		-- ["warning: alt %s already linked to %s"] = "",
		--Translation missing 
		-- ["Where to display a character's main name when on their alt."] = "",
		--Translation missing 
		-- ["Whether to report to the chat frame or not."] = "",
		--Translation missing 
		-- ["You are not in a guild"] = "",
		--Translation missing 
		-- ["You have not yet linked any alts with their mains."] = "",
	},
	["Bubbles"] = {
		--Translation missing 
		-- ["color_desc"] = "",
		--Translation missing 
		-- ["color_name"] = "",
		--Translation missing 
		-- ["font_desc"] = "",
		--Translation missing 
		-- ["font_name"] = "",
		--Translation missing 
		-- ["fontsize_desc"] = "",
		--Translation missing 
		-- ["fontsize_name"] = "",
		--Translation missing 
		-- ["format_desc"] = "",
		--Translation missing 
		-- ["format_name"] = "",
		--Translation missing 
		-- ["icons_desc"] = "",
		--Translation missing 
		-- ["icons_name"] = "",
		--Translation missing 
		-- ["module_desc"] = "",
		--Translation missing 
		-- ["module_name"] = "",
		--Translation missing 
		-- ["shorten_desc"] = "",
		--Translation missing 
		-- ["shorten_name"] = "",
		--Translation missing 
		-- ["transparent_desc"] = "",
		--Translation missing 
		-- ["transparent_name"] = "",
	},
	["Buttons"] = {
		--Translation missing 
		-- ["alpha_desc"] = "",
		--Translation missing 
		-- ["alpha_name"] = "",
		--Translation missing 
		-- ["Buttons"] = "",
		--Translation missing 
		-- ["Chat window button options."] = "",
		--Translation missing 
		-- ["chatmenu_desc"] = "",
		--Translation missing 
		-- ["chatmenu_name"] = "",
		--Translation missing 
		-- ["Default"] = "",
		--Translation missing 
		-- ["Right, Inside Frame"] = "",
		--Translation missing 
		-- ["Right, Outside Frame"] = "",
		--Translation missing 
		-- ["scrollReminder_desc"] = "",
		--Translation missing 
		-- ["scrollReminder_name"] = "",
		--Translation missing 
		-- ["Set Position"] = "",
		--Translation missing 
		-- ["Sets position of chat menu and arrows for all chat windows."] = "",
		--Translation missing 
		-- ["Show Arrows"] = "",
		--Translation missing 
		-- ["Show Chat%d Arrows"] = "",
		--Translation missing 
		-- ["showbnet_desc"] = "",
		--Translation missing 
		-- ["showbnet_name"] = "",
		--Translation missing 
		-- ["showmenu_desc"] = "",
		--Translation missing 
		-- ["showmenu_name"] = "",
		--Translation missing 
		-- ["showminimize_desc"] = "",
		--Translation missing 
		-- ["showminimize_name"] = "",
		--Translation missing 
		-- ["Toggle showing chat arrows for each chat window."] = "",
		--Translation missing 
		-- ["Toggles navigation arrows on and off."] = "",
	},
	["ChannelColorMemory"] = {
		--Translation missing 
		-- ["(%w+)%s?(.*)"] = "",
		--Translation missing 
		-- ["ChannelColorMemory"] = "",
		--Translation missing 
		-- ["Remembers the colors of each channel name."] = "",
	},
	["ChannelNames"] = {
		--Translation missing 
		-- ["%s settings."] = "",
		--Translation missing 
		-- ["<string>"] = "",
		--Translation missing 
		-- ["Add Channel Abbreviation"] = "",
		--Translation missing 
		-- ["addnick_desc"] = "",
		--Translation missing 
		-- ["Blank"] = "",
		--Translation missing 
		-- ["chanlink_desc"] = "",
		--Translation missing 
		-- ["chanlink_name"] = "",
		--Translation missing 
		-- ["Channel %d"] = "",
		--Translation missing 
		-- ["Channel name abbreviation options."] = "",
		--Translation missing 
		-- ["ChannelNames"] = "",
		--Translation missing 
		-- ["channelnick_desc"] = "",
		--Translation missing 
		-- ["channelnick_name"] = "",
		--Translation missing 
		-- ["Clear Channel Abbreviation"] = "",
		--Translation missing 
		-- ["Clears an abbreviated channel name."] = "",
		--Translation missing 
		-- ["colon_desc"] = "",
		--Translation missing 
		-- ["colon_name"] = "",
		--Translation missing 
		-- ["Dont display the channel/chat type name"] = "",
		--Translation missing 
		-- ["otheropts_desc"] = "",
		--Translation missing 
		-- ["otheropts_name"] = "",
		--Translation missing 
		-- ["Remove Channel Abbreviation"] = "",
		--Translation missing 
		-- ["Removes an an abbreviated channel name."] = "",
		--Translation missing 
		-- ["Replace"] = "",
		--Translation missing 
		-- ["Set"] = "",
		--Translation missing 
		-- ["space_desc"] = "",
		--Translation missing 
		-- ["space_name"] = "",
		--Translation missing 
		-- ["Toggle replacing this channel."] = "",
		--Translation missing 
		-- ["Use a custom replacement for the chat %s text."] = "",
	},
	["ChannelSticky"] = {
		--Translation missing 
		-- ["Channel"] = "",
		--Translation missing 
		-- ["ChannelSticky"] = "",
		--Translation missing 
		-- ["Chat channel sticky options."] = "",
		--Translation missing 
		-- ["ChatType"] = "",
		--Translation missing 
		-- ["Per chat type options."] = "",
		--Translation missing 
		-- ["smartgroup_desc"] = "",
		--Translation missing 
		-- ["smartgroup_name"] = "",
		--Translation missing 
		-- ["Sticky %s"] = "",
		--Translation missing 
		-- ["Sticky Per Chat Frame"] = "",
		--Translation missing 
		-- ["Toggle remembering the chat type last used per chat frame."] = "",
		--Translation missing 
		-- ["Toggles sticky on and off for %s."] = "",
	},
	["ChatFrames"] = {
		--Translation missing 
		-- ["Chat window frame parameter options"] = "",
		--Translation missing 
		-- ["framealpha_desc"] = "",
		--Translation missing 
		-- ["framealpha_name"] = "",
		--Translation missing 
		-- ["Frames"] = "",
		--Translation missing 
		-- ["mainchatonload_desc"] = "",
		--Translation missing 
		-- ["mainchatonload_name"] = "",
		--Translation missing 
		-- ["maxchatheight_desc"] = "",
		--Translation missing 
		-- ["maxchatheight_name"] = "",
		--Translation missing 
		-- ["maxchatwidth_desc"] = "",
		--Translation missing 
		-- ["maxchatwidth_name"] = "",
		--Translation missing 
		-- ["minchatheight_desc"] = "",
		--Translation missing 
		-- ["minchatheight_name"] = "",
		--Translation missing 
		-- ["minchatwidth_desc"] = "",
		--Translation missing 
		-- ["minchatwidth_name"] = "",
		--Translation missing 
		-- ["rememberframepositions_desc"] = "",
		--Translation missing 
		-- ["rememberframepositions_name"] = "",
		--Translation missing 
		-- ["removeclamp_desc"] = "",
		--Translation missing 
		-- ["removeclamp_name"] = "",
	},
	["ChatLink"] = {
		--Translation missing 
		-- ["gem_desc"] = "",
		--Translation missing 
		-- ["gem_name"] = "",
		--Translation missing 
		-- ["module_desc"] = "",
		--Translation missing 
		-- ["module_info"] = "",
		--Translation missing 
		-- ["module_name"] = "",
		--Translation missing 
		-- ["Trade"] = "",
	},
	["ChatLog"] = {
		--Translation missing 
		-- ["A module to automaticaly enable chat and combat logging."] = "",
		--Translation missing 
		-- ["Chat log recorded to <WoW Installation>\\Logs\\WoWChatLog.txt only upon logout."] = "",
		--Translation missing 
		-- ["Chat Log: Disabled"] = "",
		--Translation missing 
		-- ["Chat Log: Enabled"] = "",
		--Translation missing 
		-- ["ChatLog"] = "",
		--Translation missing 
		-- ["Combat log recorded to <WoW Installation>\\Logs\\WoWCombatLog.txt only upon logout."] = "",
		--Translation missing 
		-- ["Combat Log: Disabled"] = "",
		--Translation missing 
		-- ["Combat Log: Enabled"] = "",
		--Translation missing 
		-- ["quiet_desc"] = "",
		--Translation missing 
		-- ["quiet_name"] = "",
		--Translation missing 
		-- ["Toggle Chat Log"] = "",
		--Translation missing 
		-- ["Toggle chat log on and off."] = "",
		--Translation missing 
		-- ["Toggle Combat Log"] = "",
		--Translation missing 
		-- ["Toggle combat log on and off."] = "",
	},
	["ChatTabs"] = {
		--Translation missing 
		-- ["Active Alpha"] = "",
		--Translation missing 
		-- ["All"] = "",
		--Translation missing 
		-- ["Always"] = "",
		--Translation missing 
		-- ["Chat window tab options."] = "",
		--Translation missing 
		-- ["Default"] = "",
		--Translation missing 
		-- ["disableflash_desc"] = "",
		--Translation missing 
		-- ["disableflash_name"] = "",
		--Translation missing 
		-- ["Hidden"] = "",
		--Translation missing 
		-- ["Individual"] = "",
		--Translation missing 
		-- ["Not Active Alpha"] = "",
		--Translation missing 
		-- ["preventdrag_desc"] = "",
		--Translation missing 
		-- ["preventdrag_name"] = "",
		--Translation missing 
		-- ["Set ChatFrame%d Display Mode"] = "",
		--Translation missing 
		-- ["Set Display Mode"] = "",
		--Translation missing 
		-- ["Set tab display mode for each chat window."] = "",
		--Translation missing 
		-- ["Set tab display to always, hidden or the Blizzard default."] = "",
		--Translation missing 
		-- ["Sets alpha of chat tab for active chat frame."] = "",
		--Translation missing 
		-- ["Sets alpha of chat tab for not active chat frame."] = "",
		--Translation missing 
		-- ["Tabs"] = "",
	},
	["Clear"] = {
		--Translation missing 
		-- ["Adds clear text slash commands (/clear)(/cls)(/clearall)(/clsall)."] = "",
		--Translation missing 
		-- ["Clear"] = "",
		--Translation missing 
		-- ["Clearall"] = "",
		--Translation missing 
		-- ["Clears all chat frames."] = "",
		--Translation missing 
		-- ["Clears the current chat frame."] = "",
	},
	["CopyChat"] = {
		--Translation missing 
		-- [" Text"] = "",
		--Translation missing 
		-- ["BBCode"] = "",
		--Translation missing 
		-- ["BOTTOMLEFT"] = "",
		--Translation missing 
		-- ["BOTTOMRIGHT"] = "",
		--Translation missing 
		-- ["buttonpos_desc"] = "",
		--Translation missing 
		-- ["buttonpos_name"] = "",
		--Translation missing 
		-- ["ChatFrame"] = "",
		--Translation missing 
		-- ["Copy all of the text in the selected chat frame into an edit box"] = "",
		--Translation missing 
		-- ["Copy Text"] = "",
		--Translation missing 
		-- ["Copy Text Format"] = "",
		--Translation missing 
		-- ["Copy text from the active chat window."] = "",
		--Translation missing 
		-- ["Copy To Editbox"] = "",
		--Translation missing 
		-- ["CopyChat"] = "",
		--Translation missing 
		-- ["HTML"] = "",
		--Translation missing 
		-- ["Message From : %s"] = "",
		--Translation missing 
		-- ["Plain"] = "",
		--Translation missing 
		-- ["Should the copied text be plain, or formatted so you can see the colors."] = "",
		--Translation missing 
		-- ["showbutton_desc"] = "",
		--Translation missing 
		-- ["showbutton_name"] = "",
		--Translation missing 
		-- ["TOPLEFT"] = "",
		--Translation missing 
		-- ["TOPRIGHT"] = "",
		--Translation missing 
		-- ["Wowace.com Forums"] = "",
	},
	["CustomFilters"] = {
		--Translation missing 
		-- ["<string>"] = "",
		--Translation missing 
		-- ["Add a pattern to search for."] = "",
		--Translation missing 
		-- ["Add Pattern"] = "",
		--Translation missing 
		-- ["Block Message"] = "",
		--Translation missing 
		-- ["Channel Data"] = "",
		--Translation missing 
		-- ["Channel to send output text to."] = "",
		--Translation missing 
		-- ["Enabled"] = "",
		--Translation missing 
		-- ["Extra data for WHISPER (target) and CHANNEL (channel name or num)"] = "",
		--Translation missing 
		-- ["Filter Name"] = "",
		--Translation missing 
		-- ["Forward"] = "",
		--Translation missing 
		-- ["Forward the message to a chat channel."] = "",
		--Translation missing 
		-- ["Forward the message to a custom chat channel."] = "",
		--Translation missing 
		-- ["ForwardCustom"] = "",
		--Translation missing 
		-- ["ForwardMessage"] = "",
		--Translation missing 
		-- ["ForwardMessageCustom"] = "",
		--Translation missing 
		-- ["Hilight Color"] = "",
		--Translation missing 
		-- ["Hilight Match Text"] = "",
		--Translation missing 
		-- ["Inbound"] = "",
		--Translation missing 
		-- ["inchannels_desc"] = "",
		--Translation missing 
		-- ["inchannels_name"] = "",
		--Translation missing 
		-- ["Is this pattern enabled for use?"] = "",
		--Translation missing 
		-- ["Match Options"] = "",
		--Translation missing 
		-- ["module_desc"] = "",
		--Translation missing 
		-- ["module_name"] = "",
		--Translation missing 
		-- ["Only output the message portion of the chat text, leave out the channel, and playername etc."] = "",
		--Translation missing 
		-- ["Outbound"] = "",
		--Translation missing 
		-- ["Output Channel"] = "",
		--Translation missing 
		-- ["Output Message Only"] = "",
		--Translation missing 
		-- ["Pattern Info"] = "",
		--Translation missing 
		-- ["Pattern Options"] = "",
		--Translation missing 
		-- ["Play a sound when this message is output to the chatframe"] = "",
		--Translation missing 
		-- ["Play Sound"] = "",
		--Translation missing 
		-- ["Prevent the message from being displayed"] = "",
		--Translation missing 
		-- ["Remove an existing pattern."] = "",
		--Translation missing 
		-- ["Remove Pattern"] = "",
		--Translation missing 
		-- ["Replacement Text"] = "",
		--Translation missing 
		-- ["Search Format String"] = "",
		--Translation missing 
		-- ["Search Pattern"] = "",
		--Translation missing 
		-- ["Secondary Output"] = "",
		--Translation missing 
		-- ["Send to a secondary output"] = "",
		--Translation missing 
		-- ["Supplied pattern is a format string instead of a pattern"] = "",
		--Translation missing 
		-- ["Your name for this filter"] = "",
	},
	["Editbox"] = {
		--Translation missing 
		-- ["Attach edit box to..."] = "",
		--Translation missing 
		-- ["Attach to..."] = "",
		--Translation missing 
		-- ["Background color"] = "",
		--Translation missing 
		-- ["Background Inset"] = "",
		--Translation missing 
		-- ["Background texture"] = "",
		--Translation missing 
		-- ["Border color"] = "",
		--Translation missing 
		-- ["Border texture"] = "",
		--Translation missing 
		-- ["Bottom"] = "",
		--Translation missing 
		-- ["Color border by channel"] = "",
		--Translation missing 
		-- ["currently_broken_alt_behavior"] = "",
		--Translation missing 
		-- ["Edge Size"] = "",
		--Translation missing 
		-- ["Editbox"] = "",
		--Translation missing 
		-- ["Editbox options."] = "",
		--Translation missing 
		-- ["Font"] = "",
		--Translation missing 
		-- ["Free-floating"] = "",
		--Translation missing 
		-- ["Free-floating, Locked"] = "",
		--Translation missing 
		-- ["Requires the Alt key to be held down to move the cursor in chat"] = "",
		--Translation missing 
		-- ["Select the font to use for the edit box"] = "",
		--Translation missing 
		-- ["Sets the frame's border color to the color of your currently active channel"] = "",
		--Translation missing 
		-- ["Tile Size"] = "",
		--Translation missing 
		-- ["Top"] = "",
		--Translation missing 
		-- ["Use Alt key for cursor movement"] = "",
	},
	["EventNames"] = {
		--Translation missing 
		-- ["allevents_desc"] = "",
		--Translation missing 
		-- ["allevents_name"] = "",
		--Translation missing 
		-- ["Chat window event name options."] = "",
		--Translation missing 
		-- ["EventNames"] = "",
		--Translation missing 
		-- ["Show"] = "",
		--Translation missing 
		-- ["Show events on chatframes"] = "",
		--Translation missing 
		-- ["show_desc"] = "",
		--Translation missing 
		-- ["show_name"] = "",
	},
	["Fading"] = {
		--Translation missing 
		-- ["duration_desc"] = "",
		--Translation missing 
		-- ["duration_name"] = "",
		--Translation missing 
		-- ["module_desc"] = "",
		--Translation missing 
		-- ["module_name"] = "",
		--Translation missing 
		-- ["textfade_desc"] = "",
		--Translation missing 
		-- ["textfade_name"] = "",
	},
	["Filtering"] = {
		--Translation missing 
		-- ["A module to provide basic chat filtering."] = "",
		--Translation missing 
		-- ["afkdnd_desc"] = "",
		--Translation missing 
		-- ["afkdnd_name"] = "",
		--Translation missing 
		-- ["bgjoin_desc"] = "",
		--Translation missing 
		-- ["bgjoin_name"] = "",
		--Translation missing 
		-- ["Filtering"] = "",
		--Translation missing 
		-- ["leavejoin_desc"] = "",
		--Translation missing 
		-- ["leavejoin_name"] = "",
		--Translation missing 
		-- ["notices_desc"] = "",
		--Translation missing 
		-- ["notices_name"] = "",
		--Translation missing 
		-- ["tradespam_desc"] = "",
		--Translation missing 
		-- ["tradespam_name"] = "",
	},
	["Font"] = {
		--Translation missing 
		-- ["Auto Restore Font Size"] = "",
		--Translation missing 
		-- ["Chat window font options."] = "",
		--Translation missing 
		-- ["Font"] = "",
		--Translation missing 
		-- ["monochrome_desc"] = "",
		--Translation missing 
		-- ["monochrome_name"] = "",
		--Translation missing 
		-- ["None"] = "",
		--Translation missing 
		-- ["Outline"] = "",
		--Translation missing 
		-- ["outlinemode_desc"] = "",
		--Translation missing 
		-- ["outlinemode_name"] = "",
		--Translation missing 
		-- ["rememberfont_desc"] = "",
		--Translation missing 
		-- ["rememberfont_name"] = "",
		--Translation missing 
		-- ["Set ChatFrame%d Font Size"] = "",
		--Translation missing 
		-- ["Set Font Face"] = "",
		--Translation missing 
		-- ["Set Font Size"] = "",
		--Translation missing 
		-- ["Set Separately"] = "",
		--Translation missing 
		-- ["Set text font size for each chat window."] = "",
		--Translation missing 
		-- ["Set text font size."] = "",
		--Translation missing 
		-- ["Set the text font face for all chat windows."] = "",
		--Translation missing 
		-- ["shadowcolor_desc"] = "",
		--Translation missing 
		-- ["shadowcolor_name"] = "",
		--Translation missing 
		-- ["Thick Outline"] = "",
		--Translation missing 
		-- ["Toggle setting options separately for each chat window."] = "",
		--Translation missing 
		-- ["Workaround a Blizzard bug which changes the font size when you open a system menu."] = "",
	},
	["History"] = {
		--Translation missing 
		-- ["Chat history options."] = "",
		--Translation missing 
		-- ["Color GMOTD"] = "",
		--Translation missing 
		-- ["Colors the GMOTD label"] = "",
		--Translation missing 
		-- ["delaygmotd_desc"] = "",
		--Translation missing 
		-- ["delaygmotd_name"] = "",
		--Translation missing 
		-- ["divider"] = "",
		--Translation missing 
		-- ["History"] = "",
		--Translation missing 
		-- ["Maximum number of lines of command history to save."] = "",
		--Translation missing 
		-- ["Save Command History"] = "",
		--Translation missing 
		-- ["Saves command history between sessions (for use with alt+up arrow or just the up arrow)"] = "",
		--Translation missing 
		-- ["Scrollback"] = "",
		--Translation missing 
		-- ["Scrollback Options"] = "",
		--Translation missing 
		-- ["scrollbacklen_desc"] = "",
		--Translation missing 
		-- ["scrollbacklen_name"] = "",
		--Translation missing 
		-- ["Set Chat Lines"] = "",
		--Translation missing 
		-- ["Set Command History"] = "",
		--Translation missing 
		-- ["Set the number of lines of chat history for each window."] = "",
		--Translation missing 
		-- ["Store the chat lines between sessions"] = "",
	},
	["KeyBindings"] = {
		--Translation missing 
		-- ["Channel %d"] = "",
		--Translation missing 
		-- ["Copy Selected Chat Frame"] = "",
		--Translation missing 
		-- ["Guild Channel"] = "",
		--Translation missing 
		-- ["Instance Channel"] = "",
		--Translation missing 
		-- ["Next Chat Tab"] = "",
		--Translation missing 
		-- ["Officer Channel"] = "",
		--Translation missing 
		-- ["Party Channel"] = "",
		--Translation missing 
		-- ["Prat CopyChat"] = "",
		--Translation missing 
		-- ["Prat Keybindings"] = "",
		--Translation missing 
		-- ["Prat TellTarget"] = "",
		--Translation missing 
		-- ["Raid Channel"] = "",
		--Translation missing 
		-- ["Raid Warning Channel"] = "",
		--Translation missing 
		-- ["Say"] = "",
		--Translation missing 
		-- ["Smart Group Channel"] = "",
		--Translation missing 
		-- ["TellTarget"] = "",
		--Translation missing 
		-- ["Whisper"] = "",
		--Translation missing 
		-- ["Yell"] = "",
	},
	["OriginalButtons"] = {
		--Translation missing 
		-- ["alpha_desc"] = "",
		--Translation missing 
		-- ["alpha_name"] = "",
		--Translation missing 
		-- ["buttonframe_desc"] = "",
		--Translation missing 
		-- ["buttonframe_name"] = "",
		--Translation missing 
		-- ["ChannelNames"] = "",
		--Translation missing 
		-- ["Chat window button options."] = "",
		--Translation missing 
		-- ["chatmenu_desc"] = "",
		--Translation missing 
		-- ["chatmenu_name"] = "",
		--Translation missing 
		-- ["Default"] = "",
		--Translation missing 
		-- ["Original Buttons"] = "",
		--Translation missing 
		-- ["reflow_desc"] = "",
		--Translation missing 
		-- ["reflow_name"] = "",
		--Translation missing 
		-- ["reminder_desc"] = "",
		--Translation missing 
		-- ["reminder_name"] = "",
		--Translation missing 
		-- ["Right, Inside Frame"] = "",
		--Translation missing 
		-- ["Right, Outside Frame"] = "",
		--Translation missing 
		-- ["Set Position"] = "",
		--Translation missing 
		-- ["Sets position of chat menu and arrows for all chat windows."] = "",
		--Translation missing 
		-- ["Show Arrows"] = "",
		--Translation missing 
		-- ["Show Chat%d Arrows"] = "",
		--Translation missing 
		-- ["Toggle showing chat arrows for each chat window."] = "",
		--Translation missing 
		-- ["Toggles navigation arrows on and off."] = "",
	},
	["OriginalEditbox"] = {
		--Translation missing 
		-- ["Autohide"] = "",
		--Translation missing 
		-- ["BACKGROUND"] = "",
		--Translation missing 
		-- ["Bar colour"] = "",
		--Translation missing 
		-- ["Border colour"] = "",
		--Translation missing 
		-- ["Border width"] = "",
		--Translation missing 
		-- ["Bottom"] = "",
		--Translation missing 
		-- ["Click the edit box to open it up for editing. Only available if Autohide is disabled."] = "",
		--Translation missing 
		-- ["Clickable"] = "",
		--Translation missing 
		-- ["DIALOG"] = "",
		--Translation missing 
		-- ["Editbox options."] = "",
		--Translation missing 
		-- ["Enable Arrowkeys"] = "",
		--Translation missing 
		-- ["Enable using arrowkeys in editbox without the alt key."] = "",
		--Translation missing 
		-- ["Hide Border"] = "",
		--Translation missing 
		-- ["Hide the border around the edit box."] = "",
		--Translation missing 
		-- ["Hide the edit box after you have pressed enter."] = "",
		--Translation missing 
		-- ["HIGH"] = "",
		--Translation missing 
		-- ["Lock editbox position if undocked."] = "",
		--Translation missing 
		-- ["Lock Position"] = "",
		--Translation missing 
		-- ["LOW"] = "",
		--Translation missing 
		-- ["MEDIUM"] = "",
		--Translation missing 
		-- ["OriginalEditbox"] = "",
		--Translation missing 
		-- ["Padding"] = "",
		--Translation missing 
		-- ["Set Alpha"] = "",
		--Translation missing 
		-- ["Set Position"] = "",
		--Translation missing 
		-- ["Set Strata"] = "",
		--Translation missing 
		-- ["Set the alpha of the editbox."] = "",
		--Translation missing 
		-- ["Set the amount of padding inside the edit box"] = "",
		--Translation missing 
		-- ["Set the edit box background colour"] = "",
		--Translation missing 
		-- ["Set the edit box border colour"] = "",
		--Translation missing 
		-- ["Set the frame strata of the editbox."] = "",
		--Translation missing 
		-- ["Set the position of the editbox."] = "",
		--Translation missing 
		-- ["Set the texture of the chat edit box"] = "",
		--Translation missing 
		-- ["Set the width of the edit box's border"] = "",
		--Translation missing 
		-- ["Set the width of the editbox."] = "",
		--Translation missing 
		-- ["Set Width (NB: only enabled if the editbox is undocked)"] = "",
		--Translation missing 
		-- ["Texture"] = "",
		--Translation missing 
		-- ["Top"] = "",
		--Translation missing 
		-- ["Undocked"] = "",
	},
	["Paragraph"] = {
		--Translation missing 
		-- ["adjustlinks_desc"] = "",
		--Translation missing 
		-- ["adjustlinks_name"] = "",
		--Translation missing 
		-- ["Center"] = "",
		--Translation missing 
		-- ["Chat window paragraph options."] = "",
		--Translation missing 
		-- ["justification_desc"] = "",
		--Translation missing 
		-- ["justification_name"] = "",
		--Translation missing 
		-- ["Left"] = "",
		--Translation missing 
		-- ["Line Spacing"] = "",
		--Translation missing 
		-- ["Paragraph"] = "",
		--Translation missing 
		-- ["Right"] = "",
		--Translation missing 
		-- ["Set the line spacing for all chat windows."] = "",
	},
	["PlayerNames"] = {
		--Translation missing 
		-- ["Actively Query Player Info"] = "",
		--Translation missing 
		-- ["Angled"] = "",
		--Translation missing 
		-- ["Brackets"] = "",
		--Translation missing 
		-- ["Brackets Common Color"] = "",
		--Translation missing 
		-- ["Brackets Use Common Color"] = "",
		--Translation missing 
		-- ["Class"] = "",
		--Translation missing 
		-- ["Color by Level Difference"] = "",
		--Translation missing 
		-- ["coloreverywhere_desc"] = "",
		--Translation missing 
		-- ["coloreverywhere_name"] = "",
		--Translation missing 
		-- ["Enable Alt-Invite"] = "",
		--Translation missing 
		-- ["Enable Invite Links"] = "",
		--Translation missing 
		-- ["Enable TabComplete"] = "",
		--Translation missing 
		-- ["hoverhilight_desc"] = "",
		--Translation missing 
		-- ["hoverhilight_name"] = "",
		--Translation missing 
		-- ["How to color other player's level."] = "",
		--Translation missing 
		-- ["How to color player's name."] = "",
		--Translation missing 
		-- ["Keep Info"] = "",
		--Translation missing 
		-- ["Keep Lots Of Info"] = "",
		--Translation missing 
		-- ["Keep player information between session for all players except cross-server players"] = "",
		--Translation missing 
		-- ["Keep player information between session, but limit it to friends and guild members."] = "",
		--Translation missing 
		-- ["Let TasteTheNaimbow set the common color for unknown player names."] = "",
		--Translation missing 
		-- ["Level Color Mode"] = "",
		--Translation missing 
		-- ["linkifycommon_desc"] = "",
		--Translation missing 
		-- ["linkifycommon_name"] = "",
		--Translation missing 
		-- ["No additional coloring"] = "",
		--Translation missing 
		-- ["None"] = "",
		--Translation missing 
		-- ["Player Color Mode"] = "",
		--Translation missing 
		-- ["Player name formating options."] = "",
		--Translation missing 
		-- ["PlayerNames"] = "",
		--Translation missing 
		-- ["Prat_Playernames: Stored Player Data Cleared"] = "",
		--Translation missing 
		-- ["Query the server for all player names we do not know. Note: This happpens pretty slowly, and this data is not saved."] = "",
		--Translation missing 
		-- ["Random"] = "",
		--Translation missing 
		-- ["realidcolor_desc"] = "",
		--Translation missing 
		-- ["realidcolor_name"] = "",
		--Translation missing 
		-- ["Reset Settings"] = "",
		--Translation missing 
		-- ["Restore default settings, and delete stored character data."] = "",
		--Translation missing 
		-- ["Set common color of unknown player names."] = "",
		--Translation missing 
		-- ["Sets common color of brackets to use around player names."] = "",
		--Translation missing 
		-- ["Sets style of brackets to use around player names."] = "",
		--Translation missing 
		-- ["Show Group"] = "",
		--Translation missing 
		-- ["Show Level"] = "",
		--Translation missing 
		-- ["Show Raid Target Icon"] = "",
		--Translation missing 
		-- ["Square"] = "",
		--Translation missing 
		-- ["Tab completion : "] = "",
		--Translation missing 
		-- ["tabcomplete_name"] = "",
		--Translation missing 
		-- ["Toggle group invites by alt-clicking hyperlinked keywords like 'invite'."] = "",
		--Translation missing 
		-- ["Toggle group invites by alt-clicking on player name."] = "",
		--Translation missing 
		-- ["Toggle level showing."] = "",
		--Translation missing 
		-- ["Toggle raid group showing."] = "",
		--Translation missing 
		-- ["Toggle showing the raid target icon which is currently on the player."] = "",
		--Translation missing 
		-- ["Toggle tab completion of player names."] = "",
		--Translation missing 
		-- ["Toggle using a common color for brackets around player names."] = "",
		--Translation missing 
		-- ["Toggle using a common color for unknown player names."] = "",
		--Translation missing 
		-- ["Too many matches (%d possible)"] = "",
		--Translation missing 
		-- ["Unknown Common Color"] = "",
		--Translation missing 
		-- ["Unknown Common Color From TasteTheNaimbow"] = "",
		--Translation missing 
		-- ["Unknown Use Common Color"] = "",
		--Translation missing 
		-- ["Use Channel Color"] = "",
		--Translation missing 
		-- ["Use Player Color"] = "",
		--Translation missing 
		-- ["Use toon name for RealID"] = "",
	},
	["PopupMessage"] = {
		--Translation missing 
		-- ["Add Nickname"] = "",
		--Translation missing 
		-- ["Adds an alternate name to show in popups."] = "",
		--Translation missing 
		-- ["Clear Nickname"] = "",
		--Translation missing 
		-- ["Clears alternate name to show in popups."] = "",
		--Translation missing 
		-- ["framealpha_desc"] = "",
		--Translation missing 
		-- ["framealpha_name"] = "",
		--Translation missing 
		-- ["Popup"] = "",
		--Translation missing 
		-- ["PopupMessage"] = "",
		--Translation missing 
		-- ["Remove Nickname"] = "",
		--Translation missing 
		-- ["Removes an alternate name to show in popups."] = "",
		--Translation missing 
		-- ["Set Separately"] = "",
		--Translation missing 
		-- ["Show All Popups"] = "",
		--Translation missing 
		-- ["Show Popups"] = "",
		--Translation missing 
		-- ["Show Popups for all chat windows."] = "",
		--Translation missing 
		-- ["Show Popups for each window."] = "",
		--Translation missing 
		-- ["show_desc"] = "",
		--Translation missing 
		-- ["show_name"] = "",
		--Translation missing 
		-- ["show_perframedesc"] = "",
		--Translation missing 
		-- ["show_perframename"] = "",
		--Translation missing 
		-- ["showall_desc"] = "",
		--Translation missing 
		-- ["showall_name"] = "",
		--Translation missing 
		-- ["Shows messages in a popup window."] = "",
		--Translation missing 
		-- ["Shows messages with your name in a popup."] = "",
		--Translation missing 
		-- ["Toggle setting options separately for each chat window."] = "",
	},
	["Scroll"] = {
		--Translation missing 
		-- ["Bottom"] = "",
		--Translation missing 
		-- ["Chat window scrolling options."] = "",
		--Translation missing 
		-- ["Control whether text is added to the frame at the top or the bottom."] = "",
		--Translation missing 
		-- ["lowdown_desc"] = "",
		--Translation missing 
		-- ["lowdown_name"] = "",
		--Translation missing 
		-- ["modified_speed"] = "",
		--Translation missing 
		-- ["modified_speed_desc"] = "",
		--Translation missing 
		-- ["mousewheel_desc"] = "",
		--Translation missing 
		-- ["mousewheel_name"] = "",
		--Translation missing 
		-- ["Scroll"] = "",
		--Translation missing 
		-- ["Set Ctrl+MouseWheel Speed"] = "",
		--Translation missing 
		-- ["Set MouseWheel Speed"] = "",
		--Translation missing 
		-- ["Set number of lines mousewheel will scroll when ctrl is pressed."] = "",
		--Translation missing 
		-- ["Set number of lines mousewheel will scroll."] = "",
		--Translation missing 
		-- ["Set TheLowDown Delay"] = "",
		--Translation missing 
		-- ["Set time to wait before jumping to the bottom of chat windows."] = "",
		--Translation missing 
		-- ["Text scroll direction"] = "",
		--Translation missing 
		-- ["Top"] = "",
	},
	["Search"] = {
		--Translation missing 
		-- ["err_notfound"] = "",
		--Translation missing 
		-- ["err_tooshort"] = "",
		--Translation missing 
		-- ["find_results"] = "",
		--Translation missing 
		-- ["module_desc"] = "",
		--Translation missing 
		-- ["module_info"] = "",
		--Translation missing 
		-- ["module_name"] = "",
	},
	["ServerNames"] = {
		--Translation missing 
		-- ["autoabbreviate_desc"] = "",
		--Translation missing 
		-- ["autoabbreviate_name"] = "",
		--Translation missing 
		-- ["colon_desc"] = "",
		--Translation missing 
		-- ["colon_name"] = "",
		--Translation missing 
		-- ["randomclr_desc"] = "",
		--Translation missing 
		-- ["randomclr_name"] = "",
		--Translation missing 
		-- ["Server name abbreviation options."] = "",
		--Translation missing 
		-- ["ServerNames"] = "",
	},
	["Sounds"] = {
		--Translation missing 
		-- ["A module to play sounds on certain chat messages."] = "",
		--Translation missing 
		-- ["Add a custom channel"] = "",
		--Translation missing 
		-- ["bn_whisper_desc"] = "",
		--Translation missing 
		-- ["bn_whisper_name"] = "",
		--Translation missing 
		-- ["Custom Channels"] = "",
		--Translation missing 
		-- ["group_lead_desc"] = "",
		--Translation missing 
		-- ["group_lead_name"] = "",
		--Translation missing 
		-- ["guild_desc"] = "",
		--Translation missing 
		-- ["guild_name"] = "",
		--Translation missing 
		-- ["incoming"] = "",
		--Translation missing 
		-- ["Incoming Sounds"] = "",
		--Translation missing 
		-- ["officer_desc"] = "",
		--Translation missing 
		-- ["officer_name"] = "",
		--Translation missing 
		-- ["outgoing"] = "",
		--Translation missing 
		-- ["Outgoing Sounds"] = "",
		--Translation missing 
		-- ["party_desc"] = "",
		--Translation missing 
		-- ["party_name"] = "",
		--Translation missing 
		-- ["Play a sound for a certain channel name (can be a substring)"] = "",
		--Translation missing 
		-- ["raid_desc"] = "",
		--Translation missing 
		-- ["raid_name"] = "",
		--Translation missing 
		-- ["Remove a custom channel"] = "",
		--Translation missing 
		-- ["Reset settings"] = "",
		--Translation missing 
		-- ["Restore default settings and resets custom channel list"] = "",
		--Translation missing 
		-- ["Sound selection for incoming chat messages"] = "",
		--Translation missing 
		-- ["Sound selection for outgoing (from you) chat messages"] = "",
		--Translation missing 
		-- ["Sounds"] = "",
		--Translation missing 
		-- ["whisper_desc"] = "",
		--Translation missing 
		-- ["whisper_name"] = "",
	},
	["Substitutions"] = {
		--Translation missing 
		-- ["%d total user defined substitutions"] = "",
		--Translation missing 
		-- ["|cffff0000warning:|r subtitution \"%s\" already defined as \"%s\", overwriting"] = "",
		--Translation missing 
		-- ["<noguild>"] = "",
		--Translation missing 
		-- ["<notarget>"] = "",
		--Translation missing 
		-- ["A module to provide basic chat substitutions."] = "",
		--Translation missing 
		-- ["Are you sure - this will delete all user defined substitutions and reset defaults?"] = "",
		--Translation missing 
		-- ["Are you sure?"] = "",
		--Translation missing 
		-- ["can't find substitution index for a substitution named '%s'"] = "",
		--Translation missing 
		-- ["current-prompt"] = "",
		--Translation missing 
		-- ["defined %s: expands to => %s"] = "",
		--Translation missing 
		-- ["Delete all"] = "",
		--Translation missing 
		-- ["Delete substitution"] = "",
		--Translation missing 
		-- ["Deletes a user defined substitution"] = "",
		--Translation missing 
		-- ["Deletes all user defined substitutions"] = "",
		--Translation missing 
		-- ["female"] = "",
		--Translation missing 
		-- ["her"] = "",
		--Translation missing 
		-- ["hers"] = "",
		--Translation missing 
		-- ["him"] = "",
		--Translation missing 
		-- ["his"] = "",
		--Translation missing 
		-- ["it"] = "",
		--Translation missing 
		-- ["its"] = "",
		--Translation missing 
		-- ["List of available substitutions"] = "",
		--Translation missing 
		-- ["List of available substitutions defined by this module. (NB: users may define custom values for existing substitutions, but they will revert to the default value if the user definition is deleted.)"] = "",
		--Translation missing 
		-- ["List substitutions"] = "",
		--Translation missing 
		-- ["Lists all current subtitutions in the default chat frame"] = "",
		--Translation missing 
		-- ["male"] = "",
		--Translation missing 
		-- ["MapLoc"] = "",
		--Translation missing 
		-- ["MapPos"] = "",
		--Translation missing 
		-- ["MapXPos"] = "",
		--Translation missing 
		-- ["MapYPos"] = "",
		--Translation missing 
		-- ["MapZone"] = "",
		--Translation missing 
		-- ["module:buildUserSubsIndex(): warning: module patterns not defined!"] = "",
		--Translation missing 
		-- ["MouseoverTargetName"] = "",
		--Translation missing 
		-- ["NO MATCHFUNC FOUND"] = "",
		--Translation missing 
		-- ["no substitution name given"] = "",
		--Translation missing 
		-- ["no substitution name supplied for deletion"] = "",
		--Translation missing 
		-- ["no user defined subs found"] = "",
		--Translation missing 
		-- ["no value given for subtitution \"%s\""] = "",
		--Translation missing 
		-- ["Options for setting and removing user defined substitutions. (NB: users may define custom values for existing substitutions, but they will revert to the default value if the user definition is deleted.)"] = "",
		--Translation missing 
		-- ["PlayerAverageItemLevel"] = "",
		--Translation missing 
		-- ["PlayerCurrentMana"] = "",
		--Translation missing 
		-- ["PlayerHealthDeficit"] = "",
		--Translation missing 
		-- ["PlayerHP"] = "",
		--Translation missing 
		-- ["PlayerManaDeficit"] = "",
		--Translation missing 
		-- ["PlayerMaxHP"] = "",
		--Translation missing 
		-- ["PlayerMaxMana"] = "",
		--Translation missing 
		-- ["PlayerName"] = "",
		--Translation missing 
		-- ["PlayerPercentHP"] = "",
		--Translation missing 
		-- ["PlayerPercentMana"] = "",
		--Translation missing 
		-- ["RandNum"] = "",
		--Translation missing 
		-- ["removing user defined substitution \"%s\"; previously expanded to => \"%s\""] = "",
		--Translation missing 
		-- ["Set substitution"] = "",
		--Translation missing 
		-- ["Set the value of a user defined substitution (NB: this may be the same as an existing default substitution; to reset it to the default, just remove the user created definition)."] = "",
		--Translation missing 
		-- ["subname -- NOTE: sub name without the prefix '%'"] = "",
		--Translation missing 
		-- ["subname = text after expansion -- NOTE: sub name without the prefix \"%\""] = "",
		--Translation missing 
		-- ["substitution: %s defined as => %s"] = "",
		--Translation missing 
		-- ["Substitutions"] = "",
		--Translation missing 
		-- ["TargetClass"] = "",
		--Translation missing 
		-- ["TargetGender"] = "",
		--Translation missing 
		-- ["TargetGuild"] = "",
		--Translation missing 
		-- ["TargetHealth"] = "",
		--Translation missing 
		-- ["TargetHealthDeficit"] = "",
		--Translation missing 
		-- ["TargetIcon"] = "",
		--Translation missing 
		-- ["TargetLevel"] = "",
		--Translation missing 
		-- ["TargetManaDeficit"] = "",
		--Translation missing 
		-- ["TargetName"] = "",
		--Translation missing 
		-- ["TargetPercentHP"] = "",
		--Translation missing 
		-- ["TargetPossesive"] = "",
		--Translation missing 
		-- ["TargetPronoun"] = "",
		--Translation missing 
		-- ["TargetRace"] = "",
		--Translation missing 
		-- ["TargetTargetName"] = "",
		--Translation missing 
		-- ["unknown sex"] = "",
		--Translation missing 
		-- ["user defined substition \"%s\" not found"] = "",
		--Translation missing 
		-- ["User defined substitutions"] = "",
		--Translation missing 
		-- ["user substitutions index (usersubs_idx) doesn't exist! oh dear."] = "",
		--Translation missing 
		-- ["usersub_"] = "",
	},
	["TellTarget"] = {
		--Translation missing 
		-- ["/tt"] = "",
		--Translation missing 
		-- ["Adds telltarget slash command (/tt)."] = "",
		--Translation missing 
		-- ["No target selected."] = "",
		--Translation missing 
		-- ["NoTarget"] = "",
		--Translation missing 
		-- ["Target does not exist."] = "",
		--Translation missing 
		-- ["Target is not a player."] = "",
		--Translation missing 
		-- ["TellTarget"] = "",
	},
	["Timestamps"] = {
		--Translation missing 
		-- ["Chat window timestamp options."] = "",
		--Translation missing 
		-- ["colortimestamp_desc"] = "",
		--Translation missing 
		-- ["colortimestamp_name"] = "",
		--Translation missing 
		-- ["Format All Timestamps"] = "",
		--Translation missing 
		-- ["HH:MM (12-hour)"] = "",
		--Translation missing 
		-- ["HH:MM (24-hour)"] = "",
		--Translation missing 
		-- ["HH:MM:SS (12-hour)"] = "",
		--Translation missing 
		-- ["HH:MM:SS (24-hour)"] = "",
		--Translation missing 
		-- ["HH:MM:SS AM (12-hour)"] = "",
		--Translation missing 
		-- ["localtime_desc"] = "",
		--Translation missing 
		-- ["localtime_name"] = "",
		--Translation missing 
		-- ["MM:SS"] = "",
		--Translation missing 
		-- ["Post-Timestamp"] = "",
		--Translation missing 
		-- ["Pre-Timestamp"] = "",
		--Translation missing 
		-- ["Set the timestamp format"] = "",
		--Translation missing 
		-- ["Set Timestamp Color"] = "",
		--Translation missing 
		-- ["Sets the color of the timestamp."] = "",
		--Translation missing 
		-- ["Show Timestamp"] = "",
		--Translation missing 
		-- ["show_desc"] = "",
		--Translation missing 
		-- ["show_name"] = "",
		--Translation missing 
		-- ["space_desc"] = "",
		--Translation missing 
		-- ["space_name"] = "",
		--Translation missing 
		-- ["Timestamps"] = "",
		--Translation missing 
		-- ["Toggle showing timestamp for each window."] = "",
		--Translation missing 
		-- ["twocolumn_desc"] = "",
		--Translation missing 
		-- ["twocolumn_name"] = "",
	},
	["UrlCopy"] = {
		--Translation missing 
		-- ["Change the color of the URL."] = "",
		--Translation missing 
		-- ["Color URL"] = "",
		--Translation missing 
		-- ["Set Color"] = "",
		--Translation missing 
		-- ["Show Brackets"] = "",
		--Translation missing 
		-- ["Toggle"] = "",
		--Translation missing 
		-- ["Toggle showing brackets on and off."] = "",
		--Translation missing 
		-- ["Toggle the module on and off."] = "",
		--Translation missing 
		-- ["Toggle the URL color on and off."] = "",
		--Translation missing 
		-- ["URL formating options."] = "",
		--Translation missing 
		-- ["UrlCopy"] = "",
		--Translation missing 
		-- ["Use Popup"] = "",
		--Translation missing 
		-- ["Use popup window to show URL."] = "",
	}
}

PL:AddLocale(PRAT_MODULE.name, "itIT",L)


L=
{
	["display_desc"] = "Controle de Visualização de Frame de Chat",
	["display_name"] = "Configurações de Visualização",
	["extras_desc"] = "Módulos Diversos",
	--Translation missing 
	-- ["extras_name"] = "",
	--Translation missing 
	-- ["formatting_desc"] = "",
	["formatting_name"] = "Formatação do Chat",
	--Translation missing 
	-- ["load_desc"] = "",
	["load_disabled"] = "Desativado",
	--Translation missing 
	-- ["load_disabledonrestart"] = "",
	["load_enabled"] = "Ativado",
	--Translation missing 
	-- ["load_enabledonrestart"] = "",
	["load_no"] = "Não Carregar",
	["modulecontrol_desc"] = "Controlar carregamento de módulos permitidos pelo Prat",
	["modulecontrol_name"] = "Controle de Módulo",
	["prat"] = "Prat",
	["reload_required"] = "Essa alteração pode não ter efeitos até você %s sua IU.",
	["AddonMsgs"] = {
		--Translation missing 
		-- ["Addon message options."] = "",
		--Translation missing 
		-- ["AddonMsgs"] = "",
		--Translation missing 
		-- ["show_desc"] = "",
		--Translation missing 
		-- ["show_name"] = "",
		--Translation missing 
		-- ["show_perframedesc"] = "",
		--Translation missing 
		-- ["show_perframename"] = "",
	},
	["Alias"] = {
		--Translation missing 
		-- [" - list all aliases; supply <keyword> to search for matching aliases (cmd aliases: /listallaliases)"] = "",
		--Translation missing 
		-- ["%s() called with blank string!"] = "",
		--Translation missing 
		-- ["%s() called with nil argument!"] = "",
		--Translation missing 
		-- ["/%s aliased to \"/%s\""] = "",
		--Translation missing 
		-- ["/%s aliased to: /%s"] = "",
		--Translation missing 
		-- ["<alias> - remove the alias <alias> (cmd aliases: /delalias, /remalias)"] = "",
		--Translation missing 
		-- ["<command>[ <value>] - alias <command> to be executed as <value>, or return the value of the currently defined alias for <command> if <command> has not been assigned a value. eg: \"/alias /examplehello /say hello there\" - typing \"/examplehello\" will now cause your character to say \"hello there\"; \"/alias examplehello\" - s \"/examplehello is aliased to /say hello there\" (cmd aliases: /addalias)"] = "",
		--Translation missing 
		-- ["<keyword> - finds all aliases matching <keyword> (cmd aliases: /findalias)"] = "",
		--Translation missing 
		-- ["add"] = "",
		--Translation missing 
		-- ["add an alias"] = "",
		--Translation missing 
		-- ["alias \"/%s\" does not exist"] = "",
		--Translation missing 
		-- ["dealiasing command /%s to /%s"] = "",
		--Translation missing 
		-- ["deleting alias \"/%s\" (previously aliased as \"/%s\")"] = "",
		--Translation missing 
		-- ["Display extra information in the chat frame when commands are dealiased"] = "",
		--Translation missing 
		-- ["Don't overwrite existing aliases when using /addalias"] = "",
		--Translation missing 
		-- ["Expand aliases as you are typing"] = "",
		--Translation missing 
		-- ["find aliases matching a given search term"] = "",
		--Translation missing 
		-- ["findaliases"] = "",
		--Translation missing 
		-- ["infinite loop detected for alias /%s - ignoring"] = "",
		--Translation missing 
		-- ["inline"] = "",
		--Translation missing 
		-- ["list all aliases"] = "",
		--Translation missing 
		-- ["listaliases"] = "",
		--Translation missing 
		-- ["matching aliases found: %d"] = "",
		--Translation missing 
		-- ["module_desc"] = "",
		--Translation missing 
		-- ["module_name"] = "",
		--Translation missing 
		-- ["No aliases have been defined"] = "",
		--Translation missing 
		-- ["noclobber"] = "",
		--Translation missing 
		-- ["noclobber set - skipping new alias: /%s already expands to /%s"] = "",
		--Translation missing 
		-- ["Options"] = "",
		--Translation missing 
		-- ["Options for altering the behaviour of Alias"] = "",
		--Translation missing 
		-- ["overwriting existing alias \"/%s\" (was aliased to \"/%s\")"] = "",
		--Translation missing 
		-- ["refusing to alias \"/%s\" to anything in the interests of Not Buggering Everything Up"] = "",
		--Translation missing 
		-- ["remove an alias"] = "",
		--Translation missing 
		-- ["There is no alias current defined for \"%s\""] = "",
		--Translation missing 
		-- ["total aliases: %d"] = "",
		--Translation missing 
		-- ["tried to show value for alias \"%s\" but undefined in module.Aliases!"] = "",
		--Translation missing 
		-- ["unalias"] = "",
		--Translation missing 
		-- ["verbose"] = "",
		--Translation missing 
		-- ["warnUser() called with nil argument!"] = "",
		--Translation missing 
		-- ["warnUser() called with zero length string!"] = "",
	},
	["AltNames"] = {
		--Translation missing 
		-- ["%d alts found for %s: %s"] = "",
		--Translation missing 
		-- ["%s alts imported from LOKWhoIsWho"] = "",
		--Translation missing 
		-- ["%s total alts linked to mains"] = "",
		--Translation missing 
		-- ["(.-)'s? [Aa]lt"] = "",
		--Translation missing 
		-- ["([^%s%p%d%c%z]+)'s alt"] = "",
		--Translation missing 
		-- [".*[Aa]lts?$"] = "",
		--Translation missing 
		-- ["<alt name> (eg, /altnames del Personyouthoughtwassomeonesaltbutreallyisnt)"] = "",
		--Translation missing 
		-- ["<main> (eg /altnames listalts Fin)"] = "",
		--Translation missing 
		-- ["<search term> (eg, /altnames find fin)"] = "",
		--Translation missing 
		-- ["Alt"] = "",
		--Translation missing 
		-- ["alt"] = "",
		--Translation missing 
		-- ["alt name exists: %s -> %s; not overwriting as set in preferences"] = "",
		--Translation missing 
		-- ["AltNames"] = "",
		--Translation missing 
		-- ["Alts:"] = "",
		--Translation missing 
		-- ["autoguildalts_desc"] = "",
		--Translation missing 
		-- ["autoguildalts_name"] = "",
		--Translation missing 
		-- ["Be quiet"] = "",
		--Translation missing 
		-- ["character removed: %s"] = "",
		--Translation missing 
		-- ["Class colour"] = "",
		--Translation missing 
		-- ["Clear all"] = "",
		--Translation missing 
		-- ["Clear all links between alts and main names."] = "",
		--Translation missing 
		-- ["Colour"] = "",
		--Translation missing 
		-- ["Delete a character's link to another character as their main."] = "",
		--Translation missing 
		-- ["Delete alt"] = "",
		--Translation missing 
		-- ["Disabled"] = "",
		--Translation missing 
		-- ["Display a player's alts in the tooltip"] = "",
		--Translation missing 
		-- ["Display a player's main name in the tooltip"] = "",
		--Translation missing 
		-- ["Display main names in the same colour as that of the alt's class (taking the data from the PlayerNames module if it is enabled)"] = "",
		--Translation missing 
		-- ["Display main names in the same colour as that of the main's class (taking the data from the PlayerNames module if it is enabled)"] = "",
		--Translation missing 
		-- ["Don't overwrite existing alt <-> main links when importing or adding new alts."] = "",
		--Translation missing 
		-- ["Don't overwrite existing links"] = "",
		--Translation missing 
		-- ["don't use"] = "",
		--Translation missing 
		-- ["Don't use data from the PlayerNames module at all"] = "",
		--Translation missing 
		-- ["ERROR: some function sent a blank message!"] = "",
		--Translation missing 
		-- ["Find characters"] = "",
		--Translation missing 
		-- ["Fix alts"] = "",
		--Translation missing 
		-- ["Fix corrupted entries in your list of alt names."] = "",
		--Translation missing 
		-- ["Found alt: %s => main: %s"] = "",
		--Translation missing 
		-- ["guild member alts found and imported: %s"] = "",
		--Translation missing 
		-- ["Import from Guild Greet database"] = "",
		--Translation missing 
		-- ["Import from guild roster"] = "",
		--Translation missing 
		-- ["Import options"] = "",
		--Translation missing 
		-- ["Imports alt names from a Guild Greet database, if present"] = "",
		--Translation missing 
		-- ["Imports alt names from the guild roster by checking for members with the rank \"alt\" or \"alts\", or guild / officer notes like \"<name>'s alt\""] = "",
		--Translation missing 
		-- ["Imports data from LOKWhoIsWho, if present (drop your SavedVariablesLOKWhoIsWho.lua in the Prat directory to be able to use this)."] = "",
		--Translation missing 
		-- ["Left"] = "",
		--Translation missing 
		-- ["link <alt name> <main name> (eg, /altnames link Fin Finjathealtoffin)"] = "",
		--Translation missing 
		-- ["Link alt"] = "",
		--Translation missing 
		-- ["Link someone's alt character with the name of their main."] = "",
		--Translation missing 
		-- ["linked alt %s => %s"] = "",
		--Translation missing 
		-- ["List all"] = "",
		--Translation missing 
		-- ["List all links between alts and their main names."] = "",
		--Translation missing 
		-- ["List alts"] = "",
		--Translation missing 
		-- ["List alts for a given character"] = "",
		--Translation missing 
		-- ["LOKWhoIsWho data not found"] = "",
		--Translation missing 
		-- ["LOKWhoIsWho import"] = "",
		--Translation missing 
		-- ["LOKWhoIsWho lua file not found, sorry."] = "",
		--Translation missing 
		-- ["Main"] = "",
		--Translation missing 
		-- ["main"] = "",
		--Translation missing 
		-- ["Main name position"] = "",
		--Translation missing 
		-- ["Main:"] = "",
		--Translation missing 
		-- ["mainpos_desc"] = "",
		--Translation missing 
		-- ["mainpos_name"] = "",
		--Translation missing 
		-- ["module_desc"] = "",
		--Translation missing 
		-- ["no alts found for character "] = "",
		--Translation missing 
		-- ["no alts or mains found matching \"%s\""] = "",
		--Translation missing 
		-- ["No arg string given to :addAlt()"] = "",
		--Translation missing 
		-- ["no characters called \"%s\" found; nothing deleted"] = "",
		--Translation missing 
		-- ["No Guild Greet database found"] = "",
		--Translation missing 
		-- ["No main name supplied to link %s to"] = "",
		--Translation missing 
		-- ["no matches found"] = "",
		--Translation missing 
		-- ["quiet"] = "",
		--Translation missing 
		-- ["quiet_desc"] = "",
		--Translation missing 
		-- ["quiet_name"] = "",
		--Translation missing 
		-- ["Right"] = "",
		--Translation missing 
		-- ["Search the list of linked characters for matching main or alt names."] = "",
		--Translation missing 
		-- ["searched for: %s - total matches: %s"] = "",
		--Translation missing 
		-- ["Show alts in tooltip"] = "",
		--Translation missing 
		-- ["Show main in tooltip"] = "",
		--Translation missing 
		-- ["Start"] = "",
		--Translation missing 
		-- ["The colour of an alt's main name that will be displayed"] = "",
		--Translation missing 
		-- ["Use class colour (from the PlayerNames module)"] = "",
		--Translation missing 
		-- ["use class colour of alt"] = "",
		--Translation missing 
		-- ["use class colour of main"] = "",
		--Translation missing 
		-- ["Use LibAlts Data"] = "",
		--Translation missing 
		-- ["Use the data available via the shared alt information library."] = "",
		--Translation missing 
		-- ["Various ways to import a main's alts from other addons"] = "",
		--Translation missing 
		-- ["warning: alt %s already linked to %s"] = "",
		--Translation missing 
		-- ["Where to display a character's main name when on their alt."] = "",
		--Translation missing 
		-- ["Whether to report to the chat frame or not."] = "",
		--Translation missing 
		-- ["You are not in a guild"] = "",
		--Translation missing 
		-- ["You have not yet linked any alts with their mains."] = "",
	},
	["Bubbles"] = {
		--Translation missing 
		-- ["color_desc"] = "",
		--Translation missing 
		-- ["color_name"] = "",
		--Translation missing 
		-- ["font_desc"] = "",
		--Translation missing 
		-- ["font_name"] = "",
		--Translation missing 
		-- ["fontsize_desc"] = "",
		--Translation missing 
		-- ["fontsize_name"] = "",
		--Translation missing 
		-- ["format_desc"] = "",
		--Translation missing 
		-- ["format_name"] = "",
		--Translation missing 
		-- ["icons_desc"] = "",
		--Translation missing 
		-- ["icons_name"] = "",
		--Translation missing 
		-- ["module_desc"] = "",
		--Translation missing 
		-- ["module_name"] = "",
		--Translation missing 
		-- ["shorten_desc"] = "",
		--Translation missing 
		-- ["shorten_name"] = "",
		--Translation missing 
		-- ["transparent_desc"] = "",
		--Translation missing 
		-- ["transparent_name"] = "",
	},
	["Buttons"] = {
		--Translation missing 
		-- ["alpha_desc"] = "",
		--Translation missing 
		-- ["alpha_name"] = "",
		--Translation missing 
		-- ["Buttons"] = "",
		--Translation missing 
		-- ["Chat window button options."] = "",
		--Translation missing 
		-- ["chatmenu_desc"] = "",
		--Translation missing 
		-- ["chatmenu_name"] = "",
		--Translation missing 
		-- ["Default"] = "",
		--Translation missing 
		-- ["Right, Inside Frame"] = "",
		--Translation missing 
		-- ["Right, Outside Frame"] = "",
		--Translation missing 
		-- ["scrollReminder_desc"] = "",
		--Translation missing 
		-- ["scrollReminder_name"] = "",
		--Translation missing 
		-- ["Set Position"] = "",
		--Translation missing 
		-- ["Sets position of chat menu and arrows for all chat windows."] = "",
		--Translation missing 
		-- ["Show Arrows"] = "",
		--Translation missing 
		-- ["Show Chat%d Arrows"] = "",
		--Translation missing 
		-- ["showbnet_desc"] = "",
		--Translation missing 
		-- ["showbnet_name"] = "",
		--Translation missing 
		-- ["showmenu_desc"] = "",
		--Translation missing 
		-- ["showmenu_name"] = "",
		--Translation missing 
		-- ["showminimize_desc"] = "",
		--Translation missing 
		-- ["showminimize_name"] = "",
		--Translation missing 
		-- ["Toggle showing chat arrows for each chat window."] = "",
		--Translation missing 
		-- ["Toggles navigation arrows on and off."] = "",
	},
	["ChannelColorMemory"] = {
		--Translation missing 
		-- ["(%w+)%s?(.*)"] = "",
		--Translation missing 
		-- ["ChannelColorMemory"] = "",
		--Translation missing 
		-- ["Remembers the colors of each channel name."] = "",
	},
	["ChannelNames"] = {
		--Translation missing 
		-- ["%s settings."] = "",
		--Translation missing 
		-- ["<string>"] = "",
		--Translation missing 
		-- ["Add Channel Abbreviation"] = "",
		--Translation missing 
		-- ["addnick_desc"] = "",
		--Translation missing 
		-- ["Blank"] = "",
		--Translation missing 
		-- ["chanlink_desc"] = "",
		--Translation missing 
		-- ["chanlink_name"] = "",
		--Translation missing 
		-- ["Channel %d"] = "",
		--Translation missing 
		-- ["Channel name abbreviation options."] = "",
		--Translation missing 
		-- ["ChannelNames"] = "",
		--Translation missing 
		-- ["channelnick_desc"] = "",
		--Translation missing 
		-- ["channelnick_name"] = "",
		--Translation missing 
		-- ["Clear Channel Abbreviation"] = "",
		--Translation missing 
		-- ["Clears an abbreviated channel name."] = "",
		--Translation missing 
		-- ["colon_desc"] = "",
		--Translation missing 
		-- ["colon_name"] = "",
		--Translation missing 
		-- ["Dont display the channel/chat type name"] = "",
		--Translation missing 
		-- ["otheropts_desc"] = "",
		--Translation missing 
		-- ["otheropts_name"] = "",
		--Translation missing 
		-- ["Remove Channel Abbreviation"] = "",
		--Translation missing 
		-- ["Removes an an abbreviated channel name."] = "",
		--Translation missing 
		-- ["Replace"] = "",
		--Translation missing 
		-- ["Set"] = "",
		--Translation missing 
		-- ["space_desc"] = "",
		--Translation missing 
		-- ["space_name"] = "",
		--Translation missing 
		-- ["Toggle replacing this channel."] = "",
		--Translation missing 
		-- ["Use a custom replacement for the chat %s text."] = "",
	},
	["ChannelSticky"] = {
		--Translation missing 
		-- ["Channel"] = "",
		--Translation missing 
		-- ["ChannelSticky"] = "",
		--Translation missing 
		-- ["Chat channel sticky options."] = "",
		--Translation missing 
		-- ["ChatType"] = "",
		--Translation missing 
		-- ["Per chat type options."] = "",
		--Translation missing 
		-- ["smartgroup_desc"] = "",
		--Translation missing 
		-- ["smartgroup_name"] = "",
		--Translation missing 
		-- ["Sticky %s"] = "",
		--Translation missing 
		-- ["Sticky Per Chat Frame"] = "",
		--Translation missing 
		-- ["Toggle remembering the chat type last used per chat frame."] = "",
		--Translation missing 
		-- ["Toggles sticky on and off for %s."] = "",
	},
	["ChatFrames"] = {
		--Translation missing 
		-- ["Chat window frame parameter options"] = "",
		--Translation missing 
		-- ["framealpha_desc"] = "",
		--Translation missing 
		-- ["framealpha_name"] = "",
		--Translation missing 
		-- ["Frames"] = "",
		--Translation missing 
		-- ["mainchatonload_desc"] = "",
		--Translation missing 
		-- ["mainchatonload_name"] = "",
		--Translation missing 
		-- ["maxchatheight_desc"] = "",
		--Translation missing 
		-- ["maxchatheight_name"] = "",
		--Translation missing 
		-- ["maxchatwidth_desc"] = "",
		--Translation missing 
		-- ["maxchatwidth_name"] = "",
		--Translation missing 
		-- ["minchatheight_desc"] = "",
		--Translation missing 
		-- ["minchatheight_name"] = "",
		--Translation missing 
		-- ["minchatwidth_desc"] = "",
		--Translation missing 
		-- ["minchatwidth_name"] = "",
		--Translation missing 
		-- ["rememberframepositions_desc"] = "",
		--Translation missing 
		-- ["rememberframepositions_name"] = "",
		--Translation missing 
		-- ["removeclamp_desc"] = "",
		--Translation missing 
		-- ["removeclamp_name"] = "",
	},
	["ChatLink"] = {
		--Translation missing 
		-- ["gem_desc"] = "",
		--Translation missing 
		-- ["gem_name"] = "",
		--Translation missing 
		-- ["module_desc"] = "",
		--Translation missing 
		-- ["module_info"] = "",
		--Translation missing 
		-- ["module_name"] = "",
		--Translation missing 
		-- ["Trade"] = "",
	},
	["ChatLog"] = {
		--Translation missing 
		-- ["A module to automaticaly enable chat and combat logging."] = "",
		--Translation missing 
		-- ["Chat log recorded to <WoW Installation>\\Logs\\WoWChatLog.txt only upon logout."] = "",
		--Translation missing 
		-- ["Chat Log: Disabled"] = "",
		--Translation missing 
		-- ["Chat Log: Enabled"] = "",
		--Translation missing 
		-- ["ChatLog"] = "",
		--Translation missing 
		-- ["Combat log recorded to <WoW Installation>\\Logs\\WoWCombatLog.txt only upon logout."] = "",
		--Translation missing 
		-- ["Combat Log: Disabled"] = "",
		--Translation missing 
		-- ["Combat Log: Enabled"] = "",
		--Translation missing 
		-- ["quiet_desc"] = "",
		--Translation missing 
		-- ["quiet_name"] = "",
		--Translation missing 
		-- ["Toggle Chat Log"] = "",
		--Translation missing 
		-- ["Toggle chat log on and off."] = "",
		--Translation missing 
		-- ["Toggle Combat Log"] = "",
		--Translation missing 
		-- ["Toggle combat log on and off."] = "",
	},
	["ChatTabs"] = {
		--Translation missing 
		-- ["Active Alpha"] = "",
		--Translation missing 
		-- ["All"] = "",
		--Translation missing 
		-- ["Always"] = "",
		--Translation missing 
		-- ["Chat window tab options."] = "",
		--Translation missing 
		-- ["Default"] = "",
		--Translation missing 
		-- ["disableflash_desc"] = "",
		--Translation missing 
		-- ["disableflash_name"] = "",
		--Translation missing 
		-- ["Hidden"] = "",
		--Translation missing 
		-- ["Individual"] = "",
		--Translation missing 
		-- ["Not Active Alpha"] = "",
		--Translation missing 
		-- ["preventdrag_desc"] = "",
		--Translation missing 
		-- ["preventdrag_name"] = "",
		--Translation missing 
		-- ["Set ChatFrame%d Display Mode"] = "",
		--Translation missing 
		-- ["Set Display Mode"] = "",
		--Translation missing 
		-- ["Set tab display mode for each chat window."] = "",
		--Translation missing 
		-- ["Set tab display to always, hidden or the Blizzard default."] = "",
		--Translation missing 
		-- ["Sets alpha of chat tab for active chat frame."] = "",
		--Translation missing 
		-- ["Sets alpha of chat tab for not active chat frame."] = "",
		--Translation missing 
		-- ["Tabs"] = "",
	},
	["Clear"] = {
		--Translation missing 
		-- ["Adds clear text slash commands (/clear)(/cls)(/clearall)(/clsall)."] = "",
		--Translation missing 
		-- ["Clear"] = "",
		--Translation missing 
		-- ["Clearall"] = "",
		--Translation missing 
		-- ["Clears all chat frames."] = "",
		--Translation missing 
		-- ["Clears the current chat frame."] = "",
	},
	["CopyChat"] = {
		--Translation missing 
		-- [" Text"] = "",
		--Translation missing 
		-- ["BBCode"] = "",
		--Translation missing 
		-- ["BOTTOMLEFT"] = "",
		--Translation missing 
		-- ["BOTTOMRIGHT"] = "",
		--Translation missing 
		-- ["buttonpos_desc"] = "",
		--Translation missing 
		-- ["buttonpos_name"] = "",
		--Translation missing 
		-- ["ChatFrame"] = "",
		--Translation missing 
		-- ["Copy all of the text in the selected chat frame into an edit box"] = "",
		--Translation missing 
		-- ["Copy Text"] = "",
		--Translation missing 
		-- ["Copy Text Format"] = "",
		--Translation missing 
		-- ["Copy text from the active chat window."] = "",
		--Translation missing 
		-- ["Copy To Editbox"] = "",
		--Translation missing 
		-- ["CopyChat"] = "",
		--Translation missing 
		-- ["HTML"] = "",
		--Translation missing 
		-- ["Message From : %s"] = "",
		--Translation missing 
		-- ["Plain"] = "",
		--Translation missing 
		-- ["Should the copied text be plain, or formatted so you can see the colors."] = "",
		--Translation missing 
		-- ["showbutton_desc"] = "",
		--Translation missing 
		-- ["showbutton_name"] = "",
		--Translation missing 
		-- ["TOPLEFT"] = "",
		--Translation missing 
		-- ["TOPRIGHT"] = "",
		--Translation missing 
		-- ["Wowace.com Forums"] = "",
	},
	["CustomFilters"] = {
		--Translation missing 
		-- ["<string>"] = "",
		--Translation missing 
		-- ["Add a pattern to search for."] = "",
		--Translation missing 
		-- ["Add Pattern"] = "",
		--Translation missing 
		-- ["Block Message"] = "",
		--Translation missing 
		-- ["Channel Data"] = "",
		--Translation missing 
		-- ["Channel to send output text to."] = "",
		--Translation missing 
		-- ["Enabled"] = "",
		--Translation missing 
		-- ["Extra data for WHISPER (target) and CHANNEL (channel name or num)"] = "",
		--Translation missing 
		-- ["Filter Name"] = "",
		--Translation missing 
		-- ["Forward"] = "",
		--Translation missing 
		-- ["Forward the message to a chat channel."] = "",
		--Translation missing 
		-- ["Forward the message to a custom chat channel."] = "",
		--Translation missing 
		-- ["ForwardCustom"] = "",
		--Translation missing 
		-- ["ForwardMessage"] = "",
		--Translation missing 
		-- ["ForwardMessageCustom"] = "",
		--Translation missing 
		-- ["Hilight Color"] = "",
		--Translation missing 
		-- ["Hilight Match Text"] = "",
		--Translation missing 
		-- ["Inbound"] = "",
		--Translation missing 
		-- ["inchannels_desc"] = "",
		--Translation missing 
		-- ["inchannels_name"] = "",
		--Translation missing 
		-- ["Is this pattern enabled for use?"] = "",
		--Translation missing 
		-- ["Match Options"] = "",
		--Translation missing 
		-- ["module_desc"] = "",
		--Translation missing 
		-- ["module_name"] = "",
		--Translation missing 
		-- ["Only output the message portion of the chat text, leave out the channel, and playername etc."] = "",
		--Translation missing 
		-- ["Outbound"] = "",
		--Translation missing 
		-- ["Output Channel"] = "",
		--Translation missing 
		-- ["Output Message Only"] = "",
		--Translation missing 
		-- ["Pattern Info"] = "",
		--Translation missing 
		-- ["Pattern Options"] = "",
		--Translation missing 
		-- ["Play a sound when this message is output to the chatframe"] = "",
		--Translation missing 
		-- ["Play Sound"] = "",
		--Translation missing 
		-- ["Prevent the message from being displayed"] = "",
		--Translation missing 
		-- ["Remove an existing pattern."] = "",
		--Translation missing 
		-- ["Remove Pattern"] = "",
		--Translation missing 
		-- ["Replacement Text"] = "",
		--Translation missing 
		-- ["Search Format String"] = "",
		--Translation missing 
		-- ["Search Pattern"] = "",
		--Translation missing 
		-- ["Secondary Output"] = "",
		--Translation missing 
		-- ["Send to a secondary output"] = "",
		--Translation missing 
		-- ["Supplied pattern is a format string instead of a pattern"] = "",
		--Translation missing 
		-- ["Your name for this filter"] = "",
	},
	["Editbox"] = {
		--Translation missing 
		-- ["Attach edit box to..."] = "",
		--Translation missing 
		-- ["Attach to..."] = "",
		--Translation missing 
		-- ["Background color"] = "",
		--Translation missing 
		-- ["Background Inset"] = "",
		--Translation missing 
		-- ["Background texture"] = "",
		--Translation missing 
		-- ["Border color"] = "",
		--Translation missing 
		-- ["Border texture"] = "",
		--Translation missing 
		-- ["Bottom"] = "",
		--Translation missing 
		-- ["Color border by channel"] = "",
		--Translation missing 
		-- ["currently_broken_alt_behavior"] = "",
		--Translation missing 
		-- ["Edge Size"] = "",
		--Translation missing 
		-- ["Editbox"] = "",
		--Translation missing 
		-- ["Editbox options."] = "",
		--Translation missing 
		-- ["Font"] = "",
		--Translation missing 
		-- ["Free-floating"] = "",
		--Translation missing 
		-- ["Free-floating, Locked"] = "",
		--Translation missing 
		-- ["Requires the Alt key to be held down to move the cursor in chat"] = "",
		--Translation missing 
		-- ["Select the font to use for the edit box"] = "",
		--Translation missing 
		-- ["Sets the frame's border color to the color of your currently active channel"] = "",
		--Translation missing 
		-- ["Tile Size"] = "",
		--Translation missing 
		-- ["Top"] = "",
		--Translation missing 
		-- ["Use Alt key for cursor movement"] = "",
	},
	["EventNames"] = {
		--Translation missing 
		-- ["allevents_desc"] = "",
		--Translation missing 
		-- ["allevents_name"] = "",
		--Translation missing 
		-- ["Chat window event name options."] = "",
		--Translation missing 
		-- ["EventNames"] = "",
		--Translation missing 
		-- ["Show"] = "",
		--Translation missing 
		-- ["Show events on chatframes"] = "",
		--Translation missing 
		-- ["show_desc"] = "",
		--Translation missing 
		-- ["show_name"] = "",
	},
	["Fading"] = {
		--Translation missing 
		-- ["duration_desc"] = "",
		--Translation missing 
		-- ["duration_name"] = "",
		--Translation missing 
		-- ["module_desc"] = "",
		--Translation missing 
		-- ["module_name"] = "",
		--Translation missing 
		-- ["textfade_desc"] = "",
		--Translation missing 
		-- ["textfade_name"] = "",
	},
	["Filtering"] = {
		--Translation missing 
		-- ["A module to provide basic chat filtering."] = "",
		--Translation missing 
		-- ["afkdnd_desc"] = "",
		--Translation missing 
		-- ["afkdnd_name"] = "",
		--Translation missing 
		-- ["bgjoin_desc"] = "",
		--Translation missing 
		-- ["bgjoin_name"] = "",
		--Translation missing 
		-- ["Filtering"] = "",
		--Translation missing 
		-- ["leavejoin_desc"] = "",
		--Translation missing 
		-- ["leavejoin_name"] = "",
		--Translation missing 
		-- ["notices_desc"] = "",
		--Translation missing 
		-- ["notices_name"] = "",
		--Translation missing 
		-- ["tradespam_desc"] = "",
		--Translation missing 
		-- ["tradespam_name"] = "",
	},
	["Font"] = {
		--Translation missing 
		-- ["Auto Restore Font Size"] = "",
		--Translation missing 
		-- ["Chat window font options."] = "",
		--Translation missing 
		-- ["Font"] = "",
		--Translation missing 
		-- ["monochrome_desc"] = "",
		--Translation missing 
		-- ["monochrome_name"] = "",
		--Translation missing 
		-- ["None"] = "",
		--Translation missing 
		-- ["Outline"] = "",
		--Translation missing 
		-- ["outlinemode_desc"] = "",
		--Translation missing 
		-- ["outlinemode_name"] = "",
		--Translation missing 
		-- ["rememberfont_desc"] = "",
		--Translation missing 
		-- ["rememberfont_name"] = "",
		--Translation missing 
		-- ["Set ChatFrame%d Font Size"] = "",
		--Translation missing 
		-- ["Set Font Face"] = "",
		--Translation missing 
		-- ["Set Font Size"] = "",
		--Translation missing 
		-- ["Set Separately"] = "",
		--Translation missing 
		-- ["Set text font size for each chat window."] = "",
		--Translation missing 
		-- ["Set text font size."] = "",
		--Translation missing 
		-- ["Set the text font face for all chat windows."] = "",
		--Translation missing 
		-- ["shadowcolor_desc"] = "",
		--Translation missing 
		-- ["shadowcolor_name"] = "",
		--Translation missing 
		-- ["Thick Outline"] = "",
		--Translation missing 
		-- ["Toggle setting options separately for each chat window."] = "",
		--Translation missing 
		-- ["Workaround a Blizzard bug which changes the font size when you open a system menu."] = "",
	},
	["History"] = {
		--Translation missing 
		-- ["Chat history options."] = "",
		--Translation missing 
		-- ["Color GMOTD"] = "",
		--Translation missing 
		-- ["Colors the GMOTD label"] = "",
		--Translation missing 
		-- ["delaygmotd_desc"] = "",
		--Translation missing 
		-- ["delaygmotd_name"] = "",
		--Translation missing 
		-- ["divider"] = "",
		--Translation missing 
		-- ["History"] = "",
		--Translation missing 
		-- ["Maximum number of lines of command history to save."] = "",
		--Translation missing 
		-- ["Save Command History"] = "",
		--Translation missing 
		-- ["Saves command history between sessions (for use with alt+up arrow or just the up arrow)"] = "",
		--Translation missing 
		-- ["Scrollback"] = "",
		--Translation missing 
		-- ["Scrollback Options"] = "",
		--Translation missing 
		-- ["scrollbacklen_desc"] = "",
		--Translation missing 
		-- ["scrollbacklen_name"] = "",
		--Translation missing 
		-- ["Set Chat Lines"] = "",
		--Translation missing 
		-- ["Set Command History"] = "",
		--Translation missing 
		-- ["Set the number of lines of chat history for each window."] = "",
		--Translation missing 
		-- ["Store the chat lines between sessions"] = "",
	},
	["KeyBindings"] = {
		--Translation missing 
		-- ["Channel %d"] = "",
		--Translation missing 
		-- ["Copy Selected Chat Frame"] = "",
		--Translation missing 
		-- ["Guild Channel"] = "",
		--Translation missing 
		-- ["Instance Channel"] = "",
		--Translation missing 
		-- ["Next Chat Tab"] = "",
		--Translation missing 
		-- ["Officer Channel"] = "",
		--Translation missing 
		-- ["Party Channel"] = "",
		--Translation missing 
		-- ["Prat CopyChat"] = "",
		--Translation missing 
		-- ["Prat Keybindings"] = "",
		--Translation missing 
		-- ["Prat TellTarget"] = "",
		--Translation missing 
		-- ["Raid Channel"] = "",
		--Translation missing 
		-- ["Raid Warning Channel"] = "",
		--Translation missing 
		-- ["Say"] = "",
		--Translation missing 
		-- ["Smart Group Channel"] = "",
		--Translation missing 
		-- ["TellTarget"] = "",
		--Translation missing 
		-- ["Whisper"] = "",
		--Translation missing 
		-- ["Yell"] = "",
	},
	["OriginalButtons"] = {
		--Translation missing 
		-- ["alpha_desc"] = "",
		--Translation missing 
		-- ["alpha_name"] = "",
		--Translation missing 
		-- ["buttonframe_desc"] = "",
		--Translation missing 
		-- ["buttonframe_name"] = "",
		["ChannelNames"] = true,
		--Translation missing 
		-- ["Chat window button options."] = "",
		--Translation missing 
		-- ["chatmenu_desc"] = "",
		--Translation missing 
		-- ["chatmenu_name"] = "",
		["Default"] = "Padrão",
		["Original Buttons"] = "Botões Original",
		--Translation missing 
		-- ["reflow_desc"] = "",
		--Translation missing 
		-- ["reflow_name"] = "",
		--Translation missing 
		-- ["reminder_desc"] = "",
		--Translation missing 
		-- ["reminder_name"] = "",
		["Right, Inside Frame"] = "Direito, Dentro do Frame",
		--Translation missing 
		-- ["Right, Outside Frame"] = "",
		["Set Position"] = "Definir Posição",
		--Translation missing 
		-- ["Sets position of chat menu and arrows for all chat windows."] = "",
		["Show Arrows"] = "Mostar Setas",
		--Translation missing 
		-- ["Show Chat%d Arrows"] = "",
		--Translation missing 
		-- ["Toggle showing chat arrows for each chat window."] = "",
		--Translation missing 
		-- ["Toggles navigation arrows on and off."] = "",
	},
	["OriginalEditbox"] = {
		--Translation missing 
		-- ["Autohide"] = "",
		--Translation missing 
		-- ["BACKGROUND"] = "",
		--Translation missing 
		-- ["Bar colour"] = "",
		--Translation missing 
		-- ["Border colour"] = "",
		--Translation missing 
		-- ["Border width"] = "",
		--Translation missing 
		-- ["Bottom"] = "",
		--Translation missing 
		-- ["Click the edit box to open it up for editing. Only available if Autohide is disabled."] = "",
		--Translation missing 
		-- ["Clickable"] = "",
		--Translation missing 
		-- ["DIALOG"] = "",
		--Translation missing 
		-- ["Editbox options."] = "",
		--Translation missing 
		-- ["Enable Arrowkeys"] = "",
		--Translation missing 
		-- ["Enable using arrowkeys in editbox without the alt key."] = "",
		--Translation missing 
		-- ["Hide Border"] = "",
		--Translation missing 
		-- ["Hide the border around the edit box."] = "",
		--Translation missing 
		-- ["Hide the edit box after you have pressed enter."] = "",
		--Translation missing 
		-- ["HIGH"] = "",
		--Translation missing 
		-- ["Lock editbox position if undocked."] = "",
		--Translation missing 
		-- ["Lock Position"] = "",
		--Translation missing 
		-- ["LOW"] = "",
		--Translation missing 
		-- ["MEDIUM"] = "",
		--Translation missing 
		-- ["OriginalEditbox"] = "",
		--Translation missing 
		-- ["Padding"] = "",
		--Translation missing 
		-- ["Set Alpha"] = "",
		--Translation missing 
		-- ["Set Position"] = "",
		--Translation missing 
		-- ["Set Strata"] = "",
		--Translation missing 
		-- ["Set the alpha of the editbox."] = "",
		--Translation missing 
		-- ["Set the amount of padding inside the edit box"] = "",
		--Translation missing 
		-- ["Set the edit box background colour"] = "",
		--Translation missing 
		-- ["Set the edit box border colour"] = "",
		--Translation missing 
		-- ["Set the frame strata of the editbox."] = "",
		--Translation missing 
		-- ["Set the position of the editbox."] = "",
		--Translation missing 
		-- ["Set the texture of the chat edit box"] = "",
		--Translation missing 
		-- ["Set the width of the edit box's border"] = "",
		--Translation missing 
		-- ["Set the width of the editbox."] = "",
		--Translation missing 
		-- ["Set Width (NB: only enabled if the editbox is undocked)"] = "",
		--Translation missing 
		-- ["Texture"] = "",
		--Translation missing 
		-- ["Top"] = "",
		--Translation missing 
		-- ["Undocked"] = "",
	},
	["Paragraph"] = {
		--Translation missing 
		-- ["adjustlinks_desc"] = "",
		--Translation missing 
		-- ["adjustlinks_name"] = "",
		--Translation missing 
		-- ["Center"] = "",
		--Translation missing 
		-- ["Chat window paragraph options."] = "",
		--Translation missing 
		-- ["justification_desc"] = "",
		--Translation missing 
		-- ["justification_name"] = "",
		--Translation missing 
		-- ["Left"] = "",
		--Translation missing 
		-- ["Line Spacing"] = "",
		--Translation missing 
		-- ["Paragraph"] = "",
		--Translation missing 
		-- ["Right"] = "",
		--Translation missing 
		-- ["Set the line spacing for all chat windows."] = "",
	},
	["PlayerNames"] = {
		--Translation missing 
		-- ["Actively Query Player Info"] = "",
		--Translation missing 
		-- ["Angled"] = "",
		--Translation missing 
		-- ["Brackets"] = "",
		--Translation missing 
		-- ["Brackets Common Color"] = "",
		--Translation missing 
		-- ["Brackets Use Common Color"] = "",
		--Translation missing 
		-- ["Class"] = "",
		--Translation missing 
		-- ["Color by Level Difference"] = "",
		--Translation missing 
		-- ["coloreverywhere_desc"] = "",
		--Translation missing 
		-- ["coloreverywhere_name"] = "",
		--Translation missing 
		-- ["Enable Alt-Invite"] = "",
		--Translation missing 
		-- ["Enable Invite Links"] = "",
		--Translation missing 
		-- ["Enable TabComplete"] = "",
		--Translation missing 
		-- ["hoverhilight_desc"] = "",
		--Translation missing 
		-- ["hoverhilight_name"] = "",
		--Translation missing 
		-- ["How to color other player's level."] = "",
		--Translation missing 
		-- ["How to color player's name."] = "",
		--Translation missing 
		-- ["Keep Info"] = "",
		--Translation missing 
		-- ["Keep Lots Of Info"] = "",
		--Translation missing 
		-- ["Keep player information between session for all players except cross-server players"] = "",
		--Translation missing 
		-- ["Keep player information between session, but limit it to friends and guild members."] = "",
		--Translation missing 
		-- ["Let TasteTheNaimbow set the common color for unknown player names."] = "",
		--Translation missing 
		-- ["Level Color Mode"] = "",
		--Translation missing 
		-- ["linkifycommon_desc"] = "",
		--Translation missing 
		-- ["linkifycommon_name"] = "",
		--Translation missing 
		-- ["No additional coloring"] = "",
		--Translation missing 
		-- ["None"] = "",
		--Translation missing 
		-- ["Player Color Mode"] = "",
		--Translation missing 
		-- ["Player name formating options."] = "",
		--Translation missing 
		-- ["PlayerNames"] = "",
		--Translation missing 
		-- ["Prat_Playernames: Stored Player Data Cleared"] = "",
		--Translation missing 
		-- ["Query the server for all player names we do not know. Note: This happpens pretty slowly, and this data is not saved."] = "",
		--Translation missing 
		-- ["Random"] = "",
		--Translation missing 
		-- ["realidcolor_desc"] = "",
		--Translation missing 
		-- ["realidcolor_name"] = "",
		--Translation missing 
		-- ["Reset Settings"] = "",
		--Translation missing 
		-- ["Restore default settings, and delete stored character data."] = "",
		--Translation missing 
		-- ["Set common color of unknown player names."] = "",
		--Translation missing 
		-- ["Sets common color of brackets to use around player names."] = "",
		--Translation missing 
		-- ["Sets style of brackets to use around player names."] = "",
		--Translation missing 
		-- ["Show Group"] = "",
		--Translation missing 
		-- ["Show Level"] = "",
		--Translation missing 
		-- ["Show Raid Target Icon"] = "",
		--Translation missing 
		-- ["Square"] = "",
		--Translation missing 
		-- ["Tab completion : "] = "",
		--Translation missing 
		-- ["tabcomplete_name"] = "",
		--Translation missing 
		-- ["Toggle group invites by alt-clicking hyperlinked keywords like 'invite'."] = "",
		--Translation missing 
		-- ["Toggle group invites by alt-clicking on player name."] = "",
		--Translation missing 
		-- ["Toggle level showing."] = "",
		--Translation missing 
		-- ["Toggle raid group showing."] = "",
		--Translation missing 
		-- ["Toggle showing the raid target icon which is currently on the player."] = "",
		--Translation missing 
		-- ["Toggle tab completion of player names."] = "",
		--Translation missing 
		-- ["Toggle using a common color for brackets around player names."] = "",
		--Translation missing 
		-- ["Toggle using a common color for unknown player names."] = "",
		--Translation missing 
		-- ["Too many matches (%d possible)"] = "",
		--Translation missing 
		-- ["Unknown Common Color"] = "",
		--Translation missing 
		-- ["Unknown Common Color From TasteTheNaimbow"] = "",
		--Translation missing 
		-- ["Unknown Use Common Color"] = "",
		--Translation missing 
		-- ["Use Channel Color"] = "",
		--Translation missing 
		-- ["Use Player Color"] = "",
		--Translation missing 
		-- ["Use toon name for RealID"] = "",
	},
	["PopupMessage"] = {
		--Translation missing 
		-- ["Add Nickname"] = "",
		--Translation missing 
		-- ["Adds an alternate name to show in popups."] = "",
		--Translation missing 
		-- ["Clear Nickname"] = "",
		--Translation missing 
		-- ["Clears alternate name to show in popups."] = "",
		--Translation missing 
		-- ["framealpha_desc"] = "",
		--Translation missing 
		-- ["framealpha_name"] = "",
		--Translation missing 
		-- ["Popup"] = "",
		--Translation missing 
		-- ["PopupMessage"] = "",
		--Translation missing 
		-- ["Remove Nickname"] = "",
		--Translation missing 
		-- ["Removes an alternate name to show in popups."] = "",
		--Translation missing 
		-- ["Set Separately"] = "",
		--Translation missing 
		-- ["Show All Popups"] = "",
		--Translation missing 
		-- ["Show Popups"] = "",
		--Translation missing 
		-- ["Show Popups for all chat windows."] = "",
		--Translation missing 
		-- ["Show Popups for each window."] = "",
		--Translation missing 
		-- ["show_desc"] = "",
		--Translation missing 
		-- ["show_name"] = "",
		--Translation missing 
		-- ["show_perframedesc"] = "",
		--Translation missing 
		-- ["show_perframename"] = "",
		--Translation missing 
		-- ["showall_desc"] = "",
		--Translation missing 
		-- ["showall_name"] = "",
		--Translation missing 
		-- ["Shows messages in a popup window."] = "",
		--Translation missing 
		-- ["Shows messages with your name in a popup."] = "",
		--Translation missing 
		-- ["Toggle setting options separately for each chat window."] = "",
	},
	["Scroll"] = {
		--Translation missing 
		-- ["Bottom"] = "",
		--Translation missing 
		-- ["Chat window scrolling options."] = "",
		--Translation missing 
		-- ["Control whether text is added to the frame at the top or the bottom."] = "",
		--Translation missing 
		-- ["lowdown_desc"] = "",
		--Translation missing 
		-- ["lowdown_name"] = "",
		--Translation missing 
		-- ["modified_speed"] = "",
		--Translation missing 
		-- ["modified_speed_desc"] = "",
		--Translation missing 
		-- ["mousewheel_desc"] = "",
		--Translation missing 
		-- ["mousewheel_name"] = "",
		--Translation missing 
		-- ["Scroll"] = "",
		--Translation missing 
		-- ["Set Ctrl+MouseWheel Speed"] = "",
		--Translation missing 
		-- ["Set MouseWheel Speed"] = "",
		--Translation missing 
		-- ["Set number of lines mousewheel will scroll when ctrl is pressed."] = "",
		--Translation missing 
		-- ["Set number of lines mousewheel will scroll."] = "",
		--Translation missing 
		-- ["Set TheLowDown Delay"] = "",
		--Translation missing 
		-- ["Set time to wait before jumping to the bottom of chat windows."] = "",
		--Translation missing 
		-- ["Text scroll direction"] = "",
		--Translation missing 
		-- ["Top"] = "",
	},
	["Search"] = {
		--Translation missing 
		-- ["err_notfound"] = "",
		--Translation missing 
		-- ["err_tooshort"] = "",
		--Translation missing 
		-- ["find_results"] = "",
		--Translation missing 
		-- ["module_desc"] = "",
		--Translation missing 
		-- ["module_info"] = "",
		--Translation missing 
		-- ["module_name"] = "",
	},
	["ServerNames"] = {
		--Translation missing 
		-- ["autoabbreviate_desc"] = "",
		--Translation missing 
		-- ["autoabbreviate_name"] = "",
		--Translation missing 
		-- ["colon_desc"] = "",
		--Translation missing 
		-- ["colon_name"] = "",
		--Translation missing 
		-- ["randomclr_desc"] = "",
		--Translation missing 
		-- ["randomclr_name"] = "",
		--Translation missing 
		-- ["Server name abbreviation options."] = "",
		--Translation missing 
		-- ["ServerNames"] = "",
	},
	["Sounds"] = {
		--Translation missing 
		-- ["A module to play sounds on certain chat messages."] = "",
		--Translation missing 
		-- ["Add a custom channel"] = "",
		--Translation missing 
		-- ["bn_whisper_desc"] = "",
		--Translation missing 
		-- ["bn_whisper_name"] = "",
		--Translation missing 
		-- ["Custom Channels"] = "",
		--Translation missing 
		-- ["group_lead_desc"] = "",
		--Translation missing 
		-- ["group_lead_name"] = "",
		--Translation missing 
		-- ["guild_desc"] = "",
		--Translation missing 
		-- ["guild_name"] = "",
		--Translation missing 
		-- ["incoming"] = "",
		--Translation missing 
		-- ["Incoming Sounds"] = "",
		--Translation missing 
		-- ["officer_desc"] = "",
		--Translation missing 
		-- ["officer_name"] = "",
		--Translation missing 
		-- ["outgoing"] = "",
		--Translation missing 
		-- ["Outgoing Sounds"] = "",
		--Translation missing 
		-- ["party_desc"] = "",
		--Translation missing 
		-- ["party_name"] = "",
		--Translation missing 
		-- ["Play a sound for a certain channel name (can be a substring)"] = "",
		--Translation missing 
		-- ["raid_desc"] = "",
		--Translation missing 
		-- ["raid_name"] = "",
		--Translation missing 
		-- ["Remove a custom channel"] = "",
		--Translation missing 
		-- ["Reset settings"] = "",
		--Translation missing 
		-- ["Restore default settings and resets custom channel list"] = "",
		--Translation missing 
		-- ["Sound selection for incoming chat messages"] = "",
		--Translation missing 
		-- ["Sound selection for outgoing (from you) chat messages"] = "",
		--Translation missing 
		-- ["Sounds"] = "",
		--Translation missing 
		-- ["whisper_desc"] = "",
		--Translation missing 
		-- ["whisper_name"] = "",
	},
	["Substitutions"] = {
		--Translation missing 
		-- ["%d total user defined substitutions"] = "",
		--Translation missing 
		-- ["|cffff0000warning:|r subtitution \"%s\" already defined as \"%s\", overwriting"] = "",
		--Translation missing 
		-- ["<noguild>"] = "",
		--Translation missing 
		-- ["<notarget>"] = "",
		--Translation missing 
		-- ["A module to provide basic chat substitutions."] = "",
		--Translation missing 
		-- ["Are you sure - this will delete all user defined substitutions and reset defaults?"] = "",
		--Translation missing 
		-- ["Are you sure?"] = "",
		--Translation missing 
		-- ["can't find substitution index for a substitution named '%s'"] = "",
		--Translation missing 
		-- ["current-prompt"] = "",
		--Translation missing 
		-- ["defined %s: expands to => %s"] = "",
		--Translation missing 
		-- ["Delete all"] = "",
		--Translation missing 
		-- ["Delete substitution"] = "",
		--Translation missing 
		-- ["Deletes a user defined substitution"] = "",
		--Translation missing 
		-- ["Deletes all user defined substitutions"] = "",
		--Translation missing 
		-- ["female"] = "",
		--Translation missing 
		-- ["her"] = "",
		--Translation missing 
		-- ["hers"] = "",
		--Translation missing 
		-- ["him"] = "",
		--Translation missing 
		-- ["his"] = "",
		--Translation missing 
		-- ["it"] = "",
		--Translation missing 
		-- ["its"] = "",
		--Translation missing 
		-- ["List of available substitutions"] = "",
		--Translation missing 
		-- ["List of available substitutions defined by this module. (NB: users may define custom values for existing substitutions, but they will revert to the default value if the user definition is deleted.)"] = "",
		--Translation missing 
		-- ["List substitutions"] = "",
		--Translation missing 
		-- ["Lists all current subtitutions in the default chat frame"] = "",
		--Translation missing 
		-- ["male"] = "",
		--Translation missing 
		-- ["MapLoc"] = "",
		--Translation missing 
		-- ["MapPos"] = "",
		--Translation missing 
		-- ["MapXPos"] = "",
		--Translation missing 
		-- ["MapYPos"] = "",
		--Translation missing 
		-- ["MapZone"] = "",
		--Translation missing 
		-- ["module:buildUserSubsIndex(): warning: module patterns not defined!"] = "",
		--Translation missing 
		-- ["MouseoverTargetName"] = "",
		--Translation missing 
		-- ["NO MATCHFUNC FOUND"] = "",
		--Translation missing 
		-- ["no substitution name given"] = "",
		--Translation missing 
		-- ["no substitution name supplied for deletion"] = "",
		--Translation missing 
		-- ["no user defined subs found"] = "",
		--Translation missing 
		-- ["no value given for subtitution \"%s\""] = "",
		--Translation missing 
		-- ["Options for setting and removing user defined substitutions. (NB: users may define custom values for existing substitutions, but they will revert to the default value if the user definition is deleted.)"] = "",
		--Translation missing 
		-- ["PlayerAverageItemLevel"] = "",
		--Translation missing 
		-- ["PlayerCurrentMana"] = "",
		--Translation missing 
		-- ["PlayerHealthDeficit"] = "",
		--Translation missing 
		-- ["PlayerHP"] = "",
		--Translation missing 
		-- ["PlayerManaDeficit"] = "",
		--Translation missing 
		-- ["PlayerMaxHP"] = "",
		--Translation missing 
		-- ["PlayerMaxMana"] = "",
		--Translation missing 
		-- ["PlayerName"] = "",
		--Translation missing 
		-- ["PlayerPercentHP"] = "",
		--Translation missing 
		-- ["PlayerPercentMana"] = "",
		--Translation missing 
		-- ["RandNum"] = "",
		--Translation missing 
		-- ["removing user defined substitution \"%s\"; previously expanded to => \"%s\""] = "",
		--Translation missing 
		-- ["Set substitution"] = "",
		--Translation missing 
		-- ["Set the value of a user defined substitution (NB: this may be the same as an existing default substitution; to reset it to the default, just remove the user created definition)."] = "",
		--Translation missing 
		-- ["subname -- NOTE: sub name without the prefix '%'"] = "",
		--Translation missing 
		-- ["subname = text after expansion -- NOTE: sub name without the prefix \"%\""] = "",
		--Translation missing 
		-- ["substitution: %s defined as => %s"] = "",
		--Translation missing 
		-- ["Substitutions"] = "",
		--Translation missing 
		-- ["TargetClass"] = "",
		--Translation missing 
		-- ["TargetGender"] = "",
		--Translation missing 
		-- ["TargetGuild"] = "",
		--Translation missing 
		-- ["TargetHealth"] = "",
		--Translation missing 
		-- ["TargetHealthDeficit"] = "",
		--Translation missing 
		-- ["TargetIcon"] = "",
		--Translation missing 
		-- ["TargetLevel"] = "",
		--Translation missing 
		-- ["TargetManaDeficit"] = "",
		--Translation missing 
		-- ["TargetName"] = "",
		--Translation missing 
		-- ["TargetPercentHP"] = "",
		--Translation missing 
		-- ["TargetPossesive"] = "",
		--Translation missing 
		-- ["TargetPronoun"] = "",
		--Translation missing 
		-- ["TargetRace"] = "",
		--Translation missing 
		-- ["TargetTargetName"] = "",
		--Translation missing 
		-- ["unknown sex"] = "",
		--Translation missing 
		-- ["user defined substition \"%s\" not found"] = "",
		--Translation missing 
		-- ["User defined substitutions"] = "",
		--Translation missing 
		-- ["user substitutions index (usersubs_idx) doesn't exist! oh dear."] = "",
		--Translation missing 
		-- ["usersub_"] = "",
	},
	["TellTarget"] = {
		--Translation missing 
		-- ["/tt"] = "",
		--Translation missing 
		-- ["Adds telltarget slash command (/tt)."] = "",
		--Translation missing 
		-- ["No target selected."] = "",
		--Translation missing 
		-- ["NoTarget"] = "",
		--Translation missing 
		-- ["Target does not exist."] = "",
		--Translation missing 
		-- ["Target is not a player."] = "",
		--Translation missing 
		-- ["TellTarget"] = "",
	},
	["Timestamps"] = {
		--Translation missing 
		-- ["Chat window timestamp options."] = "",
		--Translation missing 
		-- ["colortimestamp_desc"] = "",
		--Translation missing 
		-- ["colortimestamp_name"] = "",
		--Translation missing 
		-- ["Format All Timestamps"] = "",
		--Translation missing 
		-- ["HH:MM (12-hour)"] = "",
		--Translation missing 
		-- ["HH:MM (24-hour)"] = "",
		--Translation missing 
		-- ["HH:MM:SS (12-hour)"] = "",
		--Translation missing 
		-- ["HH:MM:SS (24-hour)"] = "",
		--Translation missing 
		-- ["HH:MM:SS AM (12-hour)"] = "",
		--Translation missing 
		-- ["localtime_desc"] = "",
		--Translation missing 
		-- ["localtime_name"] = "",
		--Translation missing 
		-- ["MM:SS"] = "",
		--Translation missing 
		-- ["Post-Timestamp"] = "",
		--Translation missing 
		-- ["Pre-Timestamp"] = "",
		--Translation missing 
		-- ["Set the timestamp format"] = "",
		--Translation missing 
		-- ["Set Timestamp Color"] = "",
		--Translation missing 
		-- ["Sets the color of the timestamp."] = "",
		--Translation missing 
		-- ["Show Timestamp"] = "",
		--Translation missing 
		-- ["show_desc"] = "",
		--Translation missing 
		-- ["show_name"] = "",
		--Translation missing 
		-- ["space_desc"] = "",
		--Translation missing 
		-- ["space_name"] = "",
		--Translation missing 
		-- ["Timestamps"] = "",
		--Translation missing 
		-- ["Toggle showing timestamp for each window."] = "",
		--Translation missing 
		-- ["twocolumn_desc"] = "",
		--Translation missing 
		-- ["twocolumn_name"] = "",
	},
	["UrlCopy"] = {
		--Translation missing 
		-- ["Change the color of the URL."] = "",
		--Translation missing 
		-- ["Color URL"] = "",
		--Translation missing 
		-- ["Set Color"] = "",
		--Translation missing 
		-- ["Show Brackets"] = "",
		--Translation missing 
		-- ["Toggle"] = "",
		--Translation missing 
		-- ["Toggle showing brackets on and off."] = "",
		--Translation missing 
		-- ["Toggle the module on and off."] = "",
		--Translation missing 
		-- ["Toggle the URL color on and off."] = "",
		--Translation missing 
		-- ["URL formating options."] = "",
		--Translation missing 
		-- ["UrlCopy"] = "",
		--Translation missing 
		-- ["Use Popup"] = "",
		--Translation missing 
		-- ["Use popup window to show URL."] = "",
	}
}

PL:AddLocale(PRAT_MODULE.name, "ptBR",L)


end
--@end-non-debug@


local AceConfig = LibStub("AceConfig-3.0")
--local AceConfigDialog = LibStub("AceConfigDialog-3.0")
--local AceConfigCmd = LibStub("AceConfigCmd-3.0")

local moduleControlArgs = {}

Options = {
  type = "group",
  childGroups = "tab",
  get = "GetValue",
  set = "SetValue",
  args = {
    display = {
      type = "group",
      name = PL["display_name"],
      desc = PL["display_desc"],
      hidden = function(info) end,
      get = "GetValue",
      set = "SetValue",
      args = {},
      order = 1,
    },
    formatting = {
      type = "group",
      name = PL["formatting_name"],
      desc = PL["formatting_desc"],
      hidden = function(info) end,
      get = "GetValue",
      set = "SetValue",
      args = {},
      order = 2,
    },
    extras = {
      type = "group",
      name = PL["extras_name"],
      desc = PL["extras_desc"],
      hidden = function(info) end,
      get = "GetValue",
      set = "SetValue",
      args = {},
      order = 3,
    },
    modulecontrol = {
      type = "group",
      name = PL["modulecontrol_name"],
      desc = PL["modulecontrol_desc"],
      get = "GetValue",
      set = "SetValue",
      args = moduleControlArgs,
      order = 4,
    }
  }
}

--[[ WitchHunt: [Ammo] ]] --
tinsert(EnableTasks, function(self)

  local acreg = LibStub("AceConfigRegistry-3.0")
  acreg:RegisterOptionsTable(PL.prat, Options)
  acreg:RegisterOptionsTable(PL.prat .. ": " .. Options.args.display.name, Options.args.display)
  acreg:RegisterOptionsTable(PL.prat .. ": " .. Options.args.formatting.name, Options.args.formatting)
  acreg:RegisterOptionsTable(PL.prat .. ": " .. Options.args.extras.name, Options.args.extras)
  acreg:RegisterOptionsTable(PL.prat .. ": " .. Options.args.modulecontrol.name, Options.args.modulecontrol)
  acreg:RegisterOptionsTable("Prat: " .. Options.args.profiles.name, Options.args.profiles)

  local acdia = LibStub("AceConfigDialog-3.0")
  acdia:AddToBlizOptions(PL.prat, PL.prat)
  acdia:AddToBlizOptions(PL.prat .. ": " .. Options.args.display.name, Options.args.display.name, PL.prat)
  acdia:AddToBlizOptions(PL.prat .. ": " .. Options.args.formatting.name, Options.args.formatting.name, PL.prat)
  acdia:AddToBlizOptions(PL.prat .. ": " .. Options.args.extras.name, Options.args.extras.name, PL.prat)
  acdia:AddToBlizOptions(PL.prat .. ": " .. Options.args.modulecontrol.name, Options.args.modulecontrol.name, PL.prat)
  acdia:AddToBlizOptions(PL.prat .. ": " .. Options.args.profiles.name, Options.args.profiles.name, PL.prat)

  self:RegisterChatCommand(PL.prat, function() ToggleOptionsWindow() end)
end)


do
  local function getModuleFromShortName(shortname)
    for k,v in Addon:IterateModules() do
      if v.moduleName == shortname then
        return v
      end
    end
  end

  local lastReloadMessage = 0
  local function PrintReloadMessage()
    local tm = _G.GetTime()
    if tm - lastReloadMessage > 60 then
      Prat:Print(PL.reload_required:format(GetReloadUILink()))
      lastReloadMessage = tm
    end
  end

  local function setValue(info, b)
    local old = Prat.db.profile.modules[info[#info]]
    Prat.db.profile.modules[info[#info]] = b

    if old == 1 or b == 1 then
      PrintReloadMessage()
    end

    local m = getModuleFromShortName(info[#info])
    if not m then
    --            Prat.db.profile.modules[info[#info]] = b
      return
    end

    if b == 2 or b == 1 then
      m.db.profile.on = false
      m:Disable()
    elseif b == 3 then
      m.db.profile.on = true
      m:Enable()
    end
  end

  local function getValue(info)
    local v, m
    v = Prat.db.profile.modules[info[#info]]

    --		if v ~= 1 then
    --			m = getModuleFromShortName(info[#info])
    --			if m then
    --                -- Allow us to set enabled/disabled while the moduel is "dont load"
    --                if v > 3 then
    --                    v = v - 2
    ----                    m.db.profile.on = v
    --                else
    --    				v = m.db.profile.on and 3 or 2
    --                end
    --			end
    --		end

    return v
  end


  do
    local moduleControlOption = {
      name = function(info) return info[#info] end,
      desc = PL.load_desc,
      type = "select",
--      style = "radio",
      values = function(info) local v = Prat.db.profile.modules[info[#info]] if v == 1 or v > 3 then
        return {
          [1] = "|cffA0A0A0" .. PL.load_no .. "|r",
          [4] = "|cffffff80" .. PL.load_disabledonrestart .. "|r",
          [5] = "|cff80ffff" .. PL.load_enabledonrestart .. "|r"
        }
      else
        return {
          "|cffA0A0A0" .. PL.load_no .. "|r", "|cffff8080" .. PL.load_disabled .. "|r", "|cff80ff80" .. PL.load_enabled .. "|r"
        }
      end end,
      get = getValue,
      set = setValue
    }

    function CreateModuleControlOption(name)
      moduleControlArgs[name] = moduleControlOption
    end
  end
end

FrameList = {}
HookedFrameList = {}


local function updateFrameNames()
  for k,v in pairs(HookedFrames) do
    if (v.isDocked == 1) or v:IsShown() then
      HookedFrameList[k] = (v.name)
    else
      HookedFrameList[k] = nil
    end
  end
  for k,v in pairs(Frames) do
    if (v.isDocked == 1) or v:IsShown() then
      FrameList[k] = (v.name)
    else
      FrameList[k] = nil
    end
  end
  LibStub("AceConfigRegistry-3.0"):NotifyChange(PL.prat)
end

tinsert(EnableTasks, function(self)
  self:SecureHook("FCF_SetWindowName", updateFrameNames)

  _G.FCF_SetWindowName(_G.ChatFrame1, (_G.GetChatWindowInfo(1)), 1)
end)

function ToggleOptionsWindow()
  local acd = LibStub("AceConfigDialog-3.0")
  if acd.OpenFrames[PL.prat] then
    acd:Close(PL.prat)
  else
    acd:Open(PL.prat)
  end
end

	
